'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

var IconContext = /*#__PURE__*/React.createContext({
  color: "currentColor",
  size: "1em",
  weight: "regular",
  mirrored: false
});

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var renderPathFor = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "24.002 128 56.002 128 96.002 40 160.002 208 200.002 128 232.002 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "24.002 128 56.002 128 96.002 40 160.002 208 200.002 128 232.002 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M160.00439,216c-.13378,0-.2666-.00342-.40039-.00977a7.99906,7.99906,0,0,1-7.07714-5.14209L95.35205,60.7644,63.28564,131.3103A8.00165,8.00165,0,0,1,56.00244,136h-32a8,8,0,0,1,0-16H50.85107L88.71924,36.6897a7.99988,7.99988,0,0,1,14.75879.4624l57.51562,150.97729,31.85352-63.707A7.99979,7.99979,0,0,1,200.00244,120h32a8,8,0,0,1,0,16H204.94678l-37.78907,75.57764A7.99952,7.99952,0,0,1,160.00439,216Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "24.002 128 56.002 128 96.002 40 160.002 208 200.002 128 232.002 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "24.002 128 56.002 128 96.002 40 160.002 208 200.002 128 232.002 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "24.002 128 56.002 128 96.002 40 160.002 208 200.002 128 232.002 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Activity = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Activity.displayName = "Activity";

var renderPathFor$1 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,224l-40,8V208l16-16V152L24,168V144l80-40,.11255-56a24,24,0,0,1,48,0l.11255,56,80,40v24l-80-16v40L168,208v24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,224l-40,8V208l16-16V152L24,168V144l80-40,.11255-56a24,24,0,0,1,48,0l.11255,56,80,40v24l-80-16v40L168,208v24Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,224l-40,8V208l16-16V152L24,168V144l80-40,.11255-56a24,24,0,0,1,48,0l.11255,56,80,40v24l-80-16v40L168,208v24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M235.80371,136.84473,160.21582,99.05078,160.1123,48a32,32,0,0,0-64-.01611l-.10253,51.06689L20.42188,136.84473A7.99967,7.99967,0,0,0,16,144v24a8.00012,8.00012,0,0,0,9.56934,7.84473L96,161.7583V188.686L82.34277,202.34326A8.00035,8.00035,0,0,0,80,208v24a8.00012,8.00012,0,0,0,9.56934,7.84473L128,232.1582l38.43066,7.68653A8.00012,8.00012,0,0,0,176,232V208a8.00119,8.00119,0,0,0-2.30273-5.6167l-13.47168-13.66357V161.7583l70.43066,14.08643A8.00013,8.00013,0,0,0,240.22559,168V144A7.99969,7.99969,0,0,0,235.80371,136.84473Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,224l-40,8V208l16-16V152L24,168V144l80-40,.11255-56a24,24,0,0,1,48,0l.11255,56,80,40v24l-80-16v40L168,208v24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,224l-40,8V208l16-16V152L24,168V144l80-40,.11255-56a24,24,0,0,1,48,0l.11255,56,80,40v24l-80-16v40L168,208v24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,224l-40,8V208l16-16V152L24,168V144l80-40,.11255-56a24,24,0,0,1,48,0l.11255,56,80,40v24l-80-16v40L168,208v24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Airplane = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Airplane.displayName = "Airplane";

var renderPathFor$2 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "72",
        y1: "216",
        x2: "216",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M26.75225,80H44l20,24H96L83.50994,66.52982A8,8,0,0,1,91.09941,56H108l44,48h56a32,32,0,0,1,32,32v24H63.809a32,32,0,0,1-30.65044-22.80487L19.08963,90.29878A8,8,0,0,1,26.75225,80Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M26.75225,80H44l20,24H96L83.50994,66.52982A8,8,0,0,1,91.09941,56H108l44,48h56a32,32,0,0,1,32,32v24H63.809a32,32,0,0,1-30.65044-22.80487L19.08963,90.29878A8,8,0,0,1,26.75225,80Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "216",
        x2: "216",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M26.75225,80H44l20,24H96L83.50994,66.52982A8,8,0,0,1,91.09941,56H108l44,48h56a32,32,0,0,1,32,32v24H63.809a32,32,0,0,1-30.65044-22.80487L19.08963,90.29878A8,8,0,0,1,26.75225,80Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,216a8.00008,8.00008,0,0,1-8,8H72a8,8,0,0,1,0-16H216A8.00008,8.00008,0,0,1,224,216ZM208,100H153.75977L110.94824,53.29688A3.99911,3.99911,0,0,0,108,52H91.09961A12.00015,12.00015,0,0,0,79.71484,67.79492L90.4502,100H65.87305L47.07324,77.43945A4.001,4.001,0,0,0,44,76H26.752A11.99986,11.99986,0,0,0,15.25879,91.44824l14.06836,46.89649A35.77737,35.77737,0,0,0,63.80859,164H240a4.0002,4.0002,0,0,0,4-4V136A36.04061,36.04061,0,0,0,208,100Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "72",
        y1: "216",
        x2: "216",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M26.75225,80H44l20,24H96L83.50994,66.52982A8,8,0,0,1,91.09941,56H108l44,48h56a32,32,0,0,1,32,32v24H63.809a32,32,0,0,1-30.65044-22.80487L19.08963,90.29878A8,8,0,0,1,26.75225,80Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "72",
        y1: "216",
        x2: "216",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M26.75225,80H44l20,24H96L83.50994,66.52982A8,8,0,0,1,91.09941,56H108l44,48h56a32,32,0,0,1,32,32v24H63.809a32,32,0,0,1-30.65044-22.80487L19.08963,90.29878A8,8,0,0,1,26.75225,80Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "72",
        y1: "216",
        x2: "216",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M26.75225,80H44l20,24H96L83.50994,66.52982A8,8,0,0,1,91.09941,56H108l44,48h56a32,32,0,0,1,32,32v24H63.809a32,32,0,0,1-30.65044-22.80487L19.08963,90.29878A8,8,0,0,1,26.75225,80Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var AirplaneInFlight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
AirplaneInFlight.displayName = "AirplaneInFlight";

var renderPathFor$3 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "216",
        x2: "240",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M24,103.72927V51.09941a8,8,0,0,1,10.52982-7.58947L48,48,64,78,96,88V51.09941a8,8,0,0,1,10.52982-7.58947L120,48l32,56,48.5646,13.49017A32,32,0,0,1,224,148.32274V184L47.37184,134.54412A32,32,0,0,1,24,103.72927Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M24,103.72927V51.09941a8,8,0,0,1,10.52982-7.58947L48,48,64,78,96,88V51.09941a8,8,0,0,1,10.52982-7.58947L120,48l32,56,48.5646,13.49017A32,32,0,0,1,224,148.32274V184L47.37184,134.54412A32,32,0,0,1,24,103.72927Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "216",
        x2: "240",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M24,103.72927V51.09941a8,8,0,0,1,10.52982-7.58947L48,48,64,78,96,88V51.09941a8,8,0,0,1,10.52982-7.58947L120,48l32,56,48.5646,13.49017A32,32,0,0,1,224,148.32274V184L47.37184,134.54412A32,32,0,0,1,24,103.72927Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M248,216a8.00008,8.00008,0,0,1-8,8H96a8,8,0,0,1,0-16H240A8.00008,8.00008,0,0,1,248,216Zm-24-28a4.00035,4.00035,0,0,0,4-4V148.32275a36.10691,36.10691,0,0,0-26.36523-34.68652l-46.97852-13.0498L123.47266,46.01562a4.00193,4.00193,0,0,0-2.208-1.81054l-13.46973-4.49024A12.00071,12.00071,0,0,0,92,51.09961V82.55908L66.75781,74.6709,51.5293,46.11768a4.00065,4.00065,0,0,0-2.26465-1.9126L35.79492,39.71484A12.00071,12.00071,0,0,0,20,51.09961v52.62988A36.11994,36.11994,0,0,0,46.294,138.396l176.62793,49.45605A4.00591,4.00591,0,0,0,224,188Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "216",
        x2: "240",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M24,103.72927V51.09941a8,8,0,0,1,10.52982-7.58947L48,48,64,78,96,88V51.09941a8,8,0,0,1,10.52982-7.58947L120,48l32,56,48.5646,13.49017A32,32,0,0,1,224,148.32274V184L47.37184,134.54412A32,32,0,0,1,24,103.72927Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "216",
        x2: "240",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M24,103.72927V51.09941a8,8,0,0,1,10.52982-7.58947L48,48,64,78,96,88V51.09941a8,8,0,0,1,10.52982-7.58947L120,48l32,56,48.5646,13.49017A32,32,0,0,1,224,148.32274V184L47.37184,134.54412A32,32,0,0,1,24,103.72927Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "216",
        x2: "240",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M24,103.72927V51.09941a8,8,0,0,1,10.52982-7.58947L48,48,64,78,96,88V51.09941a8,8,0,0,1,10.52982-7.58947L120,48l32,56,48.5646,13.49017A32,32,0,0,1,224,148.32274V184L47.37184,134.54412A32,32,0,0,1,24,103.72927Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var AirplaneLanding = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
AirplaneLanding.displayName = "AirplaneLanding";

var renderPathFor$4 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "24",
        y1: "216",
        x2: "168",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M16.92713,140.36918,54.6225,175.70859a32,32,0,0,0,37.97,4.319L244,92,225.3607,69.21863a32,32,0,0,0-40.99128-7.31829L140,88,80,68,63.501,75.071a8,8,0,0,0-2.20037,13.29951L92,116,64,132,36,120l-16.7527,7.17973A8,8,0,0,0,16.92713,140.36918Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M16.92713,140.36918,54.6225,175.70859a32,32,0,0,0,37.97,4.319L244,92,225.3607,69.21863a32,32,0,0,0-40.99128-7.31829L140,88,80,68,63.501,75.071a8,8,0,0,0-2.20037,13.29951L92,116,64,132,36,120l-16.7527,7.17973A8,8,0,0,0,16.92713,140.36918Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "216",
        x2: "168",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M16.92713,140.36918,54.6225,175.70859a32,32,0,0,0,37.97,4.319L244,92,225.3607,69.21863a32,32,0,0,0-40.99128-7.31829L140,88,80,68,63.501,75.071a8,8,0,0,0-2.20037,13.29951L92,116,64,132,36,120l-16.7527,7.17973A8,8,0,0,0,16.92713,140.36918Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,216a8.00008,8.00008,0,0,1-8,8H24a8,8,0,0,1,0-16H168A8.00008,8.00008,0,0,1,176,216ZM247.0957,89.4668,228.45605,66.686a35.81374,35.81374,0,0,0-46.11523-8.2334L139.53906,83.62988,81.26465,64.20508a4.0083,4.0083,0,0,0-2.83985.11816l-16.5,7.0708A12.00078,12.00078,0,0,0,58.625,91.34375L85.21191,115.272l-21.46679,12.2666L37.5752,116.32324a4.00251,4.00251,0,0,0-3.1504,0l-16.75292,7.17969a12.00032,12.00032,0,0,0-3.48145,19.78418h.001l37.69531,35.33935a35.78229,35.78229,0,0,0,42.7168,4.85938L246.01074,95.458a4.001,4.001,0,0,0,1.085-5.99121Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "24",
        y1: "216",
        x2: "168",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M16.92713,140.36918,54.6225,175.70859a32,32,0,0,0,37.97,4.319L244,92,225.3607,69.21863a32,32,0,0,0-40.99128-7.31829L140,88,80,68,63.501,75.071a8,8,0,0,0-2.20037,13.29951L92,116,64,132,36,120l-16.7527,7.17973A8,8,0,0,0,16.92713,140.36918Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "24",
        y1: "216",
        x2: "168",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M16.92713,140.36918,54.6225,175.70859a32,32,0,0,0,37.97,4.319L244,92,225.3607,69.21863a32,32,0,0,0-40.99128-7.31829L140,88,80,68,63.501,75.071a8,8,0,0,0-2.20037,13.29951L92,116,64,132,36,120l-16.7527,7.17973A8,8,0,0,0,16.92713,140.36918Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "24",
        y1: "216",
        x2: "168",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M16.92713,140.36918,54.6225,175.70859a32,32,0,0,0,37.97,4.319L244,92,225.3607,69.21863a32,32,0,0,0-40.99128-7.31829L140,88,80,68,63.501,75.071a8,8,0,0,0-2.20037,13.29951L92,116,64,132,36,120l-16.7527,7.17973A8,8,0,0,0,16.92713,140.36918Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var AirplaneTakeoff = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
AirplaneTakeoff.displayName = "AirplaneTakeoff";

var renderPathFor$5 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "128.002 160 176 216 80 216 128.002 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M48,192a16,16,0,0,1-16-16V64A16,16,0,0,1,48,48H208a16,16,0,0,1,16,16V176a16,16,0,0,1-16,16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,48H48A16.00016,16.00016,0,0,0,32,64V176a16.00016,16.00016,0,0,0,16,16h52.57227l27.43017-32,27.42725,32H208a16.00016,16.00016,0,0,0,16-16V64A16.00016,16.00016,0,0,0,208,48Z",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "128.002 160 176 216 80 216 128.002 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M64,192H48a16,16,0,0,1-16-16V64A16,16,0,0,1,48,48H208a16,16,0,0,1,16,16V176a16,16,0,0,1-16,16H192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M134.07666,154.794a8.0003,8.0003,0,0,0-12.14844-.00049l-48.00293,56A8,8,0,0,0,79.99951,224h96a8.00032,8.00032,0,0,0,6.07422-13.20605Z"
      }), React__default.createElement("path", {
        d: "M208.00244,40H47.99951a24.0275,24.0275,0,0,0-24,24V176a24.0275,24.0275,0,0,0,24,24h14.104l47.67919-55.62231a24.00045,24.00045,0,0,1,36.44239.0039L193.895,200h14.10742a24.0275,24.0275,0,0,0,24-24V64A24.0275,24.0275,0,0,0,208.00244,40Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "128.002 160 176 216 80 216 128.002 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M64,192H48a16,16,0,0,1-16-16V64A16,16,0,0,1,48,48H208a16,16,0,0,1,16,16V176a16,16,0,0,1-16,16H192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "128.002 160 176 216 80 216 128.002 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M64,192H48a16,16,0,0,1-16-16V64A16,16,0,0,1,48,48H208a16,16,0,0,1,16,16V176a16,16,0,0,1-16,16H192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "128.002 160 176 216 80 216 128.002 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M64,192H48a16,16,0,0,1-16-16V64A16,16,0,0,1,48,48H208a16,16,0,0,1,16,16V176a16,16,0,0,1-16,16H192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Airplay = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Airplay.displayName = "Airplay";

var renderPathFor$6 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 80 128 128 176 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "201.53911",
        y1: "20.51977",
        x2: "235.48023",
        y2: "54.46089",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "20.51977",
        y1: "54.46089",
        x2: "54.46089",
        y2: "20.51977",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "128 72 128 128 184 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "26.17662",
        x2: "229.82338",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "26.17662",
        y1: "60.11775",
        x2: "60.11775",
        y2: "26.17662",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M235.48047,54.46094,201.53906,20.51953a8,8,0,0,0-11.31347,11.314L224.1665,65.77441a8,8,0,1,0,11.314-11.31347Z"
      }), React__default.createElement("path", {
        d: "M65.77441,20.51953a8,8,0,0,0-11.31347,0L20.51953,54.46094a8,8,0,0,0,11.314,11.31347L65.77441,31.8335A8.00061,8.00061,0,0,0,65.77441,20.51953Z"
      }), React__default.createElement("path", {
        d: "M223.957,125.22363c-.02051-.71777-.0459-1.43408-.082-2.14892-.001-.02491-.00293-.04932-.00439-.07373A96.003,96.003,0,0,0,132.999,32.12939c-.02441-.00146-.04882-.00341-.07373-.00439-.71484-.03613-1.43115-.06152-2.14892-.082-.10742-.00293-.21436-.00879-.32227-.01172Q129.2295,32.00048,128,32q-1.22973,0-2.4541.03125c-.10791.00293-.21485.00879-.32227.01172-.71777.02051-1.43408.0459-2.14892.082-.02491.001-.04932.00293-.07373.00439A96.004,96.004,0,0,0,32.12939,123.001c-.00146.02441-.00341.04882-.00439.07373-.03613.71484-.06152,1.43115-.082,2.14892-.00293.10742-.00879.21436-.01172.32227Q32.00048,126.7705,32,128q0,1.22973.03125,2.4541c.00293.10791.00879.21485.01172.32227.02051.71777.0459,1.43408.082,2.14892.001.02491.00293.04932.00439.07373A96.003,96.003,0,0,0,123.001,223.87061c.02441.00146.04882.00341.07373.00439.71484.03613,1.43115.06152,2.14892.082.10742.00293.21436.00879.32227.01172q1.2246.03077,2.4541.03125,1.22973,0,2.4541-.03125c.10791-.00293.21485-.00879.32227-.01172.71777-.02051,1.43408-.0459,2.14892-.082.02491-.001.04932-.00293.07373-.00439A96.004,96.004,0,0,0,223.87061,132.999c.00146-.02441.00341-.04882.00439-.07373.03613-.71484.06152-1.43115.082-2.14892.00293-.10742.00879-.21436.01172-.32227Q223.99952,129.2295,224,128q0-1.22973-.03125-2.4541C223.96582,125.438,223.96,125.33105,223.957,125.22363ZM184,136H128a8.00008,8.00008,0,0,1-8-8V72a8,8,0,0,1,16,0v48h48a8,8,0,0,1,0,16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 72 128 128 184 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "26.17662",
        x2: "229.82338",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "26.17662",
        y1: "60.11775",
        x2: "60.11775",
        y2: "26.17662",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 72 128 128 184 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "26.17662",
        x2: "229.82338",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "26.17662",
        y1: "60.11775",
        x2: "60.11775",
        y2: "26.17662",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 72 128 128 184 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "26.17662",
        x2: "229.82338",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "26.17662",
        y1: "60.11775",
        x2: "60.11775",
        y2: "26.17662",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Alarm = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Alarm.displayName = "Alarm";

var renderPathFor$7 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00488",
        y1: "216.00586",
        x2: "40.00488",
        y2: "216.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "122",
        y: "98",
        width: "104",
        height: "52",
        rx: "8",
        transform: "translate(50 298) rotate(-90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "32",
        width: "52",
        height: "144",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "116",
        y: "100",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(44 300) rotate(-90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "56",
        y: "32",
        width: "56",
        height: "152",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "216.00488",
        y1: "216.00586",
        x2: "40.00488",
        y2: "216.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "116",
        y: "100",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(44 300) rotate(-90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "32",
        width: "56",
        height: "152",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224.00488,216.00586a8.00008,8.00008,0,0,1-8,8h-176a8,8,0,1,1,0-16h176A8.00008,8.00008,0,0,1,224.00488,216.00586ZM152,192h40a16.01833,16.01833,0,0,0,16-16V80a16.01833,16.01833,0,0,0-16-16H152a16.01833,16.01833,0,0,0-16,16v96A16.01833,16.01833,0,0,0,152,192Zm-88,0h40a16.01833,16.01833,0,0,0,16-16V40a16.01833,16.01833,0,0,0-16-16H64A16.01833,16.01833,0,0,0,48,40V176A16.01833,16.01833,0,0,0,64,192Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00488",
        y1: "216.00586",
        x2: "40.00488",
        y2: "216.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "116",
        y: "100",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(44 300) rotate(-90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "32",
        width: "56",
        height: "152",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00488",
        y1: "216.00586",
        x2: "40.00488",
        y2: "216.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "116",
        y: "100",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(44 300) rotate(-90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "32",
        width: "56",
        height: "152",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00488",
        y1: "216.00586",
        x2: "40.00488",
        y2: "216.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "116",
        y: "100",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(44 300) rotate(-90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "32",
        width: "56",
        height: "152",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var AlignBottom = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
AlignBottom.displayName = "AlignBottom";

var renderPathFor$8 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "31.99512",
        x2: "128",
        y2: "51.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "203.99512",
        x2: "128",
        y2: "223.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "107.99512",
        x2: "128",
        y2: "147.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "64",
        y: "52",
        width: "128",
        height: "56",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "148",
        width: "176",
        height: "56",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "64",
        y: "56",
        width: "128",
        height: "56",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "56",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "31.99512",
        x2: "128",
        y2: "55.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "199.99512",
        x2: "128",
        y2: "223.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "111.99512",
        x2: "128",
        y2: "143.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "64",
        y: "56",
        width: "128",
        height: "56",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "56",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,152v40a16.01833,16.01833,0,0,1-16,16H136v15.99512a8,8,0,0,1-16,0V208H48a16.01833,16.01833,0,0,1-16-16V152a16.01833,16.01833,0,0,1,16-16h72V120H72a16.01833,16.01833,0,0,1-16-16V64A16.01833,16.01833,0,0,1,72,48h48V31.99512a8,8,0,1,1,16,0V48h48a16.01833,16.01833,0,0,1,16,16v40a16.01833,16.01833,0,0,1-16,16H136v16h72A16.01833,16.01833,0,0,1,224,152Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "31.99512",
        x2: "128",
        y2: "55.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "199.99512",
        x2: "128",
        y2: "223.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "111.99512",
        x2: "128",
        y2: "143.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "64",
        y: "56",
        width: "128",
        height: "56",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "56",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "31.99512",
        x2: "128",
        y2: "55.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "199.99512",
        x2: "128",
        y2: "223.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "111.99512",
        x2: "128",
        y2: "143.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "64",
        y: "56",
        width: "128",
        height: "56",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "56",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "31.99512",
        x2: "128",
        y2: "55.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "199.99512",
        x2: "128",
        y2: "223.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "111.99512",
        x2: "128",
        y2: "143.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "64",
        y: "56",
        width: "128",
        height: "56",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "56",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var AlignCenterHorizontal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
AlignCenterHorizontal.displayName = "AlignCenterHorizontal";

var renderPathFor$9 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "224.00488",
        y1: "128",
        x2: "204.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "52.00488",
        y1: "128",
        x2: "32.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "148.00488",
        y1: "128",
        x2: "108.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "112",
        y: "100",
        width: "128",
        height: "56",
        rx: "8",
        transform: "translate(304 -48) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "52",
        y: "40",
        width: "56",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "224.00488",
        y1: "128",
        x2: "200.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "108",
        y: "100",
        width: "128",
        height: "56",
        rx: "8",
        transform: "translate(300 -44) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "56",
        y: "40",
        width: "56",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "56.00488",
        y1: "128",
        x2: "32.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144.00488",
        y1: "128",
        x2: "112.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "108",
        y: "100",
        width: "128",
        height: "56",
        rx: "8",
        transform: "translate(300 -44) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "40",
        width: "56",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232.00488,128a7.99977,7.99977,0,0,1-8,8H208v48a16.01833,16.01833,0,0,1-16,16H152a16.01833,16.01833,0,0,1-16-16V136H120v72a16.01833,16.01833,0,0,1-16,16H64a16.01833,16.01833,0,0,1-16-16V136H32.00488a8,8,0,0,1,0-16H48V48A16.01833,16.01833,0,0,1,64,32h40a16.01833,16.01833,0,0,1,16,16v72h16V72a16.01833,16.01833,0,0,1,16-16h40a16.01833,16.01833,0,0,1,16,16v48h16.00488A7.99977,7.99977,0,0,1,232.00488,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "224.00488",
        y1: "128",
        x2: "200.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56.00488",
        y1: "128",
        x2: "32.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "144.00488",
        y1: "128",
        x2: "112.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "108",
        y: "100",
        width: "128",
        height: "56",
        rx: "8",
        transform: "translate(300 -44) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "40",
        width: "56",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "224.00488",
        y1: "128",
        x2: "200.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56.00488",
        y1: "128",
        x2: "32.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "144.00488",
        y1: "128",
        x2: "112.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "108",
        y: "100",
        width: "128",
        height: "56",
        rx: "8",
        transform: "translate(300 -44) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "40",
        width: "56",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "224.00488",
        y1: "128",
        x2: "200.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56.00488",
        y1: "128",
        x2: "32.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144.00488",
        y1: "128",
        x2: "112.00488",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "108",
        y: "100",
        width: "128",
        height: "56",
        rx: "8",
        transform: "translate(300 -44) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "40",
        width: "56",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var AlignCenterVertical = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
AlignCenterVertical.displayName = "AlignCenterVertical";

var renderPathFor$a = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "39.99414",
        y1: "39.99512",
        x2: "39.99414",
        y2: "215.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "80",
        y: "56",
        width: "104",
        height: "52",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "80",
        y: "148",
        width: "144",
        height: "52",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "72",
        y: "56",
        width: "112",
        height: "56",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "72",
        y: "144",
        width: "152",
        height: "56",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "72",
        y: "144",
        width: "152",
        height: "56",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "39.99512",
        x2: "39.99414",
        y2: "215.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "72",
        y: "56",
        width: "112",
        height: "56",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M47.99414,39.99512v176a8,8,0,0,1-16,0v-176a8,8,0,0,1,16,0ZM80,120h96a16.01833,16.01833,0,0,0,16-16V64a16.01833,16.01833,0,0,0-16-16H80A16.01833,16.01833,0,0,0,64,64v40A16.01833,16.01833,0,0,0,80,120Zm136,16H80a16.01833,16.01833,0,0,0-16,16v40a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V152A16.01833,16.01833,0,0,0,216,136Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "39.99414",
        y1: "39.99512",
        x2: "39.99414",
        y2: "215.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "72",
        y: "56",
        width: "112",
        height: "56",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "72",
        y: "144",
        width: "152",
        height: "56",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "39.99414",
        y1: "39.99512",
        x2: "39.99414",
        y2: "215.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "72",
        y: "56",
        width: "112",
        height: "56",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "72",
        y: "144",
        width: "152",
        height: "56",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "39.99414",
        y1: "39.99512",
        x2: "39.99414",
        y2: "215.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "72",
        y: "56",
        width: "112",
        height: "56",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "72",
        y: "144",
        width: "152",
        height: "56",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var AlignLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$a(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
AlignLeft.displayName = "AlignLeft";

var renderPathFor$b = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00586",
        y1: "39.99512",
        x2: "216.00586",
        y2: "215.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "72",
        y: "56",
        width: "104",
        height: "52",
        rx: "8",
        transform: "translate(248 164) rotate(180)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "32",
        y: "148",
        width: "144",
        height: "52",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "72",
        y: "56",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(256 168) rotate(180)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "144",
        width: "152",
        height: "56",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "216.00586",
        y1: "39.99512",
        x2: "216.00586",
        y2: "215.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "72",
        y: "56",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(256 168) rotate(180)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "32",
        y: "144",
        width: "152",
        height: "56",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224.00586,39.99512v176a8,8,0,0,1-16,0v-176a8,8,0,0,1,16,0ZM176,48H80A16.01833,16.01833,0,0,0,64,64v40a16.01833,16.01833,0,0,0,16,16h96a16.01833,16.01833,0,0,0,16-16V64A16.01833,16.01833,0,0,0,176,48Zm0,88H40a16.01833,16.01833,0,0,0-16,16v40a16.01833,16.01833,0,0,0,16,16H176a16.01833,16.01833,0,0,0,16-16V152A16.01833,16.01833,0,0,0,176,136Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00586",
        y1: "39.99512",
        x2: "216.00586",
        y2: "215.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "72",
        y: "56",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(256 168) rotate(180)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "32",
        y: "144",
        width: "152",
        height: "56",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00586",
        y1: "39.99512",
        x2: "216.00586",
        y2: "215.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "72",
        y: "56",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(256 168) rotate(180)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "32",
        y: "144",
        width: "152",
        height: "56",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00586",
        y1: "39.99512",
        x2: "216.00586",
        y2: "215.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "72",
        y: "56",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(256 168) rotate(180)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "32",
        y: "144",
        width: "152",
        height: "56",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var AlignRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$b(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
AlignRight.displayName = "AlignRight";

var renderPathFor$c = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00488",
        y1: "39.99414",
        x2: "40.00488",
        y2: "39.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "122",
        y: "106",
        width: "104",
        height: "52",
        rx: "8",
        transform: "translate(306 -42) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "80",
        width: "52",
        height: "144",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "116",
        y: "100",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(300 -44) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "56",
        y: "72",
        width: "56",
        height: "152",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "216.00488",
        y1: "39.99414",
        x2: "40.00488",
        y2: "39.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "116",
        y: "100",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(300 -44) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "72",
        width: "56",
        height: "152",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224.00488,39.99414a7.99977,7.99977,0,0,1-8,8h-176a8,8,0,0,1,0-16h176A7.99977,7.99977,0,0,1,224.00488,39.99414ZM192,64H152a16.01833,16.01833,0,0,0-16,16v96a16.01833,16.01833,0,0,0,16,16h40a16.01833,16.01833,0,0,0,16-16V80A16.01833,16.01833,0,0,0,192,64Zm-88,0H64A16.01833,16.01833,0,0,0,48,80V216a16.01833,16.01833,0,0,0,16,16h40a16.01833,16.01833,0,0,0,16-16V80A16.01833,16.01833,0,0,0,104,64Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00488",
        y1: "39.99414",
        x2: "40.00488",
        y2: "39.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "116",
        y: "100",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(300 -44) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "72",
        width: "56",
        height: "152",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00488",
        y1: "39.99414",
        x2: "40.00488",
        y2: "39.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "116",
        y: "100",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(300 -44) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "72",
        width: "56",
        height: "152",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216.00488",
        y1: "39.99414",
        x2: "40.00488",
        y2: "39.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "116",
        y: "100",
        width: "112",
        height: "56",
        rx: "8",
        transform: "translate(300 -44) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "56",
        y: "72",
        width: "56",
        height: "152",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var AlignTop = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$c(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
AlignTop.displayName = "AlignTop";

var renderPathFor$d = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "52",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112",
        x2: "168",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M40,144a48,48,0,0,0,48,48,40,40,0,0,1,40,40,40,40,0,0,1,40-40,48,48,0,0,0,48-48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "52",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112",
        x2: "168",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M40,144a48,48,0,0,0,48,48,40,40,0,0,1,40,40,40,40,0,0,1,40-40,48,48,0,0,0,48-48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,136a8.00039,8.00039,0,0,0-8,8,40.04584,40.04584,0,0,1-40,40,47.79539,47.79539,0,0,0-32,12.27148V120h32a8,8,0,0,0,0-16H136V78.8291a28,28,0,1,0-16,0V104H88a8,8,0,0,0,0,16h32v76.27148A47.79539,47.79539,0,0,0,88,184a40.04584,40.04584,0,0,1-40-40,8,8,0,0,0-16,0,56.0629,56.0629,0,0,0,56,56,32.03667,32.03667,0,0,1,32,32,8,8,0,0,0,16,0,32.03667,32.03667,0,0,1,32-32,56.0629,56.0629,0,0,0,56-56A8.00039,8.00039,0,0,0,216,136ZM116,52a12,12,0,1,1,12,12A12.01312,12.01312,0,0,1,116,52Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "52",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112",
        x2: "168",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M40,144a48,48,0,0,0,48,48,40,40,0,0,1,40,40,40,40,0,0,1,40-40,48,48,0,0,0,48-48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "52",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112",
        x2: "168",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M40,144a48,48,0,0,0,48,48,40,40,0,0,1,40,40,40,40,0,0,1,40-40,48,48,0,0,0,48-48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "52",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112",
        x2: "168",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M40,144a48,48,0,0,0,48,48,40,40,0,0,1,40,40,40,40,0,0,1,40-40,48,48,0,0,0,48-48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Anchor = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$d(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Anchor.displayName = "Anchor";

var renderPathFor$e = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.92969",
        y1: "24",
        x2: "75.27223",
        y2: "41.48751",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "199.92969",
        y1: "24",
        x2: "180.58646",
        y2: "41.48846",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M207.92969,152a80,80,0,0,1-160,0V104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "207.92969",
        y1: "124",
        x2: "47.92969",
        y2: "124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "155.92969",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "99.92969",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.92969,120v32a80,80,0,0,1-160,0V120Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "55.92969",
        y1: "24",
        x2: "75.27223",
        y2: "41.48751",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "199.92969",
        y1: "24",
        x2: "180.58646",
        y2: "41.48846",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M207.92969,152a80,80,0,0,1-160,0V104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "207.92969",
        y1: "120",
        x2: "47.92969",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "155.92969",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "99.92969",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "99.92969",
        cy: "84",
        r: "12"
      }), React__default.createElement("circle", {
        cx: "155.92969",
        cy: "84",
        r: "12"
      }), React__default.createElement("path", {
        d: "M191.083,42.78369l14.21191-12.84961a7.99994,7.99994,0,1,0-10.73047-11.86816l-15.71,14.20361A87.835,87.835,0,0,0,77.00488,32.269l-15.71-14.20312A7.99994,7.99994,0,1,0,50.56445,29.93408l14.2124,12.84961A87.69717,87.69717,0,0,0,39.92969,104v48a88,88,0,0,0,176,0V104A87.69973,87.69973,0,0,0,191.083,42.78369ZM127.92969,32a72.08124,72.08124,0,0,1,72,72v8h-144v-8A72.08124,72.08124,0,0,1,127.92969,32Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.92969",
        y1: "24",
        x2: "75.27223",
        y2: "41.48751",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "199.92969",
        y1: "24",
        x2: "180.58646",
        y2: "41.48846",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M207.92969,152a80,80,0,0,1-160,0V104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "207.92969",
        y1: "120",
        x2: "47.92969",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "155.92969",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "99.92969",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.92969",
        y1: "24",
        x2: "75.27223",
        y2: "41.48751",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "199.92969",
        y1: "24",
        x2: "180.58646",
        y2: "41.48846",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M207.92969,152a80,80,0,0,1-160,0V104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "207.92969",
        y1: "120",
        x2: "47.92969",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "155.92969",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "99.92969",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "56",
        y1: "24",
        x2: "75.34254",
        y2: "41.48751",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "24",
        x2: "180.65677",
        y2: "41.48846",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,152a80,80,0,0,1-160,0V104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "120",
        x2: "48",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var AndroidLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$e(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
AndroidLogo.displayName = "AndroidLogo";

var renderPathFor$f = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "32",
        x2: "164.6771",
        y2: "134.69588",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "44.86156",
        y1: "80",
        x2: "152.13735",
        y2: "99.58464",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "44.86156",
        y1: "176",
        x2: "115.46025",
        y2: "92.88876",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "224",
        x2: "91.3229",
        y2: "121.30412",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "176",
        x2: "103.86265",
        y2: "156.41536",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "140.53975",
        y2: "163.11124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M195.88226,60.11768a96.00006,96.00006,0,1,0,0,135.76464A96.00019,96.00019,0,0,0,195.88226,60.11768ZM164.67712,134.6958l-24.13733,28.41553h-.00006l-36.67706-6.6958-.00006-.00049L91.32294,121.3042h0l24.13733-28.41553h.00006l36.67706,6.6958h0l12.53973,35.11133Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "32",
        x2: "164.6771",
        y2: "134.69588",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "44.86156",
        y1: "80",
        x2: "152.13735",
        y2: "99.58464",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "44.86156",
        y1: "176",
        x2: "115.46025",
        y2: "92.88876",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "224",
        x2: "91.3229",
        y2: "121.30412",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "176",
        x2: "103.86265",
        y2: "156.41536",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "140.53975",
        y2: "163.11124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232,128A103.99994,103.99994,0,0,0,54.46094,54.46094,103.99951,103.99951,0,0,0,127.97,231.99951c.01,0,.0199.00244.03.00244.02148,0,.04321-.00244.0647-.00293A103.99851,103.99851,0,0,0,232,128ZM49.17554,88.91992l51.21631,9.35059L46.65076,161.53613A88.43277,88.43277,0,0,1,49.17554,88.91992Zm160.17383,5.54395a88.43282,88.43282,0,0,1-2.52491,72.61621l-51.21631-9.35059Zm-8.079-15.2041-33.7201,39.69628L139.63037,40.78027a87.98552,87.98552,0,0,1,61.64,38.4795ZM122.43164,40.19336l17.51148,49.03271L58.2959,74.32031a88.35033,88.35033,0,0,1,7.47851-8.54492A87.33436,87.33436,0,0,1,122.43164,40.19336Zm-67.702,136.54687L88.44971,137.044l27.91992,78.17578a87.98552,87.98552,0,0,1-61.64-38.4795Zm78.83875,39.06641-17.51148-49.03271,23.08216,4.21386.04553.0083,58.51953,10.6836a88.35033,88.35033,0,0,1-7.47851,8.54492A87.33436,87.33436,0,0,1,133.56836,215.80664Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "32",
        x2: "164.6771",
        y2: "134.69588",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "44.86156",
        y1: "80",
        x2: "152.13735",
        y2: "99.58464",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "44.86156",
        y1: "176",
        x2: "115.46025",
        y2: "92.88876",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "224",
        x2: "91.3229",
        y2: "121.30412",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "176",
        x2: "103.86265",
        y2: "156.41536",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "140.53975",
        y2: "163.11124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "32",
        x2: "164.6771",
        y2: "134.69588",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "44.86156",
        y1: "80",
        x2: "152.13735",
        y2: "99.58464",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "44.86156",
        y1: "176",
        x2: "115.46025",
        y2: "92.88876",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "224",
        x2: "91.3229",
        y2: "121.30412",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "176",
        x2: "103.86265",
        y2: "156.41536",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "140.53975",
        y2: "163.11124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "32",
        x2: "164.6771",
        y2: "134.69588",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "44.86156",
        y1: "80",
        x2: "152.13735",
        y2: "99.58464",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "44.86156",
        y1: "176",
        x2: "115.46025",
        y2: "92.88876",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "224",
        x2: "91.3229",
        y2: "121.30412",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "176",
        x2: "103.86265",
        y2: "156.41536",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "140.53975",
        y2: "163.11124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Aperture = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$f(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Aperture.displayName = "Aperture";

var renderPathFor$g = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.51254,162.9332C205.936,193.65156,183.10562,216,164,216H92c-28,0-64-48-64-100A60.00062,60.00062,0,0,1,128.00185,71.27954l-.00164-.00185a60.0047,60.0047,0,0,1,87.16862,7.63587l-.00019.00015a48.01693,48.01693,0,0,0,3.33915,84.01754Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M218.51254,162.9332C205.936,193.65156,183.10562,216,164,216H92c-28,0-64-48-64-100A60.00062,60.00062,0,0,1,128.00185,71.27954l-.00164-.00185a60.0047,60.0047,0,0,1,87.16862,7.63587l-.00019.00015a48.01693,48.01693,0,0,0,3.33915,84.01754Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M143.53892,23.36749A31.931,31.931,0,0,1,168,12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.51254,162.9332C205.936,193.65156,183.10562,216,164,216H92c-28,0-64-48-64-100A60.00062,60.00062,0,0,1,128.00185,71.27954l-.00164-.00185a60.0047,60.0047,0,0,1,87.16862,7.63587l-.00019.00015a48.01693,48.01693,0,0,0,3.33915,84.01754Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M138.12628,32.506A32.01179,32.01179,0,0,1,168,12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M218.51254,162.9332C205.936,193.65156,183.10562,216,164,216H92c-28,0-64-48-64-100A60.00062,60.00062,0,0,1,128.00185,71.27954l-.00164-.00185a60.0047,60.0047,0,0,1,87.16862,7.63587l-.00019.00015a48.01693,48.01693,0,0,0,3.33915,84.01754Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M130.66016,29.63136A40.25041,40.25041,0,0,1,168,4a8,8,0,0,1,0,16,24.15408,24.15408,0,0,0-22.4082,15.38037,8.00008,8.00008,0,0,1-14.93164-5.749Zm91.38476,126.12451a40.01719,40.01719,0,0,1-2.73144-69.99951,8.00039,8.00039,0,0,0,2.14111-11.7915A68.012,68.012,0,0,0,128,61.00441,68.00487,68.00487,0,0,0,20,116c0,25.50293,8.33594,52.4668,22.87109,73.97852C57.26514,211.28224,75.63086,224,92,224h72c22.46533,0,47.92578-23.86523,61.916-58.03515A8.00438,8.00438,0,0,0,222.04492,155.75587Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M138.12628,32.506A32.01179,32.01179,0,0,1,168,12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M218.51254,162.9332C205.936,193.65156,183.10562,216,164,216H92c-28,0-64-48-64-100A60.00062,60.00062,0,0,1,128.00185,71.27954l-.00164-.00185a60.0047,60.0047,0,0,1,87.16862,7.63587l-.00019.00015a48.01693,48.01693,0,0,0,3.33915,84.01754Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M138.12628,32.506A32.01179,32.01179,0,0,1,168,12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M218.51254,162.9332C205.936,193.65156,183.10562,216,164,216H92c-28,0-64-48-64-100A60.00062,60.00062,0,0,1,128.00185,71.27954l-.00164-.00185a60.0047,60.0047,0,0,1,87.16862,7.63587l-.00019.00015a48.01693,48.01693,0,0,0,3.33915,84.01754Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M138.12628,32.506A32.01179,32.01179,0,0,1,168,12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M218.51254,162.9332C205.936,193.65156,183.10562,216,164,216H92c-28,0-64-48-64-100A60.00062,60.00062,0,0,1,128.00185,71.27954l-.00164-.00185a60.0047,60.0047,0,0,1,87.16862,7.63587l-.00019.00015a48.01693,48.01693,0,0,0,3.33915,84.01754Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var AppleLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$g(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
AppleLogo.displayName = "AppleLogo";

var renderPathFor$h = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "48",
        rx: "7.99999",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,96V200a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "136",
        x2: "152",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,96V200a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V96Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "48",
        rx: "7.99999",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,96V200a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "136",
        x2: "152",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,40H40A16.01833,16.01833,0,0,0,24,56V88a16.01833,16.01833,0,0,0,16,16v96a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V104a16.01833,16.01833,0,0,0,16-16V56A16.01833,16.01833,0,0,0,216,40ZM152,144H104a8,8,0,0,1,0-16h48a8,8,0,0,1,0,16Zm64-56H40V56H216l.00977,32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "48",
        rx: "7.99999",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,96V200a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "136",
        x2: "152",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "48",
        rx: "7.99999",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,96V200a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "136",
        x2: "152",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "48",
        rx: "7.99999",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,96V200a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "136",
        x2: "152",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Archive = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$h(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Archive.displayName = "Archive";

var renderPathFor$i = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,216H48a8,8,0,0,1-8-8V76L56,40H200l16,36V208A8,8,0,0,1,208,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "76",
        x2: "216",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "99.716 151.716 128 180 156.284 151.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "112",
        x2: "128",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,72V208a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V72Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M208,216H48a8,8,0,0,1-8-8V72L56,40H200l16,32V208A8,8,0,0,1,208,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "94.059 150.059 128 184 161.941 150.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "104",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "72",
        x2: "216",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.15527,68.42188l-16-32A7.99967,7.99967,0,0,0,200,32H56a7.99967,7.99967,0,0,0-7.15527,4.42188l-16,32A7.99934,7.99934,0,0,0,32,72V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V72A7.99934,7.99934,0,0,0,223.15527,68.42188Zm-55.55713,87.29394-33.94091,33.94141c-.0542.0542-.11426.10107-.16944.15332-.1333.126-.26611.25244-.4082.36914-.06689.05517-.13867.10254-.207.15527-.13916.10693-.27686.21484-.42285.313-.05616.0376-.11621.06885-.17334.105-.16358.104-.32813.207-.49951.29883-.04248.023-.08692.041-.12989.0625-.18945.09765-.38135.1914-.57959.27392-.02832.01221-.05859.02051-.0874.03223-.2124.08545-.42725.16455-.64844.23193-.02929.00928-.05957.01465-.08886.02295-.21973.064-.44141.12256-.668.168-.06543.01319-.13282.01856-.19873.03028-.19092.0332-.38184.06689-.57715.08593a7.89257,7.89257,0,0,1-1.59766,0c-.19531-.019-.38623-.05273-.57715-.08593-.06591-.01172-.1333-.01709-.19873-.03028-.22656-.04541-.44824-.104-.668-.168-.02929-.0083-.05957-.01367-.08886-.02295-.22168-.06738-.438-.14746-.65088-.23291-.02783-.01123-.05713-.01953-.085-.03125-.19824-.08252-.39014-.17627-.58008-.27392-.04248-.022-.08692-.03955-.1294-.0625-.17138-.0918-.33593-.19483-.49951-.29883-.05713-.03613-.11718-.06738-.17334-.105-.146-.09815-.28369-.20606-.42285-.313-.06836-.05273-.14014-.1001-.207-.15527-.13818-.11328-.26709-.23731-.39746-.35938-.05908-.05566-.12256-.10547-.18018-.16308L88.40186,155.71582a8.00035,8.00035,0,0,1,11.314-11.31445L120,164.686V104a8,8,0,0,1,16,0v60.686l20.28418-20.28467a8.00035,8.00035,0,0,1,11.314,11.31445ZM52.94434,64l8-16H195.05566l8,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,216H48a8,8,0,0,1-8-8V72L56,40H200l16,32V208A8,8,0,0,1,208,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "94.059 150.059 128 184 161.941 150.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "104",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "72",
        x2: "216",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,216H48a8,8,0,0,1-8-8V72L56,40H200l16,32V208A8,8,0,0,1,208,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "94.059 150.059 128 184 161.941 150.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "104",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "72",
        x2: "216",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,216H48a8,8,0,0,1-8-8V72L56,40H200l16,32V208A8,8,0,0,1,208,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "94.059 150.059 128 184 161.941 150.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "104",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "72",
        x2: "216",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArchiveBox = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$i(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArchiveBox.displayName = "ArchiveBox";

var renderPathFor$j = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "99.716 115.716 128 144 156.284 115.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "76",
        x2: "128",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M39.99414,156H76.68043a8,8,0,0,1,5.65686,2.34315l19.3137,19.3137A8,8,0,0,0,107.30785,180h41.37258a8,8,0,0,0,5.65686-2.34315l19.3137-19.3137A8,8,0,0,1,179.30785,156h36.68629",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M76.68066,160a7.9996,7.9996,0,0,1,5.65674,2.34326l19.31348,19.31348A7.99962,7.99962,0,0,0,107.30762,184h41.373a7.9996,7.9996,0,0,0,5.65674-2.34326l19.31348-19.31348A7.99962,7.99962,0,0,1,179.30762,160h36.68652l.00586.00439V48a7.99977,7.99977,0,0,0-8-8H48a7.99977,7.99977,0,0,0-8,8V160Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 118.059 128 152 161.941 118.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M39.99414,160H76.68043a8,8,0,0,1,5.65686,2.34315l19.3137,19.3137A8,8,0,0,0,107.30785,184h41.37258a8,8,0,0,0,5.65686-2.34315l19.3137-19.3137A8,8,0,0,1,179.30785,160h36.68629",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V159.88379c-.00049.03906-.00586.07715-.00586.11621s.00537.07715.00586.11621V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,208,32ZM88.40234,112.40137a8.0018,8.0018,0,0,1,11.31348,0L120,132.686V72a8,8,0,0,1,16,0v60.686l20.28418-20.28467a8.00035,8.00035,0,0,1,11.314,11.31445l-33.94091,33.94141c-.0542.0542-.11426.10107-.16944.15332-.1333.126-.26611.25244-.4082.36914-.06689.05517-.13867.10254-.207.15527-.13916.10693-.27686.21484-.42285.313-.05616.0376-.11621.06885-.17334.105-.16358.104-.32813.207-.49951.29883-.04248.023-.08692.041-.12989.0625-.18945.09765-.38135.1914-.57959.27392-.02832.01221-.05859.02051-.0874.03223-.2124.08545-.42725.16455-.64844.23193-.02929.00928-.05957.01465-.08886.02295-.21973.064-.44141.12256-.668.168-.06543.01319-.13282.01856-.19873.03028-.19092.0332-.38184.06689-.57715.08593a7.89257,7.89257,0,0,1-1.59766,0c-.19531-.019-.38623-.05273-.57715-.08593-.06591-.01172-.1333-.01709-.19873-.03028-.22656-.04541-.44824-.104-.668-.168-.02929-.0083-.05957-.01367-.08886-.02295-.22168-.06738-.438-.14746-.65088-.23291-.02783-.01123-.05713-.01953-.085-.03125-.19824-.08252-.39014-.17627-.58008-.27392-.04248-.022-.08692-.03955-.1294-.0625-.17138-.0918-.33593-.19483-.49951-.29883-.05713-.03613-.11718-.06738-.17334-.105-.146-.09815-.28369-.20606-.42285-.313-.06836-.05273-.14014-.1001-.207-.15527-.13818-.11328-.26709-.23731-.39746-.35938-.05908-.05566-.12256-.10547-.18018-.16308L88.40186,123.71582A8.00076,8.00076,0,0,1,88.40234,112.40137ZM208,208H48V168l28.68066-.001,19.31446,19.31641A15.89834,15.89834,0,0,0,107.30762,192h41.373a15.89606,15.89606,0,0,0,11.31348-4.68652L179.30762,168h28.6997l.00245,40Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 118.059 128 152 161.941 118.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M39.99414,160H76.68043a8,8,0,0,1,5.65686,2.34315l19.3137,19.3137A8,8,0,0,0,107.30785,184h41.37258a8,8,0,0,0,5.65686-2.34315l19.3137-19.3137A8,8,0,0,1,179.30785,160h36.68629",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 118.059 128 152 161.941 118.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M39.99414,160H76.68043a8,8,0,0,1,5.65686,2.34315l19.3137,19.3137A8,8,0,0,0,107.30785,184h41.37258a8,8,0,0,0,5.65686-2.34315l19.3137-19.3137A8,8,0,0,1,179.30785,160h36.68629",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 118.059 128 152 161.941 118.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M39.99414,160H76.68043a8,8,0,0,1,5.65686,2.34315l19.3137,19.3137A8,8,0,0,0,107.30785,184h41.37258a8,8,0,0,0,5.65686-2.34315l19.3137-19.3137A8,8,0,0,1,179.30785,160h36.68629",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArchiveTray = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$j(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArchiveTray.displayName = "ArchiveTray";

var renderPathFor$k = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "92.118 148.118 28.118 148.118 28.118 84.118",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,184A96,96,0,0,0,60.11775,116.11775l-32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "92.118 148.118 28.118 148.118 28.118 84.118",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,184A96,96,0,0,0,60.11775,116.11775l-32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M201.53906,110.46094a103.99978,103.99978,0,0,0-147.07812,0L36.11816,128.80371V84.11816a8,8,0,0,0-16,0v63.99512c-.00024.26563.01368.53174.04.79688.0105.10742.031.21093.04566.31689.02124.15283.03979.30566.06982.45752.0249.125.05957.24609.09009.36914.03247.13037.06128.26123.10034.39014.03662.1206.08228.23681.12427.355.04565.1289.08838.25781.14062.38476.04493.10743.09766.21094.147.31641.06152.13184.1206.26465.18969.39355.052.09717.11158.189.16724.28321.0769.13037.15088.26172.23584.38818.06616.09863.14038.19141.21094.28662.08423.11475.1643.231.25537.3418.116.14111.24194.27344.36719.40625.05444.0581.10229.11914.15869.17578.05346.05322.11157.09863.166.1499.13623.12891.27222.25782.417.377.10376.085.21289.15966.31958.23877.10327.07666.20361.15673.31079.22851.11718.07813.23925.14649.35962.21826.10424.062.20581.12744.313.18506.11817.063.23975.1167.36036.17334.11669.05518.23168.11328.35131.16309.11255.04638.22754.084.3418.125.13257.04834.26367.09863.39917.13965.10889.03271.21948.05664.32959.085.14307.03662.28491.07617.43091.105.11963.02343.24072.03711.36133.05517.13745.02051.27319.0459.41259.05957.20191.01953.40455.02637.60718.03077.05957.001.11719.00878.177.00878h64a8,8,0,0,0,0-16H47.43262l18.34277-18.34277A88,88,0,0,1,216,184a8,8,0,0,0,16,0A103.322,103.322,0,0,0,201.53906,110.46094Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "92.118 148.118 28.118 148.118 28.118 84.118",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,184A96,96,0,0,0,60.11775,116.11775l-32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "92.118 148.118 28.118 148.118 28.118 84.118",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,184A96,96,0,0,0,60.11775,116.11775l-32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "92.118 148.118 28.118 148.118 28.118 84.118",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,184A96,96,0,0,0,60.11775,116.11775l-32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowArcLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$k(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowArcLeft.displayName = "ArrowArcLeft";

var renderPathFor$l = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "163.882 148.118 227.882 148.118 227.882 84.118",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,184a96,96,0,0,1,163.88225-67.88229l32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "163.882 148.118 227.882 148.118 227.882 84.118",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,184a96,96,0,0,1,163.88225-67.88229l32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M229.07861,156.019c.12061-.01806.2417-.03174.36133-.05517.146-.02881.28784-.06836.43091-.105.11011-.02832.2207-.05225.32959-.085.1355-.041.2666-.09131.39917-.13965.11426-.041.22925-.07862.3418-.125.11963-.04981.23462-.10791.35131-.16309.12061-.05664.24219-.11035.36036-.17334.10717-.05762.20874-.12305.313-.18506.12037-.07177.24244-.14013.35962-.21826.10718-.07178.20752-.15185.31079-.22851.10669-.07911.21582-.15381.31958-.23877.14478-.11914.28077-.248.417-.377.05444-.05127.11255-.09668.166-.1499.0564-.05664.10425-.11768.15869-.17578.12525-.13281.25122-.26514.36719-.40625.09107-.11084.17114-.22705.25537-.3418.07056-.09521.14478-.188.21094-.28662.085-.12646.15894-.25781.23584-.38818.05566-.09424.11523-.186.16724-.28321.06909-.1289.12817-.26171.18969-.39355.04932-.10547.102-.209.147-.31641.05224-.127.095-.25586.14062-.38476.042-.11817.08765-.23438.12427-.355.03906-.12891.06787-.25977.10034-.39014.03052-.12305.06519-.24414.09009-.36914.03-.15186.04858-.30469.06982-.45752.01465-.106.03516-.20947.04566-.31689.02636-.26514.04028-.53125.04-.79688V84.11816a8,8,0,1,0-16,0v44.68555l-18.34278-18.34277A104,104,0,0,0,24,184a8,8,0,0,0,16,0,87.99889,87.99889,0,0,1,150.22461-62.22461l18.34277,18.34277H163.88184a8,8,0,0,0,0,16h64c.05981,0,.11743-.00781.177-.00879.20263-.00439.40527-.01123.60718-.03076C228.80542,156.06494,228.94116,156.03955,229.07861,156.019Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "163.882 148.118 227.882 148.118 227.882 84.118",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,184a96,96,0,0,1,163.88225-67.88229l32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "163.882 148.118 227.882 148.118 227.882 84.118",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,184a96,96,0,0,1,163.88225-67.88229l32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "163.882 148.118 227.882 148.118 227.882 84.118",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,184a96,96,0,0,1,163.88225-67.88229l32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowArcRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$l(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowArcRight.displayName = "ArrowArcRight";

var renderPathFor$m = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 152 32 104 80 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "136 152 88 104 136 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,200a96,96,0,0,0-96-96H88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 152 32 104 80 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 152 80 104 128 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,200a96,96,0,0,0-96-96H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M43.31348,104,85.65723,61.65723A8.00053,8.00053,0,0,0,74.34277,50.34277l-48,48a8.00122,8.00122,0,0,0,0,11.31446l48,48a8.00053,8.00053,0,0,0,11.31446-11.31446Z"
      }), React__default.createElement("path", {
        d: "M128,96H99.31372l34.34351-34.34277a8.00053,8.00053,0,0,0-11.31446-11.31446l-48,48c-.05639.05664-.10424.11768-.15869.17578-.12524.13282-.25122.26514-.36719.40625-.09106.11084-.17114.22706-.25537.3418-.07055.09522-.14477.188-.21093.28662-.085.12647-.15894.25782-.23584.38819-.05567.09423-.11524.186-.16724.2832-.06909.12891-.12817.26172-.1897.39355-.04931.10547-.10205.209-.147.31641-.05225.127-.095.25586-.14063.38477-.042.11816-.08764.23437-.12426.355-.03907.1289-.06787.25976-.10034.39013-.03052.12305-.06519.24414-.09009.36914-.03.15186-.04859.30469-.06983.45752-.01465.106-.03515.20948-.04565.3169a8.02276,8.02276,0,0,0,0,1.584c.0105.10742.031.21094.04565.3169.02124.15283.0398.30566.06983.45752.0249.125.05957.24609.09009.36914.03247.13037.06127.26123.10034.39013.03662.12061.08227.23682.12426.355.04566.12891.08838.25782.14063.38477.04492.10742.09766.21094.147.31641.06153.13183.12061.26464.1897.39355.052.09717.11157.189.16724.2832.0769.13037.15088.26172.23584.38819.06616.09863.14038.1914.21093.28662.08423.11474.16431.231.25537.3418.116.14111.242.27343.36719.40625.05445.0581.1023.11914.15869.17578l48,48a8.00053,8.00053,0,0,0,11.31446-11.31446L99.31372,112H128a88.09957,88.09957,0,0,1,88,88,8,8,0,0,0,16,0A104.11791,104.11791,0,0,0,128,96Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 152 32 104 80 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "128 152 80 104 128 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,200a96,96,0,0,0-96-96H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 152 32 104 80 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "128 152 80 104 128 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,200a96,96,0,0,0-96-96H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 152 32 104 80 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 152 80 104 128 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,200a96,96,0,0,0-96-96H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowBendDoubleUpLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$m(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowBendDoubleUpLeft.displayName = "ArrowBendDoubleUpLeft";

var renderPathFor$n = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "120 152 168 104 120 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,200a96,96,0,0,1,96-96h40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 152 176 104 128 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,200a96,96,0,0,1,96-96h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M229.65723,98.34277l-48-48a8.00053,8.00053,0,0,0-11.31446,11.31446L212.68652,104l-42.34375,42.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l48-48A8.00122,8.00122,0,0,0,229.65723,98.34277Z"
      }), React__default.createElement("path", {
        d: "M181.81592,109.48145c.12524-.13282.25122-.26514.36719-.40625.09106-.11084.17114-.22706.25537-.3418.07055-.09522.14477-.188.21093-.28662.085-.12647.15894-.25782.23584-.38819.05567-.09423.11524-.186.16724-.2832.06909-.12891.12817-.26172.1897-.39355.04931-.10547.10205-.209.147-.31641.05225-.127.095-.25586.14063-.38477.042-.11816.08764-.23437.12426-.355.03907-.1289.06787-.25976.10034-.39013.03052-.12305.06519-.24414.09009-.36914.03-.15186.04859-.30469.06983-.45752.01465-.106.03515-.20948.04565-.3169a8.02276,8.02276,0,0,0,0-1.584c-.0105-.10742-.031-.21094-.04565-.3169-.02124-.15283-.0398-.30566-.06983-.45752-.0249-.125-.05957-.24609-.09009-.36914-.03247-.13037-.06127-.26123-.10034-.39013-.03662-.12061-.08227-.23682-.12426-.355-.04566-.12891-.08838-.25782-.14063-.38477-.04492-.10742-.09766-.21094-.147-.31641-.06153-.13183-.12061-.26464-.1897-.39355-.052-.09717-.11157-.189-.16724-.2832-.0769-.13037-.15087-.26172-.23584-.38819-.06616-.09863-.14038-.1914-.21093-.28662-.08423-.11474-.16431-.231-.25537-.3418-.116-.14111-.242-.27343-.36719-.40625-.05445-.0581-.1023-.11914-.15869-.17578l-48-48a8.00053,8.00053,0,0,0-11.31446,11.31446L156.68628,96H128A104.11791,104.11791,0,0,0,24,200a8,8,0,0,0,16,0,88.09957,88.09957,0,0,1,88-88h28.68628l-34.34351,34.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l48-48C181.71362,109.60059,181.76147,109.53955,181.81592,109.48145Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "128 152 176 104 128 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,200a96,96,0,0,1,96-96h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "128 152 176 104 128 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,200a96,96,0,0,1,96-96h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 152 176 104 128 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,200a96,96,0,0,1,96-96h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowBendDoubleUpRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$n(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowBendDoubleUpRight.displayName = "ArrowBendDoubleUpRight";

var renderPathFor$o = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 104 32 152 80 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,56a96,96,0,0,1-96,96H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 104 32 152 80 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,56a96,96,0,0,1-96,96H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,48a8.00039,8.00039,0,0,0-8,8,88.09957,88.09957,0,0,1-88,88H51.31372l34.34351-34.34277A8.00053,8.00053,0,0,0,74.34277,98.34277l-48,48c-.05639.05664-.10424.11768-.15869.17578-.12524.13282-.25122.26514-.36719.40625-.09106.11084-.17114.22706-.25537.3418-.07055.09522-.14477.188-.21093.28662-.085.12647-.15894.25782-.23584.38819-.05567.09423-.11524.186-.16724.2832-.06909.12891-.12817.26172-.1897.39355-.04931.10547-.102.209-.147.31641-.05225.12695-.095.25586-.14063.38477-.042.11816-.08764.23437-.12426.355-.03907.1289-.06787.25976-.10034.39013-.03052.12305-.06519.24414-.09009.36914-.03.15186-.04859.30469-.06983.45752-.01465.106-.03515.20948-.04565.3169a8.02276,8.02276,0,0,0,0,1.584c.0105.10742.031.21094.04565.3169.02124.15283.0398.30566.06983.45752.0249.125.05957.24609.09009.36914.03247.13037.06127.26123.10034.39013.03662.12061.08227.23682.12426.355.04566.12891.08838.25782.14063.38477.04492.10742.09766.21094.147.31641.06153.13183.12061.26464.1897.39355.052.09717.11157.189.16724.2832.0769.13037.15087.26172.23584.38819.06616.09863.14038.1914.21093.28662.08423.11474.16431.231.25537.3418.116.14111.24195.27343.36719.40625.05445.0581.1023.11914.15869.17578l48,48a8.00053,8.00053,0,0,0,11.31446-11.31446L51.31372,160H128A104.11791,104.11791,0,0,0,232,56,8.00039,8.00039,0,0,0,224,48Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 104 32 152 80 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,56a96,96,0,0,1-96,96H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 104 32 152 80 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,56a96,96,0,0,1-96,96H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 104 32 152 80 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,56a96,96,0,0,1-96,96H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowBendDownLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$o(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowBendDownLeft.displayName = "ArrowBendDownLeft";

var renderPathFor$p = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 104 224 152 176 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,56a96,96,0,0,0,96,96h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 104 224 152 176 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,56a96,96,0,0,0,96,96h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M230.18311,157.0752c.09106-.11084.17114-.22706.25537-.3418.07055-.09522.14477-.188.21093-.28662.085-.12647.15894-.25782.23584-.38819.05567-.09423.11524-.186.16724-.2832.06909-.12891.12817-.26172.1897-.39355.04931-.10547.10205-.209.147-.31641.05225-.12695.095-.25586.14063-.38477.042-.11816.08764-.23437.12426-.355.03907-.1289.06787-.25976.10034-.39013.03052-.12305.06519-.24414.09009-.36914.03-.15186.04859-.30469.06983-.45752.01465-.106.03515-.20948.04565-.3169a8.02276,8.02276,0,0,0,0-1.584c-.0105-.10742-.031-.21094-.04565-.3169-.02124-.15283-.0398-.30566-.06983-.45752-.0249-.125-.05957-.24609-.09009-.36914-.03247-.13037-.06127-.26123-.10034-.39013-.03662-.12061-.08227-.23682-.12426-.355-.04566-.12891-.08838-.25782-.14063-.38477-.04492-.10742-.09766-.21094-.147-.31641-.06153-.13183-.12061-.26464-.1897-.39355-.052-.09717-.11157-.189-.16724-.2832-.0769-.13037-.15088-.26172-.23584-.38819-.06616-.09863-.14038-.1914-.21093-.28662-.08423-.11474-.16431-.231-.25537-.3418-.116-.14111-.242-.27343-.36719-.40625-.05445-.0581-.1023-.11914-.15869-.17578l-48-48a8.00053,8.00053,0,0,0-11.31446,11.31446L204.68628,144H128A88.09957,88.09957,0,0,1,40,56a8,8,0,0,0-16,0A104.11791,104.11791,0,0,0,128,160h76.68628l-34.34351,34.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l48-48c.05639-.05664.10424-.11768.15869-.17578C229.94116,157.34863,230.06714,157.21631,230.18311,157.0752Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 104 224 152 176 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,56a96,96,0,0,0,96,96h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 104 224 152 176 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,56a96,96,0,0,0,96,96h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 104 224 152 176 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,56a96,96,0,0,0,96,96h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowBendDownRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$p(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowBendDownRight.displayName = "ArrowBendDownRight";

var renderPathFor$q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 176 104 224 56 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M200,32a96,96,0,0,0-96,96v96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 176 104 224 56 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,32a96,96,0,0,0-96,96v96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,24A104.11791,104.11791,0,0,0,96,128v76.68652L61.65723,170.34277a8.00053,8.00053,0,0,0-11.31446,11.31446l48,48c.05445.0542.11377.10058.16919.15283.135.12744.26978.25537.41358.37353.10644.08789.2185.16455.32837.24561.10009.07422.19726.15185.30078.22119.12182.08154.248.15234.37329.22656.09936.05909.19629.12159.29858.17627.124.0669.25147.123.37842.18262.11035.05176.21875.10693.332.15381.1211.05029.24487.09082.36792.13476.12354.04444.24536.0918.37183.13038.12158.03662.24511.06347.36816.09472.13037.03272.259.06885.3916.09522.14087.02832.283.04492.42481.06494.11645.0166.231.03857.34912.05029.26245.02588.52588.04.78955.04s.5271-.01416.78955-.04c.11816-.01172.23267-.03369.34912-.05029.14185-.02.28394-.03662.42481-.06494.13256-.02637.26123-.0625.3916-.09522.123-.03125.24658-.0581.36816-.09472.12647-.03858.24829-.08594.37183-.13038.123-.04394.24682-.08447.36792-.13476.11328-.04688.22168-.102.332-.15381.12695-.05957.25439-.11572.37842-.18262.10229-.05468.19922-.11718.29858-.17627.12525-.07422.25147-.145.37329-.22656.10352-.06934.20069-.147.30078-.22119.10987-.08106.22193-.15772.32837-.24561.1438-.11816.27857-.24609.41358-.37353.05542-.05225.11474-.09863.16919-.15283l48-48a8.00053,8.00053,0,0,0-11.31446-11.31446L112,204.68652V128a88.09957,88.09957,0,0,1,88-88,8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 176 104 224 56 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M200,32a96,96,0,0,0-96,96v96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 176 104 224 56 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M200,32a96,96,0,0,0-96,96v96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 176 104 224 56 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,32a96,96,0,0,0-96,96v96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowBendLeftDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowBendLeftDown.displayName = "ArrowBendLeftDown";

var renderPathFor$r = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 80 104 32 56 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M200,224a96,96,0,0,1-96-96V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 80 104 32 56 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,224a96,96,0,0,1-96-96V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,216a88.09957,88.09957,0,0,1-88-88V51.31372l34.34277,34.34351a8.00053,8.00053,0,0,0,11.31446-11.31446l-48-48c-.05347-.05322-.11158-.09863-.166-.1499-.13623-.12891-.27222-.25781-.417-.377-.10449-.0857-.21411-.16065-.32178-.24024-.10229-.07617-.2019-.15551-.3081-.22656-.11817-.0791-.24073-.14795-.36206-.22-.10352-.06177-.20459-.12671-.311-.18359-.11816-.06324-.23975-.11695-.36035-.17383-.1167-.05518-.23169-.11328-.35132-.16284-.11255-.04663-.22754-.084-.3418-.12525-.13256-.04785-.26367-.09839-.39917-.1394-.10962-.0332-.22094-.05713-.3313-.08521-.14233-.03637-.2832-.07592-.42846-.10473-.12134-.02393-.24414-.0376-.36621-.05567-.136-.02051-.27027-.04565-.40845-.05908-.2019-.01977-.40454-.02612-.60718-.03076C104.11743,24.00757,104.05981,24,104,24s-.11743.00757-.177.00879c-.20264.00464-.40528.011-.60718.03076-.13818.01343-.27246.03857-.40845.05908-.12207.01807-.24487.03174-.36621.05567-.14526.02881-.28613.06836-.42846.10473-.11036.02808-.22168.052-.3313.08521-.1355.041-.26661.09155-.39917.1394-.11426.04126-.22925.07862-.3418.12525-.11963.04956-.23462.10766-.35132.16284-.1206.05688-.24219.11059-.36035.17383-.10645.05688-.20752.12182-.311.18359-.12133.072-.24389.14087-.36206.22-.1062.071-.20581.15039-.3081.22656-.10767.07959-.21729.15454-.32178.24024-.14477.11914-.28076.248-.417.377-.05444.05127-.11255.09668-.166.1499l-48,48A8.00053,8.00053,0,0,0,61.65723,85.65723L96,51.31372V128A104.11791,104.11791,0,0,0,200,232a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 80 104 32 56 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M200,224a96,96,0,0,1-96-96V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 80 104 32 56 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M200,224a96,96,0,0,1-96-96V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 80 104 32 56 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,224a96,96,0,0,1-96-96V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowBendLeftUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$r(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowBendLeftUp.displayName = "ArrowBendLeftUp";

var renderPathFor$s = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 176 152 224 200 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M56,32a96,96,0,0,1,96,96v96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 176 152 224 200 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M56,32a96,96,0,0,1,96,96v96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M205.65723,170.34277a8.003,8.003,0,0,0-11.31446,0L160,204.68628V128A104.11791,104.11791,0,0,0,56,24a8,8,0,0,0,0,16,88.09957,88.09957,0,0,1,88,88v76.68628l-34.34277-34.34351a8.00053,8.00053,0,0,0-11.31446,11.31446l48,48c.05445.0542.11377.10034.16919.15283.135.12744.26978.25561.41358.37353.10644.08765.2185.16431.32837.24561.10009.074.19726.15185.30078.22119.12182.08154.248.15259.37329.22681.09936.05884.19629.12134.29858.17627.124.0664.25147.1228.37842.18237.11035.05176.21875.10693.332.15405.1211.05.24487.09058.36792.13452.12354.04444.24536.0918.37183.13013.12158.03687.24511.064.36816.09473.13037.033.259.06933.3916.0957.14087.02783.283.04443.42481.0647.11645.0166.231.03882.34912.05029.26245.02588.52588.04.78955.04s.5271-.01416.78955-.04c.11816-.01147.23267-.03369.34912-.05029.14185-.02027.28394-.03687.42481-.0647.13256-.02637.26123-.06274.3916-.0957.123-.03076.24658-.05786.36816-.09473.12647-.03833.24829-.08569.37183-.13013.12305-.04394.24682-.08447.36792-.13452.11328-.04712.22168-.10229.332-.15405.127-.05957.25439-.116.37842-.18237.10229-.05493.19922-.11743.29858-.17627.12525-.07422.25147-.14527.37329-.22681.10352-.06934.20069-.14722.30078-.22119.10987-.0813.22193-.158.32837-.24561.1438-.11792.27857-.24609.41358-.37353.05542-.05249.11474-.09863.16919-.15283l48-48A8.00122,8.00122,0,0,0,205.65723,170.34277Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 176 152 224 200 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M56,32a96,96,0,0,1,96,96v96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 176 152 224 200 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M56,32a96,96,0,0,1,96,96v96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 176 152 224 200 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M56,32a96,96,0,0,1,96,96v96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowBendRightDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$s(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowBendRightDown.displayName = "ArrowBendRightDown";

var renderPathFor$t = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 80 152 32 200 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M56,224a96,96,0,0,0,96-96V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 80 152 32 200 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M56,224a96,96,0,0,0,96-96V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M205.65723,74.34277l-48-48c-.05347-.05322-.11158-.09863-.166-.1499-.13623-.12891-.27222-.25781-.417-.377-.10449-.08545-.21411-.16065-.32178-.24024-.10229-.07617-.2019-.15527-.3081-.22656-.11817-.0791-.24073-.14795-.36206-.22021-.10352-.06153-.20459-.12647-.311-.1836-.11816-.063-.23975-.1167-.36035-.17334-.1167-.05517-.23169-.11328-.35132-.16308-.11255-.04639-.22754-.084-.3418-.125-.13256-.04834-.26367-.09864-.39917-.13965-.10962-.0332-.22094-.05713-.3313-.08545-.14233-.03613-.2832-.07568-.42846-.10449-.12134-.02393-.24414-.0376-.36621-.05567-.136-.02051-.27027-.04541-.40845-.05908-.2019-.01953-.40454-.02637-.60718-.03076C152.11743,24.00781,152.05981,24,152,24s-.11743.00781-.177.00879c-.20264.00439-.40528.01123-.60718.03076-.13818.01367-.27246.03857-.40845.05908-.12207.01807-.24487.03174-.36621.05567-.14526.02881-.28613.06836-.42846.10449-.11036.02832-.22168.05225-.3313.08545-.1355.041-.26661.09131-.39917.13965-.11426.041-.22925.07861-.3418.125-.11963.0498-.23462.10791-.35132.16308-.1206.05664-.24219.11035-.36035.17334-.10645.05713-.20752.12207-.311.1836-.12133.07226-.24389.14111-.36206.22021-.1062.07129-.20581.15039-.3081.22656-.10767.07959-.21729.15479-.32178.24024-.14477.11914-.28076.248-.417.377-.05444.05127-.11255.09668-.166.1499l-48,48a8.00053,8.00053,0,0,0,11.31446,11.31446L144,51.31348V128a88.09957,88.09957,0,0,1-88,88,8,8,0,0,0,0,16A104.11791,104.11791,0,0,0,160,128V51.31348l34.34277,34.34375a8.00053,8.00053,0,0,0,11.31446-11.31446Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 80 152 32 200 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M56,224a96,96,0,0,0,96-96V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 80 152 32 200 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M56,224a96,96,0,0,0,96-96V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 80 152 32 200 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M56,224a96,96,0,0,0,96-96V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowBendRightUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$t(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowBendRightUp.displayName = "ArrowBendRightUp";

var renderPathFor$u = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 152 32 104 80 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,200a96,96,0,0,0-96-96H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 152 32 104 80 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,200a96,96,0,0,0-96-96H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,96H51.31372L85.65723,61.65723A8.00053,8.00053,0,0,0,74.34277,50.34277l-48,48c-.05639.0564-.10424.11792-.15869.17554-.12524.13281-.25122.26538-.36719.40649-.09106.11084-.17114.22706-.25537.34156-.07055.0957-.14477.188-.21093.28686-.085.12647-.15894.25782-.23584.38819-.05567.09423-.11524.186-.16724.283-.06909.12915-.12817.262-.1897.39379-.04931.10547-.102.20874-.147.31665-.05225.12647-.095.25562-.14063.38428-.042.11817-.08764.23462-.12426.35523-.03907.1289-.06787.25976-.10034.39013-.03052.12305-.06519.24414-.09009.36939-.03.15136-.04859.30444-.06983.457-.01465.106-.03515.21-.04565.31714a8.02276,8.02276,0,0,0,0,1.584c.0105.10718.031.21118.04565.31714.02124.15259.0398.30566.06983.457.0249.12525.05957.24634.09009.36939.03247.13037.06127.26123.10034.39013.03662.12061.08227.23706.12426.35523.04566.12866.08838.25781.14063.38428.04492.10791.09766.21118.147.31665.06153.13183.12061.26464.1897.39379.052.09693.11157.18873.16724.283.0769.13037.15087.26172.23584.38819.06616.09887.14038.19116.21093.28686.08423.1145.16431.23072.25537.34156.116.14111.24195.27368.36719.40649.05445.05762.1023.11914.15869.17554l48,48a8.00053,8.00053,0,0,0,11.31446-11.31446L51.31372,112H128a88.09957,88.09957,0,0,1,88,88,8,8,0,0,0,16,0A104.11791,104.11791,0,0,0,128,96Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 152 32 104 80 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,200a96,96,0,0,0-96-96H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 152 32 104 80 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,200a96,96,0,0,0-96-96H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 152 32 104 80 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,200a96,96,0,0,0-96-96H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowBendUpLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$u(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowBendUpLeft.displayName = "ArrowBendUpLeft";

var renderPathFor$v = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,200a96,96,0,0,1,96-96h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,200a96,96,0,0,1,96-96h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M230.18311,109.0752c.09106-.11084.17114-.22706.25537-.34156.07055-.0957.14477-.188.21093-.28686.085-.12647.15894-.25782.23584-.38819.05567-.09423.11524-.186.16724-.283.06909-.12915.12817-.262.1897-.39379.04931-.10547.10205-.20874.147-.31665.05225-.12647.095-.25562.14063-.38428.042-.11817.08764-.23462.12426-.35523.03907-.1289.06787-.25976.10034-.39013.03052-.12305.06519-.24414.09009-.36939.03-.15137.04859-.30444.06983-.457.01465-.106.03515-.21.04565-.31714a8.02276,8.02276,0,0,0,0-1.584c-.0105-.10718-.031-.21118-.04565-.31714-.02124-.15259-.0398-.30567-.06983-.457-.0249-.12525-.05957-.24634-.09009-.36939-.03247-.13037-.06127-.26123-.10034-.39013-.03662-.12061-.08227-.23706-.12426-.35523-.04566-.12866-.08838-.25781-.14063-.38428-.04492-.10791-.09766-.21118-.147-.31665-.06153-.13183-.12061-.26464-.1897-.39379-.052-.09693-.11157-.18873-.16724-.283-.0769-.13037-.15088-.26172-.23584-.38819-.06616-.09887-.14038-.19116-.21093-.28686-.08423-.1145-.16431-.23072-.25537-.34156-.116-.14111-.242-.27368-.36719-.40649-.05445-.05762-.1023-.11914-.15869-.17554l-48-48a8.00053,8.00053,0,0,0-11.31446,11.31446L204.68628,96H128A104.11791,104.11791,0,0,0,24,200a8,8,0,0,0,16,0,88.09957,88.09957,0,0,1,88-88h76.68628l-34.34351,34.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l48-48c.05639-.0564.10424-.11792.15869-.17554C229.94116,109.34888,230.06714,109.21631,230.18311,109.0752Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,200a96,96,0,0,1,96-96h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,200a96,96,0,0,1,96-96h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,200a96,96,0,0,1,96-96h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowBendUpRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$v(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowBendUpRight.displayName = "ArrowBendUpRight";

var renderPathFor$w = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "94.059 134.059 128 168 161.941 134.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "94.059 134.059 128 168 161.941 134.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm39.59375,115.71875L133.666,173.64648a8.02367,8.02367,0,0,1-11.332,0L88.40625,139.71875a7.99915,7.99915,0,0,1,11.3125-11.3125L120,148.6875V88a8,8,0,0,1,16,0v60.6875l20.28125-20.28125a7.99915,7.99915,0,0,1,11.3125,11.3125Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "94.059 134.059 128 168 161.941 134.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "94.059 134.059 128 168 161.941 134.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "94.059 134.059 128 168 161.941 134.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowCircleDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$w(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowCircleDown.displayName = "ArrowCircleDown";

var renderPathFor$x = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "100 108 100 156 148 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "100",
        x2: "100",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "100 108 100 156 148 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "100",
        x2: "100",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm33.65625,81.65625L119.3125,148H148a8,8,0,0,1,0,16H100a8.02752,8.02752,0,0,1-8-8V108a8,8,0,0,1,16,0v28.6875l42.34375-42.34375a7.99915,7.99915,0,0,1,11.3125,11.3125Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "100 108 100 156 148 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "100",
        x2: "100",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "100 108 100 156 148 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "100",
        x2: "100",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "100 108 100 156 148 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "100",
        x2: "100",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowCircleDownLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$x(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowCircleDownLeft.displayName = "ArrowCircleDownLeft";

var renderPathFor$y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "108 156 156 156 156 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "100",
        x2: "156",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "108 156 156 156 156 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "100",
        x2: "156",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm36,132a8.02752,8.02752,0,0,1-8,8H108a8,8,0,0,1,0-16h28.6875L94.34375,105.65625a7.99915,7.99915,0,0,1,11.3125-11.3125L148,136.6875V108a8,8,0,0,1,16,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "108 156 156 156 156 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "100",
        x2: "156",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "108 156 156 156 156 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "100",
        x2: "156",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "108 156 156 156 156 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "100",
        x2: "156",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowCircleDownRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowCircleDownRight.displayName = "ArrowCircleDownRight";

var renderPathFor$z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "121.941 161.941 88 128 121.941 94.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "128",
        x2: "88",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "121.941 161.941 88 128 121.941 94.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "128",
        x2: "88",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm40,112H107.3125l20.28125,20.28125a7.99915,7.99915,0,1,1-11.3125,11.3125L82.35352,133.666a8.02367,8.02367,0,0,1,0-11.332l33.92773-33.92773a7.99915,7.99915,0,0,1,11.3125,11.3125L107.3125,120H168a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "121.941 161.941 88 128 121.941 94.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "121.941 161.941 88 128 121.941 94.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "121.941 161.941 88 128 121.941 94.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowCircleLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowCircleLeft.displayName = "ArrowCircleLeft";

var renderPathFor$A = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "134.059 161.941 168 128 134.059 94.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "134.059 161.941 168 128 134.059 94.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm47.38477,107.05469a7.99866,7.99866,0,0,1-1.73829,2.61133l-33.92773,33.92773a7.99915,7.99915,0,0,1-11.3125-11.3125L148.6875,136H88a8,8,0,0,1,0-16h60.6875L128.40625,99.71875a7.99915,7.99915,0,0,1,11.3125-11.3125L173.64648,122.334a8.02367,8.02367,0,0,1,1.73829,8.72071Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "134.059 161.941 168 128 134.059 94.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "134.059 161.941 168 128 134.059 94.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "134.059 161.941 168 128 134.059 94.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowCircleRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$A(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowCircleRight.displayName = "ArrowCircleRight";

var renderPathFor$B = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "94.059 121.941 128 88 161.941 121.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "94.059 121.941 128 88 161.941 121.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm39.59375,103.59375a7.99708,7.99708,0,0,1-11.3125,0L136,107.3125V168a8,8,0,0,1-16,0V107.3125L99.71875,127.59375a7.99915,7.99915,0,0,1-11.3125-11.3125L122.334,82.35352a8.02367,8.02367,0,0,1,11.332,0l33.92773,33.92773A7.99708,7.99708,0,0,1,167.59375,127.59375Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "94.059 121.941 128 88 161.941 121.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "94.059 121.941 128 88 161.941 121.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "94.059 121.941 128 88 161.941 121.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowCircleUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$B(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowCircleUp.displayName = "ArrowCircleUp";

var renderPathFor$C = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "148 100 100 100 100 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "156",
        x2: "100",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "148 100 100 100 100 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "156",
        x2: "100",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm33.65625,137.65625a7.99708,7.99708,0,0,1-11.3125,0L108,119.3125V148a8,8,0,0,1-16,0V100a8.02752,8.02752,0,0,1,8-8h48a8,8,0,0,1,0,16H119.3125l42.34375,42.34375A7.99708,7.99708,0,0,1,161.65625,161.65625Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "148 100 100 100 100 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "156",
        x2: "100",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "148 100 100 100 100 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "156",
        x2: "100",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "148 100 100 100 100 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "156",
        x2: "100",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowCircleUpLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$C(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowCircleUpLeft.displayName = "ArrowCircleUpLeft";

var renderPathFor$D = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "108 100 156 100 156 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "156",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "108 100 156 100 156 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "156",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M201.541,54.458a104,104,0,1,0,0,147.07813A104.10845,104.10845,0,0,0,201.541,54.458ZM163.99414,147.9971a8,8,0,0,1-16,0V119.3096l-42.34375,42.34375a7.99915,7.99915,0,0,1-11.3125-11.3125l42.34375-42.34375h-28.6875a8,8,0,0,1,0-16h48a8.02753,8.02753,0,0,1,8,8Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "108 100 156 100 156 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "156",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "108 100 156 100 156 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "156",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "108 100 156 100 156 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "156",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowCircleUpRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$D(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowCircleUpRight.displayName = "ArrowCircleUpRight";

var renderPathFor$E = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176.167 99.716 224.167 99.716 224.167 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,1,1,0-124.4508l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176.167 99.716 224.167 99.716 224.167 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,1,1,0-124.4508l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.33447,107.62115c.13135-.01928.26319-.03424.39356-.06005.14038-.02777.27661-.0661.4143-.10114.115-.02923.23072-.05426.34449-.08862.13427-.04059.26367-.0907.39477-.13806.11524-.04151.2312-.07929.345-.12629.12085-.05011.23682-.10876.35449-.16455.11915-.05621.23926-.10907.356-.17144.11133-.0597.21729-.12757.32544-.1922.116-.06928.2334-.13483.34644-.21051.11718-.07831.22729-.16553.33984-.24976.09644-.07227.19556-.1394.28955-.21655.18628-.1529.36426-.31531.53589-.48413.01611-.01593.03394-.02918.05-.04529.02051-.02051.0376-.04321.05762-.06391.16357-.16711.32177-.33941.47045-.52032.08277-.10059.15479-.20648.23194-.31006.07861-.10571.1604-.20862.23389-.3183.08081-.12072.15112-.24591.22485-.36993.05932-.1.12231-.19757.17749-.30035.06738-.12592.12475-.25531.18481-.384.05078-.1084.10523-.21466.15137-.32568.05151-.12463.09326-.25189.13843-.37848.04272-.11987.08911-.238.12622-.36047.03857-.12775.06714-.25757.09936-.38678.03077-.124.06568-.24622.09082-.37244.03-.15088.04834-.30328.06958-.45544.01465-.10645.03541-.21094.0459-.31867a7.97366,7.97366,0,0,0,.04-.79706V51.71582a8,8,0,0,0-16,0v28.686L195.88281,60.11768a95.9551,95.9551,0,1,0,0,135.76464,8.00018,8.00018,0,1,0-11.31445-11.31347,80.00009,80.00009,0,1,1,0-113.1377L204.853,91.71582H176.167a8,8,0,0,0,0,16h48c.02979,0,.0586-.00415.08838-.00446.23316-.00256.46631-.01245.69824-.03527C225.08252,107.66351,225.20752,107.63977,225.33447,107.62115Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176.167 99.716 224.167 99.716 224.167 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,1,1,0-124.4508l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176.167 99.716 224.167 99.716 224.167 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,1,1,0-124.4508l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176.167 99.716 224.167 99.716 224.167 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,1,1,0-124.4508l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowClockwise = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$E(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowClockwise.displayName = "ArrowClockwise";

var renderPathFor$F = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "79.833 99.716 31.833 99.716 31.833 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,1,0,0-124.4508L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "79.833 99.716 31.833 99.716 31.833 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,1,0,0-124.4508L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M195.88281,60.11768a96.10959,96.10959,0,0,0-135.76562,0L39.833,80.40186v-28.686a8,8,0,0,0-16,0V99.71069a7.97366,7.97366,0,0,0,.04.79706c.01049.10773.03125.21222.0459.31867.02124.15216.03955.30456.06958.45544.02514.12622.06005.24841.09082.37244.03222.12921.06079.259.09936.38678.03711.12243.0835.2406.12622.36047.04517.12659.08692.25385.13843.37848.04614.111.10059.21728.15137.32568.06006.12867.11743.25806.18481.384.05518.10278.11817.20031.17749.30035.07373.124.144.24921.22485.36993.07349.10968.15528.21259.23389.3183.07715.10358.14917.20947.23194.31006.14868.18091.30688.35321.47045.52032.02.0207.03711.0434.05762.06391.01611.01611.03394.02936.05.04529.17163.16882.34961.33123.53589.48413.094.07715.19311.14428.28955.21655.11255.08423.22266.17145.33984.24976.113.07568.23047.14123.34644.21051.10815.06463.21411.1325.32544.1922.1167.06237.23681.11523.356.17144.11767.05579.23364.11444.35449.16455.11377.047.22973.08478.345.12629.1311.04736.2605.09747.39477.13806.11377.03436.2295.05939.34449.08862.13769.035.27392.07337.4143.10114.13037.02581.26221.04077.39356.06005.127.01862.252.04236.38086.05494.23193.02282.46508.03271.69824.03527.02978.00031.05859.00446.08838.00446h48a8,8,0,0,0,0-16H51.147L71.43164,71.43115a79.99992,79.99992,0,1,1,0,113.13721,8.00052,8.00052,0,0,0-11.31445,11.31445A96.00062,96.00062,0,1,0,195.88281,60.11768Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "79.833 99.716 31.833 99.716 31.833 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,1,0,0-124.4508L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "79.833 99.716 31.833 99.716 31.833 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,1,0,0-124.4508L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "79.833 99.716 31.833 99.716 31.833 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,1,0,0-124.4508L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowCounterClockwise = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$F(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowCounterClockwise.displayName = "ArrowCounterClockwise";

var renderPathFor$G = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "56 144 128 216 200 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 144 128 216 200 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M205.65674,138.34277a8.00182,8.00182,0,0,0-11.31348,0L136,196.68652V40a8,8,0,0,0-16,0V196.68652L61.65674,138.34277a8.00018,8.00018,0,0,0-11.31348,11.31446l72,72c.02588.02612.05469.0476.08106.07324.16211.158.32861.31128.50341.45508.09766.08032.20118.15039.30176.22534.1084.08105.21485.16528.32764.241.11621.07788.2373.1455.35693.21679.10449.06226.20655.12793.31446.18579.12011.06421.24414.1189.36669.17676.11426.054.22657.11084.34327.15942.11816.04883.23925.08838.35937.13135.126.04541.251.09375.37988.13282.11963.03613.24122.06274.36231.09326.13183.0332.26269.07031.397.09692.13965.02759.28028.04419.42041.06421.11817.01685.23389.03931.353.051.26269.02587.52588.03979.78955.03979s.52686-.01392.78955-.03979c.11914-.01172.23486-.03418.353-.051.14013-.02.28076-.03662.42041-.06421.13428-.02661.26513-.06372.397-.09692.12109-.03052.24268-.05713.36231-.09326.1289-.03907.2539-.08741.37988-.13282.12012-.043.24121-.08252.35937-.13135.1167-.04858.229-.10546.34327-.15942.12255-.05786.24658-.11255.36669-.17676.10791-.05786.21-.12353.31446-.18579.11963-.07129.24072-.13891.35693-.21679.11279-.07569.21924-.15992.32764-.241.10058-.075.2041-.145.30176-.22534.17822-.14624.34765-.30225.51269-.46338.023-.02271.04883-.04175.07178-.06494l72-72A8.00034,8.00034,0,0,0,205.65674,138.34277Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "56 144 128 216 200 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "56 144 128 216 200 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 144 128 216 200 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$G(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowDown.displayName = "ArrowDown";

var renderPathFor$H = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "192",
        y1: "64",
        x2: "64",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "168 192 64 192 64 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "192",
        y1: "64",
        x2: "64",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "168 192 64 192 64 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M57.59033,196.772c-.08154-.10888-.166-.21582-.24219-.3291-.07763-.11621-.1455-.2373-.2163-.35644-.0625-.105-.12842-.207-.186-.315-.06445-.11962-.11865-.24316-.17627-.36572-.0542-.11474-.11133-.227-.16015-.34472-.04883-.11719-.0879-.23682-.13038-.356-.04589-.12744-.09423-.25293-.13379-.3833-.03613-.11914-.0625-.23975-.09277-.35987-.03369-.13281-.0708-.26367-.09717-.39892-.02783-.13819-.04394-.27783-.064-.41748-.01709-.11914-.03955-.23633-.05127-.35694q-.03808-.38232-.03906-.7666L56,192V88a8,8,0,0,1,16,0v84.686L186.34326,58.34277a8.00018,8.00018,0,1,1,11.31348,11.31446L83.314,184H168a8,8,0,0,1,0,16H64c-.26367,0-.52686-.01416-.78955-.04-.11914-.01172-.23486-.03369-.353-.05078-.14013-.02-.28076-.03662-.42041-.064-.13428-.02685-.26513-.064-.397-.09716-.12109-.03028-.24268-.05713-.36231-.09326-.1289-.03907-.2539-.08741-.37988-.13282-.12012-.043-.24121-.08252-.35937-.13135-.1167-.04882-.229-.10546-.34327-.15966-.12255-.05762-.24658-.11231-.36669-.17676-.10791-.05762-.21-.12305-.31446-.18555-.11963-.07129-.24072-.13867-.35693-.21679-.11279-.07569-.21924-.15967-.32764-.24073-.10058-.07519-.2041-.14551-.30176-.22558-.17822-.14649-.34765-.30225-.51269-.46338-.02295-.023-.04883-.042-.07178-.06494-.02-.02051-.03711-.04248-.05713-.063-.16406-.16748-.32275-.34082-.47168-.522C57.73438,196.97461,57.665,196.87207,57.59033,196.772Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "192",
        y1: "64",
        x2: "64",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "168 192 64 192 64 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "192",
        y1: "64",
        x2: "64",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "168 192 64 192 64 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "192",
        y1: "64",
        x2: "64",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "168 192 64 192 64 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowDownLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$H(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowDownLeft.displayName = "ArrowDownLeft";

var renderPathFor$I = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "64",
        x2: "192",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "88 192 192 192 192 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "64",
        x2: "192",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "88 192 192 192 192 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M198.40967,196.772c.08154-.10888.166-.21582.24219-.3291.07763-.11621.1455-.2373.2163-.35644.0625-.105.12842-.207.186-.315.06445-.11962.11865-.24316.17627-.36572.0542-.11474.11133-.227.16015-.34472.04883-.11719.0879-.23682.13038-.356.04589-.12744.09423-.25293.13379-.3833.03613-.11914.0625-.23975.09277-.35987.03369-.13281.0708-.26367.09717-.39892.02783-.13819.04394-.27783.064-.41748.01709-.11914.03955-.23633.05127-.35694q.03809-.38232.03906-.7666L200,192V88a8,8,0,0,0-16,0v84.686L69.65674,58.34277A8.00018,8.00018,0,0,0,58.34326,69.65723L172.686,184H88a8,8,0,0,0,0,16H192c.26367,0,.52686-.01416.78955-.04.11914-.01172.23486-.03369.353-.05078.14013-.02.28076-.03662.42041-.064.13428-.02685.26513-.064.397-.09716.12109-.03028.24268-.05713.36231-.09326.1289-.03907.2539-.08741.37988-.13282.12012-.043.24121-.08252.35937-.13135.1167-.04882.229-.10546.34327-.15966.12255-.05762.24658-.11231.36669-.17676.10791-.05762.21-.12305.31446-.18555.11963-.07129.24072-.13867.35693-.21679.11279-.07569.21924-.15967.32764-.24073.10058-.07519.2041-.14551.30176-.22558.17822-.14649.34765-.30225.51269-.46338.023-.023.04883-.042.07178-.06494.02-.02051.03711-.04248.05713-.063.16406-.16748.32275-.34082.47168-.522C198.26562,196.97461,198.335,196.87207,198.40967,196.772Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "64",
        x2: "192",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "88 192 192 192 192 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "64",
        x2: "192",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "88 192 192 192 192 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "64",
        x2: "192",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "88 192 192 192 192 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowDownRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$I(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowDownRight.displayName = "ArrowDownRight";

var renderPathFor$J = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 128 48 176 96 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "192 32 192 176 48 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 128 48 176 96 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 32 192 176 48 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,24a8.00008,8.00008,0,0,0-8,8V168H67.31348l34.34375-34.34326a8.00018,8.00018,0,1,0-11.31446-11.31348l-48,48c-.0205.02051-.03759.04321-.05761.064-.16358.167-.32178.33935-.47046.52026-.08277.10059-.15479.20654-.23194.31006-.07861.10571-.1604.20874-.23388.31836-.08081.1206-.15113.24585-.22486.36987-.05932.1001-.12231.19751-.17749.30029-.06738.126-.12475.25538-.18481.384-.05078.1084-.10523.2146-.15137.32568-.05151.12476-.09326.25195-.13843.37842-.04272.11987-.08911.238-.12622.36059-.03857.12769-.06714.25757-.09936.38672-.03076.124-.06568.2461-.09082.37256-.03.15088-.04834.30322-.06958.45532-.01465.10645-.0354.21094-.0459.31861a8.02276,8.02276,0,0,0,0,1.584c.0105.10767.03125.21216.0459.31861.02124.1521.03955.30444.06958.45532.02514.12646.06006.24853.09082.37256.03222.12915.06079.259.09936.38672.03711.12255.0835.24072.12622.36059.04517.12647.08692.25366.13843.37842.04614.11108.10059.21728.15137.32568.06006.12866.11743.25806.18481.384.05518.10278.11817.20019.17749.30029.07373.124.14405.24927.22486.36987.07348.10962.15527.21265.23388.31836.07715.10352.14917.20947.23194.31006.14868.18091.30688.35327.47046.52026.02.02076.03711.04346.05761.064l48,48a8.00018,8.00018,0,1,0,11.31446-11.31348L67.31348,184H192a8.00008,8.00008,0,0,0,8-8V32A8.00008,8.00008,0,0,0,192,24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 128 48 176 96 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "192 32 192 176 48 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 128 48 176 96 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "192 32 192 176 48 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 128 48 176 96 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 32 192 176 48 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowElbowDownLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$J(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowElbowDownLeft.displayName = "ArrowElbowDownLeft";

var renderPathFor$K = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 128 208 176 160 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "64 32 64 176 208 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 128 208 176 160 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 32 64 176 208 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M214.1853,181.07251c.08277-.10059.15479-.20654.23194-.31006.07861-.10571.1604-.20874.23388-.31836.08081-.1206.15113-.24585.22486-.36987.05932-.1001.12231-.19751.17749-.30029.06738-.126.12475-.25538.18481-.384.05078-.1084.10523-.2146.15137-.32568.05151-.12476.09326-.25195.13843-.37842.04272-.11987.08911-.238.12622-.36059.03857-.12769.06714-.25757.09936-.38672.03076-.124.06568-.2461.09082-.37256.03-.15088.04834-.30322.06958-.45532.01465-.10645.0354-.21094.0459-.31861a8.02276,8.02276,0,0,0,0-1.584c-.0105-.10767-.03125-.21216-.0459-.31861-.02124-.1521-.03955-.30444-.06958-.45532-.02514-.12646-.06006-.24853-.09082-.37256-.03222-.12915-.06079-.259-.09936-.38672-.03711-.12255-.0835-.24072-.12622-.36059-.04517-.12647-.08692-.25366-.13843-.37842-.04614-.11108-.10059-.21728-.15137-.32568-.06006-.12866-.11743-.25806-.18481-.384-.05518-.10278-.11817-.20019-.17749-.30029-.07373-.124-.144-.24927-.22486-.36987-.07348-.10962-.15527-.21265-.23388-.31836-.07715-.10352-.14917-.20947-.23194-.31006-.14868-.18091-.30688-.35327-.47046-.52026-.02-.02076-.03711-.04346-.05761-.064l-48-48a8.00018,8.00018,0,1,0-11.31446,11.31348L188.68652,168H72V32a8,8,0,0,0-16,0V176a8.00008,8.00008,0,0,0,8,8H188.68652l-34.34375,34.34326a8.00018,8.00018,0,0,0,11.31446,11.31348l48-48c.0205-.02051.03759-.04321.05761-.064C213.87842,181.42578,214.03662,181.25342,214.1853,181.07251Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 128 208 176 160 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "64 32 64 176 208 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 128 208 176 160 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "64 32 64 176 208 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 128 208 176 160 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 32 64 176 208 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowElbowDownRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$K(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowElbowDownRight.displayName = "ArrowElbowDownRight";

var renderPathFor$L = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 80 24 80 24 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "232 96 136 192 24 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 80 24 80 24 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "232 96 136 192 24 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M237.65723,90.34277a8.003,8.003,0,0,0-11.31446,0L136,180.68652,43.31445,88H96a8,8,0,0,0,0-16H24c-.05981,0-.11743.00757-.177.00891-.20264.00452-.40528.01087-.60718.03064-.13818.01343-.27246.03857-.40845.059-.12207.01831-.24487.03186-.36621.05591-.14526.02869-.28613.06811-.42846.10461-.11036.0282-.22168.05213-.3313.08521-.1355.041-.26661.09155-.39917.1394-.11426.04126-.22925.07862-.3418.12525-.11963.04956-.23462.10766-.35132.16284-.1206.05688-.24219.11059-.36035.17383-.10645.05688-.20752.12182-.311.18359-.12133.072-.24389.14087-.36206.22-.1062.071-.20581.15051-.3081.22644-.10767.07971-.21729.15466-.32178.24048-.14477.119-.28076.24792-.417.37671-.05444.05151-.11255.09668-.166.15-.05639.0564-.10424.11792-.15869.17554-.12524.13281-.25122.26538-.36719.40649-.09106.11072-.17114.22718-.25537.34156-.07055.0957-.14477.188-.21093.28686-.085.12659-.15894.25782-.23584.38806-.05567.09436-.11524.18616-.16724.28309-.06909.12915-.12817.26184-.1897.39379-.04931.10547-.102.20874-.147.31665-.05225.12647-.095.25562-.14063.38428-.042.11817-.08764.2345-.12426.35523-.03907.1289-.06787.25976-.10034.39013-.03052.12305-.06519.24414-.09009.36939-.03.15136-.04859.30444-.06983.457-.01465.106-.03515.21-.04565.31714a7.97965,7.97965,0,0,0-.04.79712V152a8,8,0,0,0,16,0V99.31445l98.34277,98.34278a8.00181,8.00181,0,0,0,11.31446,0l96-96A8.00122,8.00122,0,0,0,237.65723,90.34277Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 80 24 80 24 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "232 96 136 192 24 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 80 24 80 24 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "232 96 136 192 24 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 80 24 80 24 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "232 96 136 192 24 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowElbowLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$L(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowElbowLeft.displayName = "ArrowElbowLeft";

var renderPathFor$M = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 160 80 208 32 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "224 64 80 64 80 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 160 80 208 32 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 64 80 64 80 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,56H80a8.00008,8.00008,0,0,0-8,8V188.6864L37.65723,154.34326a8.00018,8.00018,0,0,0-11.31446,11.31348l48,48c.01612.01611.03394.0293.05.04529.17163.16882.34961.33117.53589.48413.09448.07751.19385.145.291.21765.11206.08374.22143.17053.33789.24853.11474.07679.23388.14331.3518.21363.1062.06347.21.13012.31934.18872.11987.06421.24341.11865.366.17627.11425.05395.22656.11084.34375.15942.11816.04907.23877.0885.35888.13147.12647.04553.25122.09387.38062.13318.11963.03613.24121.06262.3623.093.13184.03332.262.07031.39624.09692.14087.02783.283.04443.42481.0647.11645.01672.231.03882.34912.05041C79.4729,215.986,79.73633,216,80,216s.5271-.014.78955-.03992c.11816-.01159.23267-.03369.34912-.05041.14185-.02027.28394-.03687.42481-.0647.13427-.02661.2644-.0636.39624-.09692.12109-.0304.24267-.05689.3623-.093.1294-.03931.25415-.08765.38062-.13318.12011-.043.24072-.0824.35888-.13147.11719-.04858.2295-.10547.34375-.15942.12256-.05762.2461-.11206.366-.17627.10938-.0586.21313-.12525.31934-.18872.11792-.07032.23706-.13684.3518-.21363.11646-.078.22583-.16479.33789-.24853.09717-.07263.19654-.14014.291-.21765.18628-.153.36426-.31531.53589-.48413.01611-.016.03393-.02918.05-.04529l48-48a8.00018,8.00018,0,0,0-11.31446-11.31348L88,188.6864V72H224a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 160 80 208 32 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "224 64 80 64 80 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 160 80 208 32 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "224 64 80 64 80 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 160 80 208 32 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 64 80 64 80 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowElbowLeftDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$M(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowElbowLeftDown.displayName = "ArrowElbowLeftDown";

var renderPathFor$N = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 96 80 48 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "224 192 80 192 80 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 96 80 48 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 192 80 192 80 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,184H88V67.3136l34.34277,34.34314a8.00018,8.00018,0,0,0,11.31446-11.31348l-48-48c-.01612-.01611-.03418-.02936-.0503-.04529-.17138-.16882-.34912-.33123-.53564-.48413-.09375-.07715-.19287-.14428-.28955-.21655-.11279-.08423-.22266-.17145-.33985-.24976-.11279-.07568-.23046-.14123-.34668-.21051-.10791-.06463-.21386-.1325-.32519-.1922-.1167-.06237-.23682-.11523-.356-.17144-.11767-.05579-.2334-.11444-.35449-.16455-.11377-.047-.22949-.08478-.34473-.12629-.13134-.04736-.26074-.09747-.395-.13806-.11377-.03436-.22949-.05938-.34423-.08862-.1377-.035-.27442-.07336-.41455-.10114-.13038-.02581-.26221-.04077-.39356-.06-.12695-.01862-.25195-.04236-.38086-.05494-.23193-.02282-.46484-.03271-.69824-.03527C80.05859,40.00415,80.02979,40,80,40s-.05859.00415-.08838.00446c-.2334.00256-.46631.01245-.69824.03527-.12891.01258-.25391.03632-.38086.05494-.13135.01928-.26318.03424-.39356.06-.14013.02778-.27685.06611-.41455.10114-.11474.02924-.23046.05426-.34423.08862-.13428.04059-.26368.0907-.395.13806-.11524.04151-.231.07929-.34473.12629-.12109.05011-.23682.10876-.35449.16455-.11914.05621-.23926.10907-.356.17144-.11133.0597-.21728.12757-.32519.1922-.11622.06928-.23389.13483-.34668.21051-.11719.07831-.22706.16553-.33985.24976-.09668.07227-.1958.1394-.28955.21655-.18652.1529-.36426.31531-.53564.48413-.01612.01593-.03418.02918-.0503.04529l-48,48a8.00018,8.00018,0,0,0,11.31446,11.31348L72,67.3136V192a8.00008,8.00008,0,0,0,8,8H224a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 96 80 48 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "224 192 80 192 80 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 96 80 48 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "224 192 80 192 80 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 96 80 48 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 192 80 192 80 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowElbowLeftUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$N(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowElbowLeftUp.displayName = "ArrowElbowLeftUp";

var renderPathFor$O = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 80 232 80 232 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "24 96 120 192 232 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 80 232 80 232 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "24 96 120 192 232 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M239.96,79.208c-.0105-.10718-.031-.21118-.04565-.31714-.02124-.15259-.0398-.30567-.06983-.457-.0249-.12525-.05957-.24634-.09009-.36939-.03247-.13037-.06127-.26123-.10034-.39013-.03662-.12073-.08227-.23706-.12426-.35523-.04566-.12866-.08838-.25781-.14063-.38428-.04492-.10791-.09766-.21118-.147-.31665-.06153-.132-.12061-.26464-.1897-.39379-.052-.09693-.11157-.18873-.16724-.28309-.0769-.13024-.15088-.26147-.23584-.38806-.06616-.09887-.14038-.19116-.21093-.28686-.08423-.11438-.16431-.23084-.25537-.34156-.116-.14111-.242-.27368-.36719-.40649-.05445-.05762-.1023-.11914-.15869-.17554-.05347-.05334-.11158-.09851-.166-.15-.13623-.12879-.27222-.25769-.417-.37671-.10449-.08582-.21411-.16077-.32178-.24048-.10229-.07593-.2019-.15539-.3081-.22644-.11817-.0791-.24073-.14795-.36206-.22-.10352-.06177-.20459-.12671-.311-.18359-.11816-.06324-.23975-.117-.36035-.17383-.1167-.05518-.23169-.11328-.35132-.16284-.11255-.04663-.22754-.084-.3418-.12525-.13256-.04785-.26367-.09839-.39917-.1394-.10962-.03308-.22094-.057-.3313-.08521-.14233-.0365-.2832-.07592-.42846-.10461-.12134-.02405-.24414-.0376-.36621-.05591-.136-.02039-.27027-.04553-.40845-.059-.2019-.01977-.40454-.02612-.60718-.03064C232.11743,72.00757,232.05981,72,232,72H160a8,8,0,0,0,0,16h52.68555L120,180.68652,29.65723,90.34277a8.00053,8.00053,0,0,0-11.31446,11.31446l96,96a8.00181,8.00181,0,0,0,11.31446,0L224,99.31445V152a8,8,0,0,0,16,0V80.00513A7.97965,7.97965,0,0,0,239.96,79.208Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 80 232 80 232 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "24 96 120 192 232 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 80 232 80 232 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "24 96 120 192 232 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 80 232 80 232 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "24 96 120 192 232 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowElbowRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$O(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowElbowRight.displayName = "ArrowElbowRight";

var renderPathFor$P = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 160 176 208 224 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "32 64 176 64 176 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 160 176 208 224 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "32 64 176 64 176 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M229.65723,154.34326a8.00122,8.00122,0,0,0-11.31446,0L184,188.6864V64a8.00008,8.00008,0,0,0-8-8H32a8,8,0,0,0,0,16H168V188.6864l-34.34277-34.34314a8.00018,8.00018,0,0,0-11.31446,11.31348l48,48c.01612.01611.03418.02936.0503.04529.17138.16882.34912.33123.53564.48413.09424.07757.19385.145.291.21765.11181.08374.22168.17053.33789.24847.11474.07685.23388.14344.35156.21369.10644.06341.21045.13012.31934.18866.12011.06421.24365.11865.36621.17627.11425.054.22656.111.34375.15954.11816.04895.23877.08844.35888.13141.12647.04547.25147.09393.38037.13312.12012.03619.2417.06268.36231.09314.13183.03326.26221.07019.39648.0968.14063.02789.28321.04456.42481.06482.1167.01666.231.03876.34912.05035.26221.02588.52588.03992.78955.03992s.52734-.014.78955-.03992c.11816-.01159.23242-.03369.34912-.05035.1416-.02026.28418-.03693.42481-.06482.13427-.02661.26464-.06354.39648-.0968.12061-.03046.24219-.057.36231-.09314.1289-.03919.2539-.08765.38037-.13312.12011-.043.24072-.08246.35888-.13141.11719-.04858.2295-.10559.34375-.15954.12256-.05762.2461-.11206.36621-.17627.10889-.05854.21289-.12525.31934-.18866.11768-.07025.23682-.13684.35156-.21369.11621-.07794.22608-.16473.33789-.24847.09717-.07263.19678-.14008.291-.21765.18652-.1529.36426-.31531.53564-.48413.01612-.01593.03418-.02918.0503-.04529l48-48A8,8,0,0,0,229.65723,154.34326Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 160 176 208 224 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "32 64 176 64 176 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 160 176 208 224 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "32 64 176 64 176 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 160 176 208 224 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "32 64 176 64 176 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowElbowRightDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$P(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowElbowRightDown.displayName = "ArrowElbowRightDown";

var renderPathFor$Q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 96 176 48 224 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "32 192 176 192 176 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 96 176 48 224 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "32 192 176 192 176 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M229.65723,90.34326l-48-48c-.01612-.01611-.03394-.0293-.05-.04529-.17163-.16882-.34961-.33117-.53589-.48413-.094-.07715-.19312-.14428-.28955-.21655-.11255-.08423-.22266-.17151-.33985-.24976-.113-.07568-.23046-.14123-.34643-.21057-.10816-.06457-.21411-.13244-.32544-.19214-.1167-.06237-.23682-.11523-.356-.17138-.11767-.05591-.23364-.1145-.35449-.16455-.11377-.04712-.22974-.08484-.345-.12635-.1311-.04736-.2605-.09753-.39478-.13806-.11377-.03442-.22949-.05932-.34448-.08862-.13769-.035-.27392-.07336-.4143-.10107-.13038-.02588-.26221-.04078-.39356-.06006-.127-.01868-.252-.04248-.38086-.05494-.23193-.02294-.46509-.03271-.69824-.0354C176.05859,40.00415,176.02979,40,176,40s-.05859.00415-.08838.00439c-.23315.00269-.46631.01246-.69824.0354-.12891.01246-.25391.03626-.38086.05494-.13135.01928-.26318.03418-.39356.06006-.14038.02771-.27661.066-.4143.10107-.115.0293-.23071.0542-.34448.08862-.13428.04053-.26368.0907-.39478.13806-.11523.04151-.2312.07923-.345.12635-.12085.05-.23682.10864-.35449.16455-.11914.05615-.23926.109-.356.17138-.11133.0597-.21728.12757-.32544.19214-.116.06934-.2334.13489-.34643.21057-.11719.07825-.2273.16553-.33985.24976-.09643.07227-.19555.1394-.28955.21655-.18628.153-.36426.31531-.53589.48413-.01611.016-.03393.02918-.05.04529l-48,48a8.00018,8.00018,0,0,0,11.31446,11.31348L168,67.3136V184H32a8,8,0,0,0,0,16H176a8.00008,8.00008,0,0,0,8-8V67.3136l34.34277,34.34314a8.00018,8.00018,0,0,0,11.31446-11.31348Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 96 176 48 224 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "32 192 176 192 176 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 96 176 48 224 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "32 192 176 192 176 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 96 176 48 224 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "32 192 176 192 176 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowElbowRightUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$Q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowElbowRightUp.displayName = "ArrowElbowRightUp";

var renderPathFor$R = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 128 48 80 96 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "192 224 192 80 48 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 128 48 80 96 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 224 192 80 48 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,72H67.31348l34.34375-34.34326A8.00018,8.00018,0,0,0,90.34277,26.34326l-48,48c-.0205.02051-.03759.04321-.05761.064-.16358.167-.32178.33935-.47022.52026-.083.10059-.15527.20654-.23193.31006-.07862.10571-.16065.20862-.23438.31836-.08056.1206-.15088.24585-.22461.36987-.05957.1001-.12207.19751-.17724.30029-.06787.126-.125.25538-.18506.384-.05078.1084-.10547.2146-.15137.32568-.05127.12463-.09326.252-.13867.37842-.04248.11987-.08887.238-.126.36059-.03857.12769-.06738.25757-.09912.38672-.03125.124-.06592.24622-.09131.37244-.02978.15088-.04785.30334-.06933.45544-.01465.10645-.03516.21094-.0459.31861a8.02276,8.02276,0,0,0,0,1.584c.01074.10767.03125.21216.0459.31861.02148.1521.03955.30456.06933.45544.02539.12622.06006.24841.09131.37244.03174.12915.06055.259.09912.38672.03711.12255.0835.24072.126.36059.04541.12647.0874.25379.13867.37842.0459.11108.10059.21728.15137.32568.06006.12866.11719.25806.18506.384.05517.10278.11767.20019.17724.30029.07373.124.14405.24927.22461.36987.07373.10974.15576.21265.23438.31836.07666.10352.14892.20947.23193.31006.14844.18091.30664.35327.47022.52026.02.02076.03711.04346.05761.064l48,48a8.00018,8.00018,0,0,0,11.31446-11.31348L67.31348,88H184V224a8,8,0,0,0,16,0V80A8.00008,8.00008,0,0,0,192,72Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 128 48 80 96 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "192 224 192 80 48 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 128 48 80 96 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "192 224 192 80 48 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "192 224 192 80 48 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 128 48 80 96 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 224 192 80 48 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowElbowUpLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$R(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowElbowUpLeft.displayName = "ArrowElbowUpLeft";

var renderPathFor$S = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 128 208 80 160 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "64 224 64 80 208 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 128 208 80 160 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 224 64 80 208 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M214.18506,85.07251c.083-.10059.15527-.20654.23193-.31006.07862-.10571.16065-.20862.23438-.31836.08056-.1206.15088-.24585.22461-.36987.05957-.1001.12207-.19751.17724-.30029.06787-.126.125-.25538.18506-.384.05078-.1084.10547-.2146.15137-.32568.05127-.12463.09326-.252.13867-.37842.04248-.11987.08887-.238.126-.36059.03857-.12769.06738-.25757.09912-.38672.03125-.124.06592-.24622.09131-.37244.02978-.15088.04785-.30334.06933-.45544.01465-.10645.03516-.21094.0459-.31861a8.02276,8.02276,0,0,0,0-1.584c-.01074-.10767-.03125-.21216-.0459-.31861-.02148-.1521-.03955-.30456-.06933-.45544-.02539-.12622-.06006-.24841-.09131-.37244-.03174-.12915-.06055-.259-.09912-.38672-.03711-.12255-.0835-.24072-.126-.36059-.04541-.12647-.0874-.25379-.13867-.37842-.0459-.11108-.10059-.21728-.15137-.32568-.06006-.12866-.11719-.25806-.18506-.384-.05517-.10278-.11767-.20019-.17724-.30029-.07373-.124-.144-.24927-.22461-.36987-.07373-.10974-.15576-.21265-.23438-.31836-.07666-.10352-.14892-.20947-.23193-.31006-.14844-.18091-.30664-.35327-.47022-.52026-.02-.02076-.03711-.04346-.05761-.064l-48-48a8.00018,8.00018,0,1,0-11.31446,11.31348L188.68652,72H64a8.00008,8.00008,0,0,0-8,8V224a8,8,0,0,0,16,0V88H188.68652l-34.34375,34.34326a8.00018,8.00018,0,0,0,11.31446,11.31348l48-48c.0205-.02051.03759-.04321.05761-.064C213.87842,85.42578,214.03662,85.25342,214.18506,85.07251Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 128 208 80 160 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "64 224 64 80 208 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 128 208 80 160 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "64 224 64 80 208 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 128 208 80 160 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 224 64 80 208 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowElbowUpRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$S(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowElbowUpRight.displayName = "ArrowElbowUpRight";

var renderPathFor$T = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,136l96,96,96-96H176V48a8,8,0,0,0-8-8H88a8,8,0,0,0-8,8v88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,136l96,96,96-96H176V48a8,8,0,0,0-8-8H88a8,8,0,0,0-8,8v88Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M32,136l96,96,96-96H176V48a8,8,0,0,0-8-8H88a8,8,0,0,0-8,8v88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M229.65723,141.65723l-96,96a8.003,8.003,0,0,1-11.31446,0l-96-96A8.00065,8.00065,0,0,1,32,128H72V48A16.01833,16.01833,0,0,1,88,32h80a16.01833,16.01833,0,0,1,16,16v80h40a8.00066,8.00066,0,0,1,5.65723,13.65723Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,136l96,96,96-96H176V48a8,8,0,0,0-8-8H88a8,8,0,0,0-8,8v88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,136l96,96,96-96H176V48a8,8,0,0,0-8-8H88a8,8,0,0,0-8,8v88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,136l96,96,96-96H176V48a8,8,0,0,0-8-8H88a8,8,0,0,0-8,8v88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$T(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatDown.displayName = "ArrowFatDown";

var renderPathFor$U = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120,32,24,128l96,96V176h88a8,8,0,0,0,8-8V88a8,8,0,0,0-8-8H120Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120,32,24,128l96,96V176h88a8,8,0,0,0,8-8V88a8,8,0,0,0-8-8H120Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M120,32,24,128l96,96V176h88a8,8,0,0,0,8-8V88a8,8,0,0,0-8-8H120Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M114.34277,229.65723l-96-96a8.003,8.003,0,0,1,0-11.31446l96-96A8.00065,8.00065,0,0,1,128,32V72h80a16.01833,16.01833,0,0,1,16,16v80a16.01833,16.01833,0,0,1-16,16H128v40a8.00066,8.00066,0,0,1-13.65723,5.65723Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120,32,24,128l96,96V176h88a8,8,0,0,0,8-8V88a8,8,0,0,0-8-8H120Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120,32,24,128l96,96V176h88a8,8,0,0,0,8-8V88a8,8,0,0,0-8-8H120Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120,32,24,128l96,96V176h88a8,8,0,0,0,8-8V88a8,8,0,0,0-8-8H120Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$U(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatLeft.displayName = "ArrowFatLeft";

var renderPathFor$V = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 80 80 80 80 136 32 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 72 80 72 80 136 32 136",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 72 80 72 80 136 32 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M229.65723,141.65723l-96,96a8.003,8.003,0,0,1-11.31446,0l-96-96A8.00065,8.00065,0,0,1,32,128H72V72a8.00039,8.00039,0,0,1,8-8h96a8.00039,8.00039,0,0,1,8,8v56h40a8.00066,8.00066,0,0,1,5.65723,13.65723ZM184,40a8.00039,8.00039,0,0,0-8-8H80a8,8,0,0,0,0,16h96A8.00039,8.00039,0,0,0,184,40Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 72 80 72 80 136 32 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 72 80 72 80 136 32 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 72 80 72 80 136 32 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatLineDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$V(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatLineDown.displayName = "ArrowFatLineDown";

var renderPathFor$W = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 176 176 176 80 120 80 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "176",
        x2: "216",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 184 176 184 80 120 80 120 32",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 184 176 184 80 120 80 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "176",
        x2: "216",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M114.34277,229.65723l-96-96a8.003,8.003,0,0,1,0-11.31446l96-96A8.00065,8.00065,0,0,1,128,32V72h56a8.00039,8.00039,0,0,1,8,8v96a8.00039,8.00039,0,0,1-8,8H128v40a8.00066,8.00066,0,0,1-13.65723,5.65723ZM216,184a8.00039,8.00039,0,0,0,8-8V80a8,8,0,0,0-16,0v96A8.00039,8.00039,0,0,0,216,184Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 184 176 184 80 120 80 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "176",
        x2: "216",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 184 176 184 80 120 80 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "176",
        x2: "216",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 184 176 184 80 120 80 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "176",
        x2: "216",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatLineLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$W(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatLineLeft.displayName = "ArrowFatLineLeft";

var renderPathFor$X = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 80 176 80 80 136 80 136 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "176",
        x2: "40",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 72 176 72 80 136 80 136 32",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 72 176 72 80 136 80 136 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "176",
        x2: "40",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.93848,231.39062A8,8,0,0,1,128,224V184H72a8.00039,8.00039,0,0,1-8-8V80a8.00039,8.00039,0,0,1,8-8h56V32a8.00065,8.00065,0,0,1,13.65723-5.65723l96,96a8.003,8.003,0,0,1,0,11.31446l-96,96A8.002,8.002,0,0,1,132.93848,231.39062ZM48,176V80a8,8,0,0,0-16,0v96a8,8,0,0,0,16,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 72 176 72 80 136 80 136 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "176",
        x2: "40",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 72 176 72 80 136 80 136 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "176",
        x2: "40",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 72 176 72 80 136 80 136 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "176",
        x2: "40",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatLineRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$X(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatLineRight.displayName = "ArrowFatLineRight";

var renderPathFor$Y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 176 80 176 80 120 32 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "216",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 184 80 184 80 120 32 120",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 184 80 184 80 120 32 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "216",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M231.39062,123.06152A8,8,0,0,1,224,128H184v56a8.00039,8.00039,0,0,1-8,8H80a8.00039,8.00039,0,0,1-8-8V128H32a8.00065,8.00065,0,0,1-5.65723-13.65723l96-96a8.003,8.003,0,0,1,11.31446,0l96,96A8.002,8.002,0,0,1,231.39062,123.06152ZM176,208H80a8,8,0,0,0,0,16h96a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 184 80 184 80 120 32 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "216",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 184 80 184 80 120 32 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "216",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 184 80 184 80 120 32 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "216",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatLineUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$Y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatLineUp.displayName = "ArrowFatLineUp";

var renderPathFor$Z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 116 80 116 80 136 32 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "44",
        x2: "80",
        y2: "44",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "80",
        x2: "80",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 104 80 104 80 136 32 136",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 104 80 104 80 136 32 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "72",
        x2: "80",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M229.65674,141.65723l-96,96a8.00182,8.00182,0,0,1-11.31348,0l-96-96A8.0001,8.0001,0,0,1,32,128H72V104a8.00008,8.00008,0,0,1,8-8h96a8.00008,8.00008,0,0,1,8,8v24h40a8.0001,8.0001,0,0,1,5.65674,13.65723ZM184,40a8.00008,8.00008,0,0,0-8-8H80a8,8,0,0,0,0,16h96A8.00008,8.00008,0,0,0,184,40Zm0,32a8.00008,8.00008,0,0,0-8-8H80a8,8,0,0,0,0,16h96A8.00008,8.00008,0,0,0,184,72Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 104 80 104 80 136 32 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "72",
        x2: "80",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 104 80 104 80 136 32 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "72",
        x2: "80",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 136 128 232 224 136 176 136 176 104 80 104 80 136 32 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "72",
        x2: "80",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatLinesDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$Z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatLinesDown.displayName = "ArrowFatLinesDown";

var renderPathFor$_ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 140 176 140 80 120 80 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "212",
        y1: "176",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "176",
        x2: "176",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 152 176 152 80 120 80 120 32",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 152 176 152 80 120 80 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "176",
        x2: "216",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "176",
        x2: "184",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M114.34277,229.65674l-96-96a8.00182,8.00182,0,0,1,0-11.31348l96-96A8.0001,8.0001,0,0,1,128,32V72h24a8.00008,8.00008,0,0,1,8,8v96a8.00008,8.00008,0,0,1-8,8H128v40a8.0001,8.0001,0,0,1-13.65723,5.65674ZM216,184a8.00008,8.00008,0,0,0,8-8V80a8,8,0,0,0-16,0v96A8.00008,8.00008,0,0,0,216,184Zm-32,0a8.00008,8.00008,0,0,0,8-8V80a8,8,0,0,0-16,0v96A8.00008,8.00008,0,0,0,184,184Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 152 176 152 80 120 80 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "176",
        x2: "216",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "176",
        x2: "184",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 152 176 152 80 120 80 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "176",
        x2: "216",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "176",
        x2: "184",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 24 128 120 224 120 176 152 176 152 80 120 80 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "176",
        x2: "216",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "176",
        x2: "184",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatLinesLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$_(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatLinesLeft.displayName = "ArrowFatLinesLeft";

var renderPathFor$$ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 116 176 116 80 136 80 136 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "44",
        y1: "176",
        x2: "44",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "176",
        x2: "80",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 104 176 104 80 136 80 136 32",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 104 176 104 80 136 80 136 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "176",
        x2: "40",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "176",
        x2: "72",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.93848,231.39111A8.00015,8.00015,0,0,1,128,224V184H104a8.00008,8.00008,0,0,1-8-8V80a8.00008,8.00008,0,0,1,8-8h24V32a8.0001,8.0001,0,0,1,13.65723-5.65674l96,96a8.00182,8.00182,0,0,1,0,11.31348l-96,96A8.00061,8.00061,0,0,1,132.93848,231.39111ZM48,176V80a8,8,0,0,0-16,0v96a8,8,0,0,0,16,0Zm32,0V80a8,8,0,0,0-16,0v96a8,8,0,0,0,16,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 104 176 104 80 136 80 136 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "176",
        x2: "40",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "176",
        x2: "72",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 104 176 104 80 136 80 136 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "176",
        x2: "40",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "176",
        x2: "72",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "136 32 232 128 136 224 136 176 104 176 104 80 136 80 136 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "176",
        x2: "40",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "176",
        x2: "72",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatLinesRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$$(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatLinesRight.displayName = "ArrowFatLinesRight";

var renderPathFor$10 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 140 80 140 80 120 32 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "212",
        x2: "80",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "176",
        x2: "80",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 152 80 152 80 120 32 120",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 152 80 152 80 120 32 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "216",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "184",
        x2: "80",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M231.39111,123.06152A8.00015,8.00015,0,0,1,224,128H184v24a8.00008,8.00008,0,0,1-8,8H80a8.00008,8.00008,0,0,1-8-8V128H32a8.0001,8.0001,0,0,1-5.65674-13.65723l96-96a8.00182,8.00182,0,0,1,11.31348,0l96,96A8.00061,8.00061,0,0,1,231.39111,123.06152ZM176,208H80a8,8,0,0,0,0,16h96a8,8,0,0,0,0-16Zm0-32H80a8,8,0,0,0,0,16h96a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 152 80 152 80 120 32 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "216",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "184",
        x2: "80",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 152 80 152 80 120 32 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "216",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "184",
        x2: "80",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 120 128 24 224 120 176 120 176 152 80 152 80 120 32 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "216",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "184",
        x2: "80",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatLinesUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$10(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatLinesUp.displayName = "ArrowFatLinesUp";

var renderPathFor$11 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,32l96,96-96,96V176H48a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8h88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,32l96,96-96,96V176H48a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8h88Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M136,32l96,96-96,96V176H48a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8h88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.93848,231.39062A8,8,0,0,1,128,224V184H48a16.01833,16.01833,0,0,1-16-16V88A16.01833,16.01833,0,0,1,48,72h80V32a8.00065,8.00065,0,0,1,13.65723-5.65723l96,96a8.003,8.003,0,0,1,0,11.31446l-96,96A8.002,8.002,0,0,1,132.93848,231.39062Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,32l96,96-96,96V176H48a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8h88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,32l96,96-96,96V176H48a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8h88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,32l96,96-96,96V176H48a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8h88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$11(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatRight.displayName = "ArrowFatRight";

var renderPathFor$12 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,120l96-96,96,96H176v88a8,8,0,0,1-8,8H88a8,8,0,0,1-8-8V120Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,120l96-96,96,96H176v88a8,8,0,0,1-8,8H88a8,8,0,0,1-8-8V120Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M32,120l96-96,96,96H176v88a8,8,0,0,1-8,8H88a8,8,0,0,1-8-8V120Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M231.39062,123.06152A8,8,0,0,1,224,128H184v80a16.01833,16.01833,0,0,1-16,16H88a16.01833,16.01833,0,0,1-16-16V128H32a8.00065,8.00065,0,0,1-5.65723-13.65723l96-96a8.003,8.003,0,0,1,11.31446,0l96,96A8.002,8.002,0,0,1,231.39062,123.06152Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,120l96-96,96,96H176v88a8,8,0,0,1-8,8H88a8,8,0,0,1-8-8V120Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,120l96-96,96,96H176v88a8,8,0,0,1-8,8H88a8,8,0,0,1-8-8V120Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,120l96-96,96,96H176v88a8,8,0,0,1-8,8H88a8,8,0,0,1-8-8V120Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowFatUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$12(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowFatUp.displayName = "ArrowFatUp";

var renderPathFor$13 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "112 56 40 128 112 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "112 56 40 128 112 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M117.65723,205.65674a8.00182,8.00182,0,0,0,0-11.31348L59.31348,136H216a8,8,0,0,0,0-16H59.31348l58.34375-58.34326a8.00018,8.00018,0,0,0-11.31446-11.31348l-72,72c-.02612.02588-.0476.05469-.07324.08106-.158.16211-.31128.32861-.45508.50341-.08032.09766-.15039.20118-.22534.30176-.081.1084-.16528.21485-.241.32764-.07788.11621-.1455.2373-.21679.35693-.06226.10449-.12793.20655-.18579.31446-.06421.12011-.1189.24414-.17676.36669-.054.11426-.11084.22657-.15942.34327-.04883.11816-.08838.23925-.13135.35937-.04541.126-.09375.251-.13282.37988-.03613.11963-.06274.24122-.09326.36231-.0332.13183-.07031.26269-.09692.397-.02759.13965-.04419.28028-.06421.42041-.01685.11817-.03931.23389-.051.353C32.01392,127.47314,32,127.73633,32,128s.01392.52686.03979.78955c.01172.11914.03418.23486.051.353.02.14013.03662.28076.06421.42041.02661.13428.06372.26513.09692.397.03052.12109.05713.24268.09326.36231.03907.1289.08741.2539.13282.37988.043.12012.08252.24121.13135.35937.04858.1167.10546.229.15942.34327.05786.12255.11255.24658.17676.36669.05786.10791.12353.21.18579.31446.07129.11963.13891.24072.21679.35693.07569.11279.15992.21924.241.32764.075.10058.145.2041.22534.30176.14624.17822.30225.34765.46338.51269.02271.023.04175.04883.06494.07178l72,72A8.00034,8.00034,0,0,0,117.65723,205.65674Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "112 56 40 128 112 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "112 56 40 128 112 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "112 56 40 128 112 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$13(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowLeft.displayName = "ArrowLeft";

var renderPathFor$14 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "23.99627",
        x2: "128",
        y2: "175.99627",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "56 103.996 128 175.996 200 103.996",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "215.99627",
        x2: "208",
        y2: "215.99627",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "23.99627",
        x2: "128",
        y2: "183.99627",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 111.996 128 183.996 200 111.996",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "215.99627",
        x2: "208",
        y2: "215.99627",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M122.34082,189.65039q.28125.28125.59033.53369c.08545.07031.17578.13111.26367.19727.12061.09082.23926.18432.36524.26855.10937.073.22265.13623.335.20337.11133.0669.2207.137.33545.19849.11621.062.23584.11474.35449.17065.11816.05591.23389.1145.355.1648.11524.0476.23291.08593.3501.12817.12939.04663.25683.096.38916.136.11767.03564.23682.06152.35547.09155.13379.03369.26611.071.40283.09814.13916.02759.27979.04419.41992.06421.11817.01685.23389.03931.353.051.26269.02588.52588.03979.78955.03979s.52686-.01391.78955-.03979c.11914-.01172.23486-.03418.353-.051.14013-.02.28076-.03662.41992-.06421.13672-.0271.269-.06445.40283-.09814.11865-.03.23779-.05591.35547-.09155.13232-.04.25977-.08936.38916-.136.11719-.04224.23486-.08057.3501-.12817.12109-.0503.23681-.10889.355-.1648.11865-.05591.23828-.10864.35449-.17065.11475-.06153.22412-.13159.33545-.19849.11231-.06714.22559-.13037.335-.20337.126-.08423.24463-.17773.36524-.26855.08789-.06616.17822-.127.26367-.19727.20556-.16846.40332-.34643.59131-.53442l71.99658-71.99683a7.99983,7.99983,0,0,0-11.31348-11.31347L136,164.68262V23.99609a8,8,0,0,0-16,0V164.68262L61.65674,106.33936a7.99983,7.99983,0,0,0-11.31348,11.31347Z"
      }), React__default.createElement("path", {
        d: "M208,207.99609H48a8,8,0,1,0,0,16H208a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "23.99627",
        x2: "128",
        y2: "183.99627",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "56 111.996 128 183.996 200 111.996",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "215.99627",
        x2: "208",
        y2: "215.99627",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "23.99627",
        x2: "128",
        y2: "183.99627",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "56 111.996 128 183.996 200 111.996",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "215.99627",
        x2: "208",
        y2: "215.99627",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "23.99627",
        x2: "128",
        y2: "183.99627",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 111.996 128 183.996 200 111.996",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "215.99627",
        x2: "208",
        y2: "215.99627",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowLineDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$14(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowLineDown.displayName = "ArrowLineDown";

var renderPathFor$15 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "88",
        x2: "64",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "64 104 64 200 160 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "40",
        x2: "48",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "88",
        x2: "64",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 104 64 200 160 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "40",
        x2: "48",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M170.34277,82.34277,72,180.68579V104a8,8,0,0,0-16,0v96c0,.26349.01416.52686.04.78937.01123.118.03369.23248.05029.34887.02.142.03662.28437.06494.4253.02588.13238.0625.2608.09522.39081.03076.1231.0581.24688.09472.36877.03858.1272.08643.25.13135.37439.04346.12189.0835.24457.1333.36462.04737.11481.10352.22486.15625.33686.0586.12518.11426.25134.18018.3739.05566.10406.11963.20288.17969.30414.07324.1231.14257.24743.22314.36737.07227.108.15283.20916.23047.31329.07812.10541.15186.2132.23584.31555.13281.16193.27588.31507.4209.46594.03711.03852.06885.08008.10644.11805.03858.03808.08008.07.11914.10717.15039.145.30371.28772.46534.4206.10009.0824.20556.15436.30908.23114.10644.079.21.1615.32031.23529.11768.07879.23975.14722.36035.21911.10352.06159.20459.12665.311.18366.1206.06464.24463.11938.36816.17737.11377.05371.22559.11053.34229.15893.11816.04895.23925.08844.35937.13141.126.04541.251.09387.37988.133.11963.03613.24122.06262.36231.09308.13184.03338.26269.07037.397.097.13965.02765.28028.044.42041.06415.11817.01691.23389.03925.353.051C63.47314,207.986,63.73633,208,64,208h96a8,8,0,0,0,0-16H83.31445l98.34278-98.34277a8.00053,8.00053,0,0,0-11.31446-11.31446Z"
      }), React__default.createElement("path", {
        d: "M208,32H48a8,8,0,0,0,0,16H208a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "88",
        x2: "64",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "64 104 64 200 160 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "40",
        x2: "48",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "88",
        x2: "64",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "64 104 64 200 160 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "40",
        x2: "48",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "88",
        x2: "64",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 104 64 200 160 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "40",
        x2: "48",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowLineDownLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$15(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowLineDownLeft.displayName = "ArrowLineDownLeft";

var renderPathFor$16 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "192",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "192 104 192 200 96 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "192",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 104 192 200 96 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M192,96a8.00008,8.00008,0,0,0-8,8v76.68585L85.65723,82.34326A8.00018,8.00018,0,1,0,74.34277,93.65674L172.686,192H96a8,8,0,0,0,0,16h96c.26367,0,.52686-.014.78955-.03986.11914-.01171.23486-.03405.353-.051.14013-.02014.28076-.0365.42041-.06415.13428-.02667.26513-.06366.397-.097.12109-.03046.24268-.057.36231-.09308.1289-.039.25341-.08741.37939-.13269.12012-.04309.2417-.08271.35986-.13178.1167-.04828.228-.105.3418-.15851.12354-.058.24756-.113.36865-.17773.10645-.057.20752-.12207.311-.18366.1206-.07189.24267-.14032.36035-.21911.11035-.07379.21387-.15625.32031-.23529.10352-.07678.209-.14874.30908-.23114.16455-.13513.32032-.28028.47364-.42792.03613-.03473.07519-.06433.11084-.09985.03466-.035.064-.07337.09814-.10877.148-.15375.29346-.31006.4292-.47522.084-.10235.15772-.21014.23584-.31555.07764-.10413.1582-.20532.23047-.31329.08057-.11994.1499-.24427.22314-.36737.06006-.10126.124-.20008.17969-.30414.06592-.12256.12158-.24872.18018-.3739.05273-.112.10888-.222.15625-.33686.0498-.12.08984-.24273.1333-.36462.04492-.12439.09277-.24719.13135-.37439.03662-.12189.064-.24567.09472-.36877.03272-.13.06934-.25843.09522-.39081.02832-.14093.04492-.28327.06494-.4253.0166-.11639.03906-.23089.05029-.34887.02588-.26251.04-.52588.04-.78937V104A8.00008,8.00008,0,0,0,192,96Z"
      }), React__default.createElement("path", {
        d: "M208,32H48a8,8,0,0,0,0,16H208a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "192",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "192 104 192 200 96 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "192",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "192 104 192 200 96 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "192",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 104 192 200 96 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowLineDownRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$16(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowLineDownRight.displayName = "ArrowLineDownRight";

var renderPathFor$17 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "232.00373",
        y1: "128",
        x2: "80.00373",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "152.004 56 80.004 128 152.004 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.00373",
        y1: "48",
        x2: "40.00373",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "232.00373",
        y1: "128",
        x2: "72.00373",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144.004 56 72.004 128 144.004 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00373",
        y1: "48",
        x2: "40.00373",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M232.00391,120H91.31738l58.34278-58.34326a7.99984,7.99984,0,1,0-11.31348-11.31348L66.34961,122.34058q-.28125.28125-.53369.59008c-.07129.087-.1333.179-.20069.26831-.08984.11927-.18212.23633-.26513.3606-.07373.11047-.1377.2251-.20557.33838-.06592.11035-.13525.21838-.19629.332-.0625.11682-.11523.23682-.17138.356-.05567.11767-.11426.2334-.16456.35425-.04736.11523-.08593.23291-.12793.34985-.04638.129-.0957.25659-.13574.38867-.03564.11792-.06152.23755-.09179.35657-.0337.13367-.07129.26575-.09815.402-.02734.13769-.04346.27685-.06348.41552-.01709.11963-.03955.23731-.05175.35852q-.03736.38234-.03858.76648l-.001.02222.001.02222q.00074.38379.03858.76648c.0122.12121.03466.23889.05175.35852.02.13867.03614.27783.06348.41552.02686.13623.06445.26831.09815.402.03027.119.05615.23865.09179.35657.04.13208.08936.25964.13574.38867.042.11694.08057.23462.12793.34985.0503.12085.10889.23658.16456.35425.05615.11914.10888.23914.17138.356.061.11365.13037.22168.19629.332.06787.11328.13184.22791.20557.33838.083.12427.17529.24133.26513.3606.06739.08935.1294.18127.20069.26831q.25267.308.53369.59008l71.99707,71.99732a7.99984,7.99984,0,1,0,11.31348-11.31348L91.31738,136H232.00391a8,8,0,1,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M40.00391,40a7.99977,7.99977,0,0,0-8,8V208a8,8,0,0,0,16,0V48A8.00009,8.00009,0,0,0,40.00391,40Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "232.00373",
        y1: "128",
        x2: "72.00373",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "144.004 56 72.004 128 144.004 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.00373",
        y1: "48",
        x2: "40.00373",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "232.00373",
        y1: "128",
        x2: "72.00373",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "144.004 56 72.004 128 144.004 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.00373",
        y1: "48",
        x2: "40.00373",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "232.00373",
        y1: "128",
        x2: "72.00373",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144.004 56 72.004 128 144.004 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00373",
        y1: "48",
        x2: "40.00373",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowLineLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$17(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowLineLeft.displayName = "ArrowLineLeft";

var renderPathFor$18 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "23.99627",
        y1: "128",
        x2: "175.99627",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "103.996 200 175.996 128 103.996 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "215.99627",
        y1: "208",
        x2: "215.99627",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "23.99627",
        y1: "128",
        x2: "183.99627",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "111.996 200 183.996 128 111.996 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "215.99627",
        y1: "208",
        x2: "215.99627",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M190.6499,132.44043c.07373-.11047.1377-.2251.20557-.33838.06592-.11035.13525-.21838.19629-.332.0625-.11682.11523-.23682.17138-.356.05567-.11767.11426-.2334.16456-.35425.04736-.11523.08593-.23291.12792-.34985.04639-.129.09571-.25659.13575-.38867.03564-.11792.06152-.23755.09179-.35657.0337-.13367.07129-.26575.09815-.402.02734-.13769.04346-.27685.06348-.41552.01708-.11963.03955-.23731.05175-.35852q.03736-.38234.03858-.76648l.001-.02222-.001-.02222q-.00073-.38379-.03858-.76648c-.0122-.12121-.03467-.23889-.05175-.35852-.02-.13867-.03614-.27783-.06348-.41552-.02686-.13623-.06445-.26831-.09815-.402-.03027-.119-.05615-.23865-.09179-.35657-.04-.13208-.08936-.25964-.13575-.38867-.042-.11694-.08056-.23462-.12792-.34985-.0503-.12085-.10889-.23658-.16456-.35425-.05615-.11914-.10888-.23914-.17138-.356-.061-.11365-.13037-.22168-.19629-.332-.06787-.11328-.13184-.22791-.20557-.33838-.083-.12427-.17529-.24133-.26513-.3606-.06739-.08935-.1294-.18127-.20069-.26831a7.95171,7.95171,0,0,0-.53418-.59057L117.65332,50.34326a7.99984,7.99984,0,0,0-11.31348,11.31348L164.68262,120H23.99609a8,8,0,1,0,0,16H164.68262l-58.34278,58.34326a7.99984,7.99984,0,1,0,11.31348,11.31348l71.99658-71.99683a7.95171,7.95171,0,0,0,.53418-.59057c.07129-.087.1333-.179.20069-.26831C190.47461,132.68176,190.56689,132.5647,190.6499,132.44043Z"
      }), React__default.createElement("path", {
        d: "M215.99609,40a8.00008,8.00008,0,0,0-8,8V208a8,8,0,0,0,16,0V48A7.99977,7.99977,0,0,0,215.99609,40Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "23.99627",
        y1: "128",
        x2: "183.99627",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "111.996 200 183.996 128 111.996 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "215.99627",
        y1: "208",
        x2: "215.99627",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "23.99627",
        y1: "128",
        x2: "183.99627",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "111.996 200 183.996 128 111.996 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "215.99627",
        y1: "208",
        x2: "215.99627",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "23.99627",
        y1: "128",
        x2: "183.99627",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "111.996 200 183.996 128 111.996 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "215.99627",
        y1: "208",
        x2: "215.99627",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowLineRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$18(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowLineRight.displayName = "ArrowLineRight";

var renderPathFor$19 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "232.00373",
        x2: "128",
        y2: "80.00373",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "56 152.004 128 80.004 200 152.004",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40.00373",
        x2: "208",
        y2: "40.00373",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "232.00373",
        x2: "128",
        y2: "72.00373",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 144.004 128 72.004 200 144.004",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40.00373",
        x2: "208",
        y2: "40.00373",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M133.66016,66.35034c-.188-.188-.38575-.366-.59131-.53442-.08545-.07031-.17578-.13111-.26367-.19727-.12061-.09082-.23926-.18432-.36524-.26855-.10889-.07276-.22168-.13574-.33349-.20239-.11182-.06739-.22168-.1377-.33741-.19971-.11474-.061-.23242-.11279-.34912-.168-.11963-.05689-.23779-.11646-.36133-.16773-.1123-.04638-.22705-.08374-.3413-.125-.13184-.0476-.26221-.09814-.39747-.13891-.11377-.03443-.22851-.05933-.34326-.08838-.13818-.03516-.2749-.07349-.416-.10132-.12989-.02588-.26123-.04077-.39258-.06006-.12695-.01855-.25244-.04248-.38135-.05493-.23193-.02295-.46484-.03271-.69824-.0354-.02979-.00024-.05859-.00439-.08838-.00439s-.05859.00415-.08838.00439c-.2334.00269-.46631.01245-.69824.0354-.12891.01245-.2544.03638-.38135.05493-.13135.01929-.26269.03418-.39258.06006-.14111.02783-.27783.06616-.416.10132-.11475.02905-.22949.054-.34326.08838-.13526.04077-.26563.09131-.39747.13891-.11425.04126-.229.07862-.3413.125-.12354.05127-.2417.11084-.36133.16773-.1167.05518-.23438.10693-.34912.168-.11573.062-.22559.13232-.33741.19971-.11181.06665-.2246.12963-.33349.20239-.126.08423-.24463.17773-.36524.26855-.08789.06616-.17822.127-.26367.19727q-.30834.25267-.59033.53369L50.34326,138.34717a7.99983,7.99983,0,0,0,11.31348,11.31347L120,91.31738V232.00391a8,8,0,1,0,16,0V91.31738l58.34326,58.34326a7.99983,7.99983,0,1,0,11.31348-11.31347Z"
      }), React__default.createElement("path", {
        d: "M208,32.00391H48a8,8,0,0,0,0,16H208a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "232.00373",
        x2: "128",
        y2: "72.00373",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "56 144.004 128 72.004 200 144.004",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40.00373",
        x2: "208",
        y2: "40.00373",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "232.00373",
        x2: "128",
        y2: "72.00373",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "56 144.004 128 72.004 200 144.004",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40.00373",
        x2: "208",
        y2: "40.00373",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "232.00373",
        x2: "128",
        y2: "72.00373",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 144.004 128 72.004 200 144.004",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40.00373",
        x2: "208",
        y2: "40.00373",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowLineUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$19(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowLineUp.displayName = "ArrowLineUp";

var renderPathFor$1a = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "168",
        x2: "64",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "64 152 64 56 160 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "216",
        x2: "48",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "168",
        x2: "64",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 152 64 56 160 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "216",
        x2: "48",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M64,160a8.00008,8.00008,0,0,0,8-8V75.31372l98.34277,98.343a8.00018,8.00018,0,1,0,11.31446-11.31348L83.31348,64H160a8,8,0,0,0,0-16H64c-.02979,0-.05859.00415-.08838.00446-.2334.00256-.46631.01245-.69824.03527-.12891.01264-.2544.03632-.38135.055-.13086.01928-.26269.03418-.39258.05993-.14111.0279-.27783.06635-.416.1015-.11426.02912-.22949.054-.34326.08826-.13526.04089-.26563.09137-.39747.1391-.11425.04114-.229.07855-.3413.125-.123.05084-.24073.11047-.36036.16718-.11718.05542-.23535.1073-.35009.16864s-.22315.13079-.33448.19732c-.11279.06763-.227.13135-.33691.205-.12353.08234-.23975.17389-.35791.26282-.09033.068-.18311.13067-.27148.203-.20411.16747-.40039.34411-.58692.53069l-.00049.00006-.00293.0033c-.18505.1853-.36035.38025-.52636.58288-.07618.09217-.14161.1894-.21289.28406-.08545.1142-.17383.22595-.25342.34473-.07617.11395-.14209.23224-.21192.34912-.064.10693-.13134.21142-.18994.32153-.064.11933-.11816.24213-.17529.364-.0542.115-.11182.22809-.16065.346-.04882.11817-.08837.23883-.13134.35877-.04541.12622-.09375.25073-.13282.37976-.03662.12073-.06347.24341-.09423.36535-.03272.131-.06934.26044-.09571.39393-.02783.14038-.04443.28216-.06494.42352-.0166.11694-.03906.232-.05029.35052-.02588.26245-.04.52582-.04.78931v96A8.00008,8.00008,0,0,0,64,160Z"
      }), React__default.createElement("path", {
        d: "M208,208H48a8,8,0,0,0,0,16H208a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "168",
        x2: "64",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "64 152 64 56 160 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "216",
        x2: "48",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "168",
        x2: "64",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "64 152 64 56 160 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "216",
        x2: "48",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "168",
        x2: "64",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 152 64 56 160 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "216",
        x2: "48",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowLineUpLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1a(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowLineUpLeft.displayName = "ArrowLineUpLeft";

var renderPathFor$1b = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "168",
        x2: "192",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "192 152 192 56 96 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "216",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "168",
        x2: "192",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 152 192 56 96 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "216",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M80,176a7.977,7.977,0,0,0,5.65723-2.34326L184,75.31372V152a8,8,0,0,0,16,0V56c0-.26349-.01416-.52686-.04-.78931-.01123-.11853-.03369-.23358-.05029-.35052-.02051-.14136-.03711-.28314-.06494-.42352-.02637-.13349-.063-.26294-.09571-.39393-.03076-.12194-.05761-.24462-.09423-.36535-.03907-.129-.08741-.25354-.13282-.37976-.043-.11994-.08252-.2406-.13135-.35877-.04882-.11792-.10644-.231-.16064-.346-.05713-.12182-.11133-.24462-.17529-.364-.0586-.11011-.126-.2146-.18994-.32153-.06983-.11688-.13575-.23517-.21192-.34912-.07959-.11878-.168-.23053-.25342-.34473-.07129-.09466-.13671-.19189-.21289-.28406a8.04368,8.04368,0,0,0-1.1167-1.11694c-.08837-.07233-.18115-.135-.27148-.203-.11816-.08893-.23438-.18048-.35791-.26282-.10986-.07367-.22412-.13739-.33691-.205-.11133-.06653-.21973-.13611-.33448-.19732-.11474-.06147-.2334-.11353-.35058-.169-.11914-.05658-.23682-.116-.35938-.16675-.11279-.04663-.228-.0841-.34228-.12536-.13184-.04767-.26221-.098-.397-.1388-.11377-.0343-.229-.05914-.34326-.08826-.13818-.03515-.2749-.0736-.416-.1015-.12989-.02575-.26172-.04065-.39258-.05993-.12695-.01868-.25244-.04236-.38135-.055-.23193-.02282-.46484-.03271-.69824-.03527C192.05859,48.00415,192.02979,48,192,48H96a8,8,0,0,0,0,16h76.68652L74.34277,162.34326A8,8,0,0,0,80,176Z"
      }), React__default.createElement("path", {
        d: "M208,208H48a8,8,0,0,0,0,16H208a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "168",
        x2: "192",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "192 152 192 56 96 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "216",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "168",
        x2: "192",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "192 152 192 56 96 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "216",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "168",
        x2: "192",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 152 192 56 96 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "216",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowLineUpRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1b(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowLineUpRight.displayName = "ArrowLineUpRight";

var renderPathFor$1c = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "144 56 216 128 144 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 56 216 128 144 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M138.34277,205.65674a8.00182,8.00182,0,0,1,0-11.31348L196.68652,136H40a8,8,0,0,1,0-16H196.68652L138.34277,61.65674a8.00018,8.00018,0,1,1,11.31446-11.31348l72,72c.02612.02588.0476.05469.07324.08106.158.16211.31128.32861.45508.50341.08032.09766.15039.20118.22534.30176.08105.1084.16528.21485.241.32764.07788.11621.1455.2373.21679.35693.06226.10449.12793.20655.18579.31446.06421.12011.1189.24414.17676.36669.054.11426.11084.22657.15942.34327.04883.11816.08838.23925.13135.35937.04541.126.09375.251.13282.37988.03613.11963.06274.24122.09326.36231.0332.13184.07031.26269.09692.397.02759.13965.04419.28028.06421.42041.01685.11817.03931.23389.051.353.02587.26269.03979.52588.03979.78955s-.01392.52686-.03979.78955c-.01172.11914-.03418.23486-.051.353-.02.14013-.03662.28076-.06421.42041-.02661.13428-.06372.26514-.09692.397-.03052.12109-.05713.24268-.09326.36231-.03907.1289-.08741.2539-.13282.37988-.043.12012-.08252.24121-.13135.35937-.04858.1167-.10546.229-.15942.34327-.05786.12255-.11255.24658-.17676.36669-.05786.10791-.12353.21-.18579.31446-.07129.11963-.13891.24072-.21679.35693-.07569.11279-.15992.21924-.241.32764-.075.10058-.145.2041-.22534.30176-.14624.17822-.30225.34765-.46338.51269-.02271.023-.04175.04883-.06494.07178l-72,72A8.00034,8.00034,0,0,1,138.34277,205.65674Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "144 56 216 128 144 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "144 56 216 128 144 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 56 216 128 144 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1c(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowRight.displayName = "ArrowRight";

var renderPathFor$1d = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 134.059 128 168 161.941 134.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 134.059 128 168 161.941 134.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99414,32h-160a16.01583,16.01583,0,0,0-16,16V208a16.01583,16.01583,0,0,0,16,16h160a16.01582,16.01582,0,0,0,16-16V48A16.01582,16.01582,0,0,0,207.99414,32ZM167.60352,139.71875l-33.94336,33.92773a8.02367,8.02367,0,0,1-11.332,0L88.40039,139.71875a7.99915,7.99915,0,0,1,11.3125-11.3125l20.28125,20.28125V88a8,8,0,1,1,16,0v60.69238L156.291,128.40625a7.99915,7.99915,0,0,1,11.3125,11.3125Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 134.059 128 168 161.941 134.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 134.059 128 168 161.941 134.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 134.059 128 168 161.941 134.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowSquareDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1d(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowSquareDown.displayName = "ArrowSquareDown";

var renderPathFor$1e = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "148 156 100 156 100 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "100",
        x2: "100",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "148 156 100 156 100 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "100",
        x2: "100",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,208V48a16.01833,16.01833,0,0,0-16-16H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16H208A16.01833,16.01833,0,0,0,224,208ZM161.65674,105.65723,119.314,148H148a8,8,0,0,1,0,16H100c-.05981,0-.11768-.00781-.17725-.00879-.20251-.00488-.405-.01123-.60693-.03076-.13867-.01367-.27344-.03857-.41-.05908-.12171-.01856-.24366-.03174-.36451-.05567-.14636-.02881-.2882-.06884-.43151-.10547-.10938-.02783-.21949-.05175-.32789-.084-.13732-.042-.27014-.09277-.40429-.1416-.11231-.04053-.22547-.07715-.33618-.123-.12281-.05078-.24073-.11035-.36036-.167-.1173-.05566-.23559-.10742-.35058-.169-.11231-.06054-.219-.1289-.32813-.19384-.11523-.06885-.23181-.13428-.34423-.20948-.1167-.07812-.22669-.165-.339-.249-.09681-.07227-.19629-.13965-.29053-.21728-.1825-.14991-.35657-.30909-.525-.47413-.01953-.01953-.041-.03515-.0603-.05468-.01672-.01661-.03052-.03516-.04712-.05225-.168-.1709-.32959-.34766-.48169-.53271-.08007-.09766-.14966-.2002-.22436-.3003-.0813-.10888-.166-.21582-.242-.3291-.07788-.11621-.1455-.2373-.21655-.35644-.0625-.105-.12829-.207-.186-.315-.06482-.12109-.11988-.2456-.178-.36914-.05322-.11328-.10987-.22461-.158-.34033-.04956-.11963-.0896-.24219-.13318-.36377-.04468-.125-.09253-.24756-.13123-.375-.0371-.123-.06433-.24756-.09545-.37158-.03235-.12891-.06861-.25635-.09449-.38721-.02881-.145-.04614-.2915-.06677-.4375-.01587-.1123-.03747-.22265-.04858-.33642-.026-.26367-.03992-.52832-.03992-.793V108a8,8,0,0,1,16,0v28.686l42.34326-42.34327a8.00018,8.00018,0,1,1,11.31348,11.31446Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "148 156 100 156 100 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "100",
        x2: "100",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "148 156 100 156 100 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "100",
        x2: "100",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "148 156 100 156 100 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "100",
        x2: "100",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowSquareDownLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1e(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowSquareDownLeft.displayName = "ArrowSquareDownLeft";

var renderPathFor$1f = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "108 156 156 156 156 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "100",
        x2: "156",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "108 156 156 156 156 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "100",
        x2: "156",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,224H208a16.01833,16.01833,0,0,0,16-16V48a16.01833,16.01833,0,0,0-16-16H48A16.01833,16.01833,0,0,0,32,48V208A16.01833,16.01833,0,0,0,48,224ZM94.34326,94.34277a8.00063,8.00063,0,0,1,11.31348,0L148,136.686V108a8,8,0,0,1,16,0v47.99756c0,.26465-.01392.5293-.03992.793-.01111.11377-.03271.22412-.04858.33642-.02063.146-.038.29248-.06677.4375-.02588.13086-.06214.2583-.09449.38721-.03112.124-.05835.24854-.09545.37158-.0387.12744-.08655.25-.13123.375-.04358.12158-.08362.24414-.13318.36377-.04809.11572-.10474.22705-.158.34033-.0581.12354-.11316.248-.178.36914-.05774.10791-.12353.21-.186.315-.07105.11914-.13867.24023-.21655.35644-.07593.11328-.16065.22022-.242.3291-.0747.1001-.14429.20264-.22436.3003-.1521.185-.31372.36181-.48169.53271-.0166.01709-.0304.03564-.04712.05225-.01929.01953-.04077.03515-.0603.05468-.16846.165-.34253.32422-.525.47413-.09424.07763-.19372.145-.29053.21728-.1123.084-.22229.1709-.339.249-.11242.0752-.229.14063-.34423.20948-.10913.06494-.21582.1333-.32813.19384-.115.06153-.23328.11329-.35058.169-.11963.05664-.23755.11621-.36036.167-.11071.0459-.22387.08252-.33618.123-.13415.04883-.267.09961-.40429.1416-.1084.03223-.21851.05615-.32789.084-.14331.03663-.28515.07666-.43151.10547-.12085.02393-.2428.03711-.36451.05567-.13659.02051-.27136.04541-.41.05908-.2019.01953-.40442.02588-.60693.03076-.05957.001-.11744.00879-.17725.00879H108a8,8,0,0,1,0-16h28.686L94.34326,105.65723A8.00034,8.00034,0,0,1,94.34326,94.34277Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "108 156 156 156 156 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "100",
        x2: "156",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "108 156 156 156 156 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "100",
        x2: "156",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "108 156 156 156 156 108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "100",
        x2: "156",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowSquareDownRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1f(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowSquareDownRight.displayName = "ArrowSquareDownRight";

var renderPathFor$1g = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "121.941 94.059 88 128 121.941 161.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "128",
        x2: "88",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "121.941 94.059 88 128 121.941 161.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "128",
        x2: "88",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,207.99414v-160a16.01583,16.01583,0,0,0-16-16H48a16.01583,16.01583,0,0,0-16,16v160a16.01582,16.01582,0,0,0,16,16H208A16.01582,16.01582,0,0,0,224,207.99414ZM116.28125,167.60352,82.35352,133.66016a8.02367,8.02367,0,0,1,0-11.332l33.92773-33.92773a7.99915,7.99915,0,0,1,11.3125,11.3125L107.3125,119.99414H168a8,8,0,1,1,0,16H107.30762L127.59375,156.291a7.99915,7.99915,0,0,1-11.3125,11.3125Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "121.941 94.059 88 128 121.941 161.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "128",
        x2: "88",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "121.941 94.059 88 128 121.941 161.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "128",
        x2: "88",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "121.941 94.059 88 128 121.941 161.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "128",
        x2: "88",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowSquareLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1g(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowSquareLeft.displayName = "ArrowSquareLeft";

var renderPathFor$1h = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "134.059 94.059 168 128 134.059 161.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "134.059 94.059 168 128 134.059 161.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,223.99414H208a16.01582,16.01582,0,0,0,16-16v-160a16.01583,16.01583,0,0,0-16-16H48a16.01583,16.01583,0,0,0-16,16v160A16.01582,16.01582,0,0,0,48,223.99414Zm80.40625-56.39062a7.99708,7.99708,0,0,1,0-11.3125l20.28613-20.29688H88a8,8,0,0,1,0-16h60.6875L128.40625,99.71289a7.99915,7.99915,0,0,1,11.3125-11.3125l33.92773,33.92773a8.02367,8.02367,0,0,1,0,11.332l-33.92773,33.94336A7.99708,7.99708,0,0,1,128.40625,167.60352Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "134.059 94.059 168 128 134.059 161.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "134.059 94.059 168 128 134.059 161.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "134.059 94.059 168 128 134.059 161.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowSquareRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1h(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowSquareRight.displayName = "ArrowSquareRight";

var renderPathFor$1i = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 121.941 128 88 161.941 121.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 121.941 128 88 161.941 121.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.99414,208V48a16.01582,16.01582,0,0,0-16-16h-160a16.01583,16.01583,0,0,0-16,16V208a16.01583,16.01583,0,0,0,16,16h160A16.01582,16.01582,0,0,0,223.99414,208Zm-56.39062-80.40625a7.99708,7.99708,0,0,1-11.3125,0l-20.29688-20.28613V168a8,8,0,1,1-16,0V107.3125L99.71289,127.59375a7.99915,7.99915,0,0,1-11.3125-11.3125l33.92773-33.92773a8.02367,8.02367,0,0,1,11.332,0l33.94336,33.92773A7.99708,7.99708,0,0,1,167.60352,127.59375Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 121.941 128 88 161.941 121.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 121.941 128 88 161.941 121.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "94.059 121.941 128 88 161.941 121.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowSquareUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1i(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowSquareUp.displayName = "ArrowSquareUp";

var renderPathFor$1j = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "148 100 100 100 100 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "156",
        x2: "100",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "148 100 100 100 100 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "156",
        x2: "100",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,208,32ZM161.65674,161.65723a8.00063,8.00063,0,0,1-11.31348,0L108,119.314V148a8,8,0,0,1-16,0V100.00244c0-.26465.01392-.5293.03992-.793.01111-.11377.03271-.22412.04858-.33642.02063-.146.038-.29248.06677-.4375.02588-.13086.06214-.2583.09449-.38721.03112-.124.05835-.24854.09545-.37158.0387-.12744.08655-.25.13123-.375.04358-.12158.08362-.24414.13318-.36377.04809-.11572.10474-.22705.158-.34033.0581-.12354.11316-.24805.178-.36914.05774-.10791.12353-.21.186-.31495.071-.11914.13867-.24023.21655-.35644.07593-.11328.16065-.22022.242-.3291.0747-.1001.14429-.20264.22436-.3003.1521-.18505.31372-.36181.48169-.53271.0166-.01709.0304-.03564.04712-.05225.01929-.01953.04077-.03515.0603-.05468.16846-.165.34253-.32422.525-.47413.09424-.07763.19372-.145.29053-.21728.1123-.084.22229-.1709.339-.249.11242-.0752.229-.14063.34423-.20948.10913-.06494.21582-.1333.32813-.19384.115-.06153.23328-.11329.35058-.16895.11963-.05664.23755-.11621.36036-.167.11071-.0459.22387-.08252.33618-.12305.13415-.04883.267-.09961.40429-.1416.1084-.03223.21851-.05615.32789-.084.14331-.03663.28515-.07666.43151-.10547.12085-.02393.2428-.03711.36451-.05567.13659-.02051.27136-.04541.41-.05908.2019-.01953.40442-.02588.60693-.03076C99.88232,92.00781,99.94019,92,100,92h48a8,8,0,0,1,0,16H119.314l42.34278,42.34277A8.00034,8.00034,0,0,1,161.65674,161.65723Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "148 100 100 100 100 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "156",
        x2: "100",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "148 100 100 100 100 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "156",
        x2: "100",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "148 100 100 100 100 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "156",
        x2: "100",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowSquareUpLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1j(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowSquareUpLeft.displayName = "ArrowSquareUpLeft";

var renderPathFor$1k = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "108 100 156 100 156 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "156",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "108 100 156 100 156 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "156",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,48V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V48a16.01833,16.01833,0,0,0-16-16H48A16.01833,16.01833,0,0,0,32,48ZM94.34326,150.34277,136.686,108H108a8,8,0,0,1,0-16h48c.05981,0,.11768.00781.17725.00879.20251.00488.405.01123.60693.03076.13867.01367.27344.03857.41.05908.12171.01856.24366.03174.36451.05567.14636.02881.2882.06884.43151.10547.10938.02783.21949.05175.32789.084.13732.042.27014.09277.40429.1416.11231.04053.22547.07715.33618.12305.12281.05078.24073.11035.36036.167.1173.05566.23559.10742.35058.16895.11231.06054.219.1289.32813.19384.11523.06885.23181.13428.34423.20948.1167.07812.22669.165.339.249.09681.07227.19629.13965.29053.21728.1825.14991.35657.30909.525.47413.01953.01953.041.03515.0603.05468.01672.01661.03052.03516.04712.05225.168.1709.32959.34766.48169.53271.08007.09766.14966.2002.22436.3003.0813.10888.166.21582.242.3291.07788.11621.1455.2373.21655.35644.0625.105.12829.207.186.31495.06482.12109.11988.2456.178.36914.05322.11328.10987.22461.158.34033.04956.11963.0896.24219.13318.36377.04468.125.09253.24756.13123.375.0371.123.06433.24756.09545.37158.03235.12891.06861.25635.09449.38721.02881.145.04614.2915.06677.4375.01587.1123.03747.22265.04858.33642.026.26367.03992.52832.03992.793V148a8,8,0,0,1-16,0V119.314l-42.34326,42.34327a8.00018,8.00018,0,0,1-11.31348-11.31446Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "108 100 156 100 156 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "156",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "108 100 156 100 156 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "156",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        transform: "translate(0 256) rotate(-90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "108 100 156 100 156 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "156",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowSquareUpRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1k(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowSquareUpRight.displayName = "ArrowSquareUpRight";

var renderPathFor$1l = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 120 32 168 80 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M80,56h88a56,56,0,0,1,56,56v.00011A55.99988,55.99988,0,0,1,168.00011,168H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 120 32 168 80 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,56h88a56,56,0,0,1,56,56v.00011A55.99988,55.99988,0,0,1,168.00011,168H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,48H80a8,8,0,0,0,0,16h88a48,48,0,0,1,0,96H51.31348l34.34375-34.34326a8.00018,8.00018,0,0,0-11.31446-11.31348l-48,48c-.02392.02393-.04394.05078-.06762.07471-.15967.16406-.31495.332-.46021.50928-.08423.10254-.15771.21045-.23608.31591-.07715.10352-.15747.20459-.22949.312-.082.12255-.15333.24951-.22779.375-.05859.09863-.12036.19433-.17456.29541-.06811.12695-.12573.25732-.18652.38671-.0503.10743-.10425.2129-.1499.32325-.052.12549-.094.25341-.13941.38086-.04248.11914-.08838.23632-.12524.35791-.03882.12841-.06763.25927-.09986.38916-.03076.123-.06567.24511-.09057.3706-.03.15088-.04859.30371-.06958.45654-.0149.106-.0354.21-.0459.31739a8.02276,8.02276,0,0,0,0,1.584c.0105.10742.031.21143.0459.31738.021.15284.03955.30567.06958.45655.0249.12549.05981.24756.09057.3706.03223.12989.061.26075.09986.38916.03686.12159.08276.23877.12524.35791.04541.12745.0874.25537.13941.38086.04565.11035.0996.21582.1499.32325.06079.12939.11841.25976.18652.38671.0542.10108.116.19678.17456.29541.07446.12549.14575.25245.22779.375.072.10743.15234.2085.22949.312.07837.10546.15185.21337.23608.31591.14258.17383.29517.33887.45166.49952.02661.02734.04907.05761.07617.08447l48,48a8.00018,8.00018,0,1,0,11.31446-11.31348L51.31348,176H168a64,64,0,0,0,0-128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 120 32 168 80 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M80,56h88a56,56,0,0,1,56,56v.00011A55.99988,55.99988,0,0,1,168.00011,168H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 120 32 168 80 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M80,56h88a56,56,0,0,1,56,56v.00011A55.99988,55.99988,0,0,1,168.00011,168H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 120 32 168 80 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,56h88a56,56,0,0,1,56,56v.00011A55.99988,55.99988,0,0,1,168.00011,168H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowUDownLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1l(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowUDownLeft.displayName = "ArrowUDownLeft";

var renderPathFor$1m = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 120 224 168 176 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M176,56H88a56,56,0,0,0-56,56v.00011A55.99988,55.99988,0,0,0,87.99989,168H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 120 224 168 176 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,56H88a56,56,0,0,0-56,56v.00011A55.99988,55.99988,0,0,0,87.99989,168H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M230.18481,173.07324c.0857-.10449.16065-.21386.24024-.32129.07544-.102.15454-.20117.22534-.30664.08276-.12353.155-.25195.23023-.3789.05761-.09717.11889-.1919.17236-.29151.06811-.12744.12646-.25879.18725-.38916.05-.10644.10352-.21142.14893-.3208.05225-.126.09448-.25439.13989-.38232.04248-.11866.08814-.23584.125-.35694.03882-.12841.06763-.25879.09986-.38916.03076-.123.06567-.24511.09057-.3706.03-.15137.04859-.3042.06983-.457.01464-.106.03515-.20948.04565-.3169a8.02276,8.02276,0,0,0,0-1.584c-.0105-.10742-.031-.21094-.04565-.3169-.02124-.15283-.0398-.30566-.06983-.457-.0249-.12549-.05981-.24756-.09057-.3706-.03223-.13037-.061-.26075-.09986-.38916-.03686-.1211-.08252-.23828-.125-.35694-.04541-.12793-.08764-.25634-.13989-.38232-.04541-.10938-.09888-.21436-.14893-.3208-.06079-.13037-.11914-.26172-.18725-.38916-.05347-.09961-.11475-.19434-.17236-.29151-.0752-.127-.14747-.25537-.23023-.3789-.0708-.10547-.1499-.20459-.22534-.30664-.07959-.10743-.15454-.2168-.24024-.32129-.1394-.16992-.28881-.33057-.44165-.48828-.02978-.03125-.05542-.06494-.08593-.09522l-48-48a8.00018,8.00018,0,1,0-11.31446,11.31348L204.68652,160H88a48,48,0,0,1,0-96h88a8,8,0,0,0,0-16H88a64,64,0,0,0,0,128H204.68652l-34.34375,34.34326a8.00018,8.00018,0,0,0,11.31446,11.31348l48-48c.03344-.0332.06128-.06983.094-.104C229.90088,173.398,230.04785,173.23975,230.18481,173.07324Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 120 224 168 176 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M176,56H88a56,56,0,0,0-56,56v.00011A55.99988,55.99988,0,0,0,87.99989,168H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 120 224 168 176 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M176,56H88a56,56,0,0,0-56,56v.00011A55.99988,55.99988,0,0,0,87.99989,168H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 120 224 168 176 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,56H88a56,56,0,0,0-56,56v.00011A55.99988,55.99988,0,0,0,87.99989,168H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowUDownRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1m(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowUDownRight.displayName = "ArrowUDownRight";

var renderPathFor$1n = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "136 176 88 224 40 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M200,176V88a56,56,0,0,0-56-56h-.00011A55.99988,55.99988,0,0,0,88,87.99989V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "136 176 88 224 40 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,176V88a56,56,0,0,0-56-56h-.00011A55.99988,55.99988,0,0,0,88,87.99989V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M144,24A64.07207,64.07207,0,0,0,80,88V204.686L45.65723,170.34326a8.00018,8.00018,0,0,0-11.31446,11.31348l48,48c.02393.02392.05054.04394.075.06787.16407.15967.33252.31494.50977.46045.09961.082.20435.15332.30664.22949.10693.07959.21118.1626.322.23682.11914.07959.24219.14843.36426.22119.102.061.20166.125.30664.18115.1228.06592.249.12158.37451.18066.11182.05274.22144.1084.33594.15577.12061.0498.24341.09033.36572.13379.124.04443.24658.09228.37354.13086.12231.03662.24658.064.37036.09521.12939.03223.25708.06885.38891.09473.14209.02832.28565.04492.429.06543.11523.0166.22852.03857.34546.0498.26245.02588.52588.04.78955.04s.5271-.01416.78955-.04c.11694-.01123.23023-.0332.34546-.0498.14331-.02051.28686-.03711.429-.06543.13184-.02588.25953-.0625.38892-.09473.12378-.03125.24805-.05859.37036-.09521.127-.03858.24951-.08643.37354-.13086.12231-.04346.24511-.084.36572-.13379.1145-.04737.22412-.103.33594-.15577.12549-.05908.25171-.11474.37451-.18066.105-.05615.20459-.12012.30664-.18115.12207-.07276.24512-.1416.36426-.22119.11084-.07422.21509-.15723.322-.23682.10229-.07617.207-.14746.30664-.22949.17725-.14551.3457-.30078.50977-.46045.02441-.02393.051-.044.075-.06787l48-48a8.00018,8.00018,0,0,0-11.31446-11.31348L96,204.686V88a48,48,0,0,1,96,0v88a8,8,0,0,0,16,0V88A64.07207,64.07207,0,0,0,144,24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "136 176 88 224 40 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M200,176V88a56,56,0,0,0-56-56h-.00011A55.99988,55.99988,0,0,0,88,87.99989V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "136 176 88 224 40 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M200,176V88a56,56,0,0,0-56-56h-.00011A55.99988,55.99988,0,0,0,88,87.99989V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "136 176 88 224 40 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,176V88a56,56,0,0,0-56-56h-.00011A55.99988,55.99988,0,0,0,88,87.99989V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowULeftDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1n(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowULeftDown.displayName = "ArrowULeftDown";

var renderPathFor$1o = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "136 80 88 32 40 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M200,80v88a56,56,0,0,1-56,56h-.00011A55.99988,55.99988,0,0,1,88,168.00011V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "136 80 88 32 40 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,80v88a56,56,0,0,1-56,56h-.00011A55.99988,55.99988,0,0,1,88,168.00011V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,72a8.00008,8.00008,0,0,0-8,8v88a48,48,0,0,1-96,0V51.31348l34.34277,34.34326a8.00018,8.00018,0,0,0,11.31446-11.31348l-48-48c-.01612-.01611-.03394-.0293-.05-.04541-.17163-.1687-.34961-.33105-.53589-.48389-.094-.07714-.19312-.14453-.28955-.21679-.11255-.084-.22266-.17139-.33985-.24951-.113-.07569-.23046-.14136-.34643-.2107-.10816-.06469-.21411-.13257-.32544-.19214-.1167-.0625-.23682-.11523-.356-.17138-.11767-.05591-.23364-.1145-.35449-.16455-.11377-.04712-.22974-.085-.345-.12647-.1311-.04736-.2605-.09741-.39478-.13794-.11377-.03442-.22949-.05932-.34448-.08862-.13769-.03516-.27392-.07324-.41431-.10107-.13037-.02588-.2622-.04078-.39355-.06006-.12695-.01856-.25195-.04248-.38086-.05494-.23193-.02294-.46509-.03271-.69824-.0354C88.05859,24.00415,88.02978,24,88,24s-.05859.00415-.08838.00439c-.23315.00269-.46631.01246-.69824.0354-.12891.01246-.25391.03638-.38086.05494-.13135.01928-.26318.03418-.39356.06006-.14038.02783-.27661.06591-.4143.10107-.115.0293-.23071.0542-.34448.08862-.13428.04053-.26368.09058-.39478.13794-.11523.04151-.2312.07935-.345.12647-.12085.05005-.23682.10864-.35449.16455-.11914.05615-.23926.10888-.356.17138-.11133.05957-.21728.12745-.32544.19214-.116.06934-.2334.135-.34643.2107-.11719.07812-.2273.16552-.33985.24951-.09643.07226-.19556.13965-.28955.21679-.18628.15284-.36426.31519-.53589.48389-.01611.01611-.03393.0293-.05.04541l-48,48A8.00018,8.00018,0,0,0,45.65723,85.65674L80,51.31348V168a64,64,0,0,0,128,0V80A8.00008,8.00008,0,0,0,200,72Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "136 80 88 32 40 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M200,80v88a56,56,0,0,1-56,56h-.00011A55.99988,55.99988,0,0,1,88,168.00011V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "136 80 88 32 40 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M200,80v88a56,56,0,0,1-56,56h-.00011A55.99988,55.99988,0,0,1,88,168.00011V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "136 80 88 32 40 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,80v88a56,56,0,0,1-56,56h-.00011A55.99988,55.99988,0,0,1,88,168.00011V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowULeftUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1o(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowULeftUp.displayName = "ArrowULeftUp";

var renderPathFor$1p = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "120 176 168 224 216 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M56,176V88a56,56,0,0,1,56-56h.00011A55.99988,55.99988,0,0,1,168,87.99989V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "120 176 168 224 216 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M56,176V88a56,56,0,0,1,56-56h.00011A55.99988,55.99988,0,0,1,168,87.99989V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.65723,170.34326a8.00122,8.00122,0,0,0-11.31446,0L176,204.68652V88A64,64,0,0,0,48,88v88a8,8,0,0,0,16,0V88a48,48,0,0,1,96,0V204.68652l-34.34277-34.34326a8.00018,8.00018,0,0,0-11.31446,11.31348l48,48c.01612.01611.03394.0293.05.04541.17163.1687.34961.33105.53589.48389.09448.07763.19385.145.291.21777.11206.08374.22143.17041.33789.24853.11474.07666.23388.14331.3518.21363.1062.06347.21.13012.31934.18872.11987.06421.24341.11865.366.17627.11425.05395.22656.11084.34375.15942.11816.04907.23877.08862.35888.13159.12647.04541.25122.09375.38062.13306.11963.03613.24121.06274.3623.093.13184.0332.262.07031.39624.09692.14087.02783.283.04443.42481.0647.11645.0166.23095.03882.34912.05029.26245.02588.52588.04.78955.04s.5271-.01416.78955-.04c.11816-.01147.23267-.03369.34912-.05029.14185-.02027.28394-.03687.42481-.0647.13427-.02661.2644-.06372.39624-.09692.12109-.03028.24267-.05689.3623-.093.1294-.03931.25415-.08765.38062-.13306.12011-.043.24072-.08252.35888-.13159.11719-.04858.2295-.10547.34375-.15942.12256-.05762.2461-.11206.366-.17627.10938-.0586.21313-.12525.31934-.18872.11792-.07032.23706-.137.3518-.21363.11646-.07812.22583-.16479.33789-.24853.09717-.07276.19654-.14014.291-.21777.18628-.15284.36426-.31519.53589-.48389.01611-.01611.03393-.0293.05-.04541l48-48A8,8,0,0,0,221.65723,170.34326Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "120 176 168 224 216 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M56,176V88a56,56,0,0,1,56-56h.00011A55.99988,55.99988,0,0,1,168,87.99989V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "120 176 168 224 216 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M56,176V88a56,56,0,0,1,56-56h.00011A55.99988,55.99988,0,0,1,168,87.99989V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "120 176 168 224 216 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M56,176V88a56,56,0,0,1,56-56h.00011A55.99988,55.99988,0,0,1,168,87.99989V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowURightDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1p(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowURightDown.displayName = "ArrowURightDown";

var renderPathFor$1q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "120 80 168 32 216 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M56,80v88a56,56,0,0,0,56,56h.00011A55.99988,55.99988,0,0,0,168,168.00011V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "120 80 168 32 216 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M56,80v88a56,56,0,0,0,56,56h.00011A55.99988,55.99988,0,0,0,168,168.00011V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.65723,74.34326l-48-48c-.02076-.02051-.04346-.0376-.06446-.0581-.167-.16358-.33935-.32178-.52026-.47022-.09912-.08154-.20337-.15234-.30518-.22851-.10766-.08008-.2124-.16358-.324-.2378-.11768-.0791-.23975-.14746-.36084-.21924-.10327-.06152-.2041-.12646-.3103-.18359-.12232-.06543-.24805-.12109-.37281-.17969-.11206-.05273-.22192-.1084-.33667-.15625-.12158-.05029-.2456-.09082-.36889-.13476-.12305-.04444-.24439-.09131-.37012-.1294-.12353-.03759-.249-.06494-.374-.09619-.12842-.03222-.25489-.06836-.3855-.09424-.14478-.02881-.29126-.0459-.437-.06689-.11231-.01563-.2229-.03711-.33667-.04834a8.06858,8.06858,0,0,0-1.58106,0c-.11377.01123-.22436.03271-.33667.04834-.14575.021-.29223.03808-.437.06689-.13061.02588-.25708.062-.3855.09424-.125.03125-.25049.0586-.374.09619-.12573.03809-.24707.085-.37012.1294-.12329.04394-.24731.08447-.36889.13476-.11475.04785-.22461.10352-.33667.15625-.12476.0586-.25049.11426-.37281.17969-.1062.05713-.207.12207-.3103.18359-.12109.07178-.24316.14014-.36084.21924-.11157.07422-.21631.15772-.324.2378-.10181.07617-.20606.147-.30518.22851-.18091.14844-.35327.30664-.52026.47022-.021.0205-.0437.03759-.06446.0581l-48,48a8.00018,8.00018,0,0,0,11.31446,11.31348L160,51.314V168a48,48,0,0,1-96,0V80a8,8,0,0,0-16,0v88a64,64,0,0,0,128,0V51.314l34.34277,34.34278a8.00018,8.00018,0,0,0,11.31446-11.31348Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "120 80 168 32 216 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M56,80v88a56,56,0,0,0,56,56h.00011A55.99988,55.99988,0,0,0,168,168.00011V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "120 80 168 32 216 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M56,80v88a56,56,0,0,0,56,56h.00011A55.99988,55.99988,0,0,0,168,168.00011V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "120 80 168 32 216 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M56,80v88a56,56,0,0,0,56,56h.00011A55.99988,55.99988,0,0,0,168,168.00011V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowURightUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowURightUp.displayName = "ArrowURightUp";

var renderPathFor$1r = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 136 32 88 80 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M80,200h88a56,56,0,0,0,56-56v-.00011A55.99988,55.99988,0,0,0,168.00011,88H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 136 32 88 80 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,200h88a56,56,0,0,0,56-56v-.00011A55.99988,55.99988,0,0,0,168.00011,88H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,80H51.31348L85.65723,45.65674A8.00018,8.00018,0,0,0,74.34277,34.34326l-48,48c-.03051.03028-.05615.064-.08593.09522-.15284.15771-.30225.31836-.44165.48828-.0857.10449-.16065.21386-.24024.32129-.07544.102-.15454.20117-.22534.30664-.08276.12353-.155.252-.23023.3789-.05761.09717-.11889.1919-.17236.29151-.06811.12744-.12646.25879-.18725.38916-.05.10644-.10352.21142-.14893.3208-.05225.126-.09448.25439-.13989.38232-.04248.11866-.08814.23584-.125.35694-.03882.12841-.06763.25879-.09986.38916-.03076.123-.06567.24511-.09057.3706-.03.15137-.04859.3042-.06983.457-.01465.106-.03515.20948-.04565.3169a8.02276,8.02276,0,0,0,0,1.584c.0105.10742.031.21094.04565.3169.02124.15283.0398.30566.06983.457.0249.12549.05981.24756.09057.3706.03223.13037.061.26075.09986.38916.03686.1211.08252.23828.125.35694.04541.12793.08764.25634.13989.38232.04541.10938.09888.21436.14893.3208.06079.13037.11914.26172.18725.38916.05347.09961.11475.19434.17236.29151.0752.12695.14747.25537.23023.3789.0708.10547.1499.20459.22534.30664.07959.10742.15454.2168.24024.32129.137.16651.28393.32471.43359.47949.03271.03418.06055.07081.094.104l48,48a8.00018,8.00018,0,1,0,11.31446-11.31348L51.31348,96H168a48,48,0,0,1,0,96H80a8,8,0,0,0,0,16h88a64,64,0,0,0,0-128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 136 32 88 80 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M80,200h88a56,56,0,0,0,56-56v-.00011A55.99988,55.99988,0,0,0,168.00011,88H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 136 32 88 80 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M80,200h88a56,56,0,0,0,56-56v-.00011A55.99988,55.99988,0,0,0,168.00011,88H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 136 32 88 80 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,200h88a56,56,0,0,0,56-56v-.00011A55.99988,55.99988,0,0,0,168.00011,88H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowUUpLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1r(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowUUpLeft.displayName = "ArrowUUpLeft";

var renderPathFor$1s = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 136 224 88 176 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M176,200H88a56,56,0,0,1-56-56v-.00011A55.99988,55.99988,0,0,1,87.99989,88H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 136 224 88 176 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,200H88a56,56,0,0,1-56-56v-.00011A55.99988,55.99988,0,0,1,87.99989,88H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M170.34277,141.65674a8.00063,8.00063,0,0,0,11.31446,0l48-48c.03344-.0332.06128-.06983.094-.104.14966-.15478.29663-.313.43359-.47949.0857-.10449.16065-.21387.24024-.32129.07544-.102.15454-.20117.22534-.30664.08276-.12353.155-.252.23023-.3789.05761-.09717.11889-.1919.17236-.29151.06811-.12744.12646-.25879.18725-.38916.05-.10644.10352-.21142.14893-.3208.05225-.126.09448-.25439.13989-.38232.04248-.11866.08814-.23584.125-.35694.03882-.12841.06763-.25879.09986-.38916.03076-.123.06567-.24511.09057-.3706.03-.15137.04859-.3042.06983-.457.01464-.106.03515-.20948.04565-.3169a8.02276,8.02276,0,0,0,0-1.584c-.0105-.10742-.031-.21094-.04565-.3169-.02124-.15283-.0398-.30566-.06983-.457-.0249-.12549-.05981-.24756-.09057-.3706-.03223-.13037-.061-.26075-.09986-.38916-.03686-.1211-.08252-.23828-.125-.35694-.04541-.12793-.08764-.25634-.13989-.38232-.04541-.10938-.09888-.21436-.14893-.3208-.06079-.13037-.11914-.26172-.18725-.38916-.05347-.09961-.11475-.19434-.17236-.29151-.0752-.12695-.14747-.25537-.23023-.3789-.0708-.10547-.1499-.20459-.22534-.30664-.07959-.10743-.15454-.2168-.24024-.32129-.1394-.16992-.28881-.33057-.44165-.48828-.02978-.03125-.05542-.06494-.08593-.09522l-48-48a8.00018,8.00018,0,1,0-11.31446,11.31348L204.68652,80H88a64,64,0,0,0,0,128h88a8,8,0,0,0,0-16H88a48,48,0,0,1,0-96H204.68652l-34.34375,34.34326A8,8,0,0,0,170.34277,141.65674Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 136 224 88 176 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M176,200H88a56,56,0,0,1-56-56v-.00011A55.99988,55.99988,0,0,1,87.99989,88H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 136 224 88 176 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M176,200H88a56,56,0,0,1-56-56v-.00011A55.99988,55.99988,0,0,1,87.99989,88H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 136 224 88 176 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,200H88a56,56,0,0,1-56-56v-.00011A55.99988,55.99988,0,0,1,87.99989,88H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowUUpRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1s(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowUUpRight.displayName = "ArrowUUpRight";

var renderPathFor$1t = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "216",
        x2: "128",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "56 112 128 40 200 112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "216",
        x2: "128",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 112 128 40 200 112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M205.65674,117.65723a8.00182,8.00182,0,0,1-11.31348,0L136,59.31348V216a8,8,0,0,1-16,0V59.31348L61.65674,117.65723a8.00018,8.00018,0,0,1-11.31348-11.31446l72-72c.02588-.02612.05469-.0476.08106-.07324.16211-.158.32861-.31128.50341-.45508.09766-.08032.20118-.15039.30176-.22534.1084-.081.21485-.16528.32764-.241.11621-.07788.2373-.1455.35693-.21679.10449-.06226.20655-.12793.31446-.18579.12011-.06421.24414-.1189.36669-.17676.11426-.054.22657-.11084.34327-.15942.11816-.04883.23925-.08838.35937-.13135.126-.04541.251-.09375.37988-.13282.11963-.03613.24122-.06274.36231-.09326.13183-.0332.26269-.07031.397-.09692.13965-.02759.28028-.04419.42041-.06421.11817-.01685.23389-.03931.353-.051C127.47314,32.01392,127.73633,32,128,32s.52686.01392.78955.03979c.11914.01172.23486.03418.353.051.14013.02.28076.03662.42041.06421.13428.02661.26513.06372.397.09692.12109.03052.24268.05713.36231.09326.1289.03907.2539.08741.37988.13282.12012.043.24121.08252.35937.13135.1167.04858.229.10546.34327.15942.12255.05786.24658.11255.36669.17676.10791.05786.21.12353.31446.18579.11963.07129.24072.13891.35693.21679.11279.07569.21924.15992.32764.241.10058.075.2041.145.30176.22534.17822.14624.34765.30225.51269.46338.023.02271.04883.04175.07178.06494l72,72A8.00034,8.00034,0,0,1,205.65674,117.65723Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "216",
        x2: "128",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "56 112 128 40 200 112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "216",
        x2: "128",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "56 112 128 40 200 112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "216",
        x2: "128",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 112 128 40 200 112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1t(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowUp.displayName = "ArrowUp";

var renderPathFor$1u = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "192",
        y1: "192",
        x2: "64",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "168 64 64 64 64 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "192",
        y1: "192",
        x2: "64",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "168 64 64 64 64 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56.001,63.978q.00146-.38379.03906-.7666c.01172-.12061.03418-.2378.05127-.35694.02-.13965.03613-.27929.064-.41748.02637-.13525.06348-.26611.09717-.39892.03027-.12012.05664-.24073.09277-.35987.03956-.13037.0879-.25586.13379-.3833.04248-.11914.08155-.23877.13038-.356.04882-.11767.106-.23.16015-.34472.05762-.12256.11182-.2461.17627-.36572.05762-.10791.12354-.21.186-.315.0708-.11914.13867-.24023.2163-.35644.07618-.11328.16065-.22022.24219-.3291.07471-.1001.14405-.20264.22412-.3003.14893-.18115.30762-.35449.47168-.522.02-.02051.03711-.04248.05713-.063.023-.02246.04785-.0415.0708-.064.165-.16113.33545-.31787.51416-.46485.09619-.07861.19776-.14746.29639-.22119.11035-.08252.21826-.168.333-.24511.11377-.07618.23242-.14209.34912-.21192.10742-.06445.2124-.13183.32324-.19092.11572-.062.23535-.11425.35352-.17041.11865-.05615.23584-.11523.35742-.166.11181-.0459.22558-.083.33887-.12354.1333-.04834.26513-.09961.40185-.14062.10889-.0332.21973-.05664.33008-.085.14258-.03662.28369-.07617.42969-.105.12109-.02393.24365-.0376.36523-.05567.13623-.02051.271-.04541.40918-.05908.20215-.01953.40479-.02637.60742-.03076C63.88232,56.00781,63.94043,56,64,56H168a8,8,0,0,1,0,16H83.314L197.65674,186.34277a8.00018,8.00018,0,0,1-11.31348,11.31446L72,83.314V168a8,8,0,0,1-16,0V64Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "192",
        y1: "192",
        x2: "64",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "168 64 64 64 64 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "192",
        y1: "192",
        x2: "64",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "168 64 64 64 64 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "192",
        y1: "192",
        x2: "64",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "168 64 64 64 64 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowUpLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1u(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowUpLeft.displayName = "ArrowUpLeft";

var renderPathFor$1v = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "192",
        x2: "192",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "88 64 192 64 192 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "192",
        x2: "192",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "88 64 192 64 192 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M199.999,63.978q-.00145-.38379-.03906-.7666c-.01172-.12061-.03418-.2378-.05127-.35694-.02-.13965-.03613-.27929-.064-.41748-.02637-.13525-.06348-.26611-.09717-.39892-.03027-.12012-.05664-.24073-.09277-.35987-.03956-.13037-.0879-.25586-.13379-.3833-.04248-.11914-.08155-.23877-.13038-.356-.04882-.11767-.106-.23-.16015-.34472-.05762-.12256-.11182-.2461-.17627-.36572-.05762-.10791-.12354-.21-.186-.315-.0708-.11914-.13867-.24023-.2163-.35644-.07618-.11328-.16065-.22022-.24219-.3291-.07471-.1001-.144-.20264-.22412-.3003-.14893-.18115-.30762-.35449-.47168-.522-.02-.02051-.03711-.04248-.05713-.063-.023-.02246-.04785-.0415-.0708-.064-.165-.16113-.33545-.31787-.51416-.46485-.09619-.07861-.19776-.14746-.29639-.22119-.11035-.08252-.21826-.168-.333-.24511-.11377-.07618-.23242-.14209-.34912-.21192-.10742-.06445-.2124-.13183-.32324-.19092-.11572-.062-.23535-.11425-.35352-.17041-.11865-.05615-.23584-.11523-.35742-.166-.11181-.0459-.22558-.083-.33887-.12354-.1333-.04834-.26513-.09961-.40185-.14062-.10889-.0332-.21973-.05664-.33008-.085-.14258-.03662-.28369-.07617-.42969-.105-.12109-.02393-.24365-.0376-.36523-.05567-.13623-.02051-.271-.04541-.40918-.05908-.20215-.01953-.40479-.02637-.60742-.03076C192.11768,56.00781,192.05957,56,192,56H88a8,8,0,0,0,0,16h84.686L58.34326,186.34277a8.00018,8.00018,0,0,0,11.31348,11.31446L184,83.314V168a8,8,0,0,0,16,0V64Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "192",
        x2: "192",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "88 64 192 64 192 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "192",
        x2: "192",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "88 64 192 64 192 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "192",
        x2: "192",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "88 64 192 64 192 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowUpRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1v(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowUpRight.displayName = "ArrowUpRight";

var renderPathFor$1w = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176.167 99.716 224.167 99.716 224.167 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M65.7746,65.7746a88,88,0,0,1,124.4508,0l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "79.833 156.284 31.833 156.284 31.833 204.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,0,1-124.4508,0L31.83348,156.28427",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176.167 99.716 224.167 99.716 224.167 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M65.7746,65.7746a88,88,0,0,1,124.4508,0l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "79.833 156.284 31.833 156.284 31.833 204.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,0,1-124.4508,0L31.83348,156.28427",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M225.73047,107.56073c.13257-.02631.26123-.06274.3916-.09558.123-.03088.24658-.05792.36816-.09473.12647-.03833.2483-.08575.37183-.13006.123-.04395.24683-.08454.36792-.13465.11328-.047.22168-.10217.332-.15411.127-.05945.2544-.11591.37842-.18237.10229-.05475.19922-.11725.29858-.17627.12525-.07416.25147-.14521.37329-.22681.10352-.0694.20069-.14709.30079-.22113.10986-.08124.22192-.158.32837-.24554.14379-.118.27856-.246.41357-.37366.05542-.05243.11475-.09845.16919-.15277.0564-.0564.10425-.11786.15869-.17554.12524-.13287.25122-.26532.36719-.40649.09106-.11072.17114-.22718.25537-.34156.07056-.09564.14477-.18805.21094-.28686.085-.12659.15893-.25781.23584-.38806.05566-.09443.11523-.18622.16723-.28308.06909-.12916.12818-.26185.1897-.3938.04932-.10547.10205-.20874.147-.31665.05225-.12653.095-.25568.14063-.38428.042-.11817.08764-.2345.12426-.35517.03907-.1289.06788-.25982.10035-.39019.03051-.123.06518-.24414.09008-.36933.03-.15149.04859-.30444.06983-.45715.01465-.1059.03516-.2099.04565-.31714a7.97366,7.97366,0,0,0,.04-.79706V51.71582a8,8,0,0,0-16,0V80.40137L195.88281,60.11719a96.11137,96.11137,0,0,0-135.76562,0A8.00052,8.00052,0,0,0,71.43164,71.43164a80.08769,80.08769,0,0,1,113.13672,0l20.28418,20.28418H176.167a8,8,0,0,0,0,16h48c.26367,0,.5271-.014.78955-.03992.11817-.01159.23267-.03369.34912-.05035C225.44751,107.60529,225.5896,107.58868,225.73047,107.56073Z"
      }), React__default.createElement("path", {
        d: "M184.56836,184.56836a80.08769,80.08769,0,0,1-113.13672,0L51.14746,164.28418H79.833a8,8,0,0,0,0-16h-48c-.05982,0-.11743.00763-.177.00891-.20264.00446-.40528.01093-.60718.0307-.13819.01343-.27246.03851-.40845.0589-.12207.01831-.24487.03186-.36621.05591-.14526.02869-.28613.06811-.42847.10455-.11035.02826-.22168.05219-.3313.08521-.13549.041-.2666.09155-.39917.13952-.11425.0412-.22924.07862-.34179.12519-.11963.04962-.23462.10772-.35132.1629-.12061.05688-.24219.11047-.36035.17371-.10645.057-.20752.12194-.311.18359-.12134.07214-.24389.141-.36206.22009-.1062.071-.20581.15045-.3081.22638-.10767.07965-.21729.15473-.32178.24048-.14478.119-.28076.248-.417.37671-.05445.05151-.11255.09668-.166.15-.0564.0564-.10425.11786-.15869.17554-.12524.13287-.25122.26532-.36719.40649-.09106.11072-.17114.22718-.25537.34156-.07056.09564-.14477.188-.21094.28686-.085.12659-.15893.25781-.23584.38806-.05566.09443-.11523.18622-.16723.28308-.06909.12916-.12818.26185-.1897.3938-.04932.10547-.10205.20874-.147.31665-.05225.12653-.095.25568-.14063.38428-.042.11817-.08764.2345-.12426.35517-.03907.1289-.06788.25982-.10035.39019-.03051.123-.06518.24414-.09008.36933-.03.15149-.04859.30444-.06983.45715-.01465.1059-.03516.2099-.04565.31714a7.97366,7.97366,0,0,0-.04.79706v47.99487a8,8,0,0,0,16,0V175.59863l20.28418,20.28418a96.11136,96.11136,0,0,0,135.76562,0,8.00052,8.00052,0,0,0-11.31445-11.31445Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176.167 99.716 224.167 99.716 224.167 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M65.7746,65.7746a88,88,0,0,1,124.4508,0l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "79.833 156.284 31.833 156.284 31.833 204.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,0,1-124.4508,0L31.83348,156.28427",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176.167 99.716 224.167 99.716 224.167 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M65.7746,65.7746a88,88,0,0,1,124.4508,0l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "79.833 156.284 31.833 156.284 31.833 204.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,0,1-124.4508,0L31.83348,156.28427",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176.167 99.716 224.167 99.716 224.167 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M65.7746,65.7746a88,88,0,0,1,124.4508,0l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "79.833 156.284 31.833 156.284 31.833 204.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,0,1-124.4508,0L31.83348,156.28427",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsClockwise = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1w(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsClockwise.displayName = "ArrowsClockwise";

var renderPathFor$1x = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "79.833 99.716 31.833 99.716 31.833 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M190.2254,65.7746a88,88,0,0,0-124.4508,0L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "176.167 156.284 224.167 156.284 224.167 204.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,0,0,124.4508,0l33.94112-33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "79.833 99.716 31.833 99.716 31.833 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.2254,65.7746a88,88,0,0,0-124.4508,0L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "176.167 156.284 224.167 156.284 224.167 204.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,0,0,124.4508,0l33.94112-33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M30.26953,107.56073c-.13257-.02631-.26123-.06274-.3916-.09558-.123-.03088-.24658-.05792-.36816-.09473-.12647-.03833-.2483-.08575-.37183-.13006-.123-.04395-.24683-.08454-.36792-.13465-.11328-.047-.22168-.10217-.332-.15411-.127-.05945-.2544-.11591-.37842-.18237-.10229-.05475-.19922-.11725-.29858-.17627-.12525-.07416-.25147-.14521-.37329-.22681-.10352-.0694-.20069-.14709-.30079-.22113-.10986-.08124-.22192-.158-.32837-.24554-.14379-.118-.27856-.246-.41357-.37366-.05542-.05243-.11475-.09845-.16919-.15277-.0564-.0564-.10425-.11786-.15869-.17554-.12524-.13287-.25122-.26532-.36719-.40649-.09106-.11072-.17114-.22718-.25537-.34156-.07056-.09564-.14477-.18805-.21094-.28686-.085-.12659-.15893-.25781-.23584-.38806-.05566-.09443-.11523-.18622-.16723-.28308-.06909-.12916-.12818-.26185-.1897-.3938-.04932-.10547-.10205-.20874-.147-.31665-.05225-.12653-.095-.25568-.14063-.38428-.042-.11817-.08764-.2345-.12426-.35517-.03907-.1289-.06788-.25982-.10035-.39019-.03051-.123-.06518-.24414-.09008-.36933-.03-.15149-.04859-.30444-.06983-.45715-.01465-.1059-.03516-.2099-.04565-.31714a7.97366,7.97366,0,0,1-.04-.79706V51.71582a8,8,0,0,1,16,0V80.40137L60.11719,60.11719a96.11137,96.11137,0,0,1,135.76562,0,8.00052,8.00052,0,1,1-11.31445,11.31445,80.08769,80.08769,0,0,0-113.13672,0L51.14746,91.71582H79.833a8,8,0,0,1,0,16h-48c-.26367,0-.5271-.014-.78955-.03992-.11817-.01159-.23267-.03369-.34912-.05035C30.55249,107.60529,30.4104,107.58868,30.26953,107.56073Z"
      }), React__default.createElement("path", {
        d: "M71.43164,184.56836a80.08769,80.08769,0,0,0,113.13672,0l20.28418-20.28418H176.167a8,8,0,0,1,0-16h48c.05982,0,.11743.00763.177.00891.20264.00446.40528.01093.60718.0307.13819.01343.27246.03851.40845.0589.12207.01831.24487.03186.36621.05591.14526.02869.28613.06811.42847.10455.11035.02826.22168.05219.3313.08521.13549.041.2666.09155.39917.13952.11425.0412.22924.07862.34179.12519.11963.04962.23462.10772.35132.1629.12061.05688.24219.11047.36035.17371.10645.057.20752.12194.311.18359.12134.07214.24389.141.36206.22009.1062.071.20581.15045.3081.22638.10767.07965.21729.15473.32178.24048.14478.119.28076.248.417.37671.05445.05151.11255.09668.166.15.0564.0564.10425.11786.15869.17554.12524.13287.25122.26532.36719.40649.09106.11072.17114.22718.25537.34156.07056.09564.14477.188.21094.28686.085.12659.15893.25781.23584.38806.05566.09443.11523.18622.16723.28308.06909.12916.12818.26185.1897.3938.04932.10547.10205.20874.147.31665.05225.12653.095.25568.14063.38428.042.11817.08764.2345.12426.35517.03907.1289.06788.25982.10035.39019.03051.123.06518.24414.09008.36933.03.15149.04859.30444.06983.45715.01465.1059.03516.2099.04565.31714a7.97366,7.97366,0,0,1,.04.79706v47.99487a8,8,0,0,1-16,0V175.59863l-20.28418,20.28418a96.11136,96.11136,0,0,1-135.76562,0,8.00052,8.00052,0,0,1,11.31445-11.31445Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "79.833 99.716 31.833 99.716 31.833 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M190.2254,65.7746a88,88,0,0,0-124.4508,0L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "176.167 156.284 224.167 156.284 224.167 204.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,0,0,124.4508,0l33.94112-33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "79.833 99.716 31.833 99.716 31.833 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M190.2254,65.7746a88,88,0,0,0-124.4508,0L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "176.167 156.284 224.167 156.284 224.167 204.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,0,0,124.4508,0l33.94112-33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "79.833 99.716 31.833 99.716 31.833 51.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.2254,65.7746a88,88,0,0,0-124.4508,0L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "176.167 156.284 224.167 156.284 224.167 204.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,0,0,124.4508,0l33.94112-33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsCounterClockwise = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1x(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsCounterClockwise.displayName = "ArrowsCounterClockwise";

var renderPathFor$1y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "112 192 80 224 48 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "32",
        x2: "80",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "144 64 176 32 208 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "224.00006",
        x2: "176",
        y2: "32.00006",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "112 192 80 224 48 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "32",
        x2: "80",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 64 176 32 208 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "224.00006",
        x2: "176",
        y2: "32.00006",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M106.34277,186.34277,88,204.686V32a8,8,0,0,0-16,0V204.686L53.65723,186.34277a8.00053,8.00053,0,0,0-11.31446,11.31446l32,32c.03809.03759.07959.06933.11817.10644.15088.145.30371.28809.46582.4209.103.08447.21094.15869.31738.2373.103.07667.2041.15723.311.229.12109.08105.24658.15137.37109.2251.1001.05957.19727.12256.30029.17773.124.06641.25147.12256.37842.18213.11035.05176.21875.10693.332.1543.12158.05029.2461.09082.37012.13525.12256.044.24365.09082.36865.12891.12354.03759.249.06494.374.09619.12842.03222.25538.06836.38624.09424.14208.02832.28564.04492.42871.06543.11572.0166.229.03857.3457.0498.26221.02588.52588.04.78955.04s.52734-.01416.78955-.04c.1167-.01123.23-.0332.3457-.0498.14307-.02051.28662-.03711.42871-.06543.13086-.02588.25782-.062.38624-.09424.125-.03125.25048-.0586.374-.09619.125-.03809.24609-.085.36865-.12891.124-.04443.24854-.085.37012-.13525.11328-.04737.22168-.10254.332-.1543.12695-.05957.25439-.11572.37842-.18213.103-.05517.20019-.11816.30029-.17773.12451-.07373.25-.144.37109-.2251.10694-.07178.208-.15234.311-.229.10644-.07861.21435-.15283.31738-.2373.16211-.13281.31494-.27588.46582-.4209.03858-.03711.08008-.06885.11817-.10644l32-32a8.00053,8.00053,0,0,0-11.31446-11.31446Z"
      }), React__default.createElement("path", {
        d: "M213.65723,58.34277l-32-32c-.03516-.03466-.07325-.064-.10889-.09814-.15381-.148-.31006-.29346-.4751-.4292-.10254-.084-.21-.15772-.31543-.23584-.10449-.07764-.20556-.1582-.31347-.23047-.12012-.08057-.24414-.1499-.36719-.22314-.10156-.06006-.2002-.124-.3042-.17969-.12256-.06592-.24854-.12158-.374-.18018-.11182-.05273-.22217-.10888-.33692-.15625-.12012-.0498-.24267-.08984-.36474-.1333-.124-.04492-.24707-.09277-.374-.13135-.12207-.03662-.2456-.064-.36914-.09472-.12988-.03272-.2583-.06934-.39062-.09522-.14063-.02832-.28321-.04492-.4253-.06494-.11621-.0166-.231-.03906-.34863-.05029a8.04864,8.04864,0,0,0-1.5791,0c-.11768.01123-.23242.03369-.34863.05029-.14209.02-.28467.03662-.4253.06494-.13232.02588-.26074.0625-.39062.09522-.12354.03076-.24707.0581-.36914.09472-.127.03858-.25.08643-.374.13135-.12207.04346-.24462.0835-.36474.1333-.11475.04737-.2251.10352-.33692.15625-.12548.0586-.25146.11426-.374.18018-.104.05566-.20264.11963-.3042.17969-.12305.07324-.24707.14257-.36719.22314-.10791.07227-.209.15283-.31347.23047-.10547.07812-.21289.15186-.31543.23584-.165.13574-.32129.28125-.4751.4292-.03564.03418-.07373.06348-.10889.09814l-32,32a8.00053,8.00053,0,0,0,11.31446,11.31446L168,51.314V224a8,8,0,0,0,16,0V51.314l18.34277,18.34327a8.00053,8.00053,0,0,0,11.31446-11.31446Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "112 192 80 224 48 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "32",
        x2: "80",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "144 64 176 32 208 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "224.00006",
        x2: "176",
        y2: "32.00006",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "112 192 80 224 48 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "32",
        x2: "80",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "144 64 176 32 208 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "224.00006",
        x2: "176",
        y2: "32.00006",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "112 192 80 224 48 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "32",
        x2: "80",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 64 176 32 208 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "224.00006",
        x2: "176",
        y2: "32.00006",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsDownUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsDownUp.displayName = "ArrowsDownUp";

var renderPathFor$1z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "192 104 152 104 152 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "152",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "64 152 104 152 104 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "104",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "152 192 152 152 192 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "208",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "104 64 104 104 64 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "48",
        x2: "104",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "192 104 152 104 152 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "152",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 152 104 152 104 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "104",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 192 152 152 192 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "208",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "104 64 104 104 64 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "48",
        x2: "104",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M144.04,104.79193c.01074.10773.03125.21222.0459.31867.02148.15216.03955.30456.06933.45544.02539.12622.06006.24841.09131.37244.03174.12921.06055.259.09912.38678.03711.12243.0835.2406.126.36047.04541.12659.0874.25385.13867.37848.0459.111.10059.21728.15137.32568.06006.12866.11719.25806.18506.384.05517.10279.11767.20032.17724.30036.07373.124.144.24921.22461.36993.07373.10968.15576.21259.23438.3183.07666.10358.14892.20947.23193.31006.14844.18091.30664.35321.47022.52032.02.0207.03711.0434.05761.06391.01612.01611.03418.02936.0503.04529.17138.16882.34912.33123.53564.48413.09424.07757.19385.145.291.21765.11181.08374.22168.17053.33789.24847.11474.07685.23388.14344.35156.21369.10644.06341.21045.13012.31934.18866.12011.06421.24365.11865.36621.17627.11425.054.22656.111.34375.15954.11816.049.23877.08844.35888.13141.12647.04547.25147.09393.38037.13312.12012.03619.2417.06268.36231.09314.13184.03326.26221.07019.39648.0968.14063.02789.28321.04456.42481.06482.1167.01666.231.03876.34912.05035.26221.02588.52588.03992.78955.03992h40a8,8,0,0,0,0-16H171.314l42.34327-42.34326a8.00018,8.00018,0,0,0-11.31446-11.31348L160,84.686V64a8,8,0,0,0-16,0v39.99487Q144,104.39405,144.04,104.79193Z"
      }), React__default.createElement("path", {
        d: "M111.96,151.20807c-.01074-.10773-.03125-.21222-.0459-.31867-.02148-.15216-.03955-.30456-.06933-.45544-.02539-.12622-.06006-.24841-.09131-.37244-.03174-.12921-.06055-.259-.09912-.38678-.03711-.12243-.0835-.2406-.126-.36047-.04541-.12659-.0874-.25385-.13867-.37848-.0459-.111-.10059-.21728-.15137-.32568-.06006-.12866-.11719-.25806-.18506-.384-.05517-.10279-.11767-.20032-.17724-.30036-.07373-.124-.144-.24921-.22461-.36993-.07373-.10968-.15576-.21259-.23438-.3183-.07666-.10358-.14892-.20947-.23193-.31006-.14844-.18091-.30664-.35321-.47022-.52032-.02-.0207-.03711-.0434-.05761-.06391-.01612-.01611-.03418-.02936-.0503-.04529-.17138-.16882-.34912-.33123-.53564-.48413-.09375-.07715-.19287-.14428-.28955-.21655-.11279-.08423-.22266-.17145-.33985-.24976-.11279-.07568-.23046-.14123-.34668-.21051-.10791-.06463-.21386-.1325-.32519-.1922-.1167-.06237-.23682-.11523-.356-.17144-.11767-.05579-.2334-.11444-.35449-.16455-.11377-.047-.22949-.08478-.34473-.12629-.13134-.04736-.26074-.09747-.395-.13806-.11377-.03436-.22949-.05938-.34423-.08862-.1377-.035-.27442-.07336-.41455-.10114-.13038-.02581-.26221-.04077-.39356-.06-.12695-.01862-.25195-.04236-.38086-.05494-.23193-.02282-.46484-.03271-.69824-.03527C104.05859,144.00415,104.02979,144,104,144H64a8,8,0,0,0,0,16H84.686L42.34277,202.34277a8.00053,8.00053,0,0,0,11.31446,11.31446L96,171.31409V192a8,8,0,0,0,16,0V152.00513Q112,151.606,111.96,151.20807Z"
      }), React__default.createElement("path", {
        d: "M171.314,160H192a8,8,0,0,0,0-16H152c-.02979,0-.05859.00415-.08838.00446-.2334.00256-.46631.01245-.69824.03527-.12891.01258-.25391.03632-.38086.05494-.13135.01928-.26318.03424-.39356.06-.14013.02778-.27685.06611-.41455.10114-.11474.02924-.23046.05426-.34423.08862-.13428.04059-.26368.0907-.395.13806-.11524.04151-.231.07929-.34473.12629-.12109.05011-.23682.10876-.35449.16455-.11914.05621-.23926.10907-.356.17144-.11133.0597-.21728.12757-.32519.1922-.11622.06928-.23389.13483-.34668.21051-.11719.07831-.22706.16553-.33985.24976-.09668.07227-.1958.1394-.28955.21655-.18652.1529-.36426.31531-.53564.48413-.01612.01593-.03418.02918-.0503.04529-.0205.02051-.03759.04321-.05761.06391-.16358.16711-.32178.33941-.47022.52032-.083.10059-.15527.20648-.23193.31006-.07862.10571-.16065.20862-.23438.3183-.08056.12072-.15088.24591-.22461.36993-.05957.1-.12207.19757-.17724.30036-.06787.12591-.125.25531-.18506.384-.05078.1084-.10547.21466-.15137.32568-.05127.12463-.09326.25189-.13867.37848-.04248.11987-.08887.238-.126.36047-.03857.12775-.06738.25757-.09912.38678-.03125.124-.06592.24622-.09131.37244-.02978.15088-.04785.30328-.06933.45544-.01465.10645-.03516.21094-.0459.31867q-.03956.39752-.04.79706V192a8,8,0,0,0,16,0V171.31409l42.34277,42.34314a8.00053,8.00053,0,0,0,11.31446-11.31446Z"
      }), React__default.createElement("path", {
        d: "M112,64a8,8,0,0,0-16,0V84.686L53.65723,42.34326A8.00018,8.00018,0,1,0,42.34277,53.65674L84.686,96H64a8,8,0,0,0,0,16h40c.26367,0,.52734-.014.78955-.03992.11816-.01159.23242-.03369.34912-.05035.1416-.02026.28418-.03693.42481-.06482.13427-.02661.26464-.06354.39648-.0968.12061-.03046.24219-.057.36231-.09314.1289-.03919.2539-.08765.38037-.13312.12011-.043.24072-.08246.35888-.13141.11719-.04858.2295-.10559.34375-.15954.12256-.05762.2461-.11206.36621-.17627.10889-.05854.2129-.12525.31934-.18866.11768-.07025.23682-.13684.35156-.21369.11621-.07794.22608-.16473.33789-.24847.09717-.07263.19678-.14008.291-.21765.18652-.1529.36426-.31531.53564-.48413.01612-.01593.03418-.02918.0503-.04529.0205-.02051.03759-.04321.05761-.06391.16358-.16711.32178-.33941.47022-.52032.083-.10059.15527-.20648.23193-.31006.07862-.10571.16065-.20862.23438-.3183.08056-.12072.15088-.24591.22461-.36993.05957-.1.12207-.19757.17724-.30036.06787-.12591.125-.25531.18506-.384.05078-.1084.10547-.21466.15137-.32568.05127-.12463.09326-.25189.13867-.37848.04248-.11987.08887-.238.126-.36047.03857-.12775.06738-.25757.09912-.38678.03125-.124.06592-.24622.09131-.37244.02978-.15088.04785-.30328.06933-.45544.01465-.10645.03516-.21094.0459-.31867q.03956-.39751.04-.79706Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "192 104 152 104 152 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "152",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "64 152 104 152 104 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "104",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "152 192 152 152 192 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "208",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "104 64 104 104 64 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "48",
        x2: "104",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "192 104 152 104 152 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "152",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "64 152 104 152 104 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "104",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "152 192 152 152 192 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "208",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "104 64 104 104 64 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "48",
        x2: "104",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "192 104 152 104 152 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "152",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 152 104 152 104 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "104",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 192 152 152 192 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "208",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "104 64 104 104 64 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "48",
        x2: "104",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsIn = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsIn.displayName = "ArrowsIn";

var renderPathFor$1A = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "156.284 188.284 128 160 99.716 188.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "99.716 67.716 128 96 156.284 67.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "67.716 156.284 96 128 67.716 99.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "128",
        x2: "96",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "188.284 99.716 160 128 188.284 156.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "156.284 188.284 128 160 99.716 188.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "99.716 67.716 128 96 156.284 67.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "67.716 156.284 96 128 67.716 99.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "128",
        x2: "96",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "188.284 99.716 160 128 188.284 156.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M133.65723,154.34277c-.05323-.05334-.11133-.09851-.166-.15-.13623-.12872-.27246-.25769-.417-.37671-.10449-.08575-.21436-.16083-.32178-.24048-.10254-.07593-.20166-.15533-.3081-.22638-.11817-.0791-.24073-.14795-.36231-.22009-.10351-.06165-.2041-.12659-.31055-.18359-.11865-.06324-.24023-.11683-.36084-.17371-.11669-.05518-.23144-.11328-.35107-.1629-.1123-.04657-.22754-.084-.3418-.12519-.13281-.048-.26367-.09851-.39941-.13952-.10938-.033-.2207-.057-.33106-.08521-.14257-.03644-.2832-.07586-.42822-.10455-.12158-.024-.24414-.0376-.3667-.05591-.13574-.02039-.27-.04547-.4082-.0589-.20215-.01977-.40479-.02624-.60742-.0307C128.11768,152.00763,128.05957,152,128,152s-.11768.00763-.17676.00891c-.20263.00446-.40527.01093-.60742.0307-.13818.01343-.27246.03851-.4082.0589-.12256.01831-.24512.03186-.3667.05591-.145.02869-.28565.06811-.42822.10455-.11036.02826-.22168.05219-.33106.08521-.13574.041-.2666.09155-.39941.13952-.11426.0412-.2295.07862-.3418.12519-.11963.04962-.23438.10772-.35107.1629-.12061.05688-.24219.11047-.36084.17371-.10645.057-.207.12194-.31055.18359-.12158.07214-.24414.141-.36231.22009-.10644.07105-.20556.15045-.3081.22638-.10742.07965-.21729.15473-.32178.24048-.14453.119-.28076.248-.417.37671-.05469.05151-.11279.09668-.166.15L94.05859,182.627a8.00053,8.00053,0,0,0,11.31446,11.31446L120,179.31384V232a8,8,0,0,0,16,0V179.31384L150.627,193.94141A8.00053,8.00053,0,0,0,161.94141,182.627Z"
      }), React__default.createElement("path", {
        d: "M122.34277,101.65723c.0542.05432.11377.10034.16895.15277.13525.12762.27.25561.41406.37365.10645.08759.21826.16431.32813.24555.10009.074.19726.15173.30078.22113.12207.0816.248.15265.37353.22681.09912.059.19629.12152.29834.17627.124.06646.25147.12292.37842.18237.11035.05194.21875.10712.332.15411.1211.05011.24463.0907.36768.13465.12353.04431.2456.09173.37207.13006.12158.03681.24512.06384.36816.09473.13037.03284.25879.06927.3916.09558.14063.028.28321.04456.42481.06482.1167.01666.231.03876.34912.05035.26221.02588.52588.03992.78955.03992s.52734-.014.78955-.03992c.11816-.01159.23242-.03369.34912-.05035.1416-.02026.28418-.03687.42481-.06482.13281-.02631.26123-.06274.3916-.09558.123-.03089.24658-.05792.36816-.09473.12647-.03833.24854-.08575.37207-.13006.12305-.04395.24658-.08454.36768-.13465.11328-.047.22168-.10217.332-.15411.127-.05945.25439-.11591.37842-.18237.10205-.05475.19922-.11725.29834-.17627.12549-.07416.25146-.14521.37353-.22681.10352-.0694.20069-.1471.30078-.22113.10987-.08124.22168-.158.32813-.24555.144-.118.27881-.246.41406-.37365.05518-.05243.11475-.09845.16895-.15277l28.28418-28.28418A8.00053,8.00053,0,0,0,150.627,62.05859L136,76.68616V24a8,8,0,0,0-16,0V76.68616L105.37305,62.05859A8.00053,8.00053,0,0,0,94.05859,73.37305Z"
      }), React__default.createElement("path", {
        d: "M101.81592,133.48169c.12549-.13287.251-.26532.36719-.40649.0913-.11072.17138-.22718.25537-.34156.07031-.09564.14453-.18805.21093-.28686.085-.12659.15918-.25782.23584-.38806.05567-.09443.11524-.18622.167-.28309.06933-.12915.12841-.26184.18994-.39379.04931-.10547.10205-.20874.147-.31665.05225-.12653.09522-.25568.14063-.38428.042-.11817.0874-.2345.124-.35517.03906-.1289.06787-.25982.10058-.39019.03077-.123.06543-.24414.09034-.36933.02978-.15149.04834-.30444.06933-.45715.01465-.1059.03516-.2099.0459-.31714a8.02155,8.02155,0,0,0,0-1.58386c-.01074-.10724-.03125-.21124-.0459-.31714-.021-.15271-.03955-.30566-.06933-.45715-.02491-.12519-.05957-.24634-.09034-.36933-.03271-.13037-.06152-.26129-.10058-.39019-.03662-.12067-.082-.237-.124-.35517-.04541-.1286-.08838-.25775-.14063-.38428-.04492-.10791-.09766-.21118-.147-.31665-.06153-.132-.12061-.26464-.18994-.39379-.05176-.09687-.11133-.18866-.167-.28309-.07666-.13024-.15087-.26147-.23584-.38806-.0664-.09881-.14062-.19122-.21093-.28686-.084-.11438-.16407-.23084-.25537-.34156-.11622-.14117-.2417-.27362-.36719-.40649-.0542-.05768-.10205-.11914-.15869-.17554L73.37305,94.05859a8.00053,8.00053,0,0,0-11.31446,11.31446L76.686,120H24a8,8,0,0,0,0,16H76.686L62.05859,150.627a8.00053,8.00053,0,0,0,11.31446,11.31446l28.28418-28.28418C101.71387,133.60083,101.76172,133.53937,101.81592,133.48169Z"
      }), React__default.createElement("path", {
        d: "M232,120H179.314l14.62745-14.62695A8.00053,8.00053,0,0,0,182.627,94.05859l-28.28418,28.28418c-.05664.0564-.10449.11786-.15869.17554-.12549.13287-.251.26532-.36719.40649-.0913.11072-.17138.22718-.25537.34156-.07031.09564-.14453.188-.21093.28686-.085.12659-.15918.25782-.23584.38806-.05567.09443-.11524.18622-.167.28309-.06933.12915-.12841.26184-.18994.39379-.04931.10547-.10205.20874-.147.31665-.05225.12653-.09522.25568-.14063.38428-.042.11817-.0874.2345-.124.35517-.03906.1289-.06787.25982-.10058.39019-.03077.123-.06543.24414-.09034.36933-.02978.15149-.04834.30444-.06933.45715-.01465.1059-.03516.2099-.0459.31714a8.02155,8.02155,0,0,0,0,1.58386c.01074.10724.03125.21124.0459.31714.021.15271.03955.30566.06933.45715.02491.12519.05957.24634.09034.36933.03271.13037.06152.26129.10058.39019.03662.12067.082.237.124.35517.04541.1286.08838.25775.14063.38428.04492.10791.09766.21118.147.31665.06153.13195.12061.26464.18994.39379.05176.09687.11133.18866.167.28309.07666.13024.15087.26147.23584.38806.0664.09881.14062.19122.21093.28686.084.11438.16407.23084.25537.34156.11622.14117.2417.27362.36719.40649.0542.05768.10205.11914.15869.17554L182.627,161.94141A8.00053,8.00053,0,0,0,193.94141,150.627L179.314,136H232a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "156.284 188.284 128 160 99.716 188.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "99.716 67.716 128 96 156.284 67.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "67.716 156.284 96 128 67.716 99.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "128",
        x2: "96",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "188.284 99.716 160 128 188.284 156.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "156.284 188.284 128 160 99.716 188.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "99.716 67.716 128 96 156.284 67.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "67.716 156.284 96 128 67.716 99.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "128",
        x2: "96",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "188.284 99.716 160 128 188.284 156.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "156.284 188.284 128 160 99.716 188.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "99.716 67.716 128 96 156.284 67.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "67.716 156.284 96 128 67.716 99.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "128",
        x2: "96",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "188.284 99.716 160 128 188.284 156.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsInCardinal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1A(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsInCardinal.displayName = "ArrowsInCardinal";

var renderPathFor$1B = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "12",
        y1: "128",
        x2: "88",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "56 96 88 128 56 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "244",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "200 160 168 128 200 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "128",
        x2: "96",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 96 96 128 64 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 160 160 128 192 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,40V216a8,8,0,0,1-16,0V40a8,8,0,0,1,16,0Zm-33.56152,92.73364c.07031-.0957.14453-.188.21093-.28686.085-.12659.15918-.25782.23584-.38806.05567-.09436.11524-.18616.167-.28309.06933-.12915.12841-.26184.18994-.39379.04931-.10547.10205-.20874.147-.31665.05225-.12647.09522-.25562.14063-.38428.042-.11817.0874-.2345.124-.35523.03906-.1289.06787-.25976.10058-.39013.03077-.12305.06543-.24414.09034-.36939.02978-.15137.04834-.30444.06933-.457.01465-.106.03516-.21.0459-.31714a8.02276,8.02276,0,0,0,0-1.584c-.01074-.10718-.03125-.21118-.0459-.31714-.021-.15259-.03955-.30566-.06933-.457-.02491-.12525-.05957-.24634-.09034-.36939-.03271-.13037-.06152-.26123-.10058-.39013-.03662-.12073-.082-.23706-.124-.35523-.04541-.12866-.08838-.25781-.14063-.38428-.04492-.10791-.09766-.21118-.147-.31665-.06153-.132-.12061-.26464-.18994-.39379-.05176-.09693-.11133-.18873-.167-.28309-.07666-.13024-.15087-.26147-.23584-.38806-.0664-.09887-.14062-.19116-.21093-.28686-.084-.11438-.16407-.23084-.25537-.34156-.11622-.14111-.2417-.27368-.36719-.40649-.0542-.05762-.10205-.11914-.15869-.17554l-32-32a8.00053,8.00053,0,0,0-11.31446,11.31446L76.686,120H16a8,8,0,0,0,0,16H76.686L58.34277,154.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l32-32c.05664-.0564.10449-.11792.15869-.17554.12549-.13281.251-.26538.36719-.40649C102.27441,132.96448,102.35449,132.848,102.43848,132.73364ZM240,120H179.314l18.34327-18.34277a8.00053,8.00053,0,0,0-11.31446-11.31446l-32,32c-.05664.0564-.10449.11792-.15869.17554-.12549.13281-.251.26538-.36719.40649-.0913.11072-.17138.22718-.25537.34156-.07031.0957-.14453.188-.21093.28686-.085.12659-.15918.25782-.23584.38806-.05567.09436-.11524.18616-.167.28309-.06933.12915-.12841.26184-.18994.39379-.04931.10547-.10205.20874-.147.31665-.05225.12647-.09522.25562-.14063.38428-.042.11817-.0874.2345-.124.35523-.03906.1289-.06787.25976-.10058.39013-.03077.12305-.06543.24414-.09034.36939-.02978.15137-.04834.30444-.06933.457-.01465.106-.03516.21-.0459.31714a8.02276,8.02276,0,0,0,0,1.584c.01074.10718.03125.21118.0459.31714.021.15259.03955.30566.06933.457.02491.12525.05957.24634.09034.36939.03271.13037.06152.26123.10058.39013.03662.12073.082.23706.124.35523.04541.12866.08838.25781.14063.38428.04492.10791.09766.21118.147.31665.06153.13195.12061.26464.18994.39379.05176.09693.11133.18873.167.28309.07666.13024.15087.26147.23584.38806.0664.09887.14062.19116.21093.28686.084.11438.16407.23084.25537.34156.11622.14111.2417.27368.36719.40649.0542.05762.10205.11914.15869.17554l32,32a8.00053,8.00053,0,0,0,11.31446-11.31446L179.314,136H240a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "128",
        x2: "96",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "64 96 96 128 64 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "192 160 160 128 192 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "128",
        x2: "96",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "64 96 96 128 64 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "192 160 160 128 192 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "128",
        x2: "96",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 96 96 128 64 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 160 160 128 192 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsInLineHorizontal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1B(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsInLineHorizontal.displayName = "ArrowsInLineHorizontal";

var renderPathFor$1C = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "12",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "160 56 128 88 96 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "244",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "96 200 128 168 160 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "16",
        x2: "128",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 64 128 96 96 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "240",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 192 128 160 160 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,128a8.00039,8.00039,0,0,1-8,8H40a8,8,0,0,1,0-16H216A8.00039,8.00039,0,0,1,224,128ZM122.34277,101.65723c.0542.0542.11377.10034.16895.15283.13525.12744.27.25561.41406.37353.10645.08765.21826.16431.32813.24561.10009.074.19726.15185.30078.22119.12207.08154.248.15259.37353.22681.09912.05884.19629.12134.29834.17627.124.0664.25147.1228.37842.18237.11035.05176.21875.10693.332.154.1211.05005.24463.09058.36768.13452.12353.04444.2456.0918.37207.13013.12158.03687.24512.064.36816.09473.13037.033.25879.06933.3916.0957.14063.02783.28321.04443.42481.0647.1167.0166.231.03882.34912.05029.26221.02588.52588.04.78955.04s.52734-.01416.78955-.04c.11816-.01147.23242-.03369.34912-.05029.1416-.02027.28418-.03687.42481-.0647.13281-.02637.26123-.06274.3916-.0957.123-.03076.24658-.05786.36816-.09473.12647-.03833.24854-.08569.37207-.13013.12305-.04394.24658-.08447.36768-.13452.11328-.04712.22168-.10229.332-.154.127-.05957.25439-.116.37842-.18237.10205-.05493.19922-.11743.29834-.17627.12549-.07422.25146-.14527.37353-.22681.10352-.06934.20069-.14722.30078-.22119.10987-.0813.22168-.158.32813-.24561.144-.11792.27881-.24609.41406-.37353.05518-.05249.11475-.09863.16895-.15283l32-32a8.00053,8.00053,0,0,0-11.31446-11.31446L136,76.68628V16a8,8,0,0,0-16,0V76.68628L101.65723,58.34277A8.00053,8.00053,0,0,0,90.34277,69.65723Zm11.31446,52.68554c-.05323-.05322-.11133-.09863-.166-.1499-.13623-.12891-.27246-.25781-.417-.37695-.10449-.0857-.21436-.16065-.32178-.24024-.10254-.07617-.20166-.15551-.3081-.22656-.11817-.0791-.24073-.148-.36231-.22-.10351-.06177-.2041-.12671-.31055-.18359-.11865-.06324-.24023-.117-.36084-.17383-.11669-.05518-.23144-.11328-.35107-.16284-.1123-.04663-.22754-.084-.3418-.12525-.13281-.04785-.26367-.09839-.39941-.1394-.10938-.0332-.2207-.05713-.33106-.08521-.14257-.03637-.2832-.07592-.42822-.10473-.12158-.02393-.24414-.0376-.3667-.05567-.13574-.02051-.27-.04565-.4082-.05908-.20215-.01977-.40479-.02612-.60742-.03076C128.11768,152.00757,128.05957,152,128,152s-.11768.00757-.17676.00879c-.20263.00464-.40527.011-.60742.03076-.13818.01343-.27246.03857-.4082.05908-.12256.01807-.24512.03174-.3667.05567-.145.02881-.28565.06836-.42822.10473-.11036.02808-.22168.052-.33106.08521-.13574.041-.2666.09155-.39941.1394-.11426.04126-.2295.07862-.3418.12525-.11963.04956-.23438.10766-.35107.16284-.12061.05688-.24219.11059-.36084.17383-.10645.05688-.207.12182-.31055.18359-.12158.072-.24414.14087-.36231.22-.10644.07105-.20556.15039-.3081.22656-.10742.07959-.21729.15454-.32178.24024-.14453.11914-.28076.248-.417.37695-.05469.05127-.11279.09668-.166.1499l-32,32a8.00053,8.00053,0,0,0,11.31446,11.31446L120,179.31372V240a8,8,0,0,0,16,0V179.31372l18.34277,18.34351a8.00053,8.00053,0,0,0,11.31446-11.31446Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "16",
        x2: "128",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "160 64 128 96 96 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "240",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "96 192 128 160 160 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "16",
        x2: "128",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "160 64 128 96 96 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "240",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "96 192 128 160 160 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "16",
        x2: "128",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 64 128 96 96 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "240",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 192 128 160 160 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsInLineVertical = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1C(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsInLineVertical.displayName = "ArrowsInLineVertical";

var renderPathFor$1D = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 56 152 104 200 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "152",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "56 152 104 152 104 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "104",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 56 152 104 200 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "152",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 152 104 152 104 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "104",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M213.65723,42.34277a8.003,8.003,0,0,0-11.31446,0L160,84.68555V56a8,8,0,0,0-16,0v47.99487q0,.39918.04.79712c.01074.10718.03125.21118.0459.31714.021.15259.03955.30566.06933.457.02491.12525.05957.24634.09034.36939.03271.13037.06152.26123.10058.39013.03662.12073.082.23706.124.35523.04541.12866.08838.25781.14063.38428.04492.10791.09766.21118.147.31665.06153.132.12061.26464.18994.39379.05176.09693.11133.18873.167.28309.07666.13024.15087.26147.23584.38806.0664.09887.14062.19116.21093.28686.084.11438.16407.23084.25537.34156.11622.14111.2417.27368.36719.40649.0542.05762.10205.11914.15869.17554.0542.05432.11377.10034.16895.15283.13525.12756.27.25561.41406.37353.10645.08765.21826.16431.32813.24561.10009.074.19726.15173.30078.22119.12207.08154.248.15259.37353.22681.09912.059.19629.12146.29834.17627.124.0664.25147.1228.37842.18237.11035.05188.21875.10706.332.154.1211.05005.24463.0907.36768.13465.12353.04431.2456.09167.37207.13.12158.03687.24512.064.36816.09473.13037.033.25879.06933.3916.0957.14063.02783.28321.04443.42481.0647.1167.01672.231.03882.34912.05041.26221.02588.52588.03992.78955.03992h48a8,8,0,0,0,0-16H171.31445l42.34278-42.34277A8.00122,8.00122,0,0,0,213.65723,42.34277Z"
      }), React__default.createElement("path", {
        d: "M111.96,151.208c-.01074-.10718-.03125-.21118-.0459-.31714-.021-.15259-.03955-.30566-.06933-.457-.02491-.12525-.05957-.24634-.09034-.36939-.03271-.13037-.06152-.26123-.10058-.39013-.03662-.12073-.082-.23706-.124-.35523-.04541-.12866-.08838-.25781-.14063-.38428-.04492-.10791-.09766-.21118-.147-.31665-.06153-.13195-.12061-.26464-.18994-.39379-.05176-.09693-.11133-.18873-.167-.28309-.07666-.13024-.15087-.26147-.23584-.38806-.0664-.09887-.14062-.19116-.21093-.28686-.084-.11438-.16407-.23084-.25537-.34156-.11622-.14111-.2417-.27368-.36719-.40649-.0542-.05762-.10205-.11914-.15869-.17554-.05323-.05334-.11133-.09851-.166-.15-.13623-.12879-.27246-.25769-.417-.37671-.10449-.08582-.21436-.16077-.32178-.24048-.10254-.07593-.20166-.15539-.3081-.22644-.11817-.0791-.24073-.148-.36231-.22-.10351-.06177-.2041-.12671-.31055-.18359-.11865-.06324-.24023-.117-.36084-.17383-.11669-.05518-.23144-.11328-.35107-.16284-.1123-.04663-.22754-.084-.3418-.12525-.13281-.04785-.26367-.09839-.39941-.1394-.10938-.03308-.2207-.057-.33106-.08521-.14257-.0365-.2832-.07592-.42822-.10461-.12158-.024-.24414-.0376-.3667-.05591-.13574-.02039-.27-.04553-.4082-.059-.20215-.01977-.40479-.02612-.60742-.03064C104.11768,144.00757,104.05957,144,104,144H56a8,8,0,0,0,0,16H84.68555L42.34277,202.34277a8.00053,8.00053,0,0,0,11.31446,11.31446L96,171.31445V200a8,8,0,0,0,16,0V152.00513Q112,151.606,111.96,151.208Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 56 152 104 200 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "152",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "56 152 104 152 104 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "104",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 56 152 104 200 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "152",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "56 152 104 152 104 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "104",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "152 56 152 104 200 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "152",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 152 104 152 104 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "104",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsInSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1D(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsInSimple.displayName = "ArrowsInSimple";

var renderPathFor$1E = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "192 144 224 176 192 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "176",
        x2: "224",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "64 112 32 80 64 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "224.00006",
        y1: "80",
        x2: "32.00006",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "192 144 224 176 192 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "176",
        x2: "224",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 112 32 80 64 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224.00006",
        y1: "80",
        x2: "32.00006",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M230.18408,181.07373c.0874-.106.16406-.21777.24512-.32764.07373-.09961.15137-.19677.2207-.30029.0835-.12451.15625-.25342.23194-.38135.05712-.09668.11767-.19043.17089-.28955.06885-.12793.127-.25976.18848-.39062.04981-.106.10254-.21045.148-.31934.05225-.12646.09473-.25537.14014-.3833.04248-.11865.08789-.23486.12451-.356.03906-.1289.06787-.25976.10058-.39013.03077-.12305.06543-.24414.09034-.36914.02978-.15186.04834-.30518.06982-.458.01465-.10547.03467-.20947.04541-.31641a8.02276,8.02276,0,0,0,0-1.584c-.01074-.10694-.03076-.21094-.04541-.31641-.02148-.15283-.04-.30615-.06982-.458-.02491-.125-.05957-.24609-.09034-.36914-.03271-.13037-.06152-.26123-.10058-.39013-.03662-.1211-.082-.23731-.12451-.356-.04541-.12793-.08789-.25684-.14014-.3833-.04541-.10889-.09814-.21338-.148-.31934-.06152-.13086-.11963-.26269-.18848-.39062-.05322-.09912-.11377-.19287-.17089-.28955-.07569-.12793-.14844-.25684-.23194-.38135-.06933-.10352-.147-.20068-.2207-.30029-.08106-.10987-.15772-.22168-.24512-.32764-.13281-.16211-.27588-.31543-.42138-.46631-.03663-.03809-.06788-.07959-.10547-.11719l-32-32a8.00053,8.00053,0,0,0-11.31446,11.31446L204.68652,168H32a8,8,0,0,0,0,16H204.68652l-18.34375,18.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l32-32c.04-.04053.07422-.08448.11328-.12549C229.91309,181.3833,230.05371,181.23291,230.18408,181.07373Z"
      }), React__default.createElement("path", {
        d: "M25.5708,75.25391c-.07373.09961-.15137.19677-.2207.30029-.0835.12451-.15625.25342-.23194.38135-.05712.09668-.11767.19043-.17089.28955-.06885.12793-.127.25976-.18848.39062-.04981.106-.10254.21045-.148.31934-.05225.12646-.09473.25537-.14014.3833-.04248.11865-.08789.23486-.12451.356-.03906.1289-.06787.25976-.10058.39013-.03077.12305-.06543.24414-.09034.36914-.02978.15186-.04834.30518-.06982.458-.01465.10547-.03467.20947-.04541.31641a8.02276,8.02276,0,0,0,0,1.584c.01074.10694.03076.21094.04541.31641.02148.15283.04.30615.06982.458.02491.125.05957.24609.09034.36914.03271.13037.06152.26123.10058.39013.03662.1211.082.23731.12451.356.04541.12793.08789.25684.14014.3833.04541.10889.09814.21338.148.31934.06152.13086.11963.26269.18848.39062.05322.09912.11377.19287.17089.28955.07569.12793.14844.25684.23194.38135.06933.10352.147.20068.2207.30029.08106.10987.15772.22168.24512.32764.13037.15918.271.30957.41357.458.03906.041.07324.085.11328.12549l32,32a8.00053,8.00053,0,0,0,11.31446-11.31446L51.31348,88H224a8,8,0,0,0,0-16H51.31348L69.65723,53.65723A8.00053,8.00053,0,0,0,58.34277,42.34277l-32,32c-.03759.0376-.06884.0791-.10547.11719-.1455.15088-.28857.3042-.42138.46631C25.72852,75.03223,25.65186,75.144,25.5708,75.25391Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "192 144 224 176 192 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "176",
        x2: "224",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "64 112 32 80 64 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "224.00006",
        y1: "80",
        x2: "32.00006",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "192 144 224 176 192 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "176",
        x2: "224",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "64 112 32 80 64 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "224.00006",
        y1: "80",
        x2: "32.00006",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "192 144 224 176 192 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "176",
        x2: "224",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "64 112 32 80 64 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224.00006",
        y1: "80",
        x2: "32.00006",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsLeftRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1E(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsLeftRight.displayName = "ArrowsLeftRight";

var renderPathFor$1F = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "88 208 48 208 48 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "48",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "152",
        x2: "208",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "48 88 48 48 88 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "48",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "88 208 48 208 48 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "48",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "152",
        x2: "208",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 88 48 48 88 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "48",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M152,112a7.97619,7.97619,0,0,0,5.65723-2.34326L200,67.314V88a8,8,0,0,0,16,0V48.00488c0-.26562-.01367-.53174-.04-.79687-.01074-.10742-.03125-.21143-.0459-.31739-.021-.15234-.03955-.30517-.06933-.45654-.02539-.126-.06006-.248-.09082-.37207-.03223-.12939-.061-.25928-.09961-.38721-.03711-.12207-.083-.23925-.12549-.35839-.04541-.12745-.0874-.25586-.13965-.38086-.04541-.11035-.09912-.21582-.1499-.32325-.06055-.12939-.11817-.25976-.186-.38671-.0542-.10108-.1167-.19776-.17529-.29639-.07422-.12549-.14551-.252-.227-.374-.07178-.10694-.15186-.20752-.22852-.31055-.07861-.106-.15283-.21484-.23779-.31787-.13916-.16992-.28857-.33057-.44141-.48828-.02978-.03125-.05517-.06494-.08593-.09522-.02735-.02734-.05762-.05029-.085-.07715-.16114-.15625-.32618-.30908-.5-.45166-.09913-.081-.20313-.15234-.30518-.228-.10742-.08008-.2124-.16358-.32373-.2378-.11768-.0791-.23975-.14746-.36084-.21924-.103-.06152-.2041-.12646-.31006-.18359-.12158-.06494-.24609-.12012-.37012-.17822-.11328-.05322-.22461-.10987-.34082-.1582-.11865-.04883-.23974-.08838-.36035-.13184-.126-.04492-.25-.09326-.3789-.13233-.12012-.03662-.2417-.063-.36329-.09326-.13183-.0332-.26171-.07031-.396-.09668-.13965-.02783-.28076-.04443-.42139-.06445-.11719-.01709-.23291-.03906-.35205-.05078-.26269-.02588-.52588-.04-.78955-.04H168a8,8,0,0,0,0,16h20.686L146.34277,98.34326A8,8,0,0,0,152,112Z"
      }), React__default.createElement("path", {
        d: "M98.34277,146.34326,56,188.686V168a8,8,0,0,0-16,0v39.99512c0,.26562.01367.53174.04.79687.01074.10742.03125.21192.0459.31787.021.15235.03955.30518.06933.45606.02539.126.06006.248.09082.37207.03223.12939.061.25928.09961.38721.03711.12207.083.23974.12549.35888.04541.12744.0874.25537.13916.38037.0459.11035.09961.21582.15039.32325.06055.12939.11817.25976.186.38671.0542.10059.11572.19629.17383.29444.0747.126.14648.25342.229.37646.07129.106.15039.20606.22656.3086.0791.10644.15381.21582.23926.31933.13916.16992.28857.33057.44141.48828.02978.03125.05517.06494.08593.09522.02735.02734.05762.05029.085.07715.16114.15625.32618.30908.5.45166.1001.082.20557.15429.30909.231.106.07862.209.16114.31884.23438.11914.07959.24268.14892.36475.22168.10205.061.20215.125.30713.18164.12256.06543.249.12109.374.18018.11182.05224.22119.10839.33545.15576.12207.05029.2461.09131.37012.13525.12256.044.24365.09082.36865.12891.12354.03759.249.06494.374.09619.12842.03222.25538.06836.38624.09424.14208.02832.28564.04492.42871.06543.11572.0166.229.03857.3457.0498.26221.02588.52588.04.78955.04H88a8,8,0,0,0,0-16H67.314l42.34327-42.34326a8.00018,8.00018,0,0,0-11.31446-11.31348Z"
      }), React__default.createElement("path", {
        d: "M214.42383,212.75391c.07617-.10254.15527-.20264.22656-.3086.08252-.123.1543-.25049.229-.37646.05811-.09815.11963-.19385.17383-.29444.06787-.12695.12549-.25732.186-.38671.05078-.10743.10449-.2129.15039-.32325.05176-.125.09375-.25293.13916-.38037.04248-.11914.08838-.23681.12549-.35888.03857-.12793.06738-.25782.09961-.38721.03076-.124.06543-.2461.09082-.37207.02978-.15088.04834-.30371.06933-.45606.01465-.106.03516-.21045.0459-.31787.02637-.26513.04-.53125.04-.79687V168a8,8,0,0,0-16,0v20.686l-42.34277-42.34278a8.00018,8.00018,0,0,0-11.31446,11.31348L188.686,200H168a8,8,0,0,0,0,16h40c.26367,0,.52734-.01416.78955-.04.1167-.01123.23-.0332.3457-.0498.14307-.02051.28662-.03711.42871-.06543.13086-.02588.25782-.062.38624-.09424.125-.03125.25048-.0586.374-.09619.125-.03809.24609-.085.36865-.12891.124-.04394.24805-.085.37012-.13525.11426-.04737.22363-.10352.33545-.15576.125-.05909.25146-.11475.374-.18018.105-.05664.20508-.12061.30713-.18164.12207-.07276.24561-.14209.36475-.22168.10986-.07324.21289-.15576.31884-.23438.10352-.07666.209-.14892.30909-.231.17382-.14258.33886-.29541.5-.45166.02734-.02686.05761-.04981.085-.07715.03076-.03028.05615-.064.08593-.09522.15284-.15771.30225-.31836.44141-.48828C214.27,212.96973,214.34473,212.86035,214.42383,212.75391Z"
      }), React__default.createElement("path", {
        d: "M67.314,56H88a8,8,0,0,0,0-16H48c-.26367,0-.52686.01416-.78955.04-.11914.01172-.23486.03369-.352.05078-.14063.02-.28174.03662-.42139.06445-.13428.02637-.26416.06348-.396.09668-.12159.03028-.24317.05664-.36329.09326-.1289.03907-.25293.08741-.3789.13233-.12061.04346-.2417.083-.36035.13184-.11621.04833-.22754.105-.34082.1582-.124.0581-.24854.11328-.37012.17822-.106.05713-.207.12207-.31006.18359-.12109.07178-.24316.14014-.36084.21924-.11133.07422-.21631.15772-.32373.2378-.102.07568-.206.147-.30518.228-.17382.14258-.33886.29541-.5.45166-.02734.02686-.05761.04981-.085.07715-.03076.03028-.05615.064-.08593.09522-.15284.15771-.30225.31836-.44141.48828-.085.103-.15918.21191-.23779.31787-.07666.103-.15674.20361-.22852.31055-.08154.12207-.15283.24853-.227.374-.05859.09863-.12109.19531-.17529.29639-.06787.127-.12549.25732-.186.38671-.05078.10743-.10449.2129-.1499.32325-.05225.125-.09424.25341-.13965.38086-.04248.11914-.08838.23632-.12549.35839-.03857.12793-.06738.25782-.09961.38721-.03076.124-.06543.2461-.09082.37207-.02978.15137-.04834.3042-.06933.45654-.01465.106-.03516.21-.0459.31739-.02637.26513-.04.53125-.04.79687V88a8,8,0,0,0,16,0V67.314l42.34277,42.34278a8.00018,8.00018,0,0,0,11.31446-11.31348Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "88 208 48 208 48 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "48",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "152",
        x2: "208",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "48 88 48 48 88 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "48",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "88 208 48 208 48 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "48",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "152",
        x2: "208",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "48 88 48 48 88 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "48",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "88 208 48 208 48 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "48",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "152",
        x2: "208",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 88 48 48 88 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "48",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsOut = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1F(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsOut.displayName = "ArrowsOut";

var renderPathFor$1G = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "156.284 203.716 128 232 99.716 203.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "160",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "99.716 52.284 128 24 156.284 52.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "52.284 156.284 24 128 52.284 99.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "24",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "203.716 99.716 232 128 203.716 156.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "128",
        x2: "232",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "156.284 203.716 128 232 99.716 203.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "160",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "99.716 52.284 128 24 156.284 52.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "52.284 156.284 24 128 52.284 99.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "24",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "203.716 99.716 232 128 203.716 156.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "128",
        x2: "232",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M150.627,198.05859,136,212.686V160a8,8,0,0,0-16,0v52.686l-14.62695-14.62745a8.00036,8.00036,0,0,0-11.31446,11.314l28.28418,28.28418c.0459.0459.09668.08545.14356.12988.1416.13526.28369.269.43457.39356.06152.05078.12793.09423.19092.14306.144.11133.28808.22364.43945.3252.05127.03418.106.063.1582.09619.16846.10742.33838.21289.51514.3081.03711.02.07715.03565.11523.05518.19385.1001.39063.19629.59375.28076.02344.00977.04737.0166.07032.02588.21777.08789.43847.16895.66455.23779.02783.00879.05713.01368.085.022.2207.06445.44385.12353.67187.16894.0669.01319.13575.019.20313.03076.18945.03321.3789.06641.57226.08545a7.90223,7.90223,0,0,0,1.59864,0c.19336-.019.38281-.05224.57226-.08545.06738-.01172.13623-.01757.20313-.03076.228-.04541.45117-.10449.67187-.16894.02783-.0083.05713-.01319.085-.022.22608-.06884.44678-.1499.66455-.23779.02295-.00928.04688-.01611.07032-.02588.20312-.08447.3999-.18066.59375-.28076.03808-.01953.07812-.03516.11523-.05518.17676-.09521.34668-.20068.51514-.3081.05224-.0332.10693-.062.1582-.09619.15137-.10156.29541-.21387.43945-.3252.063-.04883.1294-.09228.19092-.14306.15088-.12452.293-.2583.43457-.39356.04688-.04443.09766-.084.14356-.12988l28.28418-28.28418a8.00036,8.00036,0,0,0-11.31446-11.314Z"
      }), React__default.createElement("path", {
        d: "M105.37305,57.94141,120,43.314V96a8,8,0,0,0,16,0V43.314L150.627,57.94141a8.00036,8.00036,0,0,0,11.31446-11.314L133.65723,18.34326c-.04151-.0415-.08789-.07715-.12989-.11767-.1455-.13965-.29248-.27784-.44824-.40577-.06152-.05078-.12793-.09423-.19092-.14306-.144-.11133-.28808-.22364-.43945-.3252-.05127-.03418-.106-.063-.1582-.09619-.16846-.10742-.33838-.21289-.51514-.3081-.0376-.02-.07764-.03614-.11621-.05567-.19336-.1001-.38965-.1958-.59229-.28027-.02587-.01074-.05224-.01807-.07812-.02832-.21533-.08692-.43359-.16748-.65723-.23535-.02783-.00879-.05713-.01368-.085-.022-.2207-.06445-.44385-.12353-.67187-.16894-.0669-.01319-.13575-.019-.20313-.03076-.18945-.03321-.3789-.06641-.57226-.08545a7.90223,7.90223,0,0,0-1.59864,0c-.19336.019-.38281.05224-.57226.08545-.06738.01172-.13623.01757-.20313.03076-.228.04541-.45117.10449-.67187.16894-.02783.0083-.05713.01319-.085.022-.22364.06787-.4419.14843-.65723.23535-.02588.01025-.05225.01758-.07812.02832-.20264.08447-.39893.18017-.59229.28027-.03857.01953-.07861.03565-.11621.05567-.17676.09521-.34668.20068-.51514.3081-.05224.0332-.10693.062-.1582.09619-.15137.10156-.29541.21387-.43945.3252-.063.04883-.1294.09228-.19092.14306-.15576.12793-.30274.26612-.44824.40577-.042.04052-.08838.07617-.12989.11767L94.05859,46.62744a8.00036,8.00036,0,0,0,11.31446,11.314Z"
      }), React__default.createElement("path", {
        d: "M43.31348,136H96a8,8,0,0,0,0-16H43.31348l14.62793-14.62744A8.00036,8.00036,0,0,0,46.627,94.05859L18.34277,122.34326c-.03076.03028-.05615.064-.08593.09522-.15284.15771-.30225.31836-.44141.48828-.08594.10449-.16113.21386-.24072.32129-.0752.102-.1543.20117-.2251.30664-.083.12353-.15479.252-.23.3789-.05762.09717-.11914.1919-.17236.29151-.06836.12744-.12647.25879-.1875.38916-.0503.10644-.10352.21142-.14893.3208-.05225.126-.09424.25439-.14014.38232-.042.11866-.08789.23584-.125.35694-.03857.12841-.06738.25879-.09961.38916-.03076.123-.06543.24511-.09082.3706-.02978.15137-.04834.3042-.06933.457-.01514.106-.03516.20948-.0459.3169a8.02276,8.02276,0,0,0,0,1.584c.01074.10742.03076.21094.0459.3169.021.15283.03955.30566.06933.457.02539.12549.06006.24756.09082.3706.03223.13037.061.26075.09961.38916.03711.1211.083.23828.125.35694.0459.12793.08789.25634.14014.38232.04541.10938.09863.21436.14893.3208.061.13037.11914.26172.1875.38916.05322.09961.11474.19434.17236.29151.07519.127.147.25537.23.3789.0708.10547.1499.20459.2251.30664.07959.10743.15478.2168.24072.32129.13672.16651.28369.32471.43311.47949.03271.03418.061.07081.09423.104L46.627,161.94141a8.00036,8.00036,0,0,0,11.31446-11.314Z"
      }), React__default.createElement("path", {
        d: "M238.18457,133.07324c.08594-.10449.16113-.21386.24072-.32129.0752-.102.1543-.20117.2251-.30664.083-.12353.15479-.25195.23-.3789.05762-.09717.11914-.1919.17236-.29151.06836-.12744.12647-.25879.1875-.38916.0503-.10644.10352-.21142.14893-.3208.05225-.126.09424-.25439.14014-.38232.042-.11866.08789-.23584.125-.35694.03857-.12841.06738-.25879.09961-.38916.03076-.123.06543-.24511.09082-.3706.02978-.15137.04834-.3042.06933-.457.01514-.106.03516-.20948.0459-.3169a8.02276,8.02276,0,0,0,0-1.584c-.01074-.10742-.03076-.21094-.0459-.3169-.021-.15283-.03955-.30566-.06933-.457-.02539-.12549-.06006-.24756-.09082-.3706-.03223-.13037-.061-.26075-.09961-.38916-.03711-.1211-.083-.23828-.125-.35694-.0459-.12793-.08789-.25634-.14014-.38232-.04541-.10938-.09863-.21436-.14893-.3208-.061-.13037-.11914-.26172-.1875-.38916-.05322-.09961-.11474-.19434-.17236-.29151-.07519-.12695-.147-.25537-.23-.3789-.0708-.10547-.1499-.20459-.2251-.30664-.07959-.10743-.15478-.2168-.24072-.32129-.13916-.16992-.28857-.33057-.44141-.48828-.02978-.03125-.05517-.06494-.08593-.09522L209.37305,94.05859a8.00036,8.00036,0,0,0-11.31446,11.314L212.68652,120H160a8,8,0,0,0,0,16h52.68652l-14.62793,14.62744a8.00036,8.00036,0,0,0,11.31446,11.314l28.28418-28.28467c.0332-.0332.06152-.06983.09423-.104C237.90088,133.398,238.04785,133.23975,238.18457,133.07324Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "156.284 203.716 128 232 99.716 203.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "160",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "99.716 52.284 128 24 156.284 52.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "52.284 156.284 24 128 52.284 99.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "24",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "203.716 99.716 232 128 203.716 156.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "128",
        x2: "232",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "156.284 203.716 128 232 99.716 203.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "160",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "99.716 52.284 128 24 156.284 52.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "52.284 156.284 24 128 52.284 99.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "24",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "203.716 99.716 232 128 203.716 156.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "128",
        x2: "232",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "156.284 203.716 128 232 99.716 203.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "160",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "99.716 52.284 128 24 156.284 52.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "52.284 156.284 24 128 52.284 99.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "24",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "203.716 99.716 232 128 203.716 156.284",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "128",
        x2: "232",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsOutCardinal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1G(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsOutCardinal.displayName = "ArrowsOutCardinal";

var renderPathFor$1H = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "12",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "44 96 12 128 44 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "128",
        x2: "244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "212 160 244 128 212 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "16",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 160 16 128 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "128",
        x2: "240",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 96 240 128 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,40V216a8,8,0,0,1-16,0V40a8,8,0,0,1,16,0ZM96,120H35.314l18.34327-18.34277A8.00053,8.00053,0,0,0,42.34277,90.34277l-32,32c-.05664.0564-.10449.11792-.15869.17554-.12549.13281-.251.26538-.36719.40649-.0913.11084-.17138.22706-.25537.34156-.07031.0957-.14453.188-.21093.28686-.085.12647-.15918.25782-.23584.38819-.05567.09423-.11524.186-.167.283-.06933.12915-.12841.262-.18994.39379-.04931.10547-.102.20874-.147.31665-.05225.12647-.09522.25562-.14063.38428-.042.11817-.0874.23462-.124.35523-.03906.1289-.06787.25976-.10058.39013-.03077.12305-.06543.24414-.09034.36939-.02978.15137-.04834.30444-.06933.457-.01465.106-.03516.21-.0459.31714a8.02276,8.02276,0,0,0,0,1.584c.01074.10718.03125.21118.0459.31714.021.15259.03955.30566.06933.457.02491.12525.05957.24634.09034.36939.03271.13037.06152.26123.10058.39013.03662.12061.082.23706.124.35523.04541.12866.08838.25781.14063.38428.04492.10791.09766.21118.147.31665.06153.13183.12061.26464.18994.39379.05176.09693.11133.18873.167.283.07666.13037.15087.26172.23584.38819.0664.09887.14062.19116.21093.28686.084.1145.16407.23072.25537.34156.11622.14111.2417.27368.36719.40649.0542.05762.10205.11914.15869.17554l32,32a8.00053,8.00053,0,0,0,11.31446-11.31446L35.314,136H96a8,8,0,0,0,0-16Zm150.18311,13.0752c.0913-.11084.17138-.22706.25537-.34156.07031-.0957.14453-.188.21093-.28686.085-.12647.15918-.25782.23584-.38819.05567-.09423.11524-.186.167-.283.06933-.12915.12841-.262.18994-.39379.04931-.10547.10205-.20874.147-.31665.05225-.12647.09522-.25562.14063-.38428.042-.11817.0874-.23462.124-.35523.03906-.1289.06787-.25976.10058-.39013.03077-.12305.06543-.24414.09034-.36939.02978-.15137.04834-.30444.06933-.457.01465-.106.03516-.21.0459-.31714a8.02276,8.02276,0,0,0,0-1.584c-.01074-.10718-.03125-.21118-.0459-.31714-.021-.15259-.03955-.30566-.06933-.457-.02491-.12525-.05957-.24634-.09034-.36939-.03271-.13037-.06152-.26123-.10058-.39013-.03662-.12061-.082-.23706-.124-.35523-.04541-.12866-.08838-.25781-.14063-.38428-.04492-.10791-.09766-.21118-.147-.31665-.06153-.13183-.12061-.26464-.18994-.39379-.05176-.09693-.11133-.18873-.167-.283-.07666-.13037-.15087-.26172-.23584-.38819-.0664-.09887-.14062-.19116-.21093-.28686-.084-.1145-.16407-.23072-.25537-.34156-.11622-.14111-.2417-.27368-.36719-.40649-.0542-.05762-.10205-.11914-.15869-.17554l-32-32a8.00053,8.00053,0,0,0-11.31446,11.31446L220.686,120H160a8,8,0,0,0,0,16h60.686l-18.34327,18.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l32-32c.05664-.0564.10449-.11792.15869-.17554C245.94141,133.34888,246.06689,133.21631,246.18311,133.0752Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "16",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "48 160 16 128 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "128",
        x2: "240",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "208 96 240 128 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "16",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "48 160 16 128 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "128",
        x2: "240",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "208 96 240 128 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "16",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 160 16 128 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "128",
        x2: "240",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 96 240 128 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsOutLineHorizontal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1H(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsOutLineHorizontal.displayName = "ArrowsOutLineHorizontal";

var renderPathFor$1I = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "160 44 128 12 96 44",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "244",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "96 212 128 244 160 212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 48 128 16 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "160",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 208 128 240 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,128a8.00039,8.00039,0,0,1-8,8H40a8,8,0,0,1,0-16H216A8.00039,8.00039,0,0,1,224,128ZM101.65723,53.65723,120,35.31372V96a8,8,0,0,0,16,0V35.31372l18.34277,18.34351a8.00053,8.00053,0,0,0,11.31446-11.31446l-32-32c-.05323-.05322-.11133-.09863-.166-.1499-.13623-.12891-.27246-.25781-.417-.37695-.10449-.0857-.21436-.16065-.32178-.24024-.10254-.07617-.20166-.15551-.3081-.22656-.11817-.0791-.24073-.14795-.36231-.22-.10351-.06177-.2041-.12671-.31055-.18359-.11865-.06324-.24023-.117-.36084-.17383-.11669-.05518-.23144-.11328-.35107-.16284-.1123-.04663-.22754-.084-.3418-.12525-.13281-.04785-.26367-.09839-.39941-.1394-.10938-.0332-.2207-.05713-.33106-.08521-.14257-.03637-.2832-.07592-.42822-.10473-.12158-.02393-.24414-.0376-.3667-.05567-.13574-.02051-.27-.04565-.4082-.05908-.20215-.01977-.40479-.02612-.60742-.03076C128.11768,8.00757,128.05957,8,128,8s-.11768.00757-.17676.00879c-.20263.00464-.40527.011-.60742.03076-.13818.01343-.27246.03857-.4082.05908-.12256.01807-.24512.03174-.3667.05567-.145.02881-.28565.06836-.42822.10473-.11036.02808-.22168.052-.33106.08521-.13574.041-.2666.09155-.39941.1394-.11426.04126-.2295.07862-.3418.12525-.11963.04956-.23438.10766-.35107.16284-.12061.05688-.24219.11059-.36084.17383-.10645.05688-.207.12182-.31055.18359-.12158.072-.24414.14087-.36231.22-.10644.07105-.20556.15039-.3081.22656-.10742.07959-.21729.15454-.32178.24024-.14453.11914-.28076.248-.417.37695-.05469.05127-.11279.09668-.166.1499l-32,32a8.00053,8.00053,0,0,0,11.31446,11.31446Zm52.68554,148.68554L136,220.68628V160a8,8,0,0,0-16,0v60.68628l-18.34277-18.34351a8.00053,8.00053,0,0,0-11.31446,11.31446l32,32c.0542.0542.11377.10034.16895.15283.13525.12744.27.25561.41406.37353.10645.08765.21826.16431.32813.24561.10009.074.19726.15185.30078.22119.12207.08154.248.15259.37353.22681.09912.05884.19629.12134.29834.17627.124.0664.25147.1228.37842.18237.11035.05176.21875.10693.332.15405.1211.05.24463.09058.36768.13452.12353.04444.2456.0918.37207.13013.12158.03687.24512.064.36816.09473.13037.033.25879.06933.3916.0957.14063.02783.28321.04443.42481.0647.1167.0166.231.03882.34912.05029.26221.02588.52588.04.78955.04s.52734-.01416.78955-.04c.11816-.01147.23242-.03369.34912-.05029.1416-.02027.28418-.03687.42481-.0647.13281-.02637.26123-.06274.3916-.0957.123-.03076.24658-.05786.36816-.09473.12647-.03833.24854-.08569.37207-.13013.12305-.04394.24658-.08447.36768-.13452.11328-.04712.22168-.10229.332-.15405.127-.05957.25439-.116.37842-.18237.10205-.05493.19922-.11743.29834-.17627.12549-.07422.25146-.14527.37353-.22681.10352-.06934.20069-.14722.30078-.22119.10987-.0813.22168-.158.32813-.24561.144-.11792.27881-.24609.41406-.37353.05518-.05249.11475-.09863.16895-.15283l32-32a8.00053,8.00053,0,0,0-11.31446-11.31446Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "96 48 128 16 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "160",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "160 208 128 240 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "96 48 128 16 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "160",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "160 208 128 240 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 48 128 16 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "160",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 208 128 240 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsOutLineVertical = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1I(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsOutLineVertical.displayName = "ArrowsOutLineVertical";

var renderPathFor$1J = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 48 208 48 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "96 208 48 208 48 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "48",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 48 208 48 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 208 48 208 48 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "48",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M215.96,47.208c-.01074-.10767-.03125-.21216-.0459-.31861-.02148-.1521-.03955-.30444-.06933-.45532-.02539-.12646-.06006-.24853-.09131-.37256-.03174-.12915-.06055-.259-.09912-.38672-.03711-.12255-.0835-.24072-.126-.36059-.04541-.12647-.0874-.25366-.13867-.37842-.0459-.11108-.10059-.21728-.15137-.32568-.06006-.12866-.11719-.25806-.18506-.384-.05517-.10278-.11767-.20019-.17724-.30029-.07373-.124-.144-.24927-.22461-.36987-.07373-.10962-.15576-.21265-.23438-.31836-.07666-.10352-.14892-.20947-.23193-.31006-.14844-.18091-.30664-.35327-.47022-.52026-.02-.02076-.03711-.04346-.05761-.064-.01612-.01611-.03418-.0293-.0503-.04541-.17138-.1687-.34912-.331-.53564-.48389-.09375-.07714-.19287-.14453-.28955-.21679-.11279-.084-.22266-.17139-.33985-.24951-.11279-.07569-.23046-.14136-.34668-.2107-.10791-.06469-.21386-.13257-.32519-.19214-.1167-.0625-.23682-.11523-.356-.17138-.11767-.05591-.2334-.1145-.35449-.16455-.11377-.04712-.22949-.085-.34473-.12647-.13134-.04736-.26074-.09741-.395-.13794-.11377-.03442-.22949-.05932-.34423-.08862-.1377-.03516-.27442-.07324-.41455-.10107-.13038-.02588-.26221-.04078-.39356-.06006-.127-.01856-.252-.04248-.38086-.05494-.23193-.02294-.46484-.03271-.69824-.0354C208.05859,40.00415,208.02979,40,208,40H160a8,8,0,0,0,0,16h28.686L146.34277,98.34326a8.00018,8.00018,0,0,0,11.31446,11.31348L200,67.314V96a8,8,0,0,0,16,0V48.00513Q216,47.606,215.96,47.208Z"
      }), React__default.createElement("path", {
        d: "M98.34277,146.34326,56,188.686V160a8,8,0,0,0-16,0v47.99487q0,.39918.04.79712c.01074.10767.03125.21216.0459.31861.02148.1521.03955.30444.06933.45532.02539.12646.06006.24853.09131.37256.03174.12915.06055.259.09912.38672.03711.12255.0835.24072.126.36059.04541.12647.0874.25366.13867.37842.0459.11108.10059.21728.15137.32568.06006.12866.11719.25806.18506.384.05517.10278.11767.20019.17724.30029.07373.124.14405.24927.22461.36987.07373.10962.15576.21265.23438.31836.07666.10352.14892.20947.23193.31006.14844.18091.30664.35327.47022.52026.02.02076.03711.04346.05761.064.01612.01611.03418.0293.0503.04541.17138.1687.34912.33105.53564.48389.09424.07763.19385.145.291.21777.11181.08374.22168.17041.33789.24853.11474.07666.23388.14331.35156.21363.10644.06347.21045.13012.31934.18872.12011.06421.24365.11865.36621.17627.11425.05395.22656.11084.34375.15942.11816.04907.23877.08862.35888.13159.12647.04541.25147.09375.38037.13306.12012.03613.2417.06274.36231.093.13184.0332.26221.07031.39648.09692.14063.02783.28321.04443.42481.0647.1167.0166.231.03882.34912.05029.26221.02588.52588.04.78955.04H96a8,8,0,0,0,0-16H67.314l42.34327-42.34326a8.00018,8.00018,0,0,0-11.31446-11.31348Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 48 208 48 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "96 208 48 208 48 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "48",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 48 208 48 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "96 208 48 208 48 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "48",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 48 208 48 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 208 48 208 48 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "48",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ArrowsOutSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1J(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ArrowsOutSimple.displayName = "ArrowsOutSimple";

var renderPathFor$1K = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "92",
        x2: "180",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "164",
        x2: "180",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "96",
        x2: "180",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "160",
        x2: "180",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,40H40A16.01833,16.01833,0,0,0,24,56V200a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V56A16.01833,16.01833,0,0,0,216,40ZM180,168H76a8,8,0,0,1,0-16H180a8,8,0,0,1,0,16Zm0-32H76a8,8,0,0,1,0-16H180a8,8,0,0,1,0,16Zm0-32H76a8,8,0,0,1,0-16H180a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "96",
        x2: "180",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "160",
        x2: "180",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "96",
        x2: "180",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "160",
        x2: "180",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "96",
        x2: "180",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "160",
        x2: "180",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Article = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1K(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Article.displayName = "Article";

var renderPathFor$1L = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "51.78976",
        y1: "84",
        x2: "204.21024",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "51.78976",
        y1: "172",
        x2: "204.21024",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "51.78976",
        y1: "84",
        x2: "204.21024",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "51.78976",
        y1: "172",
        x2: "204.21024",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.21045,165.07178,144,128l64.21045-37.07178a8,8,0,1,0-8-13.85644L136,114.14355V40a8,8,0,0,0-16,0v74.14355L55.78955,77.07178a8,8,0,0,0-8,13.85644L112,128,47.78955,165.07178a8,8,0,1,0,8,13.85644L120,141.85645V216a8,8,0,0,0,16,0V141.85645l64.21045,37.07177a8,8,0,0,0,8-13.85644Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "51.78976",
        y1: "84",
        x2: "204.21024",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "51.78976",
        y1: "172",
        x2: "204.21024",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "51.78976",
        y1: "84",
        x2: "204.21024",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "51.78976",
        y1: "172",
        x2: "204.21024",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "51.78976",
        y1: "84",
        x2: "204.21024",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "51.78976",
        y1: "172",
        x2: "204.21024",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Asterisk = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1L(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Asterisk.displayName = "Asterisk";

var renderPathFor$1M = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99121",
        cy: "127.99512",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M181.07274,207.99724a96.00809,96.00809,0,1,1,42.91847-80.00212c0,22.09139-8,40-28,40s-28-17.90861-28-40v-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "127.99512",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "127.99512",
        cy: "127.99512",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M181.07664,207.99724a96.00808,96.00808,0,1,1,42.91848-80.00212c0,22.09139-8,40-28,40s-28-17.90861-28-40v-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M128,23.99121a104,104,0,1,0,93.78125,148.9364A49.2519,49.2519,0,0,1,204,175.99121c-18.28711,0-28.52441-8.00488-33.8916-14.7207a39.57375,39.57375,0,0,1-3.37793-4.96948A48.00646,48.00646,0,1,1,160,92.2522v-4.261a8,8,0,0,1,16,0v40c0,14.59863,4.85742,32,28,32,22.3457,0,27.64258-16.22314,27.98047-30.4823.00732-.50574.01953-1.01037.01953-1.5177A104.11791,104.11791,0,0,0,128,23.99121Z"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "127.99121",
        r: "32"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99512",
        cy: "127.99512",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M181.07664,207.99724a96.00808,96.00808,0,1,1,42.91848-80.00212c0,22.09139-8,40-28,40s-28-17.90861-28-40v-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99902",
        cy: "127.99512",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M181.08055,207.99724A96.00809,96.00809,0,1,1,223.999,127.99512c0,22.09139-8,40-28,40s-28-17.90861-28-40v-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00293",
        cy: "127.99512",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M181.08446,207.99724a96.00809,96.00809,0,1,1,42.91847-80.00212c0,22.09139-8,40-28,40s-28-17.90861-28-40v-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var At = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1M(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
At.displayName = "At";

var renderPathFor$1N = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M61.66958,204.116,16,128l45.66958-76.116a8,8,0,0,1,6.85994-3.884H216a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H68.52952A8,8,0,0,1,61.66958,204.116Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "104.00005",
        x2: "112",
        y2: "152.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "152.00005",
        x2: "112",
        y2: "104.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M61.66958,204.116,16,128l45.66958-76.116a8,8,0,0,1,6.85994-3.884H216a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H68.52952A8,8,0,0,1,61.66958,204.116Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M61.66958,204.116,16,128l45.66958-76.116a8,8,0,0,1,6.85994-3.884H216a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H68.52952A8,8,0,0,1,61.66958,204.116Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "104.00005",
        x2: "112",
        y2: "152.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "152.00005",
        x2: "112",
        y2: "104.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99512,39.99805H68.52637a16.1162,16.1162,0,0,0-13.71875,7.76562L9.13574,123.88086a8.02459,8.02459,0,0,0,0,8.23437l45.67188,76.11719v.00781a16.10652,16.10652,0,0,0,13.71875,7.75782H215.99512a16.01583,16.01583,0,0,0,16-16v-144A16.01582,16.01582,0,0,0,215.99512,39.99805ZM165.65137,146.3418a7.99915,7.99915,0,1,1-11.3125,11.3125l-18.34375-18.34375L117.65137,157.6543a7.99915,7.99915,0,0,1-11.3125-11.3125l18.34375-18.34375L106.33887,109.6543a7.99915,7.99915,0,0,1,11.3125-11.3125l18.34375,18.34375L154.33887,98.3418a7.99915,7.99915,0,0,1,11.3125,11.3125l-18.34375,18.34375Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M61.66958,204.116,16,128l45.66958-76.116a8,8,0,0,1,6.85994-3.884H216a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H68.52952A8,8,0,0,1,61.66958,204.116Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "104.00005",
        x2: "112",
        y2: "152.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "152.00005",
        x2: "112",
        y2: "104.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M61.66958,204.116,16,128l45.66958-76.116a8,8,0,0,1,6.85994-3.884H216a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H68.52952A8,8,0,0,1,61.66958,204.116Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "104.00005",
        x2: "112",
        y2: "152.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "152.00005",
        x2: "112",
        y2: "104.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M61.66958,204.116,16,128l45.66958-76.116a8,8,0,0,1,6.85994-3.884H216a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H68.52952A8,8,0,0,1,61.66958,204.116Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "104.00005",
        x2: "112",
        y2: "152.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "152.00005",
        x2: "112",
        y2: "104.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Backspace = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1N(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Backspace.displayName = "Backspace";

var renderPathFor$1O = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "64",
        width: "176",
        height: "144",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M88,64a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "64",
        width: "176",
        height: "144",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "64",
        width: "176",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M88,64a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,56H175.3208a47.99073,47.99073,0,0,0-94.6416,0H48A16.01833,16.01833,0,0,0,32,72V200a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V72A16.01833,16.01833,0,0,0,208,56ZM128,32a32.05773,32.05773,0,0,1,30.9873,24H97.0127A32.05773,32.05773,0,0,1,128,32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "64",
        width: "176",
        height: "144",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M88,64a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "64",
        width: "176",
        height: "144",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M88,64a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "64",
        width: "176",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M88,64a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Bag = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1O(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Bag.displayName = "Bag";

var renderPathFor$1P = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M49.37258,94.62742A32,32,0,0,1,94.62742,49.37258l112,112a32,32,0,0,1-45.25484,45.25484Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M161.37258,49.37258a32,32,0,0,1,45.25484,45.25484l-112,112a32,32,0,0,1-45.25484-45.25484Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M206.62744,94.62744a32,32,0,0,0-45.25488-45.25488L128,82.74512,173.25488,128Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M49.37256,161.37256a32,32,0,0,0,45.25488,45.25488L128,173.25488,82.74512,128Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M94.62744,49.37256A32,32,0,0,0,49.37256,94.62744L82.74512,128,128,82.74512Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M173.25488,128,128,173.25488l33.37256,33.37256a32,32,0,0,0,45.25488-45.25488Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M49.37258,94.62742A32,32,0,0,1,94.62742,49.37258l112,112a32,32,0,0,1-45.25484,45.25484Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M161.37258,49.37258a32,32,0,0,1,45.25484,45.25484l-112,112a32,32,0,0,1-45.25484-45.25484Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "12"
      }), React__default.createElement("path", {
        d: "M184.56836,128l27.71582-27.71558a40,40,0,1,0-56.56836-56.5686L128,71.43164,100.28418,43.71582a39.99987,39.99987,0,1,0-56.56836,56.56836L71.43164,128,43.71582,155.71558a40,40,0,1,0,56.56836,56.5686L128,184.56836l27.71582,27.71582a39.99987,39.99987,0,1,0,56.56836-56.56836ZM128,94.05957,161.94043,128,128,161.94043,94.05957,128ZM167.03027,55.0293a23.99951,23.99951,0,1,1,33.93946,33.9414L173.25439,116.686,139.314,82.74561ZM88.96973,200.9707a23.99951,23.99951,0,1,1-33.93946-33.9414L82.74561,139.314,116.686,173.25439Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M49.37258,94.62742A32,32,0,0,1,94.62742,49.37258l112,112a32,32,0,0,1-45.25484,45.25484Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M161.37258,49.37258a32,32,0,0,1,45.25484,45.25484l-112,112a32,32,0,0,1-45.25484-45.25484Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M161.37258,49.37258a32,32,0,0,1,45.25484,45.25484l-112,112a32,32,0,0,1-45.25484-45.25484Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M49.37258,94.62742A32,32,0,0,1,94.62742,49.37258l112,112a32,32,0,0,1-45.25484,45.25484Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M49.37258,94.62742A32,32,0,0,1,94.62742,49.37258l112,112a32,32,0,0,1-45.25484,45.25484Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M161.37258,49.37258a32,32,0,0,1,45.25484,45.25484l-112,112a32,32,0,0,1-45.25484-45.25484Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Bandaids = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1P(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Bandaids.displayName = "Bandaids";

var renderPathFor$1Q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32.002 96 224.002 96 128.002 32 32.002 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "56.00244",
        y1: "96",
        x2: "56.00244",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104.00244",
        y1: "96",
        x2: "104.00244",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152.00244",
        y1: "96",
        x2: "152.00244",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200.00244",
        y1: "96",
        x2: "200.00244",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "32.00244",
        y1: "168",
        x2: "224.00244",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "16.00244",
        y1: "208",
        x2: "240.00244",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32.002 96 224.002 96 128.002 32 32.002 96",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "32.002 96 224.002 96 128.002 32 32.002 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56.00244",
        y1: "96",
        x2: "56.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104.00244",
        y1: "96",
        x2: "104.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152.00244",
        y1: "96",
        x2: "152.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200.00244",
        y1: "96",
        x2: "200.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32.00244",
        y1: "176",
        x2: "224.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16.00244",
        y1: "208",
        x2: "240.00244",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M240.00244,200h-224a8,8,0,0,0,0,16h224a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M32.00244,168a8,8,0,0,0,0,16h192a8,8,0,0,0,0-16h-16V104h16a8.00005,8.00005,0,0,0,4.4375-14.65625l-96-64a8.00131,8.00131,0,0,0-8.875,0l-96,64A8.00005,8.00005,0,0,0,32.00244,104h16v64Zm112-56a8,8,0,1,1,16,0v48a8,8,0,0,1-16,0Zm-48,0a8,8,0,0,1,16,0v48a8,8,0,0,1-16,0Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32.002 96 224.002 96 128.002 32 32.002 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56.00244",
        y1: "96",
        x2: "56.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104.00244",
        y1: "96",
        x2: "104.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152.00244",
        y1: "96",
        x2: "152.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200.00244",
        y1: "96",
        x2: "200.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "32.00244",
        y1: "176",
        x2: "224.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "16.00244",
        y1: "208",
        x2: "240.00244",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32.002 96 224.002 96 128.002 32 32.002 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56.00244",
        y1: "96",
        x2: "56.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104.00244",
        y1: "96",
        x2: "104.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152.00244",
        y1: "96",
        x2: "152.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200.00244",
        y1: "96",
        x2: "200.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "32.00244",
        y1: "176",
        x2: "224.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "16.00244",
        y1: "208",
        x2: "240.00244",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32.002 96 224.002 96 128.002 32 32.002 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56.00244",
        y1: "96",
        x2: "56.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104.00244",
        y1: "96",
        x2: "104.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152.00244",
        y1: "96",
        x2: "152.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200.00244",
        y1: "96",
        x2: "200.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32.00244",
        y1: "176",
        x2: "224.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16.00244",
        y1: "208",
        x2: "240.00244",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Bank = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1Q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Bank.displayName = "Bank";

var renderPathFor$1R = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "52",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "164",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,80h24a8,8,0,0,1,8,8v80a8,8,0,0,1-8,8H208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M48,176H24a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8H48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "92",
        y1: "128",
        x2: "164",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "168",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "48",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "168",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,80h24a8,8,0,0,1,8,8v80a8,8,0,0,1-8,8H208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M48,176H24a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8H48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232,72H216V64a16.01833,16.01833,0,0,0-16-16H176a16.01833,16.01833,0,0,0-16,16v56H96V64A16.01833,16.01833,0,0,0,80,48H56A16.01833,16.01833,0,0,0,40,64v8H24A16.01833,16.01833,0,0,0,8,88v80a16.01833,16.01833,0,0,0,16,16H40v8a16.01833,16.01833,0,0,0,16,16H80a16.01833,16.01833,0,0,0,16-16V136h64v56a16.01833,16.01833,0,0,0,16,16h24a16.01833,16.01833,0,0,0,16-16v-8h16a16.01833,16.01833,0,0,0,16-16V88A16.01833,16.01833,0,0,0,232,72ZM24,168V88H40v80Zm208,0H216V88h16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "168",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,80h24a8,8,0,0,1,8,8v80a8,8,0,0,1-8,8H208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M48,176H24a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8H48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "168",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,80h24a8,8,0,0,1,8,8v80a8,8,0,0,1-8,8H208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M48,176H24a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8H48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "168",
        y: "56",
        width: "40",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,80h24a8,8,0,0,1,8,8v80a8,8,0,0,1-8,8H208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M48,176H24a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8H48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Barbell = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1R(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Barbell.displayName = "Barbell";

var renderPathFor$1S = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "180 52 220 52 220 92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "76 204 36 204 36 164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "220 164 220 204 180 204",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "36 92 36 52 76 52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "92",
        x2: "88",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "92",
        x2: "168",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "92",
        x2: "128",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "184 48 224 48 224 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "72 208 32 208 32 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 168 224 208 184 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "32 88 32 48 72 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "80",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "88",
        x2: "176",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "88",
        x2: "144",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "88",
        x2: "112",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M224,40H184a8,8,0,0,0,0,16h32V88a8,8,0,0,0,16,0V48A8.00039,8.00039,0,0,0,224,40Z"
      }), React__default.createElement("path", {
        d: "M72,200H40V168a8,8,0,0,0-16,0v40a8.00039,8.00039,0,0,0,8,8H72a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M224,160a8.00039,8.00039,0,0,0-8,8v32H184a8,8,0,0,0,0,16h40a8.00039,8.00039,0,0,0,8-8V168A8.00039,8.00039,0,0,0,224,160Z"
      }), React__default.createElement("path", {
        d: "M32,96a8.00039,8.00039,0,0,0,8-8V56H72a8,8,0,0,0,0-16H32a8.00039,8.00039,0,0,0-8,8V88A8.00039,8.00039,0,0,0,32,96Z"
      }), React__default.createElement("path", {
        d: "M80,80a8.00039,8.00039,0,0,0-8,8v80a8,8,0,0,0,16,0V88A8.00039,8.00039,0,0,0,80,80Z"
      }), React__default.createElement("path", {
        d: "M184,168V88a8,8,0,0,0-16,0v80a8,8,0,0,0,16,0Z"
      }), React__default.createElement("path", {
        d: "M144,80a8.00039,8.00039,0,0,0-8,8v80a8,8,0,0,0,16,0V88A8.00039,8.00039,0,0,0,144,80Z"
      }), React__default.createElement("path", {
        d: "M112,80a8.00039,8.00039,0,0,0-8,8v80a8,8,0,0,0,16,0V88A8.00039,8.00039,0,0,0,112,80Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "184 48 224 48 224 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "72 208 32 208 32 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "224 168 224 208 184 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "32 88 32 48 72 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "80",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "88",
        x2: "176",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "88",
        x2: "144",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "88",
        x2: "112",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "184 48 224 48 224 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "72 208 32 208 32 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "224 168 224 208 184 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "32 88 32 48 72 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "80",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "88",
        x2: "176",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "88",
        x2: "144",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "88",
        x2: "112",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "184 48 224 48 224 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "72 208 32 208 32 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 168 224 208 184 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "32 88 32 48 72 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "80",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "88",
        x2: "176",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "88",
        x2: "144",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "88",
        x2: "112",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Barcode = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1S(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Barcode.displayName = "Barcode";

var renderPathFor$1T = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "46",
        y: "38",
        width: "144",
        height: "180",
        rx: "16",
        transform: "translate(246 10) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "244",
        y1: "96",
        x2: "244",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "118 168 134 128 102 128 118 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "116 168 132 128 100 128 116 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M240,88a8.00008,8.00008,0,0,0-8,8v64a8,8,0,0,0,16,0V96A8.00008,8.00008,0,0,0,240,88Z"
      }), React__default.createElement("path", {
        d: "M192,47.99805H40a24.02624,24.02624,0,0,0-24,24v112a24.02624,24.02624,0,0,0,24,24H192a24.02625,24.02625,0,0,0,24-24v-112A24.02624,24.02624,0,0,0,192,47.99805ZM139.42187,130.9668l-16,40a7.99361,7.99361,0,1,1-14.84375-5.9375l11.60938-29.03125H100a7.99271,7.99271,0,0,1-7.42188-10.96875l16-40a7.99361,7.99361,0,1,1,14.84375,5.9375L111.8125,119.99805H132a7.9927,7.9927,0,0,1,7.42187,10.96875Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "116 168 132 128 100 128 116 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "116 168 132 128 100 128 116 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "116 168 132 128 100 128 116 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BatteryCharging = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1T(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BatteryCharging.displayName = "BatteryCharging";

var renderPathFor$1U = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "180",
        rx: "16",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "12",
        x2: "160",
        y2: "12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "128 178 144 138 112 138 128 98",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "184",
        rx: "16",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "16",
        x2: "160",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "184",
        rx: "16",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "128 180 144 140 112 140 128 100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M96,24h64a8,8,0,0,0,0-16H96a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M184,40.00781H72a24.02625,24.02625,0,0,0-24,24v152a24.02624,24.02624,0,0,0,24,24H184a24.02624,24.02624,0,0,0,24-24v-152A24.02624,24.02624,0,0,0,184,40.00781ZM151.42969,142.97656l-16,40a8.00086,8.00086,0,0,1-14.85938-5.9375l11.61719-29.03125L112,147.99219a8.001,8.001,0,0,1-7.42969-10.96875l16-39.98438a8.00086,8.00086,0,0,1,14.85938,5.9375L123.8125,131.99219,144,132.00781a8.001,8.001,0,0,1,7.42969,10.96875Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "16",
        x2: "160",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "184",
        rx: "16",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "128 180 144 140 112 140 128 100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "16",
        x2: "160",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "184",
        rx: "16",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "128 180 144 140 112 140 128 100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "16",
        x2: "160",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "184",
        rx: "16",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "128 180 144 140 112 140 128 100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BatteryChargingVertical = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1U(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BatteryChargingVertical.displayName = "BatteryChargingVertical";

var renderPathFor$1V = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "46",
        y: "38",
        width: "144",
        height: "180",
        rx: "16",
        transform: "translate(246 10) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "244",
        y1: "96",
        x2: "244",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M240,88a8.00008,8.00008,0,0,0-8,8v64a8,8,0,0,0,16,0V96A8.00008,8.00008,0,0,0,240,88Z"
      }), React__default.createElement("path", {
        d: "M192,48H40A24.0275,24.0275,0,0,0,16,72V184a24.0275,24.0275,0,0,0,24,24H192a24.0275,24.0275,0,0,0,24-24V72A24.0275,24.0275,0,0,0,192,48Zm8,136a8.00917,8.00917,0,0,1-8,8H40a8.00917,8.00917,0,0,1-8-8V72a8.00917,8.00917,0,0,1,8-8H192a8.00917,8.00917,0,0,1,8,8Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BatteryEmpty = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1V(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BatteryEmpty.displayName = "BatteryEmpty";

var renderPathFor$1W = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "46",
        y: "38",
        width: "144",
        height: "180",
        rx: "16",
        transform: "translate(246 10) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "164",
        x2: "64",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "164",
        x2: "100",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "164",
        x2: "136",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "172",
        y1: "164",
        x2: "172",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "244",
        y1: "96",
        x2: "244",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "134.4",
        y1: "168.00043",
        x2: "134.4",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "171.2",
        y1: "168.00043",
        x2: "171.2",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M240,88a7.99977,7.99977,0,0,0-8,8v64a8,8,0,0,0,16,0V96A7.99977,7.99977,0,0,0,240,88Z"
      }), React__default.createElement("path", {
        d: "M192,48H40A24.0275,24.0275,0,0,0,16,72V184a24.0275,24.0275,0,0,0,24,24H192a24.0275,24.0275,0,0,0,24-24V72A24.0275,24.0275,0,0,0,192,48Zm8,136a8.00917,8.00917,0,0,1-8,8H40a8.00917,8.00917,0,0,1-8-8V72a8.00917,8.00917,0,0,1,8-8H192a8.00917,8.00917,0,0,1,8,8Z"
      }), React__default.createElement("rect", {
        x: "48",
        y: "80.00049",
        width: "136",
        height: "96",
        rx: "8"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "134.4",
        y1: "168.00043",
        x2: "134.4",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "171.2",
        y1: "168.00043",
        x2: "171.2",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "134.4",
        y1: "168.00043",
        x2: "134.4",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "171.2",
        y1: "168.00043",
        x2: "171.2",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "134.4",
        y1: "168.00043",
        x2: "134.4",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "171.2",
        y1: "168.00043",
        x2: "171.2",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BatteryFull = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1W(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BatteryFull.displayName = "BatteryFull";

var renderPathFor$1X = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "46",
        y: "38",
        width: "144",
        height: "180",
        rx: "16",
        transform: "translate(246 10) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "164",
        x2: "64",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "164",
        x2: "100",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "164",
        x2: "136",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "244",
        y1: "96",
        x2: "244",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "134.4",
        y1: "168.00043",
        x2: "134.4",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M240,88.00781a7.9954,7.9954,0,0,0-8,8v64a8,8,0,0,0,16,0v-64A7.99541,7.99541,0,0,0,240,88.00781Z"
      }), React__default.createElement("path", {
        d: "M192,48.00781H40a24.02624,24.02624,0,0,0-24,24v112a24.02624,24.02624,0,0,0,24,24H192a24.02624,24.02624,0,0,0,24-24v-112A24.02625,24.02625,0,0,0,192,48.00781Zm8,136a8.01042,8.01042,0,0,1-8,8H40a8.01042,8.01042,0,0,1-8-8v-112a8.01042,8.01042,0,0,1,8-8H192a8.01042,8.01042,0,0,1,8,8Z"
      }), React__default.createElement("rect", {
        x: "48",
        y: "80.00781",
        width: "96",
        height: "96",
        rx: "8"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "134.4",
        y1: "168.00043",
        x2: "134.4",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "134.4",
        y1: "168.00043",
        x2: "134.4",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "134.4",
        y1: "168.00043",
        x2: "134.4",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BatteryHigh = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1X(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BatteryHigh.displayName = "BatteryHigh";

var renderPathFor$1Y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "46",
        y: "38",
        width: "144",
        height: "180",
        rx: "16",
        transform: "translate(246 10) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "164",
        x2: "64",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "244",
        y1: "96",
        x2: "244",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M240,88a8.00008,8.00008,0,0,0-8,8v64a8,8,0,0,0,16,0V96A8.00008,8.00008,0,0,0,240,88Z"
      }), React__default.createElement("path", {
        d: "M192,48H40A24.0275,24.0275,0,0,0,16,72V184a24.0275,24.0275,0,0,0,24,24H192a24.0275,24.0275,0,0,0,24-24V72A24.0275,24.0275,0,0,0,192,48Zm8,136a8.00917,8.00917,0,0,1-8,8H40a8.00917,8.00917,0,0,1-8-8V72a8.00917,8.00917,0,0,1,8-8H192a8.00917,8.00917,0,0,1,8,8Z"
      }), React__default.createElement("rect", {
        x: "48",
        y: "80.00049",
        width: "32",
        height: "96",
        rx: "8"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BatteryLow = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1Y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BatteryLow.displayName = "BatteryLow";

var renderPathFor$1Z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "46",
        y: "38",
        width: "144",
        height: "180",
        rx: "16",
        transform: "translate(246 10) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "164",
        x2: "64",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "164",
        x2: "100",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "244",
        y1: "96",
        x2: "244",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M240,88a7.99977,7.99977,0,0,0-8,8v64a8,8,0,0,0,16,0V96A7.99977,7.99977,0,0,0,240,88Z"
      }), React__default.createElement("path", {
        d: "M192,48H40A24.0275,24.0275,0,0,0,16,72V184a24.0275,24.0275,0,0,0,24,24H192a24.0275,24.0275,0,0,0,24-24V72A24.0275,24.0275,0,0,0,192,48Zm8,136a8.00917,8.00917,0,0,1-8,8H40a8.00917,8.00917,0,0,1-8-8V72a8.00917,8.00917,0,0,1,8-8H192a8.00917,8.00917,0,0,1,8,8Z"
      }), React__default.createElement("rect", {
        x: "48",
        y: "80.00049",
        width: "72",
        height: "96",
        rx: "8"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "97.6",
        y1: "168.00043",
        x2: "97.6",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "60.8",
        y1: "168.00043",
        x2: "60.8",
        y2: "88.00043",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BatteryMedium = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1Z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BatteryMedium.displayName = "BatteryMedium";

var renderPathFor$1_ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "46",
        y: "38.00452",
        width: "144",
        height: "180",
        rx: "16",
        transform: "translate(246.00452 10.00452) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "244",
        y1: "96.00452",
        x2: "244",
        y2: "160.00452",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "116",
        y1: "92",
        x2: "116",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "116",
        cy: "160",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "116",
        y1: "88",
        x2: "116",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "116",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M248,96.00012v64a8,8,0,1,1-16,0v-64a8,8,0,1,1,16,0Zm-32-24v112a24.0275,24.0275,0,0,1-24,24H40a24.0275,24.0275,0,0,1-24-24v-112a24.0275,24.0275,0,0,1,24-24H192A24.0275,24.0275,0,0,1,216,72.00012Zm-108,56a8,8,0,0,0,16,0v-40a8,8,0,1,0-16,0Zm20,36a12,12,0,1,0-12,12A12.01375,12.01375,0,0,0,128,164.00012Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "116",
        y1: "88",
        x2: "116",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "116",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "116",
        y1: "88",
        x2: "116",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "116",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "116",
        y1: "88",
        x2: "116",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "96",
        x2: "240",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "36",
        width: "144",
        height: "184",
        rx: "16",
        transform: "translate(244 12) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "116",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BatteryWarning = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1_(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BatteryWarning.displayName = "BatteryWarning";

var renderPathFor$1$ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "180",
        rx: "16",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "12",
        x2: "160",
        y2: "12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "184",
        rx: "16",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "100",
        x2: "128",
        y2: "140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "16",
        x2: "160",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "184",
        rx: "16",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,16a7.99977,7.99977,0,0,1,8-8h64a8,8,0,0,1,0,16H96A7.99977,7.99977,0,0,1,88,16ZM208,64V216a24.0275,24.0275,0,0,1-24,24H72a24.0275,24.0275,0,0,1-24-24V64A24.0275,24.0275,0,0,1,72,40H184A24.0275,24.0275,0,0,1,208,64Zm-88,76a8,8,0,0,0,16,0V100a8,8,0,0,0-16,0Zm20,36a12,12,0,1,0-12,12A12.01375,12.01375,0,0,0,140,176Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "100",
        x2: "128",
        y2: "140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "16",
        x2: "160",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "184",
        rx: "16",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "100",
        x2: "128",
        y2: "140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "16",
        x2: "160",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "184",
        rx: "16",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "100",
        x2: "128",
        y2: "140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "16",
        x2: "160",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "56",
        y: "48",
        width: "144",
        height: "184",
        rx: "16",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BatteryWarningVertical = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$1$(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BatteryWarningVertical.displayName = "BatteryWarningVertical";

var renderPathFor$20 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,168V80H208a32,32,0,0,1,32,32v56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "208",
        x2: "16",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "16 168 240 168 240 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "80",
        x2: "16",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,80H208a32,32,0,0,1,32,32v56a0,0,0,0,1,0,0H104a0,0,0,0,1,0,0V80A0,0,0,0,1,104,80Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M104,168V80H208a32,32,0,0,1,32,32v56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "208",
        x2: "16",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "16 168 240 168 240 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "80",
        x2: "16",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,72H24V48A8,8,0,0,0,8,48V208a8,8,0,0,0,16,0V176H232v32a8,8,0,0,0,16,0V112A40.04521,40.04521,0,0,0,208,72ZM24,88H96v72H24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,168V80H208a32,32,0,0,1,32,32v56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "208",
        x2: "16",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "16 168 240 168 240 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "80",
        x2: "16",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,168V80H208a32,32,0,0,1,32,32v56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "208",
        x2: "16",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "16 168 240 168 240 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "80",
        x2: "16",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,168V80H208a32,32,0,0,1,32,32v56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "208",
        x2: "16",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "16 168 240 168 240 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "80",
        x2: "16",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Bed = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$20(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Bed.displayName = "Bed";

var renderPathFor$21 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56.20305,104A71.899,71.899,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,35.81563,7.49325,56.59893,14.093,67.95814A7.999,7.999,0,0,1,207.01628,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M96,192v8a32,32,0,0,0,64,0v-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56.20305,104A71.899,71.899,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,35.81563,7.49325,56.59893,14.093,67.95814A7.999,7.999,0,0,1,207.01628,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M56.20305,104A71.899,71.899,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,35.81563,7.49325,56.59893,14.093,67.95814A7.999,7.999,0,0,1,207.01628,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M96,192v8a32,32,0,0,0,64,0v-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220.81445,175.9397c-5.93457-10.21582-13.00976-29.60157-13.00976-63.93946v-7.09668c0-44.28515-35.52735-80.57715-79.19629-80.90136-.2041-.001-.40625-.002-.61035-.002a79.89891,79.89891,0,0,0-79.79493,80v8c0,34.33594-7.0791,53.72071-13.0166,63.93555A15.99885,15.99885,0,0,0,48.9834,200.00024H88a40,40,0,0,0,80,0h39.0166a15.99808,15.99808,0,0,0,13.79785-24.06054ZM128,224.00024a24.0275,24.0275,0,0,1-24-24h48A24.0275,24.0275,0,0,1,128,224.00024Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56.20305,104A71.899,71.899,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,35.81563,7.49325,56.59893,14.093,67.95814A7.999,7.999,0,0,1,207.01628,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M96,192v8a32,32,0,0,0,64,0v-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56.20305,104A71.899,71.899,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,35.81563,7.49325,56.59893,14.093,67.95814A7.999,7.999,0,0,1,207.01628,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M96,192v8a32,32,0,0,0,64,0v-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56.20305,104A71.899,71.899,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,35.81563,7.49325,56.59893,14.093,67.95814A7.999,7.999,0,0,1,207.01628,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M96,192v8a32,32,0,0,0,64,0v-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Bell = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$21(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Bell.displayName = "Bell";

var renderPathFor$22 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "228",
        x2: "160",
        y2: "228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M56.20305,104A71.899,71.899,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V108c0,35.81563,7.49325,56.59893,14.093,67.95814A7.999,7.999,0,0,1,207.01628,188H48.98365A7.99908,7.99908,0,0,1,42.103,175.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M55.99674,104A72.00377,72.00377,0,0,1,128.55,32.002c39.70343.29432,71.46127,33.20133,71.46127,72.90185V112c0,35.81563,7.51478,56.59893,14.13351,67.95814A7.99892,7.99892,0,0,1,207.24334,192H48.75659a7.999,7.999,0,0,1-6.90041-12.04359C48.47844,168.59682,55.99674,147.81381,55.99674,112Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "224",
        x2: "160",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M56.20305,104A71.899,71.899,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,35.81563,7.49325,56.59893,14.093,67.95814A7.999,7.999,0,0,1,207.01628,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M221.048,175.93066C215.09778,165.7168,208.004,146.335,208.004,112v-7.0957c0-44.28516-35.61621-80.57813-79.39453-80.90235-.20508-.001-.40722-.002-.61133-.002A79.99928,79.99928,0,0,0,48.004,104v8c0,34.33105-7.09668,53.71387-13.0498,63.92676A15.999,15.999,0,0,0,48.76478,200h158.4707a15.99861,15.99861,0,0,0,13.8125-24.06934Z"
      }), React__default.createElement("path", {
        d: "M159.92884,216h-64a8,8,0,1,0,0,16h64a8,8,0,1,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "95.92521",
        y1: "224.02075",
        x2: "159.92521",
        y2: "224.02075",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M56.20305,104A71.899,71.899,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,35.81563,7.49325,56.59893,14.093,67.95814A7.999,7.999,0,0,1,207.01628,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "224",
        x2: "160",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M56.20305,104A71.899,71.899,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,35.81563,7.49325,56.59893,14.093,67.95814A7.999,7.999,0,0,1,207.01628,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "224",
        x2: "160",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M56.20305,104A71.899,71.899,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,35.81563,7.49325,56.59893,14.093,67.95814A7.999,7.999,0,0,1,207.01628,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BellSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$22(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BellSimple.displayName = "BellSimple";

var renderPathFor$23 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "227.97925",
        x2: "160",
        y2: "227.97925",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M182.52658,187.97925H48.98365A7.99908,7.99908,0,0,1,42.103,175.93566c6.60328-11.35959,14.1-32.1426,14.1-67.95641v-4A71.80588,71.80588,0,0,1,68.93752,63.03149",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M99.95187,37.68155a71.42431,71.42431,0,0,1,28.59653-5.70028c39.58967.29432,71.25651,33.20133,71.25651,72.90185v3.09613c0,18.98255,2.10491,33.7424,5.0661,45.11452",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M55.99674,104A72.00377,72.00377,0,0,1,128.55,32.002c39.70343.29432,71.46127,33.20133,71.46127,72.90185V112c0,35.81563,7.51478,56.59893,14.13351,67.95814A7.99892,7.99892,0,0,1,207.24334,192H48.75659a7.999,7.999,0,0,1-6.90041-12.04359C48.47844,168.59682,55.99674,147.81381,55.99674,112Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40.02075",
        x2: "208",
        y2: "216.02075",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "224",
        x2: "160",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.50261,41.40252A71.33429,71.33429,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,26.69367,4.16238,45.03713,9.015,57.35221",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M186.163,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641v-8A71.80594,71.80594,0,0,1,68.93758,63.05215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.91992,210.61816a8.0006,8.0006,0,0,1-11.83984,10.76368l-19.45654-21.40235H48.9834A15.99885,15.99885,0,0,1,35.18652,175.915c5.9375-10.21484,13.0166-29.59961,13.0166-63.93555v-8a79.6939,79.6939,0,0,1,10.7212-40.06885L42.08008,45.38184A8.0006,8.0006,0,1,1,53.91992,34.61816ZM160,215.97949H96a8,8,0,0,0,0,16h64a8,8,0,0,0,0-16Zm42.90039-41.2666a8.0004,8.0004,0,0,0,13.36328-8.31445c-5.61328-14.24414-8.459-32.55274-8.459-54.41895v-7.09668c0-44.28515-35.52735-80.57715-79.19629-80.90136A79.49567,79.49567,0,0,0,88.5332,34.43652,8.00109,8.00109,0,0,0,86.583,46.76367Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "223.97925",
        x2: "160",
        y2: "223.97925",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M92.50261,41.38177a71.33429,71.33429,0,0,1,36.04579-9.4005c39.58967.29432,71.25651,33.20133,71.25651,72.90185v7.09613c0,26.69367,4.16238,45.03713,9.015,57.35221",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M186.163,191.97925H48.98365A7.99908,7.99908,0,0,1,42.103,179.93566c6.60328-11.35959,14.1-32.1426,14.1-67.95641v-8A71.806,71.806,0,0,1,68.93758,63.03139",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "223.97925",
        x2: "160",
        y2: "223.97925",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M92.50261,41.38177a71.33429,71.33429,0,0,1,36.04579-9.4005c39.58967.29432,71.25651,33.20133,71.25651,72.90185v7.09613c0,26.69367,4.16238,45.03713,9.015,57.35221",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M186.163,191.97925H48.98365A7.99908,7.99908,0,0,1,42.103,179.93566c6.60328-11.35959,14.1-32.1426,14.1-67.95641v-8A71.806,71.806,0,0,1,68.93758,63.03139",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "223.97925",
        x2: "160",
        y2: "223.97925",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.50261,41.38177a71.33429,71.33429,0,0,1,36.04579-9.4005c39.58967.29432,71.25651,33.20133,71.25651,72.90185v7.09613c0,26.69367,4.16238,45.03713,9.015,57.35221",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M186.163,191.97925H48.98365A7.99908,7.99908,0,0,1,42.103,179.93566c6.60328-11.35959,14.1-32.1426,14.1-67.95641v-8A71.806,71.806,0,0,1,68.93758,63.03139",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BellSimpleSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$23(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BellSimpleSlash.displayName = "BellSimpleSlash";

var renderPathFor$24 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M96,192v8a32,32,0,0,0,64,0v-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M186.18182,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641v-8A71.80594,71.80594,0,0,1,68.9457,63.0404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M99.96516,37.69664A71.42478,71.42478,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112a189.04639,189.04639,0,0,0,3.776,39.67466",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56.20305,103.97925a71.899,71.899,0,0,1,72.34535-71.998c39.58967.29432,71.25651,33.20133,71.25651,72.90185v7.09613c0,35.81563,7.49325,56.59893,14.093,67.95814a7.999,7.999,0,0,1-6.88165,12.04186H48.98365A7.99908,7.99908,0,0,1,42.103,179.93566c6.60328-11.35959,14.1-32.1426,14.1-67.95641Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M96,192v8a32,32,0,0,0,64,0v-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M186.18182,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641v-8A71.80594,71.80594,0,0,1,68.9457,63.0404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.515,41.39547A71.33425,71.33425,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,26.66813,4.15442,45.002,9.001,57.31684",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M53.91992,34.61816A8.0006,8.0006,0,1,0,42.08008,45.38184L58.93164,63.91846A79.70131,79.70131,0,0,0,48.20312,104v8c0,34.33594-7.0791,53.7207-13.0166,63.93555A15.99886,15.99886,0,0,0,48.9834,200H88a40,40,0,0,0,80,0h14.64209l19.438,21.38184a8.0006,8.0006,0,1,0,11.83984-10.76368ZM128,224a24.0275,24.0275,0,0,1-24-24h48A24.0275,24.0275,0,0,1,128,224ZM86.59473,46.77734a8.00066,8.00066,0,0,1,1.95215-12.32812A79.89269,79.89269,0,0,1,128.6084,24.002c43.66894.32422,79.19629,36.61719,79.19629,80.90235V112c0,21.85059,2.84179,40.14844,8.44531,54.38672a8.00047,8.00047,0,0,1-13.36426,8.31152Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M96,192v8a32,32,0,0,0,64,0v-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M186.18182,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641v-8A71.80594,71.80594,0,0,1,68.9457,63.0404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M92.515,41.39547A71.33425,71.33425,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,26.66813,4.15442,45.002,9.001,57.31684",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M96,192v8a32,32,0,0,0,64,0v-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M186.18182,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641v-8A71.80594,71.80594,0,0,1,68.9457,63.0404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M92.515,41.39547A71.33425,71.33425,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,26.66813,4.15442,45.002,9.001,57.31684",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M96,192v8a32,32,0,0,0,64,0v-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M186.18182,192H48.98365A7.99908,7.99908,0,0,1,42.103,179.95641c6.60328-11.35959,14.1-32.1426,14.1-67.95641v-8A71.80594,71.80594,0,0,1,68.9457,63.0404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.515,41.39547A71.33425,71.33425,0,0,1,128.5484,32.002c39.58967.29432,71.25651,33.20133,71.25651,72.90185V112c0,26.66813,4.15442,45.002,9.001,57.31684",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BellSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$24(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BellSlash.displayName = "BellSlash";

var renderPathFor$25 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "52",
        cy: "160",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "204",
        cy: "160",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "52 64 79.2 64 132 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "52 160 96.8 96 168.8 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "184 64 151.2 64 204 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "52",
        cy: "160",
        r: "40",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "204",
        cy: "160",
        r: "40",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "160",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "204",
        cy: "160",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "52 64 79.2 64 132 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "52 160 96.8 96 168.8 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "184 64 151.2 64 204 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M51.99292,168.00049A8.00066,8.00066,0,0,1,45.446,155.41211l27.13623-38.76636a48.15264,48.15264,0,1,0,13.09522,9.19312l-27.124,38.749A7.989,7.989,0,0,1,51.99292,168.00049Z"
      }), React__default.createElement("path", {
        d: "M203.99975,112a47.7705,47.7705,0,0,0-15.79443,2.68237l22.8042,41.46216A8.00009,8.00009,0,1,1,196.99,163.85547l-22.79248-41.44141A47.96118,47.96118,0,1,0,203.99975,112Z"
      }), React__default.createElement("path", {
        d: "M175.842,92.20337l-.02027-.03662L164.73022,72h19.26953a8,8,0,0,0,0-16H151.2a7.99969,7.99969,0,0,0-7.00977,11.85547L155.26977,88H101.53L86.20971,60.14453A8.00017,8.00017,0,0,0,79.2,56H51.99975a8,8,0,0,0,0,16H74.46948L87.38989,95.49194,72.58227,116.64575a48.20354,48.20354,0,0,1,13.09522,9.19312L95.9834,111.11621,124.99,163.85547a8.00009,8.00009,0,1,0,14.01953-7.71094L110.33008,104h53.73974l10.12769,18.41406a47.94767,47.94767,0,0,1,14.00781-7.73169Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "52",
        cy: "160",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "204",
        cy: "160",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "52 64 79.2 64 132 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "52 160 96.8 96 168.8 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "184 64 151.2 64 204 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "52",
        cy: "160",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "204",
        cy: "160",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "52 64 79.2 64 132 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "52 160 96.8 96 168.8 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "184 64 151.2 64 204 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "52",
        cy: "160",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "204",
        cy: "160",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "52 64 79.2 64 132 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "52 160 96.8 96 168.8 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "184 64 151.2 64 204 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Bicycle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$25(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Bicycle.displayName = "Bicycle";

var renderPathFor$26 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32.003 184 80.003 120 128.003 120 32.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "120 128.003 184 176.003 120 224.003 120 128.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32.003 184 80.003 120 128.003 120 32.003",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "120 128.003 184 176.003 120 224.003 120 128.003",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "120 128.003 184 176.003 120 224.003 120 128.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "120 32.003 184 80.003 120 128.003 120 32.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188.79883,169.60193l-55.46631-41.59967,55.46631-41.6a7.99952,7.99952,0,0,0,0-12.7998l-64-48a8,8,0,0,0-12.79981,6.3999v80.00006l-51.20019-38.4a7.9998,7.9998,0,1,0-9.59961,12.7998l55.46631,41.6L51.19922,169.60193a8.0002,8.0002,0,0,0,9.59961,12.80078L111.999,144.00238v79.99994a8.00025,8.00025,0,0,0,12.79981,6.40039l64-48a8.0005,8.0005,0,0,0,0-12.80078ZM127.999,48.00232l42.667,32-42.667,32Zm0,160v-64l42.667,32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32.003 184 80.003 120 128.003 120 32.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "120 128.003 184 176.003 120 224.003 120 128.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32.003 184 80.003 120 128.003 120 32.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "120 128.003 184 176.003 120 224.003 120 128.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32.003 184 80.003 120 128.003 120 32.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "120 128.003 184 176.003 120 224.003 120 128.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Bluetooth = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$26(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Bluetooth.displayName = "Bluetooth";

var renderPathFor$27 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 184 80 120 128 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "120 128 184 176 120 224 120 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80",
        x2: "120",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "120",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 184 80 120 128 120 32",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "120 128 184 176 120 224 120 128",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "120 32 184 80 120 128 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "120 128 184 176 120 224 120 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80",
        x2: "120",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "120",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188.7998,169.6,133.334,128.00037,188.7998,86.40076a8.00048,8.00048,0,0,0,0-12.80078l-64-48A8.0003,8.0003,0,0,0,112,32.00037v79.99957L60.7998,73.6a8.00019,8.00019,0,0,0-9.5996,12.80078L106.666,128.00037,51.2002,169.6a8.00019,8.00019,0,0,0,9.5996,12.80078l51.2002-38.4v79.99958a8.00024,8.00024,0,0,0,12.7998,6.40039l64-48a8.00048,8.00048,0,0,0,0-12.80078ZM128,48.00037l42.667,32-42.667,32Zm0,160v-64l42.667,32Zm80-80a12,12,0,1,1-12-12A12.01344,12.01344,0,0,1,208,128.00037Zm-156,12a12,12,0,1,1,12-12A12.01344,12.01344,0,0,1,52,140.00037Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 184 80 120 128 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "120 128 184 176 120 224 120 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80",
        x2: "120",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "120",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 184 80 120 128 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "120 128 184 176 120 224 120 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80",
        x2: "120",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "120",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 32 184 80 120 128 120 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "120 128 184 176 120 224 120 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80",
        x2: "120",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "120",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BluetoothConnected = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$27(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BluetoothConnected.displayName = "BluetoothConnected";

var renderPathFor$28 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.99414",
        y1: "176.00256",
        x2: "119.99414",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "176.648 181.512 119.994 224.003 119.994 119.194",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "119.994 59.729 119.994 32.003 183.994 80.003 156.899 100.324",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "119.971 32.003 183.971 80.003 119.971 128.003 119.971 32.003",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "119.971 128 183.971 176 119.971 224 119.971 128",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48.00586",
        y1: "40",
        x2: "208.00586",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "120 71.622 120 32.003 184 80.003 150.476 105.146",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "176.654 181.512 120 224.003 120 128.003 145.169 146.879",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M213.91943,210.61865l-31.39087-34.53-.009-.01-31.35718-34.49292-.02148-.02343L53.91943,34.61865a7.99991,7.99991,0,1,0-11.83886,10.7627l70.8413,77.92553L51.19434,169.60254a7.9998,7.9998,0,1,0,9.5996,12.7998l51.2002-38.40014v80.00024a7.99975,7.99975,0,0,0,12.7998,6.3999l50.83033-38.12292,26.4563,29.10193a7.99991,7.99991,0,0,0,11.83886-10.7627Zm-85.92529-2.61621v-64l11.76013,8.82007,25.05945,27.56519Z"
      }), React__default.createElement("path", {
        d: "M119.99414,79.62207a7.99977,7.99977,0,0,0,8-8V48.00244l42.6665,32L145.67041,98.74561a7.9998,7.9998,0,1,0,9.59961,12.7998l33.52392-25.14307a7.9995,7.9995,0,0,0,0-12.7998l-64-48a8,8,0,0,0-12.7998,6.3999V71.62207A7.99977,7.99977,0,0,0,119.99414,79.62207Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.99414",
        y1: "176.00256",
        x2: "119.99414",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "119.994 71.622 119.994 32.003 183.994 80.003 150.47 105.146",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "176.648 181.512 119.994 224.003 119.994 128.003 145.163 146.879",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.99414",
        y1: "176.00256",
        x2: "119.99414",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "119.994 71.622 119.994 32.003 183.994 80.003 150.47 105.146",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "176.648 181.512 119.994 224.003 119.994 128.003 145.163 146.879",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.99414",
        y1: "176.00256",
        x2: "119.99414",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "119.994 71.622 119.994 32.003 183.994 80.003 150.47 105.146",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "176.648 181.512 119.994 224.003 119.994 128.003 145.163 146.879",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BluetoothSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$28(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BluetoothSlash.displayName = "BluetoothSlash";

var renderPathFor$29 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 128.003 184 176.003 120 224.003 120 128.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "56",
        x2: "184",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "104",
        x2: "184",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "144.406 109.698 120 128.003 120 32.003 144.405 50.307",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "119.971 32.003 183.971 80.003 119.971 128.003 119.971 32.003",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "119.971 128 183.971 176 119.971 224 119.971 128",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "120 128.003 184 176.003 120 224.003 120 128.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "56",
        x2: "184",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "104",
        x2: "184",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 104.002 120 128.003 120 32.003 151.999 56.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M188.7998,169.60254,133.333,128.00244l23.46679-17.6001a7.9998,7.9998,0,1,0-9.59961-12.7998L128,112.00244v-64l19.19922,14.39893a7.99981,7.99981,0,0,0,9.59961-12.79981l-31.999-23.999A8,8,0,0,0,112,32.00244v80.00025L60.7998,73.60254a7.9998,7.9998,0,0,0-9.59961,12.7998l55.4668,41.6001-55.4668,41.6001a7.9998,7.9998,0,1,0,9.59961,12.7998L112,144.0022v80.00024a7.99975,7.99975,0,0,0,12.7998,6.3999l64-48a7.9995,7.9995,0,0,0,0-12.7998ZM128,208.00244v-64l42.6665,32Z"
      }), React__default.createElement("path", {
        d: "M219.31348,80l18.34326-18.34326a7.99984,7.99984,0,0,0-11.31348-11.31348L208,68.68652,189.65674,50.34326a7.99984,7.99984,0,0,0-11.31348,11.31348L196.68652,80,178.34326,98.34326a7.99984,7.99984,0,1,0,11.31348,11.31348L208,91.31348l18.34326,18.34326a7.99984,7.99984,0,1,0,11.31348-11.31348Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 128.003 184 176.003 120 224.003 120 128.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "56",
        x2: "184",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "104",
        x2: "184",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "152 104.002 120 128.003 120 32.003 151.999 56.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 128.003 184 176.003 120 224.003 120 128.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "56",
        x2: "184",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "104",
        x2: "184",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "152 104.002 120 128.003 120 32.003 151.999 56.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "120 128.003 184 176.003 120 224.003 120 128.003",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "80.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176.00256",
        x2: "120",
        y2: "128.00256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "56",
        x2: "184",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "104",
        x2: "184",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 104.002 120 128.003 120 32.003 151.999 56.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BluetoothX = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$29(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BluetoothX.displayName = "BluetoothX";

var renderPathFor$2a = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "48 224 48 232 192 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M48,224a32,32,0,0,1,32-32H208V32H72A24,24,0,0,0,48,56V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,224a24,24,0,0,1,24-24H208V32H72A24,24,0,0,0,48,56Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M48,224a24,24,0,0,1,24-24H208V32H72A24,24,0,0,0,48,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 224 48 232 192 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99414,23.9971h-136a32.03667,32.03667,0,0,0-32,32v176a7.9954,7.9954,0,0,0,8,8h144a8,8,0,0,0,0-16h-136a16.01583,16.01583,0,0,1,16-16h136a7.99539,7.99539,0,0,0,8-8v-168A7.9954,7.9954,0,0,0,207.99414,23.9971Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,224a24,24,0,0,1,24-24H208V32H72A24,24,0,0,0,48,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "48 224 48 232 192 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,224a24,24,0,0,1,24-24H208V32H72A24,24,0,0,0,48,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "48 224 48 232 192 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,224a24,24,0,0,1,24-24H208V32H72A24,24,0,0,0,48,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 224 48 232 192 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Book = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2a(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Book.displayName = "Book";

var renderPathFor$2b = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "172.002 32 172.002 128 139.995 104 108.002 128 108.002 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "48.002 224 48.002 232 192.002 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M48.00244,224a32,32,0,0,1,32-32h128V32h-136a24,24,0,0,0-24,24V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176.00244,32v96l-32.00732-24-31.99268,24V32H72A23.99994,23.99994,0,0,0,48,56V224a23.99994,23.99994,0,0,1,24-24H208V32Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M48,224a24,24,0,0,1,24-24H208V32H72A24,24,0,0,0,48,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 224 48 232 192 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "176.002 32 176.002 128 143.995 104 112.002 128 112.002 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99951,24h-136a32.03667,32.03667,0,0,0-32,32V232a8.00039,8.00039,0,0,0,8,8h144a8,8,0,0,0,0-16h-136a16.01833,16.01833,0,0,1,16-16h136a8.00039,8.00039,0,0,0,8-8V32A8.00039,8.00039,0,0,0,207.99951,24ZM128.00244,40h56v80.001L158.394,100.7998a4.0005,4.0005,0,0,0-4.7998,0L128.00244,119.999Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,224a24,24,0,0,1,24-24H208V32H72A24,24,0,0,0,48,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "48 224 48 232 192 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "176.002 32 176.002 128 143.995 104 112.002 128 112.002 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,224a24,24,0,0,1,24-24H208V32H72A24,24,0,0,0,48,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "48 224 48 232 192 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "176.002 32 176.002 128 143.995 104 112.002 128 112.002 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,224a24,24,0,0,1,24-24H208V32H72A24,24,0,0,0,48,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 224 48 232 192 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "176.002 32 176.002 128 143.995 104 112.002 128 112.002 32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BookBookmark = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2b(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BookBookmark.displayName = "BookBookmark";

var renderPathFor$2c = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,88a32,32,0,0,1,32-32h64a8,8,0,0,1,8,8V192a8,8,0,0,1-8,8H160a32,32,0,0,0-32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M24,192a8,8,0,0,0,8,8H96a32,32,0,0,1,32,32V88A32,32,0,0,0,96,56H32a8,8,0,0,0-8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,56H160a32.00018,32.00018,0,0,0-32,32A31.99986,31.99986,0,0,0,96,56H32a7.99993,7.99993,0,0,0-8,8V192a7.99993,7.99993,0,0,0,8,8H96a31.99986,31.99986,0,0,1,32,32,32.00018,32.00018,0,0,1,32-32h64a7.99993,7.99993,0,0,0,8-8V64A7.99993,7.99993,0,0,0,224,56Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,88a32,32,0,0,1,32-32h64a8,8,0,0,1,8,8V192a8,8,0,0,1-8,8H160a32,32,0,0,0-32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M24,192a8,8,0,0,0,8,8H96a32,32,0,0,1,32,32V88A32,32,0,0,0,96,56H32a8,8,0,0,0-8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,208a24.0275,24.0275,0,0,1,24,24,8,8,0,0,0,16,0,24.0275,24.0275,0,0,1,24-24h64a16.01833,16.01833,0,0,0,16-16V64a16.01833,16.01833,0,0,0-16-16H176a40.04552,40.04552,0,0,0-40,40v80a8,8,0,0,1-16,0V88A40.04552,40.04552,0,0,0,80,48H32A16.01833,16.01833,0,0,0,16,64V192a16.01833,16.01833,0,0,0,16,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,88a32,32,0,0,1,32-32h64a8,8,0,0,1,8,8V192a8,8,0,0,1-8,8H160a32,32,0,0,0-32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M24,192a8,8,0,0,0,8,8H96a32,32,0,0,1,32,32V88A32,32,0,0,0,96,56H32a8,8,0,0,0-8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,88a32,32,0,0,1,32-32h64a8,8,0,0,1,8,8V192a8,8,0,0,1-8,8H160a32,32,0,0,0-32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M24,192a8,8,0,0,0,8,8H96a32,32,0,0,1,32,32V88A32,32,0,0,0,96,56H32a8,8,0,0,0-8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,88a32,32,0,0,1,32-32h64a8,8,0,0,1,8,8V192a8,8,0,0,1-8,8H160a32,32,0,0,0-32,32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M24,192a8,8,0,0,0,8,8H96a32,32,0,0,1,32,32V88A32,32,0,0,0,96,56H32a8,8,0,0,0-8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BookOpen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2c(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BookOpen.displayName = "BookOpen";

var renderPathFor$2d = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 176 127.993 136 56 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M200,224l-72.0074-40L56,224V40a8,8,0,0,1,8-8H192a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "56 224 127.993 184 200 224 200 176 127.993 136 56 176 56 224",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "200 176 127.993 136 56 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,224l-72.0074-40L56,224V40a8,8,0,0,1,8-8H192a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.00586,176.05115V40a16.01833,16.01833,0,0,0-16-16h-128a16.01833,16.01833,0,0,0-16,16V176.05334c0,.01667-.00025.03315,0,.04981V224a7.99994,7.99994,0,0,0,11.88525,6.99316L127.999,193.15137l68.12207,37.84179A8.00006,8.00006,0,0,0,208.00586,224V176.10352C208.0061,176.08606,208.00574,176.0686,208.00586,176.05115Zm-76.12256.95569a7.9988,7.9988,0,0,0-7.77,0L64.00586,210.40332V180.707l63.99316-35.5556,64.00684,35.55578V210.4043Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 176 127.993 136 56 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M200,224l-72.0074-40L56,224V40a8,8,0,0,1,8-8H192a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 176 127.993 136 56 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M200,224l-72.0074-40L56,224V40a8,8,0,0,1,8-8H192a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224l-72.0074-40L56,224V40a8,8,0,0,1,8-8H192a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "200 176 127.993 136 56 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Bookmark = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2d(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Bookmark.displayName = "Bookmark";

var renderPathFor$2e = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224l-72.0074-40L56,224V40a8,8,0,0,1,8-8H192a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224l-72.0074-40L56,224V40a8,8,0,0,1,8-8H192a8,8,0,0,1,8,8Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,224l-72.0074-40L56,224V40a8,8,0,0,1,8-8H192a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,24H64A16.01583,16.01583,0,0,0,48,40V224a7.99583,7.99583,0,0,0,11.89063,6.99219L128,193.14844l68.10938,37.84375A7.99583,7.99583,0,0,0,208,224V40A16.01582,16.01582,0,0,0,192,24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224l-72.0074-40L56,224V40a8,8,0,0,1,8-8H192a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224l-72.0074-40L56,224V40a8,8,0,0,1,8-8H192a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224l-72.0074-40L56,224V40a8,8,0,0,1,8-8H192a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BookmarkSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2e(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BookmarkSimple.displayName = "BookmarkSimple";

var renderPathFor$2f = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M164,228l-56.0074-40L52,228V76a8,8,0,0,1,8-8h96a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M92,28H196a8,8,0,0,1,8,8V188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,224l-56.0074-40L56,224V72a8,8,0,0,1,8-8h96a8,8,0,0,1,8,8Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M168,224l-56.0074-40L56,224V72a8,8,0,0,1,8-8h96a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,32H192a8,8,0,0,1,8,8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M160,56H64A16.01833,16.01833,0,0,0,48,72V224a8.00026,8.00026,0,0,0,12.65039,6.50977l51.34277-36.67872,51.35743,36.67872A7.99952,7.99952,0,0,0,176,224V72A16.01833,16.01833,0,0,0,160,56Z"
      }), React__default.createElement("path", {
        d: "M192,24H88a8,8,0,0,0,0,16H192V192a8,8,0,0,0,16,0V40A16.01833,16.01833,0,0,0,192,24Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,224l-56.0074-40L56,224V72a8,8,0,0,1,8-8h96a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,32H192a8,8,0,0,1,8,8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,224l-56.0074-40L56,224V72a8,8,0,0,1,8-8h96a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,32H192a8,8,0,0,1,8,8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,224l-56.0074-40L56,224V72a8,8,0,0,1,8-8h96a8,8,0,0,1,8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,32H192a8,8,0,0,1,8,8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Bookmarks = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2f(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Bookmarks.displayName = "Bookmarks";

var renderPathFor$2g = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "68.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,68V48a16,16,0,0,0-16-16H104A16,16,0,0,0,88,48V68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224.00806,122.30915A191.11647,191.11647,0,0,1,128,148a191.11667,191.11667,0,0,1-95.99345-25.68239",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "116",
        y1: "112",
        x2: "140",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,152a191.11689,191.11689,0,0,1-95.99219-25.68164V208a7.99993,7.99993,0,0,0,8,8h176a7.99992,7.99992,0,0,0,8-8V126.30908A191.1142,191.1142,0,0,1,128,152Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224.00806,126.30915A191.11647,191.11647,0,0,1,128,152a191.11667,191.11667,0,0,1-95.99345-25.68239",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "116",
        y1: "120",
        x2: "140",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.00781,64H176V56a24.0275,24.0275,0,0,0-24-24H104A24.0275,24.0275,0,0,0,80,56v8H40.00781a16.01833,16.01833,0,0,0-16,16V208a16.01833,16.01833,0,0,0,16,16h176a16.01833,16.01833,0,0,0,16-16V80A16.01833,16.01833,0,0,0,216.00781,64ZM96,56a8.00917,8.00917,0,0,1,8-8h48a8.00917,8.00917,0,0,1,8,8v8H96ZM216.00781,80l.00318,41.606A184.00072,184.00072,0,0,1,128,144a184.00068,184.00068,0,0,1-87.99219-22.38428V80ZM108,120a8.00039,8.00039,0,0,1,8-8h24a8,8,0,0,1,0,16H116A8.00039,8.00039,0,0,1,108,120Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224.00806,126.30915A191.11647,191.11647,0,0,1,128,152a191.11667,191.11667,0,0,1-95.99345-25.68239",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "116",
        y1: "120",
        x2: "140",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224.00806,126.30915A191.11647,191.11647,0,0,1,128,152a191.11667,191.11667,0,0,1-95.99345-25.68239",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "116",
        y1: "120",
        x2: "140",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224.00806,126.30915A191.11647,191.11647,0,0,1,128,152a191.11667,191.11667,0,0,1-95.99345-25.68239",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "116",
        y1: "120",
        x2: "140",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Briefcase = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2g(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Briefcase.displayName = "Briefcase";

var renderPathFor$2h = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "68.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,68V48a16,16,0,0,0-16-16H104A16,16,0,0,0,88,48V68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.00781,64H176V56a24.0275,24.0275,0,0,0-24-24H104A24.0275,24.0275,0,0,0,80,56v8H40.00781a16.01833,16.01833,0,0,0-16,16V208a16.01833,16.01833,0,0,0,16,16h176a16.01833,16.01833,0,0,0,16-16V80A16.01833,16.01833,0,0,0,216.00781,64ZM96,56a8.00917,8.00917,0,0,1,8-8h48a8.00917,8.00917,0,0,1,8,8v8H96Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BriefcaseSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2h(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BriefcaseSimple.displayName = "BriefcaseSimple";

var renderPathFor$2i = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M77.08831,178.91169a71.93858,71.93858,0,0,1,0-101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M178.91169,77.08831a71.93858,71.93858,0,0,1,0,101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M48.804,207.196a111.90445,111.90445,0,0,1,0-158.39192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M207.196,48.804a111.90445,111.90445,0,0,1,0,158.39192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M77.08831,178.91169a71.93858,71.93858,0,0,1,0-101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M178.91169,77.08831a71.93858,71.93858,0,0,1,0,101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M48.804,207.196a111.90445,111.90445,0,0,1,0-158.39192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M207.196,48.804a111.90445,111.90445,0,0,1,0,158.39192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "40"
      }), React__default.createElement("path", {
        d: "M82.74512,82.74512A8.00018,8.00018,0,1,0,71.43066,71.43164a79.94026,79.94026,0,0,0,0,113.13672,8.00018,8.00018,0,1,0,11.31446-11.31348,63.93958,63.93958,0,0,1,0-90.50976Z"
      }), React__default.createElement("path", {
        d: "M208,128a79.7769,79.7769,0,0,0-23.43066-56.56836,8.00018,8.00018,0,1,0-11.31446,11.31348,63.93958,63.93958,0,0,1,0,90.50976,8.00018,8.00018,0,0,0,11.31446,11.31348A79.7769,79.7769,0,0,0,208,128Z"
      }), React__default.createElement("path", {
        d: "M32.16992,168.479a103.90428,103.90428,0,0,1,22.291-114.01806A8.00018,8.00018,0,0,0,43.14648,43.14746a119.906,119.906,0,0,0,0,169.70508,8.00018,8.00018,0,1,0,11.31446-11.31348A103.65105,103.65105,0,0,1,32.16992,168.479Z"
      }), React__default.createElement("path", {
        d: "M238.56641,81.28809a119.58135,119.58135,0,0,0-25.71289-38.14063,8.00018,8.00018,0,1,0-11.31446,11.31348,103.90471,103.90471,0,0,1,0,147.07812,8.00018,8.00018,0,0,0,11.31446,11.31348A120.12116,120.12116,0,0,0,238.56641,81.28809Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M77.08831,178.91169a71.93858,71.93858,0,0,1,0-101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M178.91169,77.08831a71.93858,71.93858,0,0,1,0,101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M48.804,207.196a111.90445,111.90445,0,0,1,0-158.39192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M207.196,48.804a111.90445,111.90445,0,0,1,0,158.39192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M77.08831,178.91169a71.93858,71.93858,0,0,1,0-101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M178.91169,77.08831a71.93858,71.93858,0,0,1,0,101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M48.804,207.196a111.90445,111.90445,0,0,1,0-158.39192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M207.196,48.804a111.90445,111.90445,0,0,1,0,158.39192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M77.08831,178.91169a71.93858,71.93858,0,0,1,0-101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M178.91169,77.08831a71.93858,71.93858,0,0,1,0,101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M48.804,207.196a111.90445,111.90445,0,0,1,0-158.39192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M207.196,48.804a111.90445,111.90445,0,0,1,0,158.39192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Broadcast = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2i(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Broadcast.displayName = "Broadcast";

var renderPathFor$2j = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "96",
        x2: "224",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,96H224l.00781-39.99995a8,8,0,0,0-8-8h-176a8,8,0,0,0-8,8Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "96",
        x2: "224",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.00781,40h-176a16.01833,16.01833,0,0,0-16,16V95.84521C24.00684,95.89746,24,95.94775,24,96s.00684.10254.00781.15479V200a16.01833,16.01833,0,0,0,16,16h176a16.01833,16.01833,0,0,0,16-16V56A16.01833,16.01833,0,0,0,216.00781,40Zm0,16,.002,32H40.00781V56Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "96",
        x2: "224",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "96",
        x2: "224",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "96",
        x2: "224",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Browser = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2j(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Browser.displayName = "Browser";

var renderPathFor$2k = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "28.00781",
        y: "84.00005",
        width: "160",
        height: "128",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M68.00781,84.00005v-32a8,8,0,0,1,8-8h144a8,8,0,0,1,8,8V164a8,8,0,0,1-8,8h-32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "28",
        y1: "124",
        x2: "188",
        y2: "124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.00781,48h-144a7.99993,7.99993,0,0,0-8,8V80h120a7.99993,7.99993,0,0,1,8,8v88h24a7.99977,7.99977,0,0,0,8-8V56A7.99993,7.99993,0,0,0,216.00781,48Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "80.00005",
        width: "160",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M64.00781,80.00005v-24a8,8,0,0,1,8-8h144a8,8,0,0,1,8,8V168a8,8,0,0,1-8,8h-24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.00781,40h-144a16.01818,16.01818,0,0,0-16,16V72h-16a16.01818,16.01818,0,0,0-16,16v23.84521c-.001.052-.00781.10254-.00781.15479s.00684.10278.00781.15479V200a16.01833,16.01833,0,0,0,16,16h144a16.01833,16.01833,0,0,0,16-16V184h16a16.01833,16.01833,0,0,0,16-16V56A16.01817,16.01817,0,0,0,216.00781,40Zm-32,48,.00147,16H40.00781V88Zm32,80h-16V88a16.01817,16.01817,0,0,0-16-16h-112V56h144Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "80.00005",
        width: "160",
        height: "128",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M64.00781,80.00005v-24a8,8,0,0,1,8-8h144a8,8,0,0,1,8,8V168a8,8,0,0,1-8,8h-24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "80.00005",
        width: "160",
        height: "128",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M64.00781,80.00005v-24a8,8,0,0,1,8-8h144a8,8,0,0,1,8,8V168a8,8,0,0,1-8,8h-24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "80.00005",
        width: "160",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M64.00781,80.00005v-24a8,8,0,0,1,8-8h144a8,8,0,0,1,8,8V168a8,8,0,0,1-8,8h-24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Browsers = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2k(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Browsers.displayName = "Browsers";

var renderPathFor$2l = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "28.00781",
        y: "84.00005",
        width: "160",
        height: "128",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M64.00781,44.00005h156a8,8,0,0,1,8,8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "80.00005",
        width: "160",
        height: "128",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "80.00005",
        width: "160",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M64.00781,48.00005h152a8,8,0,0,1,8,8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("rect", {
        x: "24.00781",
        y: "72",
        width: "176",
        height: "144",
        rx: "16"
      }), React__default.createElement("path", {
        d: "M216.00781,40h-152a8,8,0,0,0,0,16h152V176a8,8,0,0,0,16,0V56A16.01833,16.01833,0,0,0,216.00781,40Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "80.00005",
        width: "160",
        height: "128",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M64.00781,48.00005h152a8,8,0,0,1,8,8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "80.00005",
        width: "160",
        height: "128",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M64.00781,48.00005h152a8,8,0,0,1,8,8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "80.00005",
        width: "160",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M64.00781,48.00005h152a8,8,0,0,1,8,8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var BrowsersSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2l(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
BrowsersSimple.displayName = "BrowsersSimple";

var renderPathFor$2m = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M143.99414,223.98316v-184a8,8,0,0,0-8-8h-96a8,8,0,0,0-8,8v184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M223.99414,223.98316v-120a8,8,0,0,0-8-8h-72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "67.99414",
        y1: "71.98316",
        x2: "95.99414",
        y2: "71.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "151.98316",
        x2: "107.99414",
        y2: "151.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "67.99414",
        y1: "191.98316",
        x2: "95.99414",
        y2: "191.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "179.99414",
        y1: "175.98316",
        x2: "187.99414",
        y2: "175.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "179.99414",
        y1: "135.98316",
        x2: "187.99414",
        y2: "135.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M143.99414,223.98316v-184a8,8,0,0,0-8-8h-96a8,8,0,0,0-8,8v184",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M143.99414,223.98316v-184a8,8,0,0,0-8-8h-96a8,8,0,0,0-8,8v184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M223.99414,223.98316v-120a8,8,0,0,0-8-8h-72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "71.98316",
        x2: "95.99414",
        y2: "71.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "151.98316",
        x2: "111.99414",
        y2: "151.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "191.98316",
        x2: "95.99414",
        y2: "191.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "175.99414",
        y1: "175.98316",
        x2: "191.99414",
        y2: "175.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "175.99414",
        y1: "135.98316",
        x2: "191.99414",
        y2: "135.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M191.99414,167.98316h-16a8,8,0,0,0,0,16h16a8,8,0,1,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M191.99414,127.98316h-16a8,8,0,0,0,0,16h16a8,8,0,1,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M215.99414,87.98316h-64v-48a16.01833,16.01833,0,0,0-16-16h-96a16.01833,16.01833,0,0,0-16,16v184a8.00009,8.00009,0,0,0,8,8h112a8.00009,8.00009,0,0,0,8-8v-120h64v120a8,8,0,0,0,16,0v-120A16.01833,16.01833,0,0,0,215.99414,87.98316Zm-152-24h32a8,8,0,1,1,0,16h-32a8,8,0,0,1,0-16Zm32,136h-32a8,8,0,0,1,0-16h32a8,8,0,1,1,0,16Zm16-40h-32a8,8,0,0,1,0-16h32a8,8,0,1,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M143.99414,223.98316v-184a8,8,0,0,0-8-8h-96a8,8,0,0,0-8,8v184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M223.99414,223.98316v-120a8,8,0,0,0-8-8h-72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "71.98316",
        x2: "95.99414",
        y2: "71.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "151.98316",
        x2: "111.99414",
        y2: "151.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "191.98316",
        x2: "95.99414",
        y2: "191.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "175.99414",
        y1: "175.98316",
        x2: "191.99414",
        y2: "175.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "175.99414",
        y1: "135.98316",
        x2: "191.99414",
        y2: "135.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M143.99414,223.98316v-184a8,8,0,0,0-8-8h-96a8,8,0,0,0-8,8v184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M223.99414,223.98316v-120a8,8,0,0,0-8-8h-72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "71.98316",
        x2: "95.99414",
        y2: "71.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "151.98316",
        x2: "111.99414",
        y2: "151.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "191.98316",
        x2: "95.99414",
        y2: "191.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "175.99414",
        y1: "175.98316",
        x2: "191.99414",
        y2: "175.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "175.99414",
        y1: "135.98316",
        x2: "191.99414",
        y2: "135.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M143.99414,223.98316v-184a8,8,0,0,0-8-8h-96a8,8,0,0,0-8,8v184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M223.99414,223.98316v-120a8,8,0,0,0-8-8h-72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "71.98316",
        x2: "95.99414",
        y2: "71.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "151.98316",
        x2: "111.99414",
        y2: "151.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "191.98316",
        x2: "95.99414",
        y2: "191.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "175.99414",
        y1: "175.98316",
        x2: "191.99414",
        y2: "175.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "175.99414",
        y1: "135.98316",
        x2: "191.99414",
        y2: "135.98316",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Buildings = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2m(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Buildings.displayName = "Buildings";

var renderPathFor$2n = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "42",
        y1: "80",
        x2: "214",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "42",
        y1: "132",
        x2: "214",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M214,184H42V64A24,24,0,0,1,66,40H190a24,24,0,0,1,24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M214,184v32a8,8,0,0,1-8,8H182a8,8,0,0,1-8-8V184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M82,184v32a8,8,0,0,1-8,8H50a8,8,0,0,1-8-8V184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M214,192v24a8,8,0,0,1-8,8H182a8,8,0,0,1-8-8V192Z",
        opacity: "0.3"
      }), React__default.createElement("path", {
        d: "M82,192v24a8,8,0,0,1-8,8H50a8,8,0,0,1-8-8V192Z",
        opacity: "0.3"
      }), React__default.createElement("rect", {
        x: "42",
        y: "72",
        width: "172",
        height: "48",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "42",
        y1: "72",
        x2: "214",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "42",
        y1: "120",
        x2: "214",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M214,192H42V64A24,24,0,0,1,66,40H190a24,24,0,0,1,24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M214,192v24a8,8,0,0,1-8,8H182a8,8,0,0,1-8-8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M82,192v24a8,8,0,0,1-8,8H50a8,8,0,0,1-8-8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M190,32H66A32.03667,32.03667,0,0,0,34,64V216a16.01833,16.01833,0,0,0,16,16H74a16.01833,16.01833,0,0,0,16-16V200h76v16a16.01833,16.01833,0,0,0,16,16h24a16.01833,16.01833,0,0,0,16-16V64A32.03667,32.03667,0,0,0,190,32ZM74,216H50V200H74Zm8-48a12,12,0,1,1,12-12A12,12,0,0,1,82,168Zm92,0a12,12,0,1,1,12-12A12,12,0,0,1,174,168Zm32,48H182V200h24Zm0-96H50V72H206Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "42",
        y1: "72",
        x2: "214",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "42",
        y1: "120",
        x2: "214",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M214,192H42V64A24,24,0,0,1,66,40H190a24,24,0,0,1,24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M214,192v24a8,8,0,0,1-8,8H182a8,8,0,0,1-8-8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M82,192v24a8,8,0,0,1-8,8H50a8,8,0,0,1-8-8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "42",
        y1: "72",
        x2: "214",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "42",
        y1: "120",
        x2: "214",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M214,192H42V64A24,24,0,0,1,66,40H190a24,24,0,0,1,24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M214,192v24a8,8,0,0,1-8,8H182a8,8,0,0,1-8-8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M82,192v24a8,8,0,0,1-8,8H50a8,8,0,0,1-8-8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "42",
        y1: "72",
        x2: "214",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "42",
        y1: "120",
        x2: "214",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M214,192H42V64A24,24,0,0,1,66,40H190a24,24,0,0,1,24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M214,192v24a8,8,0,0,1-8,8H182a8,8,0,0,1-8-8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M82,192v24a8,8,0,0,1-8,8H50a8,8,0,0,1-8-8V192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Bus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2n(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Bus.displayName = "Bus";

var renderPathFor$2o = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "31.99995",
        y: "48.00781",
        width: "192",
        height: "160",
        rx: "8",
        transform: "translate(256.00777 0.00786) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "92",
        y1: "76",
        x2: "164",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "152",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "152",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "104",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "104",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "80",
        y: "64",
        width: "96",
        height: "48",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "80",
        y: "64",
        width: "96",
        height: "48",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "31.99995",
        y: "48.00781",
        width: "192",
        height: "160",
        rx: "8",
        transform: "translate(256.00777 0.00786) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,24.00781H56a16.01833,16.01833,0,0,0-16,16v176a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16v-176A16.01833,16.01833,0,0,0,200,24.00781ZM88,200a12,12,0,1,1,12-12A12.01375,12.01375,0,0,1,88,200Zm0-40a12,12,0,1,1,12-12A12.01375,12.01375,0,0,1,88,160Zm40,40a12,12,0,1,1,12-12A12.01375,12.01375,0,0,1,128,200Zm0-40a12,12,0,1,1,12-12A12.01375,12.01375,0,0,1,128,160Zm40,40a12,12,0,1,1,12-12A12.01375,12.01375,0,0,1,168,200Zm0-40a12,12,0,1,1,12-12A12.01375,12.01375,0,0,1,168,160Zm16-56a7.99977,7.99977,0,0,1-8,8H80a7.99977,7.99977,0,0,1-8-8V64a7.99977,7.99977,0,0,1,8-8h96a7.99977,7.99977,0,0,1,8,8Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "80",
        y: "64",
        width: "96",
        height: "48",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "31.99995",
        y: "48.00781",
        width: "192",
        height: "160",
        rx: "8",
        transform: "translate(256.00777 0.00786) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "80",
        y: "64",
        width: "96",
        height: "48",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "31.99995",
        y: "48.00781",
        width: "192",
        height: "160",
        rx: "8",
        transform: "translate(256.00777 0.00786) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "80",
        y: "64",
        width: "96",
        height: "48",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "31.99995",
        y: "48.00781",
        width: "192",
        height: "160",
        rx: "8",
        transform: "translate(256.00777 0.00786) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Calculator = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2o(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Calculator.displayName = "Calculator";

var renderPathFor$2p = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "20",
        x2: "176",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "20",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,127.99666h28l-16,20a16,16,0,1,1-11.30681,27.3206",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "148 139.997 164 127.997 164 179.997",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,88H216V48a8,8,0,0,0-8-8H48a8,8,0,0,0-8,8Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92,127.99666h28l-16,20a16,16,0,1,1-11.30681,27.3206",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 139.997 160 127.997 160 179.997",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99414,31.99707h-24v-8a8,8,0,0,0-16,0v8h-80v-8a8,8,0,1,0-16,0v8h-24a16.01583,16.01583,0,0,0-16,16v160a16.01583,16.01583,0,0,0,16,16h160a16.01582,16.01582,0,0,0,16-16v-160A16.01582,16.01582,0,0,0,207.99414,31.99707ZM104,187.99707a23.84464,23.84464,0,0,1-16.96045-7.01953,8,8,0,0,1,11.30713-11.32031A7.99993,7.99993,0,1,0,104,155.99707h-.00488c-.249,0-.49805-.01465-.74658-.03809-.07959-.00732-.15723-.01953-.23584-.029-.16651-.02075-.33252-.04492-.498-.07593-.09229-.01757-.1836-.03711-.2749-.05761-.15039-.03369-.3003-.07276-.44922-.11548-.09082-.02612-.18164-.05152-.271-.08081-.15039-.04907-.29932-.10523-.44726-.16358-.08057-.03173-.16211-.06054-.24122-.09472-.17236-.07447-.34179-.15845-.51074-.24585-.04883-.02564-.1001-.04712-.14843-.07349q-.31641-.17322-.6211-.37744c-.06836-.0459-.13183-.09741-.19873-.14526-.11719-.08374-.23584-.16455-.34961-.25562-.01465-.01172-.02734-.02515-.042-.03711-.12061-.09814-.23389-.2041-.34863-.30908-.0835-.07617-.17139-.14917-.251-.22827-.07715-.07666-.147-.15991-.22119-.23975a8.03993,8.03993,0,0,1-1.95069-3.71777c-.00537-.02539-.01416-.05-.01953-.07544-.02783-.13477-.04443-.27344-.06543-.41065-.019-.12426-.04345-.24755-.05664-.37255-.01123-.10279-.01269-.208-.02-.312-.01123-.16381-.02343-.32739-.02441-.4917C96.00244,148.032,96,148.01489,96,147.99707c0-.083.00977-.16357.0127-.24609.00488-.16577.00976-.3313.0249-.49683.01025-.11182.02783-.221.043-.3313.02-.14892.03955-.29761.06787-.44556.023-.11889.05273-.23461.08056-.3518.03272-.13623.06495-.27246.105-.40772.03614-.12109.07862-.239.12012-.35766.04444-.12671.08789-.25366.13867-.37891.04981-.12231.10645-.24048.16211-.35986.05469-.1167.10742-.23364.168-.34863.06543-.12452.13867-.24439.21045-.365.062-.10375.12158-.20849.18848-.3103.085-.12817.17724-.25024.269-.37329.05566-.07446.10352-.1521.16211-.2251l5.602-7.00195H92a8,8,0,1,1,0-16h28a8.00023,8.00023,0,0,1,6.24707,12.998l-8.86914,11.08642A23.99341,23.99341,0,0,1,104,187.99707Zm64-8a8,8,0,0,1-16,0v-36l-3.2002,2.40039a8.00019,8.00019,0,0,1-9.5996-12.80078l16-12A8.00031,8.00031,0,0,1,168,127.99707Zm39.99414-100h-160v-32h24v8a8,8,0,0,0,16,0v-8h80v8a8,8,0,1,0,16,0v-8h24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M92,127.99666h28l-16,20a16,16,0,1,1-11.30681,27.3206",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "144 139.997 160 127.997 160 179.997",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M92,127.99666h28l-16,20a16,16,0,1,1-11.30681,27.3206",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "144 139.997 160 127.997 160 179.997",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92,127.99666h28l-16,20a16,16,0,1,1-11.30681,27.3206",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 139.997 160 127.997 160 179.997",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Calendar = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2p(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Calendar.displayName = "Calendar";

var renderPathFor$2q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "20",
        x2: "176",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "20",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,88H216V48a8,8,0,0,0-8-8H48a8,8,0,0,0-8,8Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99414,31.9971h-24v-8a8,8,0,1,0-16,0v8h-80v-8a8,8,0,0,0-16,0v8h-24a16.01583,16.01583,0,0,0-16,16v160a16.01582,16.01582,0,0,0,16,16h160a16.01581,16.01581,0,0,0,16-16v-160A16.01582,16.01582,0,0,0,207.99414,31.9971Zm0,48h-160v-32h24v8a8,8,0,0,0,16,0v-8h80v8a8,8,0,1,0,16,0v-8h24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CalendarBlank = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CalendarBlank.displayName = "CalendarBlank";

var renderPathFor$2r = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152",
        y1: "128",
        x2: "104",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "176",
        x2: "104",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "20",
        x2: "176",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "20",
        x2: "80",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,88H216V48a8,8,0,0,0-8-8H48a8,8,0,0,0-8,8Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "128",
        x2: "104",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "176",
        x2: "104",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99414,31.9971h-24v-8a8,8,0,1,0-16,0v8h-80v-8a8,8,0,0,0-16,0v8h-24a16.01583,16.01583,0,0,0-16,16v160a16.01582,16.01582,0,0,0,16,16h160a16.01581,16.01581,0,0,0,16-16v-160A16.01582,16.01582,0,0,0,207.99414,31.9971ZM157.65039,170.34085a7.99915,7.99915,0,1,1-11.3125,11.3125L127.99414,163.3096l-18.34375,18.34375a7.99915,7.99915,0,0,1-11.3125-11.3125l18.34375-18.34375L98.33789,133.65335a7.99915,7.99915,0,1,1,11.3125-11.3125l18.34375,18.34375,18.34375-18.34375a7.99915,7.99915,0,1,1,11.3125,11.3125L139.30664,151.9971ZM207.99414,79.9971h-160v-32h24v8a8,8,0,0,0,16,0v-8h80v8a8,8,0,1,0,16,0v-8h24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "128",
        x2: "104",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "176",
        x2: "104",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "128",
        x2: "104",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "176",
        x2: "104",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "24",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "24",
        x2: "80",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "88",
        x2: "216",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "128",
        x2: "104",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "176",
        x2: "104",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CalendarX = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2r(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CalendarX.displayName = "CalendarX";

var renderPathFor$2s = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,208H48a16,16,0,0,1-16-16V80A16,16,0,0,1,48,64H79.99414l16-24h64l16,24H208a16,16,0,0,1,16,16V192A16,16,0,0,1,208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "132",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,64H175.99414l-16-24h-64l-16,24H48A16,16,0,0,0,32,80V192a16,16,0,0,0,16,16H208a16,16,0,0,0,16-16V80A16,16,0,0,0,208,64ZM128,168a36,36,0,1,1,36-36A36,36,0,0,1,128,168Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M208,208H48a16,16,0,0,1-16-16V80A16,16,0,0,1,48,64H79.99414l16-24h64l16,24H208a16,16,0,0,1,16,16V192A16,16,0,0,1,208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "132",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,56H180.27539l-13.625-20.4375A7.99942,7.99942,0,0,0,159.99414,32h-64a7.99943,7.99943,0,0,0-6.65625,3.5625L75.71289,56H48A24.0275,24.0275,0,0,0,24,80V192a24.0275,24.0275,0,0,0,24,24H208a24.0275,24.0275,0,0,0,24-24V80A24.0275,24.0275,0,0,0,208,56Zm-44,76a36,36,0,1,1-36-36A36.04043,36.04043,0,0,1,164,132Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,208H48a16,16,0,0,1-16-16V80A16,16,0,0,1,48,64H79.99414l16-24h64l16,24H208a16,16,0,0,1,16,16V192A16,16,0,0,1,208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "132",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,208H48a16,16,0,0,1-16-16V80A16,16,0,0,1,48,64H79.99414l16-24h64l16,24H208a16,16,0,0,1,16,16V192A16,16,0,0,1,208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "132",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,208H48a16,16,0,0,1-16-16V80A16,16,0,0,1,48,64H79.99414l16-24h64l16,24H208a16,16,0,0,1,16,16V192A16,16,0,0,1,208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "132",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Camera = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2s(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Camera.displayName = "Camera";

var renderPathFor$2t = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "33.45455",
        y1: "24",
        x2: "222.54545",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M200.72725,208H48a16,16,0,0,1-16-16V80A16,16,0,0,1,48,64H69.8181",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M154.13957,156.75336a36.00072,36.00072,0,1,1-48.298-53.128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M102.05858,40h57.93556l16,24H208a16,16,0,0,1,16,16v94.13562",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.00244,64.00684H175.99658l-16-24h-64l-16,24H48.00244a16,16,0,0,0-16,16v112a16,16,0,0,0,16,16h160a16,16,0,0,0,16-16v-112A16,16,0,0,0,208.00244,64.00684Zm-80,104a36,36,0,1,1,36-36A36,36,0,0,1,128.00244,168.00684Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "33.45455",
        y1: "24",
        x2: "222.54545",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M93.98553,43.01291,95.99414,40h64l16,24H208a16,16,0,0,1,16,16V186.02889",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200.72725,208H48a16,16,0,0,1-16-16V80A16,16,0,0,1,48,64H69.8181",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M154.13957,156.75336a36.00072,36.00072,0,1,1-48.298-53.128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M39.37451,18.61865a8.00027,8.00027,0,0,0-11.83984,10.7627L51.7334,56H47.99951a24.0275,24.0275,0,0,0-24,24V192a24.0275,24.0275,0,0,0,24,24H197.188l19.4375,21.38135a8.00027,8.00027,0,0,0,11.83984-10.7627ZM128,168a35.97306,35.97306,0,0,1-27.86426-58.75781L148.02246,161.918A35.81152,35.81152,0,0,1,128,168Z"
      }), React__default.createElement("path", {
        d: "M207.99951,56H180.2749l-13.625-20.4375A7.99942,7.99942,0,0,0,159.99365,32h-64a7.99954,7.99954,0,0,0-6.65722,3.56348l-2.00782,3.01318a8.00079,8.00079,0,0,0,.73731,9.81787L218.07959,191.41016a8.0004,8.0004,0,0,0,13.91992-5.38135V80A24.0275,24.0275,0,0,0,207.99951,56Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "33.45455",
        y1: "24",
        x2: "222.54545",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M93.98553,43.01291,95.99414,40h64l16,24H208a16,16,0,0,1,16,16V186.02889",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M200.72725,208H48a16,16,0,0,1-16-16V80A16,16,0,0,1,48,64H69.8181",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M154.13957,156.75336a36.00072,36.00072,0,1,1-48.298-53.128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "33.45455",
        y1: "24",
        x2: "222.54545",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M93.98553,43.01291,95.99414,40h64l16,24H208a16,16,0,0,1,16,16V186.02889",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M200.72725,208H48a16,16,0,0,1-16-16V80A16,16,0,0,1,48,64H69.8181",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M154.13957,156.75336a36.00072,36.00072,0,1,1-48.298-53.128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "33.45455",
        y1: "24",
        x2: "222.54545",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M93.98553,43.01291,95.99414,40h64l16,24H208a16,16,0,0,1,16,16V186.02889",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200.72725,208H48a16,16,0,0,1-16-16V80A16,16,0,0,1,48,64H69.8181",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M154.13957,156.75336a36.00072,36.00072,0,1,1-48.298-53.128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CameraSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2t(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CameraSlash.displayName = "CameraSlash";

var renderPathFor$2u = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,176v32a8,8,0,0,1-8,8H192a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M72,176v32a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,120,194.11151,52.75089A8,8,0,0,0,186.801,48H69.199a8,8,0,0,0-7.31049,4.75089L32,120v56H224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,184v24a8,8,0,0,1-8,8H192a8,8,0,0,1-8-8V184Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M72,184v24a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V184Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M224,120,194.11151,52.75089A8,8,0,0,0,186.801,48H69.199a8,8,0,0,0-7.31049,4.75089L32,120Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,184v24a8,8,0,0,1-8,8H192a8,8,0,0,1-8-8V184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M72,184v24a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "152",
        x2: "80",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "152",
        x2: "192",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,120,194.11151,52.75089A8,8,0,0,0,186.801,48H69.199a8,8,0,0,0-7.31049,4.75089L32,120v64H224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,112H229.199L201.42188,49.501A16.01649,16.01649,0,0,0,186.80078,40H69.19922a16.0158,16.0158,0,0,0-14.6211,9.502L26.801,112H16a8,8,0,0,0,0,16h8v80a16.01833,16.01833,0,0,0,16,16H64a16.01833,16.01833,0,0,0,16-16V192h96v16a16.01833,16.01833,0,0,0,16,16h24a16.01833,16.01833,0,0,0,16-16V128h8a8,8,0,0,0,0-16ZM64,208H40V192H64Zm16-48H64a8,8,0,0,1,0-16H80a8,8,0,0,1,0,16Zm96,0a8,8,0,0,1,0-16h16a8,8,0,0,1,0,16Zm40,48H192V192h24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,184v24a8,8,0,0,1-8,8H192a8,8,0,0,1-8-8V184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M72,184v24a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "152",
        x2: "80",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "152",
        x2: "192",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,120,194.11151,52.75089A8,8,0,0,0,186.801,48H69.199a8,8,0,0,0-7.31049,4.75089L32,120v64H224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,184v24a8,8,0,0,1-8,8H192a8,8,0,0,1-8-8V184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M72,184v24a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "152",
        x2: "80",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "152",
        x2: "192",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,120,194.11151,52.75089A8,8,0,0,0,186.801,48H69.199a8,8,0,0,0-7.31049,4.75089L32,120v64H224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,184v24a8,8,0,0,1-8,8H192a8,8,0,0,1-8-8V184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M72,184v24a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "152",
        x2: "80",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "152",
        x2: "192",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,120,194.11151,52.75089A8,8,0,0,0,186.801,48H69.199a8,8,0,0,0-7.31049,4.75089L32,120v64H224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Car = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2u(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Car.displayName = "Car";

var renderPathFor$2v = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M216,216H192a8,8,0,0,1-8-8V184H72v24a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V120L61.88849,52.75089A8,8,0,0,1,69.199,48H186.801a8,8,0,0,1,7.31049,4.75089L224,120v88A8,8,0,0,1,216,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,120,61.88849,52.75089A8,8,0,0,1,69.199,48H186.801a8,8,0,0,1,7.31049,4.75089L224,120Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M216,216H192a8,8,0,0,1-8-8V184H72v24a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V120L61.88849,52.75089A8,8,0,0,1,69.199,48H186.801a8,8,0,0,1,7.31049,4.75089L224,120v88A8,8,0,0,1,216,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,112H229.199L201.42188,49.501A16.01649,16.01649,0,0,0,186.80078,40H69.19922a16.0158,16.0158,0,0,0-14.6211,9.502L26.801,112H16a8,8,0,0,0,0,16h8v80a16.01833,16.01833,0,0,0,16,16H64a16.01833,16.01833,0,0,0,16-16V192h96v16a16.01833,16.01833,0,0,0,16,16h24a16.01833,16.01833,0,0,0,16-16V128h8a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M216,216H192a8,8,0,0,1-8-8V184H72v24a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V120L61.88849,52.75089A8,8,0,0,1,69.199,48H186.801a8,8,0,0,1,7.31049,4.75089L224,120v88A8,8,0,0,1,216,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M216,216H192a8,8,0,0,1-8-8V184H72v24a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V120L61.88849,52.75089A8,8,0,0,1,69.199,48H186.801a8,8,0,0,1,7.31049,4.75089L224,120v88A8,8,0,0,1,216,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M216,216H192a8,8,0,0,1-8-8V184H72v24a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V120L61.88849,52.75089A8,8,0,0,1,69.199,48H186.801a8,8,0,0,1,7.31049,4.75089L224,120v88A8,8,0,0,1,216,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CarSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2v(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CarSimple.displayName = "CarSimple";

var renderPathFor$2w = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "160 88 128 120 96 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "160 144 128 176 96 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 88 128 120 96 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 144 128 176 96 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M54.46094,54.46094a103.95314,103.95314,0,1,0,147.07812,0A104.12262,104.12262,0,0,0,54.46094,54.46094Zm99.88281,83.88281a7.99915,7.99915,0,1,1,11.3125,11.3125l-32,32a7.99708,7.99708,0,0,1-11.3125,0l-32-32a7.99915,7.99915,0,0,1,11.3125-11.3125L128,164.6875Zm0-56a7.99915,7.99915,0,1,1,11.3125,11.3125l-32,32a7.99708,7.99708,0,0,1-11.3125,0l-32-32a7.99915,7.99915,0,0,1,11.3125-11.3125L128,108.6875Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "160 88 128 120 96 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "160 144 128 176 96 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "160 88 128 120 96 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "160 144 128 176 96 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 88 128 120 96 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 144 128 176 96 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretCircleDoubleDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2w(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretCircleDoubleDown.displayName = "CaretCircleDoubleDown";

var renderPathFor$2x = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "168 160 136 128 168 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "112 160 80 128 112 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "168 160 136 128 168 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "112 160 80 128 112 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M201.53906,54.46094a103.95314,103.95314,0,1,0,0,147.07812A104.12262,104.12262,0,0,0,201.53906,54.46094Zm-83.88281,99.88281a7.99915,7.99915,0,1,1-11.3125,11.3125l-32-32a7.99708,7.99708,0,0,1,0-11.3125l32-32a7.99915,7.99915,0,0,1,11.3125,11.3125L91.3125,128Zm56,0a7.99915,7.99915,0,1,1-11.3125,11.3125l-32-32a7.99708,7.99708,0,0,1,0-11.3125l32-32a7.99915,7.99915,0,0,1,11.3125,11.3125L147.3125,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "168 160 136 128 168 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "112 160 80 128 112 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "168 160 136 128 168 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "112 160 80 128 112 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "168 160 136 128 168 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "112 160 80 128 112 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretCircleDoubleLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2x(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretCircleDoubleLeft.displayName = "CaretCircleDoubleLeft";

var renderPathFor$2y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "88 160 120 128 88 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "144 160 176 128 144 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "88 160 120 128 88 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 160 176 128 144 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M201.53906,54.46094a103.95314,103.95314,0,1,0,0,147.07812A104.12262,104.12262,0,0,0,201.53906,54.46094Zm-75.88281,79.19531-32,32a7.99915,7.99915,0,0,1-11.3125-11.3125L108.6875,128,82.34375,101.65625a7.99915,7.99915,0,0,1,11.3125-11.3125l32,32A7.99708,7.99708,0,0,1,125.65625,133.65625Zm56,0-32,32a7.99915,7.99915,0,0,1-11.3125-11.3125L164.6875,128l-26.34375-26.34375a7.99915,7.99915,0,0,1,11.3125-11.3125l32,32A7.99708,7.99708,0,0,1,181.65625,133.65625Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "88 160 120 128 88 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "144 160 176 128 144 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "88 160 120 128 88 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "144 160 176 128 144 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "88 160 120 128 88 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 160 176 128 144 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretCircleDoubleRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretCircleDoubleRight.displayName = "CaretCircleDoubleRight";

var renderPathFor$2z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "96 168 128 136 160 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "96 112 128 80 160 112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 168 128 136 160 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 112 128 80 160 112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M201.53906,201.53906a103.95314,103.95314,0,1,0-147.07812,0A104.12262,104.12262,0,0,0,201.53906,201.53906Zm-99.88281-83.88281a7.99915,7.99915,0,1,1-11.3125-11.3125l32-32a7.99708,7.99708,0,0,1,11.3125,0l32,32a7.99915,7.99915,0,0,1-11.3125,11.3125L128,91.3125Zm0,56a7.99915,7.99915,0,1,1-11.3125-11.3125l32-32a7.99708,7.99708,0,0,1,11.3125,0l32,32a7.99915,7.99915,0,0,1-11.3125,11.3125L128,147.3125Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "96 168 128 136 160 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "96 112 128 80 160 112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "96 168 128 136 160 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "96 112 128 80 160 112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 168 128 136 160 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 112 128 80 160 112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretCircleDoubleUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretCircleDoubleUp.displayName = "CaretCircleDoubleUp";

var renderPathFor$2A = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "164 116 128 156 92 116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "164 116 128 156 92 116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm41.94531,97.35156-36,40a7.99734,7.99734,0,0,1-11.89062,0l-36-40a7.99912,7.99912,0,1,1,11.89062-10.70312L128,144.03906l30.05469-33.39062a7.99912,7.99912,0,1,1,11.89062,10.70312Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "164 116 128 156 92 116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "164 116 128 156 92 116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "164 116 128 156 92 116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretCircleDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2A(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretCircleDown.displayName = "CaretCircleDown";

var renderPathFor$2B = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "144 92 104 128 144 164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 92 104 128 144 164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm21.35156,134.05469a7.99912,7.99912,0,1,1-10.70312,11.89062l-40-36a7.99734,7.99734,0,0,1,0-11.89062l40-36a7.99912,7.99912,0,1,1,10.70312,11.89062L115.96094,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "144 92 104 128 144 164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "144 92 104 128 144 164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 92 104 128 144 164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretCircleLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2B(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretCircleLeft.displayName = "CaretCircleLeft";

var renderPathFor$2C = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "116 92 156 128 116 164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "116 92 156 128 116 164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm33.35156,109.94531-40,36a7.99912,7.99912,0,1,1-10.70312-11.89062L144.03906,128,110.64844,97.94531a7.99912,7.99912,0,0,1,10.70312-11.89062l40,36a7.99734,7.99734,0,0,1,0,11.89062Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "116 92 156 128 116 164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "116 92 156 128 116 164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "116 92 156 128 116 164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretCircleRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2C(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretCircleRight.displayName = "CaretCircleRight";

var renderPathFor$2D = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "164 144 128 104 92 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "164 144 128 104 92 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm41.35156,125.94531a7.997,7.997,0,0,1-11.29687-.59375L128,115.96094,97.94531,149.35156a7.99912,7.99912,0,0,1-11.89062-10.70312l36-40a8.24769,8.24769,0,0,1,11.89062,0l36,40A8.00337,8.00337,0,0,1,169.35156,149.94531Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "164 144 128 104 92 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "164 144 128 104 92 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "164 144 128 104 92 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretCircleUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2D(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretCircleUp.displayName = "CaretCircleUp";

var renderPathFor$2E = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 128 128 208 48 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "208 48 128 128 48 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "208 48 128 128 48 48 208 48",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "208 128 128 208 48 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "208 48 128 128 48 48 208 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,120H147.31348l66.34326-66.34326A7.99981,7.99981,0,0,0,208,40H48a7.99981,7.99981,0,0,0-5.65674,13.65674L108.68652,120H48a7.99981,7.99981,0,0,0-5.65674,13.65674l80,80.00049a8.00063,8.00063,0,0,0,11.31348,0l80-80.00049A7.99981,7.99981,0,0,0,208,120Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 128 128 208 48 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "208 48 128 128 48 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 128 128 208 48 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "208 48 128 128 48 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 128 128 208 48 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 48 128 128 48 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretDoubleDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2E(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretDoubleDown.displayName = "CaretDoubleDown";

var renderPathFor$2F = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 208 120 128 200 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "120 208 40 128 120 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "200 208 120 128 200 48 200 208",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "200 208 120 128 200 48 200 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "120 208 40 128 120 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M203.06152,40.60889a7.99927,7.99927,0,0,0-8.71826,1.73437L128,108.68652V48a7.99981,7.99981,0,0,0-13.65674-5.65674l-80,80a7.99915,7.99915,0,0,0,0,11.31348l80,80A7.99981,7.99981,0,0,0,128,208V147.31348l66.34326,66.34326A7.99981,7.99981,0,0,0,208,208V48A8.00015,8.00015,0,0,0,203.06152,40.60889Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 208 120 128 200 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "120 208 40 128 120 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 208 120 128 200 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "120 208 40 128 120 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 208 120 128 200 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "120 208 40 128 120 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretDoubleLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2F(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretDoubleLeft.displayName = "CaretDoubleLeft";

var renderPathFor$2G = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "56 48 136 128 56 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "136 48 216 128 136 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "56 48 136 128 56 208 56 48",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "56 48 136 128 56 208 56 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "136 48 216 128 136 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.65674,122.34326l-80-80A7.99981,7.99981,0,0,0,128,48v60.68652L61.65674,42.34326A7.99981,7.99981,0,0,0,48,48V208a7.99984,7.99984,0,0,0,13.65674,5.65674L128,147.31348V208a7.99984,7.99984,0,0,0,13.65674,5.65674l80-80A7.99915,7.99915,0,0,0,221.65674,122.34326Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "56 48 136 128 56 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "136 48 216 128 136 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "56 48 136 128 56 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "136 48 216 128 136 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "56 48 136 128 56 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "136 48 216 128 136 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretDoubleRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2G(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretDoubleRight.displayName = "CaretDoubleRight";

var renderPathFor$2H = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "48 208 128 128 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "48 128 128 48 208 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "48 208 128 128 208 208 48 208",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "48 208 128 128 208 208 48 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 128 128 48 208 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M147.314,136H208a8.0001,8.0001,0,0,0,5.65674-13.65723l-80-80a8.00182,8.00182,0,0,0-11.31348,0l-80,80A8.0001,8.0001,0,0,0,48,136h60.686L42.34326,202.34277A8.0001,8.0001,0,0,0,48,216H208a8.0001,8.0001,0,0,0,5.65674-13.65723Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "48 208 128 128 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "48 128 128 48 208 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "48 208 128 128 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "48 128 128 48 208 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "48 208 128 128 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 128 128 48 208 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretDoubleUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2H(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretDoubleUp.displayName = "CaretDoubleUp";

var renderPathFor$2I = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 96 128 176 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "208 96 128 176 48 96 208 96",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "208 96 128 176 48 96 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.39111,92.93848A8.00015,8.00015,0,0,0,208,88H48a8,8,0,0,0-5.65674,13.657l80,79.99976a7.99945,7.99945,0,0,0,11.31348,0l80-79.99976A8.00011,8.00011,0,0,0,215.39111,92.93848Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 96 128 176 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 96 128 176 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 96 128 176 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2I(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretDown.displayName = "CaretDown";

var renderPathFor$2J = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 208 80 128 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "160 208 80 128 160 48 160 208",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "160 208 80 128 160 48 160 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M163.06152,40.60889a8.00159,8.00159,0,0,0-8.71826,1.73388l-80,80a8.00034,8.00034,0,0,0,0,11.31446l80,80A8.0001,8.0001,0,0,0,168,208V48A8.00065,8.00065,0,0,0,163.06152,40.60889Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 208 80 128 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 208 80 128 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "160 208 80 128 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2J(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretLeft.displayName = "CaretLeft";

var renderPathFor$2K = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 48 176 128 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "96 48 176 128 96 208 96 48",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "96 48 176 128 96 208 96 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M181.65674,122.34277l-80-80A8.0001,8.0001,0,0,0,88,48V208a8.00018,8.00018,0,0,0,13.65674,5.65723l80-80A8.00034,8.00034,0,0,0,181.65674,122.34277Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 48 176 128 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 48 176 128 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 48 176 128 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2K(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretRight.displayName = "CaretRight";

var renderPathFor$2L = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "48 160 128 80 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "48 160 128 80 208 160 48 160",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "48 160 128 80 208 160 48 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.65674,154.34326l-80-80a8,8,0,0,0-11.31348,0l-80,80A7.99981,7.99981,0,0,0,48,168H208a7.99981,7.99981,0,0,0,5.65674-13.65674Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "48 160 128 80 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "48 160 128 80 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "48 160 128 80 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CaretUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2L(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CaretUp.displayName = "CaretUp";

var renderPathFor$2M = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "64",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "104",
        x2: "120",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "144",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M198.12305,28.53186a15.95339,15.95339,0,0,0-17.4375,3.46826L16.001,196.68616a15.99933,15.99933,0,0,0,11.3125,27.314H192a16.018,16.018,0,0,0,16-16V43.3136A15.95222,15.95222,0,0,0,198.12305,28.53186Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "64",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "104",
        x2: "120",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "144",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "64",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "104",
        x2: "120",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "144",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "64",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "104",
        x2: "120",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "144",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CellSignalFull = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2M(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CellSignalFull.displayName = "CellSignalFull";

var renderPathFor$2N = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "64",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M160,216H27.31371a8,8,0,0,1-5.65686-13.65685L160,64Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "64",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M198.12305,28.53186a15.95339,15.95339,0,0,0-17.4375,3.46826L16.001,196.68616a15.95542,15.95542,0,0,0-4.69092,11.65869q.01319.58374.06933,1.168a16.06842,16.06842,0,0,0,8.02735,12.40771q.50536.28712,1.031.53662a16.00569,16.00569,0,0,0,6.87574,1.543H192a16.018,16.018,0,0,0,16-16V43.3136A15.95222,15.95222,0,0,0,198.12305,28.53186ZM192,208.00012l-24-.00049V67.31946L192,43.32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "64",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "64",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "64",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CellSignalHigh = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2N(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CellSignalHigh.displayName = "CellSignalHigh";

var renderPathFor$2O = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "144",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,216H27.31371a8,8,0,0,1-5.65686-13.65685L80,144Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "144",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M198.12305,28.53186a15.95427,15.95427,0,0,0-17.4375,3.46826L74.34692,138.33948l-.00415.0039L16.001,196.68616a15.99945,15.99945,0,0,0,11.3125,27.314H192a16.01833,16.01833,0,0,0,16-16V43.3136A15.95272,15.95272,0,0,0,198.12305,28.53186ZM192,208.00012,88,207.9967V147.31653L192,43.32043Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "144",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "144",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "144",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CellSignalLow = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2O(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CellSignalLow.displayName = "CellSignalLow";

var renderPathFor$2P = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "104",
        x2: "120",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120,216H27.31371a8,8,0,0,1-5.65686-13.65685L120,104Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "104",
        x2: "120",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M198.12305,28.53186a15.95339,15.95339,0,0,0-17.4375,3.46826L114.34473,98.34143l-.002.00195L16.001,196.68616a15.95542,15.95542,0,0,0-4.69092,11.65869q.01319.58374.06933,1.168a16.06842,16.06842,0,0,0,8.02735,12.40771q.50536.28712,1.031.53662a16.00569,16.00569,0,0,0,6.87574,1.543H192a16.018,16.018,0,0,0,16-16V43.3136A15.95272,15.95272,0,0,0,198.12305,28.53186ZM192,208.00012l-64-.002V107.318l64-63.99756Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "104",
        x2: "120",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "104",
        x2: "120",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "104",
        x2: "120",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CellSignalMedium = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2P(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CellSignalMedium.displayName = "CellSignalMedium";

var renderPathFor$2Q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,224H27.31348A15.9994,15.9994,0,0,1,16.001,196.686L180.68555,32A16.00046,16.00046,0,0,1,208,43.31372V208A16.01825,16.01825,0,0,1,192,224ZM27.31934,207.99512,192,208V43.32031L27.31445,208Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CellSignalNone = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2Q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CellSignalNone.displayName = "CellSignalNone";

var renderPathFor$2R = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "47.99463",
        y1: "40.00842",
        x2: "207.99463",
        y2: "216.00842",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M207.99463,216.00842,27.31371,216a8,8,0,0,1-5.65686-13.65685l91.09823-91.09823",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M141.07158,82.92842l45.27157-45.27157A8,8,0,0,1,200,43.31371v104.436",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M199.99414,43.32213V208.00842a8,8,0,0,1-8,8H27.30785A8,8,0,0,1,21.651,202.35157L186.33729,37.66528A8,8,0,0,1,199.99414,43.32213Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M135.40815,88.59185l50.935-50.935A8,8,0,0,1,200,43.31371V159.64292",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("g", null, React__default.createElement("line", {
        x1: "47.99463",
        y1: "40.00842",
        x2: "207.99463",
        y2: "216.00842",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M207.99463,216H27.31371a8,8,0,0,1-5.65686-13.65685l91.09823-91.09823",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      })));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M194.08057,165.025A8.00011,8.00011,0,0,0,208,159.64319V43.31409a15.99974,15.99974,0,0,0-27.31348-11.31446L129.75146,82.9342a7.99987,7.99987,0,0,0-.26269,11.03809Z"
      }), React__default.createElement("path", {
        d: "M214.2179,221.02112c.13305-.16455.25988-.33252.37805-.50537.02783-.04053.054-.082.08105-.12354.113-.17187.22034-.34619.31885-.52441.03027-.05469.05786-.11084.08691-.16651.08765-.16845.17139-.33838.24634-.51123.03333-.07666.063-.15478.094-.23242.06225-.15723.12182-.31494.17382-.4751.032-.09814.05957-.19775.08777-.29736.04138-.147.08093-.29395.11377-.44238.02478-.11133.0448-.22364.06494-.33643.02552-.144.04871-.28857.06629-.43408.01416-.11621.02441-.23291.03344-.35059.01136-.14648.01917-.29345.02234-.44043.00135-.061.00916-.12011.00916-.18164s-.00781-.12109-.00928-.18213c-.00317-.13818-.0105-.27587-.02075-.41406-.01-.13428-.022-.26806-.03857-.40039-.01465-.1167-.03321-.23193-.053-.34766-.02539-.1499-.053-.29834-.08655-.44531-.02222-.09668-.04822-.19189-.0741-.28808-.04321-.16065-.08886-.31983-.1416-.47657-.02759-.082-.05884-.16308-.08935-.24414-.06226-.1665-.12745-.33056-.2002-.49121-.032-.0708-.06689-.14013-.10107-.21-.08277-.16943-.16968-.33642-.26392-.49951-.03345-.05762-.06909-.11426-.10425-.17139-.10644-.17383-.21826-.34326-.33716-.50781-.03247-.04443-.06579-.08838-.09912-.13232q-.19886-.26369-.41784-.50928c-.01551-.01709-.0282-.03613-.04383-.05322l-160-176A8.00024,8.00024,0,1,0,42.0752,45.39026l59.62866,65.59179L16,196.68616a15.99962,15.99962,0,0,0,11.31348,27.31347H207.82361c.058.00147.1156.00879.17346.00879a7.98959,7.98959,0,0,0,3.10938-.63672l.00537-.00244q.34863-.14721.68505-.33008l.02356-.01269q.31842-.17358.62342-.37891l.04736-.03174q.28491-.19482.55615-.416l.06983-.05762c.08593-.07226.175-.13769.25879-.21387.07837-.07129.14648-.14892.22143-.22265.03711-.03662.07349-.07324.10987-.11084.14733-.15039.28808-.3042.42114-.46338C214.15894,221.09534,214.18811,221.05823,214.2179,221.02112Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "47.99463",
        y1: "40.00842",
        x2: "207.99463",
        y2: "216.00842",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M135.40815,88.59185l50.935-50.935A8,8,0,0,1,200,43.31371V159.64292",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M207.99463,216.00842,27.31371,216a8,8,0,0,1-5.65686-13.65685l91.09823-91.09823",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "47.99463",
        y1: "40.00842",
        x2: "207.99463",
        y2: "216.00842",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M135.40815,88.59185l50.935-50.935A8,8,0,0,1,200,43.31371V159.64292",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M207.99463,216.00842,27.31371,216a8,8,0,0,1-5.65686-13.65685l91.09823-91.09823",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "47.99463",
        y1: "40.00842",
        x2: "207.99463",
        y2: "216.00842",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M135.40815,88.59185l50.935-50.935A8,8,0,0,1,200,43.31371V159.64292",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M207.99463,216.00842,27.31371,216a8,8,0,0,1-5.65686-13.65685l91.09823-91.09823",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CellSignalSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2R(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CellSignalSlash.displayName = "CellSignalSlash";

var renderPathFor$2S = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "224",
        y1: "104",
        x2: "176",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "152",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M200,183.99507V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371V72.00485",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,43.31371V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "104",
        x2: "176",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "152",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,173.2544V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371V82.74556",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M211.314,128l18.34278-18.34277a8.00018,8.00018,0,1,0-11.31348-11.31446L200,116.686,181.65674,98.34277a8.00018,8.00018,0,0,0-11.31348,11.31446L188.686,128l-18.34278,18.34277a8.00018,8.00018,0,0,0,11.31348,11.31446L200,139.314l18.34326,18.34327a8.00018,8.00018,0,0,0,11.31348-11.31446Z"
      }), React__default.createElement("path", {
        d: "M200,161.94141l-7.0293,7.02929a24.00019,24.00019,0,0,1-33.9414-33.9414L166.05859,128l-7.02929-7.0293a24.00019,24.00019,0,0,1,33.9414-33.9414L200,94.05859l7.0293-7.02929c.312-.312.64624-.58594.9707-.87744V43.31348A15.99974,15.99974,0,0,0,180.68652,32L15.99951,196.68652A16.00018,16.00018,0,0,0,27.31348,224H192a16.01833,16.01833,0,0,0,16-16V169.84814c-.32446-.2915-.65869-.56543-.9707-.87744Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "224",
        y1: "104",
        x2: "176",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "152",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M200,173.2544V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371V82.74556",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "224",
        y1: "104",
        x2: "176",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "152",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M200,173.2544V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371V82.74556",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "224",
        y1: "104",
        x2: "176",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "152",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,173.2544V208a8,8,0,0,1-8,8H27.31371a8,8,0,0,1-5.65686-13.65685l164.6863-164.6863A8,8,0,0,1,200,43.31371V82.74556",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CellSignalX = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2S(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CellSignalX.displayName = "CellSignalX";

var renderPathFor$2T = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "228",
        y1: "208",
        x2: "28",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "100 208 100 88 156 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "56",
        height: "168",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "44 208 44 136 100 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "56",
        height: "168",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "228",
        y1: "208",
        x2: "28",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "100 208 100 88 156 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "56",
        height: "168",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "44 208 44 136 100 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M228,200h-8V40a8.00008,8.00008,0,0,0-8-8H156a8.00008,8.00008,0,0,0-8,8V80H100a8.00008,8.00008,0,0,0-8,8v40H44a8.00008,8.00008,0,0,0-8,8v64H28a8,8,0,0,0,0,16H228a8,8,0,0,0,0-16ZM108,96h40V200H108ZM52,144H92v56H52Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "228",
        y1: "208",
        x2: "28",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "100 208 100 88 156 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "56",
        height: "168",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "44 208 44 136 100 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "228",
        y1: "208",
        x2: "28",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "100 208 100 88 156 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "56",
        height: "168",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "44 208 44 136 100 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "44 208 44 136 100 136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "228",
        y1: "208",
        x2: "28",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "100 208 100 88 156 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "56",
        height: "168",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChartBar = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2T(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChartBar.displayName = "ChartBar";

var renderPathFor$2U = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216",
        x2: "40",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "40 56 168 56 168 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "104",
        width: "176",
        height: "48",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "136 152 136 200 40 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "104",
        width: "176",
        height: "48",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "216",
        x2: "40",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "40 56 168 56 168 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "104",
        width: "176",
        height: "48",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "136 152 136 200 40 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,96H176V56a7.99977,7.99977,0,0,0-8-8H48V40a8,8,0,0,0-16,0V216a8,8,0,0,0,16,0v-8h88a7.99977,7.99977,0,0,0,8-8V160h72a7.99977,7.99977,0,0,0,8-8V104A7.99977,7.99977,0,0,0,216,96ZM160,64V96H48V64ZM128,192H48V160h80Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216",
        x2: "40",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "40 56 168 56 168 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "104",
        width: "176",
        height: "48",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "136 152 136 200 40 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216",
        x2: "40",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "40 56 168 56 168 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "104",
        width: "176",
        height: "48",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "136 152 136 200 40 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216",
        x2: "40",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "40 56 168 56 168 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "104",
        width: "176",
        height: "48",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("polyline", {
        points: "136 152 136 200 40 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChartBarHorizontal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2U(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChartBarHorizontal.displayName = "ChartBarHorizontal";

var renderPathFor$2V = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 208 32 208 32 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "224.002 96 160.002 152 96.002 104 32.002 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 208 32 208 32 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224.002 96 160.002 152 96.002 104 32.002 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.99951,200h-184V163.63232L96.39014,114.291l58.8125,44.10888a7.99913,7.99913,0,0,0,10.06738-.37939l64-56a7.99962,7.99962,0,1,0-10.53516-12.041L159.61475,141.709,100.80225,97.6001a7.99909,7.99909,0,0,0-10.06739.37939L39.99951,142.37305V48a8,8,0,0,0-16,0V208a8.00039,8.00039,0,0,0,8,8h192a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 208 32 208 32 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "224.002 96 160.002 152 96.002 104 32.002 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 208 32 208 32 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "224.002 96 160.002 152 96.002 104 32.002 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 208 32 208 32 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224.002 96 160.002 152 96.002 104 32.002 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChartLine = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2V(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChartLine.displayName = "ChartLine";

var renderPathFor$2W = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 208 32 208 32 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "208.002 64 128.002 144 96.002 112 32.002 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "208.002 104 208.002 64 168.002 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 208 32 208 32 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208.002 64 128.002 144 96.002 112 32.002 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208.002 104 208.002 64 168.002 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.99951,200h-184V179.31738l56.00293-56.0039,26.34277,26.34375a8.00122,8.00122,0,0,0,11.31446,0l66.34277-66.34278V104a8,8,0,0,0,16,0V64.00488c0-.26562-.01367-.53174-.04-.79687-.01074-.10694-.03076-.21094-.04541-.31641-.02148-.15283-.04-.30615-.06982-.458-.0249-.125-.05957-.24609-.09033-.36914-.03272-.13037-.06153-.26123-.10059-.39013-.03662-.1211-.082-.23731-.12451-.356-.04541-.12793-.08789-.25684-.14014-.3833-.04541-.10889-.09814-.21338-.148-.31934-.06152-.13086-.11963-.26269-.18847-.39062-.05323-.09912-.11377-.19287-.1709-.28955-.07569-.12793-.14844-.25684-.23194-.38135-.06933-.10352-.147-.20068-.2207-.30029-.081-.10987-.15771-.22168-.24512-.32764-.13281-.16211-.27588-.31543-.42138-.46631-.03662-.03808-.06787-.07959-.10547-.11719-.03516-.03466-.07324-.064-.10889-.09814-.15381-.148-.31006-.29346-.4751-.4292-.10254-.084-.21-.15772-.31543-.23584-.10449-.07764-.20556-.1582-.31347-.23047-.12012-.08057-.24414-.1499-.36719-.22314-.10156-.06006-.2002-.124-.3042-.17969-.12256-.06592-.24853-.12158-.374-.18018-.11182-.05273-.22217-.10888-.33692-.15625-.12011-.0498-.24267-.08984-.36474-.1333-.124-.04492-.24707-.09277-.374-.13135-.12207-.03662-.2456-.064-.36914-.09472-.12988-.03272-.2583-.06934-.39062-.09522-.14063-.02832-.28321-.04492-.42529-.06494-.11622-.0166-.231-.03906-.34864-.05029-.26269-.02588-.52588-.04-.78955-.04h-40a8,8,0,0,0,0,16h20.686l-60.686,60.68652-26.34277-26.34375a8.00122,8.00122,0,0,0-11.31446,0l-50.3457,50.34571V48a8,8,0,0,0-16,0V208a8.00039,8.00039,0,0,0,8,8h192a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 208 32 208 32 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "208.002 64 128.002 144 96.002 112 32.002 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "208.002 104 208.002 64 168.002 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 208 32 208 32 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "208.002 64 128.002 144 96.002 112 32.002 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "208.002 104 208.002 64 168.002 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 208 32 208 32 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208.002 64 128.002 144 96.002 112 32.002 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208.002 104 208.002 64 168.002 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChartLineUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2W(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChartLineUp.displayName = "ChartLineUp";

var renderPathFor$2X = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "44.86156",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,44.86156,176l-.01368.00827A96.02522,96.02522,0,0,1,128,32Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "44.86156",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.27124,76.39893c-.06738-.13331-.12878-.26807-.20435-.39893-.102-.17676-.21545-.34229-.32849-.50781A103.97483,103.97483,0,0,0,37.72876,179.60107c.06738.1333.12878.26807.20435.39893.07153.124.15856.23242.23559.35107A103.97546,103.97546,0,0,0,218.27124,76.39893Zm-18.40454.87158L136,114.14355V40.36768A88.02766,88.02766,0,0,1,199.8667,77.27051ZM128,216a87.95493,87.95493,0,0,1-71.8667-37.27051L207.88574,91.11572A87.9798,87.9798,0,0,1,128,216Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "44.86156",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "44.86156",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "44.86156",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChartPie = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2X(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChartPie.displayName = "ChartPie";

var renderPathFor$2Y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "44.86156",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,32A96,96,0,1,1,45.21664,176.64005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M87.99413,106.14643,32.532,138.16712A97.09884,97.09884,0,0,1,32,128,96.0159,96.0159,0,0,1,87.99362,40.7076Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M33.60061,145.5506A96.15147,96.15147,0,0,1,95.99845,37.46313V109.5252Z"
      })), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "44.86156",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M33.60061,145.5506A96.15147,96.15147,0,0,1,95.99845,37.46313V109.5252Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,32A96,96,0,1,1,45.21664,176.64005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M99.99854,116.45312a7.99932,7.99932,0,0,0,4-6.92773V37.46289a8.00029,8.00029,0,0,0-10.666-7.54248,104.15035,104.15035,0,0,0-67.59863,117.0835,7.99907,7.99907,0,0,0,11.8667,5.47461Zm-12-66.86328v55.31641L40.11621,132.55078Q40.00048,130.27881,40,128A88.20107,88.20107,0,0,1,87.99854,49.58984Z"
      }), React__default.createElement("path", {
        d: "M218.27124,76.39893c-.06738-.13331-.12878-.26807-.20435-.39893-.102-.17676-.21545-.34229-.32849-.50781A104.0515,104.0515,0,0,0,128,24a8.00008,8.00008,0,0,0-8,8v91.38135L40.86133,169.07178A8.00042,8.00042,0,0,0,37.93311,180c.03369.05811.07592.10791.11084.165.08837.17969.17614.35889.27929.53418A104.0111,104.0111,0,0,0,232,128,103.36465,103.36465,0,0,0,218.27124,76.39893Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "44.86156",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M33.60061,145.5506A96.15147,96.15147,0,0,1,95.99845,37.46313V109.5252Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,32A96,96,0,1,1,45.21664,176.64005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "44.86156",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M33.60061,145.5506A96.15147,96.15147,0,0,1,95.99845,37.46313V109.5252Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,32A96,96,0,1,1,45.21664,176.64005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "211.13844",
        y1: "80",
        x2: "44.86156",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M33.60061,145.5506A96.15147,96.15147,0,0,1,95.99845,37.46313V109.5252Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,32A96,96,0,1,1,45.21664,176.64005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChartPieSlice = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2Y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChartPieSlice.displayName = "ChartPieSlice";

var renderPathFor$2Z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.35142,201.87677l-32.2031,27.07116a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H82.49925A8,8,0,0,0,77.35142,201.87677Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.98509,201.34409,45.14832,228.94793a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H81.67142Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M77.35142,201.87677l-32.2031,27.07116a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H82.49925A8,8,0,0,0,77.35142,201.87677Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.002,48.00293h-176a16.02085,16.02085,0,0,0-16,16V222.82324a15.8614,15.8614,0,0,0,9.25,14.50781,16.11258,16.11258,0,0,0,6.79688,1.51563,15.86968,15.86968,0,0,0,10.25-3.77344l31.75-26.69531,133.95312-.375a16.02084,16.02084,0,0,0,16-16v-128A16.02084,16.02084,0,0,0,216.002,48.00293Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.35142,201.87677l-32.2031,27.07116a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H82.49925A8,8,0,0,0,77.35142,201.87677Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.35142,201.87677l-32.2031,27.07116a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H82.49925A8,8,0,0,0,77.35142,201.87677Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.35142,201.87677l-32.2031,27.07116a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H82.49925A8,8,0,0,0,77.35142,201.87677Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Chat = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2Z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Chat.displayName = "Chat";

var renderPathFor$2_ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,40H40A16.01833,16.01833,0,0,0,24,56V183.999a16.01833,16.01833,0,0,0,16,16L99.46973,200l14.81054,24.68262a16.00024,16.00024,0,0,0,27.43946,0L156.5293,200H215.999A16.01853,16.01853,0,0,0,232,184V56A16.01833,16.01833,0,0,0,216,40Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatCentered = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2_(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatCentered.displayName = "ChatCentered";

var renderPathFor$2$ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149.67005,195.88358l-14.80962,24.68269a8,8,0,0,1-13.71989,0l-14.80963-24.68272a8,8,0,0,0-6.85994-3.884H40.00049a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8.00006,8l-59.47038-.00041A8,8,0,0,0,149.67005,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "79.99414",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "175.99414",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149.67005,195.88358l-14.80962,24.68269a8,8,0,0,1-13.71989,0l-14.80963-24.68272a8,8,0,0,0-6.85994-3.884H40.00049a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8.00006,8l-59.47038-.00041A8,8,0,0,0,149.67005,195.88358Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M149.67005,195.88358l-14.80962,24.68269a8,8,0,0,1-13.71989,0l-14.80963-24.68272a8,8,0,0,0-6.85994-3.884H40.00049a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8.00006,8l-59.47038-.00041A8,8,0,0,0,149.67005,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "79.99023",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.99023",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "175.99023",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.001,40h-176a16.01833,16.01833,0,0,0-16,16V183.999a16.01833,16.01833,0,0,0,16,16L99.4707,200l14.81055,24.68262a16.00023,16.00023,0,0,0,27.43945,0L156.53027,200H216a16.01854,16.01854,0,0,0,16.001-16V56A16.01833,16.01833,0,0,0,216.001,40ZM80.00049,132.00049a12,12,0,1,1,12-12A12,12,0,0,1,80.00049,132.00049Zm48,0a12,12,0,1,1,12-12A12,12,0,0,1,128.00049,132.00049Zm48,0a12,12,0,1,1,12-12A12,12,0,0,1,176.00049,132.00049Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149.67005,195.88358l-14.80962,24.68269a8,8,0,0,1-13.71989,0l-14.80963-24.68272a8,8,0,0,0-6.85994-3.884H40.00049a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8.00006,8l-59.47038-.00041A8,8,0,0,0,149.67005,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "79.99609",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "127.99609",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "175.99609",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149.67005,195.88358l-14.80962,24.68269a8,8,0,0,1-13.71989,0l-14.80963-24.68272a8,8,0,0,0-6.85994-3.884H40.00049a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8.00006,8l-59.47038-.00041A8,8,0,0,0,149.67005,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "79.99805",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "127.99805",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "175.99805",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149.67005,195.88358l-14.80962,24.68269a8,8,0,0,1-13.71989,0l-14.80963-24.68272a8,8,0,0,0-6.85994-3.884H40.00049a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8.00006,8l-59.47038-.00041A8,8,0,0,0,149.67005,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "80",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "120",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatCenteredDots = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$2$(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatCenteredDots.displayName = "ChatCenteredDots";

var renderPathFor$30 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96.00049",
        y1: "99.99951",
        x2: "160.00049",
        y2: "99.99951",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "139.99951",
        x2: "160.00049",
        y2: "139.99951",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "103.99951",
        x2: "160.00049",
        y2: "103.99951",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "135.99951",
        x2: "160.00049",
        y2: "135.99951",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,40H40A16.01833,16.01833,0,0,0,24,56V183.999a16.01833,16.01833,0,0,0,16,16L99.46973,200l14.81054,24.68262a16.00024,16.00024,0,0,0,27.43946,0L156.5293,200H215.999A16.01853,16.01853,0,0,0,232,184V56A16.01833,16.01833,0,0,0,216,40ZM160,143.999H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm0-32H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96.00049",
        y1: "103.99951",
        x2: "160.00049",
        y2: "103.99951",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "135.99951",
        x2: "160.00049",
        y2: "135.99951",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96.00049",
        y1: "103.99951",
        x2: "160.00049",
        y2: "103.99951",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "135.99951",
        x2: "160.00049",
        y2: "135.99951",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96.00049",
        y1: "103.99951",
        x2: "160.00049",
        y2: "103.99951",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "135.99951",
        x2: "160.00049",
        y2: "135.99951",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M149.66907,195.88358l-14.80961,24.68269a8,8,0,0,1-13.71989,0l-14.80964-24.68272a8,8,0,0,0-6.85994-3.884H39.99951a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8V184a8,8,0,0,1-8,8l-59.47039-.00041A8,8,0,0,0,149.66907,195.88358Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatCenteredText = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$30(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatCenteredText.displayName = "ChatCenteredText";

var renderPathFor$31 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128.00146,24.002A104.02442,104.02442,0,0,0,36.814,178.041l-8.55468,29.91406a16.00544,16.00544,0,0,0,19.78125,19.78125l29.91406-8.54688A104.00785,104.00785,0,1,0,128.00146,24.002Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$31(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatCircle.displayName = "ChatCircle";

var renderPathFor$32 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "80",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "80.00098",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128.00098",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "176.00098",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128.00146,24.00781A104.01819,104.01819,0,0,0,36.814,178.03906l-8.55468,29.90625a15.995,15.995,0,0,0,19.78125,19.78125l29.91406-8.53125a104.00785,104.00785,0,1,0,50.04687-195.1875ZM80.00049,140a12,12,0,1,1,12-12A12,12,0,0,1,80.00049,140Zm48,0a12,12,0,1,1,12-12A12,12,0,0,1,128.00049,140Zm48,0a12,12,0,1,1,12-12A12,12,0,0,1,176.00049,140Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "79.99951",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "127.99951",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "175.99951",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "79.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "127.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "175.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "79.99854",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.99854",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "175.99854",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatCircleDots = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$32(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatCircleDots.displayName = "ChatCircleDots";

var renderPathFor$33 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "108",
        x2: "160",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "148",
        x2: "160",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "112",
        x2: "160",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "144",
        x2: "160",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128.00146,23.99316A104.03063,104.03063,0,0,0,36.814,178.04l-8.55468,29.90625a15.995,15.995,0,0,0,19.78125,19.78125l29.91406-8.53125A104.01366,104.01366,0,1,0,128.00146,23.99316Zm32,128h-64a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm0-32h-64a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "112",
        x2: "160",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "144",
        x2: "160",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "112",
        x2: "160",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "144",
        x2: "160",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.42853,176.99811A95.95978,95.95978,0,1,1,79.00228,210.5717l.00023-.001L45.84594,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "112",
        x2: "160",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "144",
        x2: "160",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatCircleText = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$33(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatCircleText.displayName = "ChatCircleText";

var renderPathFor$34 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.35142,201.87677l-32.2031,27.07116a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H82.49925A8,8,0,0,0,77.35142,201.87677Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "80.00049",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128.00049",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "176.00049",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.98509,201.34409,45.14832,228.94793a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H81.67142Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M77.35142,201.87677l-32.2031,27.07116a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H82.49925A8,8,0,0,0,77.35142,201.87677Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "80.00146",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128.00146",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "176.00146",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.002,47.99316h-176a16.01583,16.01583,0,0,0-16,16V222.82129a15.97593,15.97593,0,0,0,26.29688,12.25l31.75781-26.70313,133.94531-.375a16.01581,16.01581,0,0,0,16-16v-128A16.01582,16.01582,0,0,0,216.002,47.99316ZM80.001,140.001a12,12,0,1,1,12-12A12,12,0,0,1,80.001,140.001Zm48,0a12,12,0,1,1,12-12A12,12,0,0,1,128.001,140.001Zm48,0a12,12,0,1,1,12-12A12,12,0,0,1,176.001,140.001Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.35142,201.87677l-32.2031,27.07116a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H82.49925A8,8,0,0,0,77.35142,201.87677Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "80",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.35142,201.87677l-32.2031,27.07116a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H82.49925A8,8,0,0,0,77.35142,201.87677Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "79.99951",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "127.99951",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "175.99951",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.35142,201.87677l-32.2031,27.07116a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H82.49925A8,8,0,0,0,77.35142,201.87677Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "79.99902",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.99902",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "175.99902",
        cy: "127.99805",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatDots = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$34(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatDots.displayName = "ChatDots";

var renderPathFor$35 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132,23.99219a100.113,100.113,0,0,0-100,100v84.33349a15.68449,15.68449,0,0,0,15.667,15.66651H132a100,100,0,0,0,0-200Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatTeardrop = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$35(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatTeardrop.displayName = "ChatTeardrop";

var renderPathFor$36 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "83.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "131.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "179.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "83.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "131.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "179.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132,23.99219a100.113,100.113,0,0,0-100,100v84.33349a15.68449,15.68449,0,0,0,15.667,15.66651H132a100,100,0,0,0,0-200Zm-48.00195,116.001a12,12,0,1,1,12-12A12,12,0,0,1,83.99805,139.99316Zm48,0a12,12,0,1,1,12-12A12,12,0,0,1,131.99805,139.99316Zm48,0a12,12,0,1,1,12-12A12,12,0,0,1,179.99805,139.99316Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "83.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "131.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "179.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "83.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "131.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "179.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "83.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "131.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "179.99902",
        cy: "127.99707",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatTeardropDots = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$36(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatTeardropDots.displayName = "ChatTeardropDots";

var renderPathFor$37 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "99.99902",
        y1: "107.99219",
        x2: "159.99902",
        y2: "107.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "99.99902",
        y1: "147.99219",
        x2: "159.99902",
        y2: "147.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "99.99805",
        y1: "111.99219",
        x2: "159.99805",
        y2: "111.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "99.99805",
        y1: "143.99219",
        x2: "159.99805",
        y2: "143.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132,23.99219a100.113,100.113,0,0,0-100,100v84.33349a15.68449,15.68449,0,0,0,15.667,15.66651H132a100,100,0,0,0,0-200Zm27.99805,128h-60a8,8,0,0,1,0-16h60a8,8,0,0,1,0,16Zm0-32h-60a8,8,0,0,1,0-16h60a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "99.99951",
        y1: "111.99219",
        x2: "159.99951",
        y2: "111.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "99.99951",
        y1: "143.99219",
        x2: "159.99951",
        y2: "143.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "111.99219",
        x2: "160",
        y2: "111.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "143.99219",
        x2: "160",
        y2: "143.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.00018,215.99219H47.66667A7.66667,7.66667,0,0,1,40,208.32552V123.992a91.99981,91.99981,0,0,1,91.99982-91.99981H132a92,92,0,0,1,92,92v.00018A91.99982,91.99982,0,0,1,132.00018,215.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100.00049",
        y1: "111.99219",
        x2: "160.00049",
        y2: "111.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100.00049",
        y1: "143.99219",
        x2: "160.00049",
        y2: "143.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatTeardropText = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$37(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatTeardropText.displayName = "ChatTeardropText";

var renderPathFor$38 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.98509,201.34409,45.14832,228.94793a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H81.67142Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "108",
        x2: "160.00049",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "148",
        x2: "160.00049",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.98509,201.34409,45.14832,228.94793a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H81.67142Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M77.98509,201.34409,45.14832,228.94793a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H81.67142Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "112",
        x2: "160.00049",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "144",
        x2: "160.00049",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.002,48.002h-176a16.02085,16.02085,0,0,0-16,16V222.82227a15.8614,15.8614,0,0,0,9.25,14.50781,16.11272,16.11272,0,0,0,6.79688,1.51562,15.86972,15.86972,0,0,0,10.25-3.77343l31.75-26.69532,133.95312-.375a16.02083,16.02083,0,0,0,16-16v-128A16.02084,16.02084,0,0,0,216.002,48.002Zm-56,104h-64a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm0-32h-64a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.98509,201.34409,45.14832,228.94793a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H81.67142Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "112",
        x2: "160.00049",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "144",
        x2: "160.00049",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.98509,201.34409,45.14832,228.94793a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H81.67142Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "112",
        x2: "160.00049",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "144",
        x2: "160.00049",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.98509,201.34409,45.14832,228.94793a8,8,0,0,1-13.14783-6.12372V64.00049a8,8,0,0,1,8-8h176a8,8,0,0,1,8,8v128a8,8,0,0,1-8,8H81.67142Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "112",
        x2: "160.00049",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96.00049",
        y1: "144",
        x2: "160.00049",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatText = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$38(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatText.displayName = "ChatText";

var renderPathFor$39 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M71.5834,144.00049l-39.58291,32v-128a8,8,0,0,1,8-8h128a8,8,0,0,1,8,8v88a8,8,0,0,1-8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M80.00049,144.00048v40a8,8,0,0,0,8,8h96.41709l39.58291,32v-128a8,8,0,0,0-8-8h-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80.00049,144.00048v40a8,8,0,0,0,8,8h96.41709l39.58291,32v-128a8,8,0,0,0-8-8h-40v48a8,8,0,0,1-8,8Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M71.5834,144.00049l-39.58291,32v-128a8,8,0,0,1,8-8h128a8,8,0,0,1,8,8v88a8,8,0,0,1-8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80.00049,144.00048v40a8,8,0,0,0,8,8h96.41709l39.58291,32v-128a8,8,0,0,0-8-8h-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232,96.00049a16.01833,16.01833,0,0,0-16-16H184v-32a16.01833,16.01833,0,0,0-16-16H40a16.01833,16.01833,0,0,0-16,16v128a7.99978,7.99978,0,0,0,13.0293,6.22119L72,153.95032l.001,30.05017a16.01833,16.01833,0,0,0,16,16h93.58789l37.38281,30.22119a7.99979,7.99979,0,0,0,13.0293-6.22119ZM189.44727,185.7793a7.99922,7.99922,0,0,0-5.0293-1.77881H88.001l-.001-32h80a16.01833,16.01833,0,0,0,16-16v-40h32l.001,111.24512Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M71.5834,144.00049l-39.58291,32v-128a8,8,0,0,1,8-8h128a8,8,0,0,1,8,8v88a8,8,0,0,1-8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M80.00049,144.00048v40a8,8,0,0,0,8,8h96.41709l39.58291,32v-128a8,8,0,0,0-8-8h-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M71.5834,144.00049l-39.58291,32v-128a8,8,0,0,1,8-8h128a8,8,0,0,1,8,8v88a8,8,0,0,1-8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M80.00049,144.00048v40a8,8,0,0,0,8,8h96.41709l39.58291,32v-128a8,8,0,0,0-8-8h-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M71.5834,144.00049l-39.58291,32v-128a8,8,0,0,1,8-8h128a8,8,0,0,1,8,8v88a8,8,0,0,1-8,8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80.00049,144.00048v40a8,8,0,0,0,8,8h96.41709l39.58291,32v-128a8,8,0,0,0-8-8h-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Chats = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$39(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Chats.displayName = "Chats";

var renderPathFor$3a = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M34.0714,140.74858a71.96979,71.96979,0,1,1,25.18031,25.1802l.00017-.00075-24.86742,7.105a6,6,0,0,1-7.41747-7.41747l7.105-24.86742Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M92.059,175.89247a72.04349,72.04349,0,0,0,104.68926,38.03631l-.00017-.00075,24.86742,7.105a6,6,0,0,0,7.41747-7.41747l-7.105-24.86742.00057.00046A72.01951,72.01951,0,0,0,163.93781,80.10585",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.059,175.89247a72.04349,72.04349,0,0,0,104.68926,38.03631l-.00017-.00075,24.86742,7.105a6,6,0,0,0,7.41747-7.41747l-7.105-24.86742.00057.00046A72.01951,72.01951,0,0,0,163.93781,80.10585l.00231-.00076A72.05057,72.05057,0,0,1,96,176q-1.98343,0-3.941-.106Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M34.0714,140.74858a71.96979,71.96979,0,1,1,25.18031,25.1802l.00017-.00075-24.86742,7.105a6,6,0,0,1-7.41747-7.41747l7.105-24.86742Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.059,175.89247a72.04349,72.04349,0,0,0,104.68926,38.03631l-.00017-.00075,24.86742,7.105a6,6,0,0,0,7.41747-7.41747l-7.105-24.86742.00057.00046A72.01951,72.01951,0,0,0,163.93781,80.10585",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M230.53955,189.7666A80.01439,80.01439,0,0,0,169.56543,72.58691a80.00141,80.00141,0,1,0-144.105,69.17969l-6.18457,21.6499a13.99955,13.99955,0,0,0,17.30566,17.30909l21.65235-6.186a79.84121,79.84121,0,0,0,28.18994,8.88367,80.03721,80.03721,0,0,0,111.34326,39.11584l21.65137,6.18653A14.00007,14.00007,0,0,0,236.7251,211.418Zm-15.4873-5.10791a8.00114,8.00114,0,0,0-.81641,6.28711l6.11621,21.40625-21.40625-6.11572a8.00193,8.00193,0,0,0-6.28613.8164,64.03376,64.03376,0,0,1-88.33985-23.48608,79.90524,79.90524,0,0,0,70.37549-93.85889,64.02222,64.02222,0,0,1,40.35694,94.95093Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M34.0714,140.74858a71.96979,71.96979,0,1,1,25.18031,25.1802l.00017-.00075-24.86742,7.105a6,6,0,0,1-7.41747-7.41747l7.105-24.86742Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M92.059,175.89247a72.04349,72.04349,0,0,0,104.68926,38.03631l-.00017-.00075,24.86742,7.105a6,6,0,0,0,7.41747-7.41747l-7.105-24.86742.00057.00046A72.01951,72.01951,0,0,0,163.93781,80.10585",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M34.0714,140.74858a71.96979,71.96979,0,1,1,25.18031,25.1802l.00017-.00075-24.86742,7.105a6,6,0,0,1-7.41747-7.41747l7.105-24.86742Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M92.059,175.89247a72.04349,72.04349,0,0,0,104.68926,38.03631l-.00017-.00075,24.86742,7.105a6,6,0,0,0,7.41747-7.41747l-7.105-24.86742.00057.00046A72.01951,72.01951,0,0,0,163.93781,80.10585",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M34.0714,140.74858a71.96979,71.96979,0,1,1,25.18031,25.1802l.00017-.00075-24.86742,7.105a6,6,0,0,1-7.41747-7.41747l7.105-24.86742Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.059,175.89247a72.04349,72.04349,0,0,0,104.68926,38.03631l-.00017-.00075,24.86742,7.105a6,6,0,0,0,7.41747-7.41747l-7.105-24.86742.00057.00046A72.01951,72.01951,0,0,0,163.93781,80.10585",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatsCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3a(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatsCircle.displayName = "ChatsCircle";

var renderPathFor$3b = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96.00014,175.99219H30a6,6,0,0,1-6-6V103.992A71.99985,71.99985,0,0,1,95.99986,31.99219H96a72,72,0,0,1,72,72v.00014A71.99986,71.99986,0,0,1,96.00014,175.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M92.098,175.99521a72.0298,72.0298,0,0,0,67.9019,47.997H226a6,6,0,0,0,6-6V151.992a72.00294,72.00294,0,0,0-68.06587-71.8942",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M163.93962,80.09586A71.887,71.887,0,0,1,168,103.99219v.00014a71.99986,71.99986,0,0,1-71.99986,71.99986H92.098v.003a72.0298,72.0298,0,0,0,67.9019,47.997H226a6,6,0,0,0,6-6V151.992a72.00294,72.00294,0,0,0-68.06587-71.8942Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M96.00014,175.99219H30a6,6,0,0,1-6-6V103.992A71.99985,71.99985,0,0,1,95.99986,31.99219H96a72,72,0,0,1,72,72v.00014A71.99986,71.99986,0,0,1,96.00014,175.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.098,175.99521a72.0298,72.0298,0,0,0,67.9019,47.997H226a6,6,0,0,0,6-6V151.992a72.00294,72.00294,0,0,0-68.06587-71.8942",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M169.56592,72.5788A79.99487,79.99487,0,0,0,16,103.99219v66a14.01573,14.01573,0,0,0,14,14H86.667a80.1557,80.1557,0,0,0,73.333,48h66a14.01573,14.01573,0,0,0,14-14v-66A79.96635,79.96635,0,0,0,169.56592,72.5788ZM224,215.99219H160a64.14151,64.14151,0,0,1-55.67871-32.43335,79.90546,79.90546,0,0,0,70.37451-93.859A63.99067,63.99067,0,0,1,224,151.99219Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96.00014,175.99219H30a6,6,0,0,1-6-6V103.992A71.99985,71.99985,0,0,1,95.99986,31.99219H96a72,72,0,0,1,72,72v.00014A71.99986,71.99986,0,0,1,96.00014,175.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M92.098,175.99521a72.0298,72.0298,0,0,0,67.9019,47.997H226a6,6,0,0,0,6-6V151.992a72.00294,72.00294,0,0,0-68.06587-71.8942",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96.00014,175.99219H30a6,6,0,0,1-6-6V103.992A71.99985,71.99985,0,0,1,95.99986,31.99219H96a72,72,0,0,1,72,72v.00014A71.99986,71.99986,0,0,1,96.00014,175.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M92.098,175.99521a72.0298,72.0298,0,0,0,67.9019,47.997H226a6,6,0,0,0,6-6V151.992a72.00294,72.00294,0,0,0-68.06587-71.8942",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96.00014,175.99219H30a6,6,0,0,1-6-6V103.992A71.99985,71.99985,0,0,1,95.99986,31.99219H96a72,72,0,0,1,72,72v.00014A71.99986,71.99986,0,0,1,96.00014,175.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.098,175.99521a72.0298,72.0298,0,0,0,67.9019,47.997H226a6,6,0,0,0,6-6V151.992a72.00294,72.00294,0,0,0-68.06587-71.8942",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ChatsTeardrop = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3b(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ChatsTeardrop.displayName = "ChatsTeardrop";

var renderPathFor$3c = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "216 72.005 104 184 48 128.005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "216 72.005 104 184 48 128.005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M103.99951,192.00012a7.97346,7.97346,0,0,1-5.65625-2.34277l-56-55.99561a7.99983,7.99983,0,1,1,11.3125-11.31445l50.34375,50.33935L210.34229,66.34778a8.00018,8.00018,0,0,1,11.31445,11.31347l-112,111.9961A7.97937,7.97937,0,0,1,103.99951,192.00012Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "216 72.005 104 184 48 128.005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "216 72.005 104 184 48 128.005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "216 72.005 104 184 48 128.005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Check = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3c(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Check.displayName = "Check";

var renderPathFor$3d = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "172 104 113.333 160 84 132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "172 104 113.333 160 84 132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm49.53125,85.78906-58.67187,56a8.02441,8.02441,0,0,1-11.0625,0l-29.32813-28a8.00675,8.00675,0,0,1,11.0625-11.57812l23.79687,22.72656,53.14063-50.72656a8.00675,8.00675,0,0,1,11.0625,11.57812Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "172 104 113.333 160 84 132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "172 104 113.333 160 84 132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "172 104 113.333 160 84 132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CheckCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3d(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CheckCircle.displayName = "CheckCircle";

var renderPathFor$3e = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "172 104 113.333 160 84 132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "172 104 113.333 160 84 132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.00146,32h-160a16.01582,16.01582,0,0,0-16,16V208a16.01583,16.01583,0,0,0,16,16h160a16.01582,16.01582,0,0,0,16-16V48A16.01581,16.01581,0,0,0,208.00146,32ZM177.5249,109.78125l-58.67187,56a7.98451,7.98451,0,0,1-11.04688,0l-29.32812-28a7.99571,7.99571,0,1,1,11.04687-11.5625l23.80469,22.71875L166.478,98.21875a7.99571,7.99571,0,1,1,11.04687,11.5625Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "172 104 113.333 160 84 132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "172 104 113.333 160 84 132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "172 104 113.333 160 84 132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CheckSquare = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3e(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CheckSquare.displayName = "CheckSquare";

var renderPathFor$3f = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M43.99951,143.27273V52a8,8,0,0,1,8-8h152a8,8,0,0,1,8,8V204a8,8,0,0,1-8,8h-68.3641",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "128 152 64 216 32 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "44 44 44 196 60 212 212 212 212 44 44 44",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M43.99951,143.27273V52a8,8,0,0,1,8-8h152a8,8,0,0,1,8,8V204a8,8,0,0,1-8,8h-68.3641",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 152 64 216 32 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M203.99951,36.00012h-152a16.01834,16.01834,0,0,0-16,16v91.27246a8,8,0,0,0,16,0V52.00012h152v152H135.63525a8,8,0,0,0,0,16h68.36426a16.01833,16.01833,0,0,0,16-16v-152A16.01833,16.01833,0,0,0,203.99951,36.00012Z"
      }), React__default.createElement("path", {
        d: "M133.65674,146.34338a8.00121,8.00121,0,0,0-11.31445,0L63.99951,204.68664,37.65674,178.34338a8.00018,8.00018,0,1,0-11.31445,11.31348l32,32a8.00062,8.00062,0,0,0,11.31445,0l64-64A8,8,0,0,0,133.65674,146.34338Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M43.99951,143.27273V52a8,8,0,0,1,8-8h152a8,8,0,0,1,8,8V204a8,8,0,0,1-8,8h-68.3641",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "128 152 64 216 32 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M43.99951,143.27273V52a8,8,0,0,1,8-8h152a8,8,0,0,1,8,8V204a8,8,0,0,1-8,8h-68.3641",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "128 152 64 216 32 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M43.99951,143.27273V52a8,8,0,0,1,8-8h152a8,8,0,0,1,8,8V204a8,8,0,0,1-8,8h-68.3641",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 152 64 216 32 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CheckSquareOffset = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3f(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CheckSquareOffset.displayName = "CheckSquareOffset";

var renderPathFor$3g = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "144 84 56 172 12 128.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "244 84 156 172 139.941 155.941",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "148 84 60 172 16 128.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "240 84 152 172 128.627 148.628",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M153.65674,89.65686l-87.999,88a8.00062,8.00062,0,0,1-11.31347,0l-44.001-43.99805a7.99983,7.99983,0,0,1,11.3125-11.31445l38.34473,38.3418,82.3418-82.34375a8.00052,8.00052,0,0,1,11.31445,11.31445Zm92-11.31445a8.003,8.003,0,0,0-11.31445,0l-82.3418,82.34375-17.71778-17.71582a7.99983,7.99983,0,0,0-11.3125,11.31445l23.374,23.37207a8.00062,8.00062,0,0,0,11.31347,0l87.999-88A8.00121,8.00121,0,0,0,245.65674,78.34241Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "148 84 60 172 16 128.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "240 84 152 172 128.627 148.628",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "148 84 60 172 16 128.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "240 84 152 172 128.627 148.628",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "148 84 60 172 16 128.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "240 84 152 172 128.627 148.628",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Checks = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3g(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Checks.displayName = "Checks";

var renderPathFor$3h = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "104"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Circle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3h(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Circle.displayName = "Circle";

var renderPathFor$3i = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "32",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "68.00584",
        x2: "218.91188",
        y2: "158.91774",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128.00002",
        y1: "140.00588",
        x2: "189.61412",
        y2: "201.61998",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32a96,96,0,0,1,0,192",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "32",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24ZM40,128a88.11715,88.11715,0,0,1,80-87.63257V215.63257A88.11715,88.11715,0,0,1,40,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "32",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "48.00584",
        x2: "222.85577",
        y2: "142.86163",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128.00002",
        y1: "104.00588",
        x2: "206.81368",
        y2: "182.81953",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128.00002",
        y1: "160.00588",
        x2: "177.97522",
        y2: "209.98108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "32",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "48.00584",
        x2: "222.85577",
        y2: "142.86163",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128.00002",
        y1: "104.00588",
        x2: "206.81368",
        y2: "182.81953",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128.00002",
        y1: "160.00588",
        x2: "177.97522",
        y2: "209.98108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "32",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "48.00584",
        x2: "222.85577",
        y2: "142.86163",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128.00002",
        y1: "104.00588",
        x2: "206.81368",
        y2: "182.81953",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128.00002",
        y1: "160.00588",
        x2: "177.97522",
        y2: "209.98108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CircleHalf = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3i(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CircleHalf.displayName = "CircleHalf";

var renderPathFor$3j = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "60.11775",
        x2: "60.11775",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "195.88224",
        y2: "195.88224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "164.00291",
        y1: "91.99705",
        x2: "221.56149",
        y2: "149.55563",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "92.00294",
        y1: "163.99708",
        x2: "149.56507",
        y2: "221.55921",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M195.88225,60.11775a96,96,0,0,1-135.7645,135.7645",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "60.11775",
        x2: "60.11775",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M201.53906,54.46094A103.99994,103.99994,0,1,0,54.46094,201.53906,103.99994,103.99994,0,1,0,201.53906,54.46094ZM65.77539,65.77441a88.08476,88.08476,0,0,1,118.52368-5.38794L60.38086,184.30579A87.98425,87.98425,0,0,1,65.77539,65.77441Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "60.11775",
        x2: "60.11775",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "142.00291",
        y1: "113.99705",
        x2: "208.43906",
        y2: "180.4332",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "114.00294",
        y1: "141.99708",
        x2: "180.44043",
        y2: "208.43457",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "86.00586",
        y1: "170",
        x2: "139.33798",
        y2: "223.33212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "170.00001",
        y1: "86.00001",
        x2: "223.33246",
        y2: "139.33246",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "60.11775",
        x2: "60.11775",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "142.00291",
        y1: "113.99705",
        x2: "208.43906",
        y2: "180.4332",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "114.00294",
        y1: "141.99708",
        x2: "180.44043",
        y2: "208.43457",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "86.00586",
        y1: "170",
        x2: "139.33798",
        y2: "223.33212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "170.00001",
        y1: "86.00001",
        x2: "223.33246",
        y2: "139.33246",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "60.11775",
        x2: "60.11775",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "142.00291",
        y1: "113.99705",
        x2: "208.43906",
        y2: "180.4332",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "114.00294",
        y1: "141.99708",
        x2: "180.44043",
        y2: "208.43457",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "86.00586",
        y1: "170",
        x2: "139.33798",
        y2: "223.33212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "170.00001",
        y1: "86.00001",
        x2: "223.33246",
        y2: "139.33246",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CircleHalfTilt = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3j(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CircleHalfTilt.displayName = "CircleHalfTilt";

var renderPathFor$3k = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "74",
        cy: "74",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "182",
        cy: "74",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "74",
        cy: "182",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "182",
        cy: "182",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "36",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "36",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "36",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "36",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "44"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "44"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "44"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "44"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CirclesFour = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3k(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CirclesFour.displayName = "CirclesFour";

var renderPathFor$3l = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "172",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "172",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "40",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "172",
        r: "40",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "172",
        r: "40",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "172",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "172",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "48"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "172",
        r: "48"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "172",
        r: "48"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "172",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "172",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "172",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "172",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "172",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "172",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CirclesThree = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3l(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CirclesThree.displayName = "CirclesThree";

var renderPathFor$3m = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "74",
        cy: "74",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "182",
        cy: "74",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "74",
        cy: "182",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("g", null, React__default.createElement("line", {
        x1: "182",
        y1: "156",
        x2: "182",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "182",
        x2: "156",
        y2: "182",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      })));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "36",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "36",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "36",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "180",
        y1: "152",
        x2: "180",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "180",
        x2: "152",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "44"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "44"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "44"
      }), React__default.createElement("path", {
        d: "M208,172H188V152a8,8,0,0,0-16,0v20H152a8,8,0,0,0,0,16h20v20a8,8,0,0,0,16,0V188h20a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "180",
        y1: "152",
        x2: "180",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "180",
        x2: "152",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "180",
        y1: "152",
        x2: "180",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "180",
        x2: "152",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "180",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "180",
        y1: "152",
        x2: "180",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "180",
        x2: "152",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CirclesThreePlus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3m(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CirclesThreePlus.displayName = "CirclesThreePlus";

var renderPathFor$3n = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "88",
        y: "24",
        width: "80",
        height: "40",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,40h32a8,8,0,0,1,8,8V216a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,40H56a8,8,0,0,0-8,8V216a8,8,0,0,0,8,8H200a8,8,0,0,0,8-8V48a8,8,0,0,0-8-8H168V64H88Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "88",
        y: "24",
        width: "80",
        height: "40",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,40h32a8,8,0,0,1,8,8V216a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,32H176V24a8.00039,8.00039,0,0,0-8-8H88a8.00039,8.00039,0,0,0-8,8v8H56A16.01833,16.01833,0,0,0,40,48V216a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,200,32ZM96,32h64V56H96Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "88",
        y: "24",
        width: "80",
        height: "40",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,40h32a8,8,0,0,1,8,8V216a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "88",
        y: "24",
        width: "80",
        height: "40",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,40h32a8,8,0,0,1,8,8V216a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "88",
        y: "24",
        width: "80",
        height: "40",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,40h32a8,8,0,0,1,8,8V216a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Clipboard = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3n(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Clipboard.displayName = "Clipboard";

var renderPathFor$3o = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "88",
        y: "24",
        width: "80",
        height: "40",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,40h32a8,8,0,0,1,8,8V216a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "156",
        x2: "160",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "116",
        x2: "160",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,40H56a8,8,0,0,0-8,8V216a8,8,0,0,0,8,8H200a8,8,0,0,0,8-8V48a8,8,0,0,0-8-8H168V64H88Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "88",
        y: "24",
        width: "80",
        height: "40",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,40h32a8,8,0,0,1,8,8V216a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "152",
        x2: "160",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "120",
        x2: "160",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,32H176V24a8.00039,8.00039,0,0,0-8-8H88a8.00039,8.00039,0,0,0-8,8v8H56A16.01833,16.01833,0,0,0,40,48V216a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,200,32ZM96,32h64V56H96Zm64,128H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm0-32H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "88",
        y: "24",
        width: "80",
        height: "40",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,40h32a8,8,0,0,1,8,8V216a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "152",
        x2: "160",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "120",
        x2: "160",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "88",
        y: "24",
        width: "80",
        height: "40",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,40h32a8,8,0,0,1,8,8V216a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "152",
        x2: "160",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "120",
        x2: "160",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "88",
        y: "24",
        width: "80",
        height: "40",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,40h32a8,8,0,0,1,8,8V216a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "152",
        x2: "160",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "120",
        x2: "160",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ClipboardText = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3o(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ClipboardText.displayName = "ClipboardText";

var renderPathFor$3p = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "128 72 128 128 184 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 72 128 128 184 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm56,112H128a7.99541,7.99541,0,0,1-8-8V72a8,8,0,0,1,16,0v48h48a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "128 72 128 128 184 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "128 72 128 128 184 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 72 128 128 184 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Clock = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3p(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Clock.displayName = "Clock";

var renderPathFor$3q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "184",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "167.59798",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "184",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "167.59798",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm56,112H147.31348l25.9414,25.94141a7.99983,7.99983,0,0,1-11.31347,11.31347l-39.59766-39.59765c-.18652-.18653-.36328-.38282-.53076-.58692-.07373-.08984-.1377-.18457-.20654-.27636-.0879-.1167-.17823-.23145-.25977-.353-.07471-.11182-.13916-.22754-.208-.34229-.06494-.10937-.13379-.21582-.19385-.32861-.0625-.1167-.11572-.23731-.17187-.35693-.05566-.11719-.11426-.23243-.16406-.353-.04785-.11572-.08643-.23389-.12842-.35108-.04639-.12841-.0957-.25585-.13574-.38769-.03565-.11816-.06153-.23779-.0918-.35693-.03369-.13379-.0708-.26563-.09814-.40186-.02686-.1377-.04346-.27637-.063-.41553-.01758-.11963-.04-.23681-.05176-.3584q-.03808-.38232-.03906-.7666L120,128l.001-.022q.00145-.38452.03906-.7666c.01172-.12159.03418-.23877.05176-.3584.01953-.13916.03613-.27783.063-.41553.02734-.13623.06445-.26807.09814-.40186.03027-.11914.05615-.23876.0918-.35693.04-.13183.08935-.25928.13574-.38769.042-.11719.08057-.23536.12842-.35108.0498-.1206.1084-.23584.16406-.353.05615-.11962.10937-.24023.17187-.35693.06006-.11279.12891-.21924.19385-.32861.06885-.11475.1333-.23047.208-.34229.08154-.12158.17187-.23633.25977-.353.06884-.09179.13281-.18652.20654-.27636a8.04468,8.04468,0,0,1,1.1167-1.1167c.09179-.0752.188-.14014.28174-.21094.11474-.08594.22705-.1748.34668-.25439.11425-.07666.23242-.14258.3496-.21241.10694-.064.21143-.13134.32129-.18994.11963-.064.24268-.11816.36475-.17578.11475-.0542.22754-.11133.34473-.16015.11914-.04932.24072-.08887.36132-.13184.12549-.04541.249-.09326.37745-.13233.12207-.03662.24609-.064.36914-.09472.12988-.03272.25732-.06885.38965-.09522.14306-.02832.28808-.04541.43261-.06591.11377-.01612.22608-.03809.34131-.04932q.39477-.03956.7915-.04H184a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "184",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "167.59798",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "184",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "167.59798",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "184",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "167.59798",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ClockAfternoon = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ClockAfternoon.displayName = "ClockAfternoon";

var renderPathFor$3r = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "169.56922",
        y1: "152",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "184.167 99.716 224.167 99.716 224.167 59.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,1,1,0-124.4508l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "169.56922",
        y1: "152",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "184.167 99.716 224.167 99.716 224.167 59.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,1,1,0-124.4508l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M128,72a8.00008,8.00008,0,0,0-8,8v48c0,.07269.00879.14313.01074.21533.00488.16107.01026.32172.02442.48187.01074.124.02734.24573.04394.368.01758.12957.03516.25872.05908.38714.02588.142.05811.28156.09131.42084.02637.108.05274.2157.083.32257.0415.14606.08838.28943.13818.432.03516.10131.07129.20208.11036.30194.05419.13665.1123.27063.17333.4035.04834.1062.09864.21143.15186.31561.06055.11792.12451.2334.19043.34778.06641.11511.13477.22864.207.34058.063.09771.12891.19317.19629.2879.085.12.17236.23792.26416.35352.06641.08294.13477.16351.2041.24377.09961.11548.20117.22882.30811.339.07617.07849.15478.15381.23388.22913.105.09991.21094.19854.32276.29333.09765.0835.19922.16235.30127.24115.09912.07642.19775.153.30127.22534.12988.09131.26513.17548.40088.2591.0625.03839.11963.082.18359.11889l41.56934,24a8,8,0,0,0,8-13.85644L136,123.38116V80A8.00008,8.00008,0,0,0,128,72Z"
      }), React__default.createElement("path", {
        d: "M224.1665,51.71582a7.99977,7.99977,0,0,0-8,8V80.4021L195.88184,60.11768a95.9551,95.9551,0,1,0,0,135.76464,7.99983,7.99983,0,1,0-11.31348-11.31347,80.00009,80.00009,0,1,1,0-113.1377L204.853,91.71582H184.1665a8,8,0,0,0,0,16h39.99756c.26465.00006.5293-.01392.793-.03992.11377-.01111.22363-.03265.33594-.04846.14648-.02069.293-.038.438-.06683.13134-.02606.25879-.06238.38818-.09479.12354-.03107.24805-.05817.37012-.09521.12842-.03888.25195-.087.37744-.132.1206-.04328.24219-.08307.36133-.13233.11816-.04889.231-.10626.34619-.16052.12109-.05725.24365-.11121.36279-.17493.11182-.06.21826-.12823.32715-.19329.11475-.06873.231-.13355.34326-.20856.12207-.08179.23731-.17267.35449-.2608.09131-.06861.18555-.13184.27442-.2049a8.05625,8.05625,0,0,0,1.11767-1.1181c.07178-.0871.13379-.17908.20069-.26844.08984-.1192.18213-.23632.26562-.36059.07373-.11041.1377-.2251.20508-.33826.06641-.11035.13574-.21844.19629-.33215.0625-.11676.11523-.23682.17187-.3559.05567-.11767.11426-.23346.16407-.35418.04785-.1153.08593-.233.12793-.34992.04687-.129.09619-.25659.13623-.38867.03564-.11786.06152-.23755.09131-.35657.03418-.13367.07128-.26575.09863-.402.02734-.13769.043-.27679.06348-.41552.01709-.11957.03955-.23725.05126-.35846.02588-.26227.04-.52539.04-.7887v-40A7.99977,7.99977,0,0,0,224.1665,51.71582Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "169.56922",
        y1: "152",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "184.167 99.716 224.167 99.716 224.167 59.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,1,1,0-124.4508l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "169.56922",
        y1: "152",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "184.167 99.716 224.167 99.716 224.167 59.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,1,1,0-124.4508l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "169.56922",
        y1: "152",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "184.167 99.716 224.167 99.716 224.167 59.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.2254,190.2254a88,88,0,1,1,0-124.4508l33.94112,33.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ClockClockwise = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3r(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ClockClockwise.displayName = "ClockClockwise";

var renderPathFor$3s = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "169.56922",
        y1: "152",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "71.833 99.716 31.833 99.716 31.833 59.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,1,0,0-124.4508L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "169.56922",
        y1: "152",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "71.833 99.716 31.833 99.716 31.833 59.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,1,0,0-124.4508L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M128,72a8.00008,8.00008,0,0,0-8,8v48c0,.07269.00879.14313.01074.21533.00489.16107.01026.32172.02442.48187.01074.124.02734.24573.04394.368.01758.12957.03516.25872.05908.38714.02588.142.05811.28156.09131.42084.02637.108.05274.2157.083.32257.0415.14606.08838.28943.13818.432.03516.10131.07129.20208.11036.30194.05419.13665.1123.27063.17334.4035.04833.1062.09863.21143.15185.31561.06055.11792.12451.2334.19043.34778.06641.11511.13477.22864.207.34058.063.09771.12891.19317.19629.2879.085.12.17236.23792.26416.35352.06641.08294.13477.16351.2041.24377.09961.11548.20117.22882.30811.339.07617.07849.15478.15381.23388.22913.105.09991.21094.19854.32276.29333.09765.0835.19922.16235.30127.24115.09912.07642.19775.153.30127.22534.12988.09131.26513.17548.40088.2591.0625.03839.11963.082.18359.11889l41.56934,24a8,8,0,0,0,8-13.85644L136,123.38116V80A8.00008,8.00008,0,0,0,128,72Z"
      }), React__default.createElement("path", {
        d: "M195.88184,60.11768a96.10782,96.10782,0,0,0-135.76416,0L39.8335,80.402V59.71582a8,8,0,1,0-16,0v40l.001.02216q.00147.38388.03907.76654c.01171.12121.03417.23889.05126.35846.02051.13873.03614.27783.06348.41552.02735.13629.06445.26838.09863.402.02979.119.05567.23871.09131.35657.04.13208.08936.25964.13623.38867.042.11688.08008.23462.12793.34992.04981.12072.1084.23651.16407.35418.05664.11908.10937.23914.17187.3559.06055.11371.12988.2218.19629.33215.06738.11316.13135.22785.20508.33826.08349.12427.17578.24139.26562.36059.0669.08936.12891.18134.20069.26844a8.034,8.034,0,0,0,1.11865,1.11865c.08545.07025.17578.131.26367.19714.12061.091.23926.18439.36523.26856.10889.07275.22168.13568.3335.20251.11182.06739.22217.13764.3374.19959.11475.06115.23243.11279.34912.168.11963.05688.2378.11657.36084.1676.1128.04645.22754.08386.3418.125.13184.04773.2627.09821.39746.1391.11377.0343.229.0592.34375.08838.1377.03515.27442.07348.415.10132.13086.02588.2627.04089.394.06018.127.01855.25147.04223.38038.05481.23242.02282.46582.03283.69921.03534.0293.0003.05762.00439.08741.00439h40a8,8,0,0,0,0-16H51.147L71.43164,71.43115a80.00025,80.00025,0,1,1,0,113.13721,8.00035,8.00035,0,0,0-11.314,11.31445A96.0001,96.0001,0,0,0,195.88184,60.11768Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "169.56922",
        y1: "152",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "71.833 99.716 31.833 99.716 31.833 59.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,1,0,0-124.4508L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "169.56922",
        y1: "152",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "71.833 99.716 31.833 99.716 31.833 59.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,1,0,0-124.4508L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "169.56922",
        y1: "152",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "71.833 99.716 31.833 99.716 31.833 59.716",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M65.7746,190.2254a88,88,0,1,0,0-124.4508L31.83348,99.71573",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ClockCounterClockwise = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3s(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ClockCounterClockwise.displayName = "ClockCounterClockwise";

var renderPathFor$3t = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M113.00272,152.80413a28,28,0,1,1-.00014-49.60833",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M185.00272,152.80413a28,28,0,1,1-.00014-49.60833",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M116,147.59582a28,28,0,1,1,.00011-39.19153",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M188,147.59582a28,28,0,1,1,.00011-39.19153",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,40H40A16.01833,16.01833,0,0,0,24,56V200a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V56A16.01833,16.01833,0,0,0,216,40ZM96,148a19.85259,19.85259,0,0,0,14.28613-6.00293,7.99956,7.99956,0,0,1,11.42774,11.19727,36,36,0,1,1,0-50.38868,7.99956,7.99956,0,0,1-11.42774,11.19727A20.00012,20.00012,0,1,0,96,148Zm72,0a19.85259,19.85259,0,0,0,14.28613-6.00293,7.99956,7.99956,0,0,1,11.42774,11.19727,36,36,0,1,1,0-50.38868,7.99956,7.99956,0,0,1-11.42774,11.19727A20.00012,20.00012,0,1,0,168,148Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M116,147.59582a28,28,0,1,1,.00011-39.19153",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M188,147.59582a28,28,0,1,1,.00011-39.19153",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M116,147.59582a28,28,0,1,1,.00011-39.19153",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M188,147.59582a28,28,0,1,1,.00011-39.19153",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M116,147.59582a28,28,0,1,1,.00011-39.19153",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M188,147.59582a28,28,0,1,1,.00011-39.19153",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ClosedCaptioning = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3t(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ClosedCaptioning.displayName = "ClosedCaptioning";

var renderPathFor$3u = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M160,40A88.102,88.102,0,0,0,81.28711,88.6709l-.00537-.00049A87.464,87.464,0,0,0,71.98828,128a8,8,0,0,1-16,0,103.43561,103.43561,0,0,1,7.78-39.45264A63.99161,63.99161,0,0,0,72,216h88a88,88,0,0,0,0-176Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Cloud = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3u(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Cloud.displayName = "Cloud";

var renderPathFor$3v = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "118.059 174.059 152 208 185.941 174.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "128",
        x2: "152",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M96,208H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,144.00241,48.00459",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "118.053 174.059 151.994 208 185.935 174.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "151.99414",
        y1: "128",
        x2: "151.99414",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M95.99414,208h-24A56,56,0,1,1,85.91338,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M79.99414,128a80,80,0,1,1,144.00241,48.00459",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M160.001,40A88.102,88.102,0,0,0,81.28809,88.6709l-.00538-.00049A87.46336,87.46336,0,0,0,71.98926,128a8,8,0,0,1-16,0,103.43674,103.43674,0,0,1,7.78-39.45264A63.99161,63.99161,0,0,0,72.001,216h88a88,88,0,0,0,0-176ZM191.5918,163.71582l-33.937,33.937a7.95865,7.95865,0,0,1-.59205.5354c-.08374.06885-.17224.12818-.258.19312-.12256.09253-.24317.18725-.3711.273-.10766.07177-.2196.134-.32983.20019-.11316.06812-.22412.13892-.34082.20142-.11523.06152-.23377.11377-.35132.16919-.11877.05639-.23584.11548-.35766.166-.11451.04737-.23169.08545-.34778.12744-.13.04688-.25843.09668-.39136.13672-.11694.0354-.23572.06128-.35376.09107-.1344.03393-.26721.07153-.40418.09863-.13891.02759-.27929.044-.41931.064-.11816.01684-.23437.03955-.35412.05127-.26245.02587-.52588.03979-.78931.03979s-.52685-.01392-.78931-.03979c-.11975-.01172-.236-.03443-.35412-.05127-.14-.02-.2804-.03638-.41931-.064-.137-.0271-.26978-.0647-.40418-.09863-.118-.02979-.23681-.05567-.35376-.09107-.13293-.04-.26135-.08984-.39136-.13672-.11608-.042-.23327-.08007-.34777-.12744-.12183-.05053-.2389-.10962-.35767-.166-.11755-.05542-.23608-.10767-.35132-.16919-.1167-.0625-.22766-.1333-.34082-.20142-.11023-.06616-.22217-.12842-.32983-.20019-.12793-.0857-.24854-.18042-.3711-.273-.08581-.06494-.17431-.12427-.258-.19312a7.95651,7.95651,0,0,1-.592-.5354l-33.937-33.937A7.99984,7.99984,0,1,1,123.71,152.40234l20.28418,20.28418V112a8,8,0,0,1,16,0v60.68652l20.28418-20.28418a7.99984,7.99984,0,1,1,11.31348,11.31348Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "118.059 174.059 152 208 185.941 174.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "128",
        x2: "152",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M96,208H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,144.00241,48.00459",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "118.059 174.059 152 208 185.941 174.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "128",
        x2: "152",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M96,208H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,144.00241,48.00459",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "118.059 174.059 152 208 185.941 174.059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "128",
        x2: "152",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M96,208H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,144.00241,48.00459",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CloudArrowDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3v(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CloudArrowDown.displayName = "CloudArrowDown";

var renderPathFor$3w = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,207.98437H72A56,56,0,1,1,85.91924,97.7279",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M80,127.98437A80,80,0,1,1,224.00241,175.989",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "118.059 161.926 152 127.984 185.941 161.926",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "207.98437",
        x2: "152",
        y2: "127.98437",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,127.98437a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.7279",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M95.99414,207.98437h-24A56,56,0,1,1,85.91338,97.7279",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M79.99414,127.98437A80,80,0,1,1,223.99655,175.989",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "118.053 161.926 151.994 127.984 185.935 161.926",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "151.99414",
        y1: "207.98437",
        x2: "151.99414",
        y2: "127.98437",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M160.001,40A88.102,88.102,0,0,0,81.28809,88.6709l-.00538-.00049A87.46336,87.46336,0,0,0,71.98926,128a8,8,0,0,1-16,0,103.43674,103.43674,0,0,1,7.78-39.45264A63.99161,63.99161,0,0,0,72.001,216h88a88,88,0,0,0,0-176ZM191.5918,151.59766a7.99945,7.99945,0,0,1-11.31348,0l-20.28418-20.28418V192a8,8,0,0,1-16,0V131.31348L123.71,151.59766a7.99984,7.99984,0,1,1-11.31348-11.31348l33.937-33.937a7.95651,7.95651,0,0,1,.592-.5354c.08374-.06885.17224-.12818.258-.19312.12256-.09253.24317-.18725.3711-.273.10718-.07153.2185-.1333.32837-.19922.11377-.06836.22534-.13964.34277-.20263.11353-.06055.23022-.11182.34583-.16651.12072-.05737.23986-.11767.36389-.16894.11157-.04614.22583-.08325.33911-.124.13281-.04834.26416-.09888.40014-.14014.1128-.03394.22718-.0586.34107-.08765.13867-.0354.27612-.074.4176-.1018.12976-.02588.26087-.04053.3916-.05982.12744-.0188.25305-.04272.38233-.05518.232-.02294.465-.03271.69812-.0354.02978-.00024.05871-.00439.08862-.00439s.05884.00415.08862.00439c.23316.00269.46607.01246.69812.0354.12928.01246.25489.03638.38233.05518.13074.01929.26184.03394.3916.05982.14148.02783.27893.0664.4176.1018.11389.029.22827.05371.34107.08765.136.04126.26733.0918.40014.14014.11328.04077.22754.07788.33911.124.124.05127.24317.11157.3639.16894.1156.05469.2323.106.34582.16651.11743.063.229.13427.34277.20263.10987.06592.2212.12769.32837.19922.12793.0857.24854.18042.3711.273.08581.06494.17431.12427.258.19312a7.95865,7.95865,0,0,1,.59205.5354l33.937,33.937A7.99915,7.99915,0,0,1,191.5918,151.59766Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,207.98437H72A56,56,0,1,1,85.91924,97.7279",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M80,127.98437A80,80,0,1,1,224.00241,175.989",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "118.059 161.926 152 127.984 185.941 161.926",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "207.98437",
        x2: "152",
        y2: "127.98437",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,207.98437H72A56,56,0,1,1,85.91924,97.7279",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M80,127.98437A80,80,0,1,1,224.00241,175.989",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "118.059 161.926 152 127.984 185.941 161.926",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "207.98437",
        x2: "152",
        y2: "127.98437",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,207.98437H72A56,56,0,1,1,85.91924,97.7279",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,127.98437A80,80,0,1,1,224.00241,175.989",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "118.059 161.926 152 127.984 185.941 161.926",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "207.98437",
        x2: "152",
        y2: "127.98437",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CloudArrowUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3w(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CloudArrowUp.displayName = "CloudArrowUp";

var renderPathFor$3x = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "192 116 144 164 120 140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80.00586,128a80,80,0,1,1,80,80h-88A56,56,0,1,1,85.9251,97.74352",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 116 144 164 120 140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M160.001,40A88.102,88.102,0,0,0,81.28809,88.6709l-.00538-.00049A87.46336,87.46336,0,0,0,71.98926,128a8,8,0,0,1-16,0,103.43674,103.43674,0,0,1,7.78-39.45264A63.99161,63.99161,0,0,0,72.001,216h88a88,88,0,0,0,0-176Zm37.65576,81.65674-48,48a7.99945,7.99945,0,0,1-11.31348,0l-24-24a7.99984,7.99984,0,0,1,11.31348-11.31348L144,152.68652l42.34326-42.34326a7.99984,7.99984,0,0,1,11.31348,11.31348Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "192 116 144 164 120 140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "192 116 144 164 120 140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,128a80,80,0,1,1,80,80H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 116 144 164 120 140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CloudCheck = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3x(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CloudCheck.displayName = "CloudCheck";

var renderPathFor$3y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "120",
        y1: "200",
        x2: "72",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "200",
        x2: "160",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "240",
        x2: "104",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "192",
        x2: "72",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "192",
        x2: "160",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "104",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120,200H72a8,8,0,0,1,0-16h48a8,8,0,0,1,0,16Zm64-16H160a8,8,0,0,0,0,16h24a8,8,0,0,0,0-16Zm-24,32H104a8,8,0,0,0,0,16h56a8,8,0,0,0,0-16ZM156,16A76.13113,76.13113,0,0,0,85.03711,64.7832,52.0037,52.0037,0,1,0,76,168h80a76,76,0,0,0,0-152Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "120",
        y1: "192",
        x2: "72",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "192",
        x2: "160",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "104",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "120",
        y1: "192",
        x2: "72",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "192",
        x2: "160",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "104",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "120",
        y1: "192",
        x2: "72",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "192",
        x2: "160",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "104",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CloudFog = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CloudFog.displayName = "CloudFog";

var renderPathFor$3z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 240 154.25 200 104 200 130.25 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "128 240 154.25 200 104 200 130.25 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M134.564,168l-15.75,24h35.43116a8.00016,8.00016,0,0,1,6.68847,12.38916l-26.25,40a8,8,0,1,1-13.377-8.77832L139.42627,208H103.99512a8.00017,8.00017,0,0,1-6.68848-12.38916L115.42627,168H75.99512A52.0014,52.0014,0,0,1,68.16479,64.59033,91.68713,91.68713,0,0,0,63.99512,92a8,8,0,0,0,16,0,75.62312,75.62312,0,0,1,5.03723-27.2168l.007-.01758A76.00126,76.00126,0,1,1,155.99512,168Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 240 154.25 200 104 200 130.25 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 240 154.25 200 104 200 130.25 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "128 240 154.25 200 104 200 130.25 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CloudLightning = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CloudLightning.displayName = "CloudLightning";

var renderPathFor$3A = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,148a68,68,0,1,1,68,68H76a44,44,0,1,1,14.30583-85.62208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M49.96509,136.529A64.11761,64.11761,0,0,1,17.6218,94.37955l.00023-.001A64.0566,64.0566,0,0,0,94.37854,17.622l.00084-.00019A64.02478,64.02478,0,0,1,144,80q0,.52871-.00853,1.05539",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M90.30559,130.37786a68.14083,68.14083,0,0,1,45.47328-47.32071l.15152-.04541Q135.99975,81.51458,136,80A64.02478,64.02478,0,0,0,86.37938,17.62177l-.00084.00019A64.05661,64.05661,0,0,1,9.622,94.37856l-.00023.001A64.12919,64.12919,0,0,0,46.99,138.92889l-.00581-.00661a44.06953,44.06953,0,0,1,43.32161-8.54436Z"
      })), React__default.createElement("path", {
        d: "M88,148a68,68,0,1,1,68,68H76a44,44,0,1,1,14.30583-85.62208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M46.99,138.92889A64.12919,64.12919,0,0,1,9.6218,94.37955l.00023-.001A64.0566,64.0566,0,0,0,86.37854,17.622l.00084-.00019A64.02478,64.02478,0,0,1,136,80q0,1.51431-.06961,3.01174",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M156,72a76.16623,76.16623,0,0,0-12.356,1.012A71.97744,71.97744,0,0,0,88.16846,9.8252a7.9997,7.9997,0,0,0-9.58741,9.58691A56.33865,56.33865,0,0,1,80,32,56.06322,56.06322,0,0,1,24,88a56.39592,56.39592,0,0,1-12.59082-1.418,8.00013,8.00013,0,0,0-9.585,9.58789A72.18778,72.18778,0,0,0,34.11353,141.2312,51.96571,51.96571,0,0,0,76,224h80a76,76,0,0,0,0-152ZM21.36816,103.95215Q22.68287,104.0005,24,104A72.08124,72.08124,0,0,0,96,32q0-1.3374-.04932-2.67285a55.64963,55.64963,0,0,1,31.98267,48.05249A76.41925,76.41925,0,0,0,85.03711,120.7832,52.31117,52.31117,0,0,0,76,120a51.69716,51.69716,0,0,0-30.02808,9.58643A56.254,56.254,0,0,1,21.36816,103.95215Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,148a68,68,0,1,1,68,68H76a44,44,0,1,1,14.30583-85.62208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M46.99,138.92889A64.12919,64.12919,0,0,1,9.6218,94.37955l.00023-.001A64.0566,64.0566,0,0,0,86.37854,17.622l.00084-.00019A64.02478,64.02478,0,0,1,136,80q0,1.51431-.06961,3.01174",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,148a68,68,0,1,1,68,68H76a44,44,0,1,1,14.30583-85.62208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M46.99,138.92889A64.12919,64.12919,0,0,1,9.6218,94.37955l.00023-.001A64.0566,64.0566,0,0,0,86.37854,17.622l.00084-.00019A64.02478,64.02478,0,0,1,136,80q0,1.51431-.06961,3.01174",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,148a68,68,0,1,1,68,68H76a44,44,0,1,1,14.30583-85.62208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M46.99,138.92889A64.12919,64.12919,0,0,1,9.6218,94.37955l.00023-.001A64.0566,64.0566,0,0,0,86.37854,17.622l.00084-.00019A64.02478,64.02478,0,0,1,136,80q0,1.51431-.06961,3.01174",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CloudMoon = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3A(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CloudMoon.displayName = "CloudMoon";

var renderPathFor$3B = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "240",
        x2: "154.25007",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "98.74999",
        y1: "208",
        x2: "130.25007",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "240",
        x2: "154.25007",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "98.74999",
        y1: "208",
        x2: "130.25007",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M160.93359,204.38916l-26.25,40a8,8,0,1,1-13.377-8.77832l26.25-40a8,8,0,1,1,13.377,8.77832ZM155.99512,16A76.1302,76.1302,0,0,0,85.03931,64.76562l-.007.01758A75.62312,75.62312,0,0,0,79.99512,92a8,8,0,0,1-16,0,91.68713,91.68713,0,0,1,4.16967-27.40967A52.0014,52.0014,0,0,0,75.99512,168h39.43115L92.05664,203.61084a8,8,0,1,0,13.37695,8.77832L134.564,168h21.43116a76,76,0,0,0,0-152Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "240",
        x2: "154.25007",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "98.74999",
        y1: "208",
        x2: "130.25007",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "240",
        x2: "154.25007",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "98.74999",
        y1: "208",
        x2: "130.25007",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "240",
        x2: "154.25007",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "98.74999",
        y1: "208",
        x2: "130.25007",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CloudRain = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3B(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CloudRain.displayName = "CloudRain";

var renderPathFor$3C = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M193.8943,200.486A79.69516,79.69516,0,0,1,160,208H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M80,128A79.62931,79.62931,0,0,1,91.06793,87.375",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M119.38894,59.05967A80.01177,80.01177,0,0,1,224.76359,174.97434",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80.00586,127.6178a80,80,0,1,1,80,80h-88A56,56,0,1,1,85.9251,97.36132",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M193.8943,200.486A79.69516,79.69516,0,0,1,160,208H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M112.63246,63.52392a80.0033,80.0033,0,0,1,107.0479,117.75254",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,128A79.62931,79.62931,0,0,1,91.06793,87.375",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M53.91943,34.61865a7.99991,7.99991,0,1,0-11.83886,10.7627L81.32349,88.54858c-.02.0398-.04187.07862-.06177.11841A64.00311,64.00311,0,1,0,72,216h88a87.30213,87.30213,0,0,0,31.79883-5.92847l10.28174,11.30982a7.99991,7.99991,0,0,0,11.83886-10.7627Z"
      }), React__default.createElement("path", {
        d: "M160,40a87.31991,87.31991,0,0,0-52.10938,17.08057,8.00024,8.00024,0,0,0-1.17773,11.8247L213.76074,186.65771a8.00079,8.00079,0,0,0,5.91944,2.61866h.03466A7.99883,7.99883,0,0,0,225.646,186.606,88.00035,88.00035,0,0,0,160,40Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M193.8943,200.486A79.69516,79.69516,0,0,1,160,208H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M112.63246,63.52392a80.0033,80.0033,0,0,1,107.0479,117.75254",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M80,128A79.62931,79.62931,0,0,1,91.06793,87.375",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M193.8943,200.486A79.69516,79.69516,0,0,1,160,208H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M112.63246,63.52392a80.0033,80.0033,0,0,1,107.0479,117.75254",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M80,128A79.62931,79.62931,0,0,1,91.06793,87.375",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M193.8943,200.486A79.69516,79.69516,0,0,1,160,208H72A56,56,0,1,1,85.91924,97.74352",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M112.63246,63.52392a80.0033,80.0033,0,0,1,107.0479,117.75254",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,128A79.62931,79.62931,0,0,1,91.06793,87.375",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CloudSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3C(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CloudSlash.displayName = "CloudSlash";

var renderPathFor$3D = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,96a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,78.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "216",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "64",
        cy: "216",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "112",
        cy: "216",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "116",
        cy: "212",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "236",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "236",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M175.99512,196a12,12,0,1,1-12-12A12.01375,12.01375,0,0,1,175.99512,196Zm-100-12a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,75.99512,184Zm40,16a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,115.99512,200Zm-48,24a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,67.99512,224Zm88,0a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,155.99512,224Zm0-208A76.1302,76.1302,0,0,0,85.03931,64.76562l-.007.01758A75.62312,75.62312,0,0,0,79.99512,92a8,8,0,0,1-16,0,91.68713,91.68713,0,0,1,4.16967-27.40967A52.0014,52.0014,0,0,0,75.99512,168h80a76,76,0,0,0,0-152Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "116",
        cy: "212",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "236",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "236",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "116",
        cy: "212",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "236",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "236",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,92a68,68,0,1,1,68,68H76A44,44,0,1,1,90.30583,74.37792",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "116",
        cy: "212",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "236",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "236",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CloudSnow = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3D(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CloudSnow.displayName = "CloudSnow";

var renderPathFor$3E = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,148a68,68,0,1,1,68,68H76a44,44,0,1,1,14.30583-85.62208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "79.6638",
        y1: "56.73022",
        x2: "75.49625",
        y2: "33.09483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48.68557",
        y1: "76.45789",
        x2: "29.02592",
        y2: "62.69205",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.73022",
        y1: "112.31237",
        x2: "17.09483",
        y2: "116.47993",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "115.51829",
        y1: "64.68557",
        x2: "129.28412",
        y2: "45.02592",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M51.64386,135.35374A48.008,48.008,0,1,1,131.83232,84.4235",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M131.83232,84.4235a48.00729,48.00729,0,1,0-80.18846,50.93024l-.00154-.00232a44.09694,44.09694,0,0,1,38.66351-4.9735l-.00024-.00007A68.15692,68.15692,0,0,1,131.83113,84.4204Z"
      })), React__default.createElement("path", {
        d: "M88,148a68,68,0,1,1,68,68H76a44,44,0,1,1,14.30583-85.62208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "79.6638",
        y1: "56.73022",
        x2: "75.49625",
        y2: "33.09483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48.68557",
        y1: "76.45789",
        x2: "29.02592",
        y2: "62.69205",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.73022",
        y1: "112.31237",
        x2: "17.09483",
        y2: "116.47993",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "115.51829",
        y1: "64.68557",
        x2: "129.28412",
        y2: "45.02592",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M51.64386,135.35374A48.008,48.008,0,1,1,131.83232,84.4235",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M156,72a75.81,75.81,0,0,0-20.23584,2.73853,55.73208,55.73208,0,0,0-9.41089-11.57911l9.48413-13.54419A8.00015,8.00015,0,0,0,122.731,40.4375l-9.48413,13.54419A55.868,55.868,0,0,0,86.251,48.01953L83.37451,31.70605A7.99987,7.99987,0,1,0,67.61768,34.4834l2.87475,16.30371A55.397,55.397,0,0,0,47.17651,65.635L33.61426,56.13867A8.00027,8.00027,0,0,0,24.4375,69.24609l13.55981,9.49463a55.39532,55.39532,0,0,0-5.98669,26.98535l-16.305,2.87452a8.00079,8.00079,0,0,0,1.37988,15.87988,8.12832,8.12832,0,0,0,1.39844-.12207l16.31079-2.87573a55.95086,55.95086,0,0,0,5.85571,12.42749A51.96741,51.96741,0,0,0,76,224h80a76,76,0,0,0,0-152ZM48.62964,111.09448c-.00879-.05713-.01123-.11352-.02124-.17065-.011-.0625-.02954-.12158-.042-.18335A39.72794,39.72794,0,0,1,55.12793,81.186c.0354-.04834.07642-.08985.11084-.13916.03857-.05518.06909-.11329.106-.16895a39.72789,39.72789,0,0,1,25.48584-16.2395c.07422-.011.148-.01612.22216-.029.06983-.01221.136-.033.20508-.04688a39.95749,39.95749,0,0,1,29.17383,6.28857c.16138.13282.32336.26514.49756.38721.12671.08887.26294.15161.39282.23193a39.78776,39.78776,0,0,1,9.26489,9.31006,76.44756,76.44756,0,0,0-35.5498,40.00293A52.31117,52.31117,0,0,0,76,120a51.67572,51.67572,0,0,0-22.07556,4.93262A40.03451,40.03451,0,0,1,48.62964,111.09448Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,148a68,68,0,1,1,68,68H76a44,44,0,1,1,14.30583-85.62208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "79.6638",
        y1: "56.73022",
        x2: "75.49625",
        y2: "33.09483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48.68557",
        y1: "76.45789",
        x2: "29.02592",
        y2: "62.69205",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.73022",
        y1: "112.31237",
        x2: "17.09483",
        y2: "116.47993",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "115.51829",
        y1: "64.68557",
        x2: "129.28412",
        y2: "45.02592",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M51.64386,135.35374A48.008,48.008,0,1,1,131.83232,84.4235",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,148a68,68,0,1,1,68,68H76a44,44,0,1,1,14.30583-85.62208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "79.6638",
        y1: "56.73022",
        x2: "75.49625",
        y2: "33.09483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48.68557",
        y1: "76.45789",
        x2: "29.02592",
        y2: "62.69205",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.73022",
        y1: "112.31237",
        x2: "17.09483",
        y2: "116.47993",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "115.51829",
        y1: "64.68557",
        x2: "129.28412",
        y2: "45.02592",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M51.64386,135.35374A48.008,48.008,0,1,1,131.83232,84.4235",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,148a68,68,0,1,1,68,68H76a44,44,0,1,1,14.30583-85.62208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "79.6638",
        y1: "56.73022",
        x2: "75.49625",
        y2: "33.09483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48.68557",
        y1: "76.45789",
        x2: "29.02592",
        y2: "62.69205",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.73022",
        y1: "112.31237",
        x2: "17.09483",
        y2: "116.47993",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "115.51829",
        y1: "64.68557",
        x2: "129.28412",
        y2: "45.02592",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M51.64386,135.35374A48.008,48.008,0,1,1,131.83232,84.4235",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CloudSun = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3E(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CloudSun.displayName = "CloudSun";

var renderPathFor$3F = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104.512,186.61814a47.9857,47.9857,0,1,1-17.29771-85.30105l-.00069.00287a48,48,0,1,1,81.57046.00366l-.00718-.00443a48.00516,48.00516,0,1,1-17.28893,85.299L160,232H96Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M112.51708,179.15431a47.97767,47.97767,0,1,1-25.30276-77.83722l-.00069.00287a48,48,0,1,1,81.57046.00366l-.00718-.00443a48.00575,48.00575,0,1,1-25.29289,77.8364L160,232H96Z"
      })), React__default.createElement("path", {
        d: "M112.51708,179.15431a47.97767,47.97767,0,1,1-25.30276-77.83722l-.00069.00287a48,48,0,1,1,81.57046.00366l-.00718-.00443a48.00575,48.00575,0,1,1-25.29289,77.8364L160,232H96Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232,148a52.00505,52.00505,0,0,1-80.459,43.52539l10.6538,34.08789A7.99984,7.99984,0,0,1,154.55908,236H101.44092a7.99954,7.99954,0,0,1-7.63526-10.38672L104.45459,191.542a51.7046,51.7046,0,0,1-29.9624,8.43653c-27.72657-.78516-50.377-24.00489-50.4917-51.75977A51.99976,51.99976,0,0,1,76,96q2.02881,0,4.04883.15625a52.00294,52.00294,0,1,1,95.89648,0,53.33621,53.33621,0,0,1,5.46387-.1377A51.70261,51.70261,0,0,1,232,148Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M112.51708,179.15431a47.97767,47.97767,0,1,1-25.30276-77.83722l-.00069.00287a48,48,0,1,1,81.57046.00366l-.00718-.00443a48.00575,48.00575,0,1,1-25.29289,77.8364L160,232H96Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M112.51708,179.15431a47.97767,47.97767,0,1,1-25.30276-77.83722l-.00069.00287a48,48,0,1,1,81.57046.00366l-.00718-.00443a48.00575,48.00575,0,1,1-25.29289,77.8364L160,232H96Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M112.51708,179.15431a47.97767,47.97767,0,1,1-25.30276-77.83722l-.00069.00287a48,48,0,1,1,81.57046.00366l-.00718-.00443a48.00575,48.00575,0,1,1-25.29289,77.8364L160,232H96Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Club = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3F(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Club.displayName = "Club";

var renderPathFor$3G = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "64 88 16 128 64 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "192 88 240 128 192 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "40",
        x2: "96",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "64 88 16 128 64 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 88 240 128 192 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "40",
        x2: "96",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M70.146,82.87891a8.00043,8.00043,0,0,0-11.26758-1.02442l-48,40a7.99963,7.99963,0,0,0,0,12.291l48,40a7.99987,7.99987,0,1,0,10.24316-12.291L28.49658,128l40.625-33.85449A7.99977,7.99977,0,0,0,70.146,82.87891Z"
      }), React__default.createElement("path", {
        d: "M245.12158,121.85449l-48-40a7.99987,7.99987,0,1,0-10.24316,12.291L227.50342,128l-40.625,33.85449a7.99987,7.99987,0,1,0,10.24316,12.291l48-40a7.99963,7.99963,0,0,0,0-12.291Z"
      }), React__default.createElement("path", {
        d: "M162.73389,32.48145a8.005,8.005,0,0,0-10.25244,4.78418l-64,176a8.00034,8.00034,0,1,0,15.0371,5.46875l64-176A8.0008,8.0008,0,0,0,162.73389,32.48145Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "64 88 16 128 64 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "192 88 240 128 192 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "40",
        x2: "96",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "64 88 16 128 64 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "192 88 240 128 192 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "40",
        x2: "96",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "64 88 16 128 64 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192 88 240 128 192 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "40",
        x2: "96",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Code = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3G(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Code.displayName = "Code";

var renderPathFor$3H = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "88 64 16 128 88 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "168 64 240 128 168 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "88 64 16 128 88 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "168 64 240 128 168 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M93.97949,58.68555a7.99976,7.99976,0,0,0-11.29443-.665l-72,64a8.00054,8.00054,0,0,0,0,11.959l72,64a8.00018,8.00018,0,0,0,10.62988-11.959L28.0415,128,93.31494,69.97949A8,8,0,0,0,93.97949,58.68555Z"
      }), React__default.createElement("path", {
        d: "M245.31494,122.02051l-72-64a8.00018,8.00018,0,0,0-10.62988,11.959L227.9585,128l-65.27344,58.02051a8.00018,8.00018,0,0,0,10.62988,11.959l72-64a8.00054,8.00054,0,0,0,0-11.959Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "88 64 16 128 88 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "168 64 240 128 168 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "88 64 16 128 88 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "168 64 240 128 168 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "88 64 16 128 88 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "168 64 240 128 168 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CodeSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3H(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CodeSimple.displayName = "CodeSimple";

var renderPathFor$3I = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "84",
        y1: "24",
        x2: "84",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "24",
        x2: "120",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "24",
        x2: "156",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "216",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M83.29651,216.0038A88.01441,88.01441,0,0,1,32,136V88H208v48a88.0144,88.0144,0,0,1-51.29712,80.00408",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M208,88h4a32,32,0,0,1,32,32V128a32,32,0,0,1-32,32h-7.37846",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M83.29651,216.0038A88.01441,88.01441,0,0,1,32,136V88H208v48a88.0144,88.0144,0,0,1-51.29712,80.00408Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "24",
        x2: "88",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "24",
        x2: "120",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "24",
        x2: "152",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "216",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M83.29651,216.0038A88.01441,88.01441,0,0,1,32,136V88H208v48a88.0144,88.0144,0,0,1-51.29712,80.00408",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,88h0a32,32,0,0,1,32,32V128a32,32,0,0,1-32,32h-3.37846",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,56V24a8,8,0,0,1,16,0V56a8,8,0,0,1-16,0Zm40,8a8.00008,8.00008,0,0,0,8-8V24a8,8,0,0,0-16,0V56A8.00008,8.00008,0,0,0,120,64Zm32,0a8.00008,8.00008,0,0,0,8-8V24a8,8,0,0,0-16,0V56A8.00008,8.00008,0,0,0,152,64Zm96,56v8a40.04613,40.04613,0,0,1-37.50781,39.91455A96.65441,96.65441,0,0,1,183.46387,208H208a8,8,0,0,1,0,16H156.8208c-.0376.00049-.07568.00586-.11279.00586-.02832,0-.05615-.00537-.08447-.00586H83.15869c-.04541-.001-.09033.00146-.13574,0H32a8,8,0,0,1,0-16H56.53613A96.31957,96.31957,0,0,1,24,136V88a8.00008,8.00008,0,0,1,8-8H208A40.04521,40.04521,0,0,1,248,120Zm-16,0a24.03806,24.03806,0,0,0-16-22.624V136a95.32337,95.32337,0,0,1-1.20312,15.01367A24.039,24.039,0,0,0,232,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "88",
        y1: "24",
        x2: "88",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "24",
        x2: "120",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "24",
        x2: "152",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "216",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M83.29651,216.0038A88.01441,88.01441,0,0,1,32,136V88H208v48a88.0144,88.0144,0,0,1-51.29712,80.00408",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M208,88h0a32,32,0,0,1,32,32V128a32,32,0,0,1-32,32h-3.37846",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "88",
        y1: "24",
        x2: "88",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "24",
        x2: "120",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "24",
        x2: "152",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "216",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M83.29651,216.0038A88.01441,88.01441,0,0,1,32,136V88H208v48a88.0144,88.0144,0,0,1-51.29712,80.00408",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M208,88h0a32,32,0,0,1,32,32V128a32,32,0,0,1-32,32h-3.37846",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "88",
        y1: "24",
        x2: "88",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "24",
        x2: "120",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "24",
        x2: "152",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "216",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M83.29651,216.0038A88.01441,88.01441,0,0,1,32,136V88H208v48a88.0144,88.0144,0,0,1-51.29712,80.00408",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,88h0a32,32,0,0,1,32,32V128a32,32,0,0,1-32,32h-3.37846",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Coffee = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3I(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Coffee.displayName = "Coffee";

var renderPathFor$3J = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "-10",
        y: "98",
        width: "176",
        height: "60",
        rx: "8",
        transform: "translate(206 50) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "90",
        y: "98",
        width: "176",
        height: "60",
        rx: "8",
        transform: "translate(306 -50) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "-8",
        y: "96",
        width: "176",
        height: "64",
        rx: "8",
        transform: "translate(208 48) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "88",
        y: "96",
        width: "176",
        height: "64",
        rx: "8",
        transform: "translate(304 -48) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "-8",
        y: "96",
        width: "176",
        height: "64",
        rx: "8",
        transform: "translate(208 48) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "88",
        y: "96",
        width: "176",
        height: "64",
        rx: "8",
        transform: "translate(304 -48) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("rect", {
        x: "40",
        y: "32",
        width: "80",
        height: "192",
        rx: "16"
      }), React__default.createElement("rect", {
        x: "136",
        y: "32",
        width: "80",
        height: "192",
        rx: "16"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "-8",
        y: "96",
        width: "176",
        height: "64",
        rx: "8",
        transform: "translate(208 48) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "88",
        y: "96",
        width: "176",
        height: "64",
        rx: "8",
        transform: "translate(304 -48) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "-8",
        y: "96",
        width: "176",
        height: "64",
        rx: "8",
        transform: "translate(208 48) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "88",
        y: "96",
        width: "176",
        height: "64",
        rx: "8",
        transform: "translate(304 -48) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "-8",
        y: "96",
        width: "176",
        height: "64",
        rx: "8",
        transform: "translate(208 48) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "88",
        y: "96",
        width: "176",
        height: "64",
        rx: "8",
        transform: "translate(304 -48) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Columns = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3J(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Columns.displayName = "Columns";

var renderPathFor$3K = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M180,48h.00006A27.99994,27.99994,0,0,1,208,75.99994V76a28,28,0,0,1-28,28H152a0,0,0,0,1,0,0V76a28,28,0,0,1,28-28Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M48,48H76a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,76.00006,104H76A28,28,0,0,1,48,76V48A0,0,0,0,1,48,48Z",
        transform: "translate(152 152) rotate(180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152,152h28a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,180.00006,208H180a28,28,0,0,1-28-28V152A0,0,0,0,1,152,152Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M76,152h.00006A27.99994,27.99994,0,0,1,104,179.99994V180a28,28,0,0,1-28,28H48a0,0,0,0,1,0,0V180A28,28,0,0,1,76,152Z",
        transform: "translate(152 360) rotate(-180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "104",
        y: "104",
        width: "48",
        height: "48",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M180,48h.00006A27.99994,27.99994,0,0,1,208,75.99994V76a28,28,0,0,1-28,28H152a0,0,0,0,1,0,0V76a28,28,0,0,1,28-28Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M48,48H76a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,76.00006,104H76A28,28,0,0,1,48,76V48A0,0,0,0,1,48,48Z",
        transform: "translate(152 152) rotate(180)",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M152,152h28a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,180.00006,208H180a28,28,0,0,1-28-28V152A0,0,0,0,1,152,152Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M76,152h.00006A27.99994,27.99994,0,0,1,104,179.99994V180a28,28,0,0,1-28,28H48a0,0,0,0,1,0,0V180A28,28,0,0,1,76,152Z",
        transform: "translate(152 360) rotate(-180)",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M76,152h.00006A27.99994,27.99994,0,0,1,104,179.99994V180a28,28,0,0,1-28,28H48a0,0,0,0,1,0,0V180A28,28,0,0,1,76,152Z",
        transform: "translate(152 360) rotate(-180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M180,48h.00006A27.99994,27.99994,0,0,1,208,75.99994V76a28,28,0,0,1-28,28H152a0,0,0,0,1,0,0V76a28,28,0,0,1,28-28Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M48,48H76a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,76.00006,104H76A28,28,0,0,1,48,76V48A0,0,0,0,1,48,48Z",
        transform: "translate(152 152) rotate(180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,152h28a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,180.00006,208H180a28,28,0,0,1-28-28V152A0,0,0,0,1,152,152Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "104",
        y: "104",
        width: "48",
        height: "48",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M180,144H160V112h20a36,36,0,1,0-36-36V96H112V76a36,36,0,1,0-36,36H96v32H76a36,36,0,1,0,36,36V160h32v20a36,36,0,1,0,36-36ZM160,76a20,20,0,1,1,20,20H160ZM56,76a20,20,0,0,1,40,0V96H76A20.0226,20.0226,0,0,1,56,76ZM96,180a20,20,0,1,1-20-20H96Zm16-68h32v32H112Zm68,88a20.0226,20.0226,0,0,1-20-20V160h20a20,20,0,0,1,0,40Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M180,48h.00006A27.99994,27.99994,0,0,1,208,75.99994V76a28,28,0,0,1-28,28H152a0,0,0,0,1,0,0V76a28,28,0,0,1,28-28Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M48,48H76a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,76.00006,104H76A28,28,0,0,1,48,76V48A0,0,0,0,1,48,48Z",
        transform: "translate(152 152) rotate(180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M152,152h28a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,180.00006,208H180a28,28,0,0,1-28-28V152A0,0,0,0,1,152,152Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M76,152h.00006A27.99994,27.99994,0,0,1,104,179.99994V180a28,28,0,0,1-28,28H48a0,0,0,0,1,0,0V180A28,28,0,0,1,76,152Z",
        transform: "translate(152 360) rotate(-180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "104",
        y: "104",
        width: "48",
        height: "48",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M180,48h.00006A27.99994,27.99994,0,0,1,208,75.99994V76a28,28,0,0,1-28,28H152a0,0,0,0,1,0,0V76a28,28,0,0,1,28-28Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M48,48H76a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,76.00006,104H76A28,28,0,0,1,48,76V48A0,0,0,0,1,48,48Z",
        transform: "translate(152 152) rotate(180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M152,152h28a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,180.00006,208H180a28,28,0,0,1-28-28V152A0,0,0,0,1,152,152Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M76,152h.00006A27.99994,27.99994,0,0,1,104,179.99994V180a28,28,0,0,1-28,28H48a0,0,0,0,1,0,0V180A28,28,0,0,1,76,152Z",
        transform: "translate(152 360) rotate(-180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "104",
        y: "104",
        width: "48",
        height: "48",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M180,48h.00006A27.99994,27.99994,0,0,1,208,75.99994V76a28,28,0,0,1-28,28H152a0,0,0,0,1,0,0V76a28,28,0,0,1,28-28Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M48,48H76a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,76.00006,104H76A28,28,0,0,1,48,76V48A0,0,0,0,1,48,48Z",
        transform: "translate(152 152) rotate(180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,152h28a28,28,0,0,1,28,28v.00006A27.99994,27.99994,0,0,1,180.00006,208H180a28,28,0,0,1-28-28V152A0,0,0,0,1,152,152Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M76,152h.00006A27.99994,27.99994,0,0,1,104,179.99994V180a28,28,0,0,1-28,28H48a0,0,0,0,1,0,0V180A28,28,0,0,1,76,152Z",
        transform: "translate(152 360) rotate(-180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "104",
        y: "104",
        width: "48",
        height: "48",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Command = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3K(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Command.displayName = "Command";

var renderPathFor$3L = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "144.965 144.971 167.402 88.485 111.024 111.029 88.396 167.598 144.965 144.971",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32a96,96,0,1,0,96,96A95.99991,95.99991,0,0,0,128,32Zm16.9646,112.9707-59.397,25.45557,25.45606-59.397,62.0354-28.20069Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "144.965 144.971 173.059 82.828 111.024 111.029 85.568 170.426 144.965 144.971",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M127.99975,24a104,104,0,1,0,104,104A104.11791,104.11791,0,0,0,127.99975,24Zm52.34961,62.124-28.09472,62.14209a7.99954,7.99954,0,0,1-4.13868,4.05713L88.71948,177.7793A7.99971,7.99971,0,0,1,78.2146,167.27539l25.45507-59.39746a8.00275,8.00275,0,0,1,4.043-4.13086L169.74878,75.5459A8,8,0,0,1,180.34936,86.124Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "144.965 144.971 173.059 82.828 111.024 111.029 85.568 170.426 144.965 144.971",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "144.965 144.971 173.059 82.828 111.024 111.029 85.568 170.426 144.965 144.971",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "144.965 144.971 173.059 82.828 111.024 111.029 85.568 170.426 144.965 144.971",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Compass = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3L(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Compass.displayName = "Compass";

var renderPathFor$3M = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "76",
        x2: "96",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "116",
        x2: "96",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "184",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "32",
        y: "56",
        width: "192",
        height: "144",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "56",
        width: "192",
        height: "144",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "72",
        x2: "96",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "104",
        x2: "96",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "32",
        y: "56",
        width: "192",
        height: "144",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,24H64A16.01833,16.01833,0,0,0,48,40V216a16.01833,16.01833,0,0,0,16,16H192a16.01833,16.01833,0,0,0,16-16V40A16.01833,16.01833,0,0,0,192,24ZM128,192a12,12,0,1,1,12-12A12.01343,12.01343,0,0,1,128,192Zm32-80H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm0-32H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "72",
        x2: "96",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "104",
        x2: "96",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "32",
        y: "56",
        width: "192",
        height: "144",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "72",
        x2: "96",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "104",
        x2: "96",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "32",
        y: "56",
        width: "192",
        height: "144",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "72",
        x2: "96",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "104",
        x2: "96",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "32",
        y: "56",
        width: "192",
        height: "144",
        rx: "8",
        transform: "translate(256 0) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ComputerTower = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3M(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ComputerTower.displayName = "ComputerTower";

var renderPathFor$3N = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 167.993 216 167.993 216 39.993 88 39.993 88 87.993",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "39.99902",
        y: "87.99414",
        width: "128",
        height: "128",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "168 87.993 168 167.993 216 167.993 216 39.993 88 39.993 88 87.993 168 87.993",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "168 167.993 216 167.993 216 39.993 88 39.993 88 87.993",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.99902",
        y: "87.99414",
        width: "128",
        height: "128",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99414,31.99316h-128a8.0004,8.0004,0,0,0-8,8v40.001h-40.001a8.0004,8.0004,0,0,0-8,8v128a8.0004,8.0004,0,0,0,8,8h128a8.00039,8.00039,0,0,0,8-8v-40.001h40.001a8.00039,8.00039,0,0,0,8-8v-128A8.0004,8.0004,0,0,0,215.99414,31.99316Zm-8,128h-32.001v-71.999a8.00039,8.00039,0,0,0-8-8h-71.999v-32.001h112Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 167.993 216 167.993 216 39.993 88 39.993 88 87.993",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "39.99902",
        y: "87.99414",
        width: "128",
        height: "128",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 167.993 216 167.993 216 39.993 88 39.993 88 87.993",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "39.99902",
        y: "87.99414",
        width: "128",
        height: "128",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 167.993 216 167.993 216 39.993 88 39.993 88 87.993",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.99902",
        y: "87.99414",
        width: "128",
        height: "128",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Copy = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3N(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Copy.displayName = "Copy";

var renderPathFor$3O = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "219.993 175.995 219.993 35.994 79.986 35.994",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "39.98633",
        y: "75.99512",
        width: "140.00586",
        height: "140",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.98633",
        y: "71.99512",
        width: "144.00586",
        height: "144",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "215.993 183.995 215.993 39.994 71.986 39.994",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.98633",
        y: "71.99512",
        width: "144.00586",
        height: "144",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M215.99365,31.99414H71.98682a8,8,0,1,0,0,16H207.99365v136.001a8,8,0,0,0,16,0V39.99414A8.00008,8.00008,0,0,0,215.99365,31.99414Z"
      }), React__default.createElement("rect", {
        x: "31.98682",
        y: "63.99512",
        width: "160.00586",
        height: "160",
        rx: "8"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "215.993 183.995 215.993 39.994 71.986 39.994",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "39.98633",
        y: "71.99512",
        width: "144.00586",
        height: "144",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "215.993 183.995 215.993 39.994 71.986 39.994",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "39.98633",
        y: "71.99512",
        width: "144.00586",
        height: "144",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "215.993 183.995 215.993 39.994 71.986 39.994",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.98633",
        y: "71.99512",
        width: "144.00586",
        height: "144",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CopySimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3O(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CopySimple.displayName = "CopySimple";

var renderPathFor$3P = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M160.00112,152.00142a40,40,0,1,1-.00029-48.013",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M160.00112,152.00142a40,40,0,1,1-.00029-48.013",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,20A108,108,0,1,0,236,128,108.12249,108.12249,0,0,0,128,20Zm0,196a88,88,0,1,1,88-88A88.09957,88.09957,0,0,1,128,216Zm0-160a72,72,0,1,0,72,72A72.08124,72.08124,0,0,0,128,56Zm.00293,103.99512a31.76384,31.76384,0,0,0,25.60254-12.79981,8,8,0,0,1,12.791,9.61182,47.99976,47.99976,0,1,1,0-57.62451,8,8,0,0,1-12.791,9.61181,32.001,32.001,0,1,0-25.60254,51.20069Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M160.00112,152.00142a40,40,0,1,1-.00029-48.013",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M160.00112,152.00142a40,40,0,1,1-.00029-48.013",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M160.00112,152.00142a40,40,0,1,1-.00029-48.013",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Copyright = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3P(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Copyright.displayName = "Copyright";

var renderPathFor$3Q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 96 160 96 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "48 160 96 160 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "160 208 160 160 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "96 48 96 96 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 96 160 96 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 160 96 160 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 208 160 160 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 48 96 96 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M160,104h48a8,8,0,0,0,0-16H168V48a8,8,0,0,0-16,0V96A8.00008,8.00008,0,0,0,160,104Z"
      }), React__default.createElement("path", {
        d: "M96,152H48a8,8,0,0,0,0,16H88v40a8,8,0,0,0,16,0V160A8.00008,8.00008,0,0,0,96,152Z"
      }), React__default.createElement("path", {
        d: "M208,152H160a8.00008,8.00008,0,0,0-8,8v48a8,8,0,0,0,16,0V168h40a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M96,40a8.00008,8.00008,0,0,0-8,8V88H48a8,8,0,0,0,0,16H96a8.00008,8.00008,0,0,0,8-8V48A8.00008,8.00008,0,0,0,96,40Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 96 160 96 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "48 160 96 160 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "160 208 160 160 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "96 48 96 96 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 96 160 96 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "48 160 96 160 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "160 208 160 160 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "96 48 96 96 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "208 96 160 96 160 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 160 96 160 96 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 208 160 160 208 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "96 48 96 96 48 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CornersIn = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3Q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CornersIn.displayName = "CornersIn";

var renderPathFor$3R = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "88 208 48 208 48 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "48 88 48 48 88 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "88 208 48 208 48 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 88 48 48 88 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M208,40H168a8,8,0,0,0,0,16h32V88a8,8,0,0,0,16,0V48A8.00008,8.00008,0,0,0,208,40Z"
      }), React__default.createElement("path", {
        d: "M88,200H56V168a8,8,0,0,0-16,0v40a8.00039,8.00039,0,0,0,8,8H88a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M208,160a8.00039,8.00039,0,0,0-8,8v32H168a8,8,0,0,0,0,16h40a8.00039,8.00039,0,0,0,8-8V168A8.00039,8.00039,0,0,0,208,160Z"
      }), React__default.createElement("path", {
        d: "M88,40H48a8.00008,8.00008,0,0,0-8,8V88a8,8,0,0,0,16,0V56H88a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "88 208 48 208 48 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "48 88 48 48 88 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "88 208 48 208 48 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "48 88 48 48 88 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "88 208 48 208 48 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "48 88 48 48 88 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CornersOut = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3R(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CornersOut.displayName = "CornersOut";

var renderPathFor$3S = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "56",
        width: "208",
        height: "144",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "163.99414",
        y1: "164",
        x2: "195.99414",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "107.99414",
        y1: "164",
        x2: "123.99414",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "23.99414",
        y1: "96.85228",
        x2: "231.99412",
        y2: "96.85228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M23.99414,96.85228h208L232,192a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8Z"
      })), React__default.createElement("rect", {
        x: "24",
        y: "56",
        width: "208",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "167.99414",
        y1: "168",
        x2: "199.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "119.99414",
        y1: "168",
        x2: "135.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "23.99414",
        y1: "96.85228",
        x2: "231.99412",
        y2: "96.85228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,48H32A16.01833,16.01833,0,0,0,16,64V96.73633c-.00049.03906-.00586.07715-.00586.11621s.00537.07715.00586.11621V192a16.01833,16.01833,0,0,0,16,16H224a16.01833,16.01833,0,0,0,16-16V64A16.01833,16.01833,0,0,0,224,48ZM135.99414,176h-16a8,8,0,0,1,0-16h16a8,8,0,1,1,0,16Zm64,0h-32a8,8,0,0,1,0-16h32a8,8,0,1,1,0,16ZM32,88.85254V64H224l.002,24.85254Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "56",
        width: "208",
        height: "144",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "167.99414",
        y1: "168",
        x2: "199.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "119.99414",
        y1: "168",
        x2: "135.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "23.99414",
        y1: "96.85228",
        x2: "231.99412",
        y2: "96.85228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "56",
        width: "208",
        height: "144",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "167.99414",
        y1: "168",
        x2: "199.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "119.99414",
        y1: "168",
        x2: "135.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "23.99414",
        y1: "96.85228",
        x2: "231.99412",
        y2: "96.85228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "56",
        width: "208",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "167.99414",
        y1: "168",
        x2: "199.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "119.99414",
        y1: "168",
        x2: "135.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "23.99414",
        y1: "96.85228",
        x2: "231.99412",
        y2: "96.85228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CreditCard = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3S(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CreditCard.displayName = "CreditCard";

var renderPathFor$3T = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.99414",
        y1: "56",
        x2: "16.00244",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "56.002 16 56.002 200.001 240.002 200.001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "200.002 160.001 200.002 56 95.994 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200.00244",
        y1: "240.00098",
        x2: "200.00244",
        y2: "200.00098",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.99414",
        y1: "56",
        x2: "16.00244",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56.002 16 56.002 200.001 240.002 200.001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "200.002 168.001 200.002 56 87.994 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200.00244",
        y1: "240.00098",
        x2: "200.00244",
        y2: "200.00098",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M240.00244,192.001h-176V16a8,8,0,0,0-16,0V48h-32a8,8,0,0,0,0,16h32V200.001a8.00039,8.00039,0,0,0,8,8h136v32a8,8,0,0,0,16,0v-32h32a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M87.99365,64H192.00244V168.001a8,8,0,0,0,16,0V56a8.00008,8.00008,0,0,0-8-8H87.99365a8,8,0,0,0,0,16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.99414",
        y1: "56",
        x2: "16.00244",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "56.002 16 56.002 200.001 240.002 200.001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "200.002 168.001 200.002 56 87.994 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200.00244",
        y1: "240.00098",
        x2: "200.00244",
        y2: "200.00098",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.99414",
        y1: "56",
        x2: "16.00244",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "56.002 16 56.002 200.001 240.002 200.001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "200.002 168.001 200.002 56 87.994 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200.00244",
        y1: "240.00098",
        x2: "200.00244",
        y2: "200.00098",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "55.99414",
        y1: "56",
        x2: "16.00244",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56.002 16 56.002 200.001 240.002 200.001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "200.002 168.001 200.002 56 87.994 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200.00244",
        y1: "240.00098",
        x2: "200.00244",
        y2: "200.00098",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Crop = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3T(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Crop.displayName = "Crop";

var renderPathFor$3U = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "20",
        x2: "128",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "20",
        y1: "128",
        x2: "56",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "236",
        x2: "128",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "236",
        y1: "128",
        x2: "200",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "20",
        x2: "128",
        y2: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "20",
        y1: "128",
        x2: "60",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "236",
        x2: "128",
        y2: "196",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "236",
        y1: "128",
        x2: "196",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M236,120H223.66406A96.15352,96.15352,0,0,0,136,32.33618V20a8,8,0,0,0-16,0V32.33618A96.15352,96.15352,0,0,0,32.33594,120H20a8,8,0,0,0,0,16H32.33594A96.15352,96.15352,0,0,0,120,223.66382V236a8,8,0,0,0,16,0V223.66382A96.15352,96.15352,0,0,0,223.66406,136H236a8,8,0,0,0,0-16Zm-40,16h11.59912A80.14164,80.14164,0,0,1,136,207.59912V196a8,8,0,0,0-16,0v11.59912A80.14164,80.14164,0,0,1,48.40088,136H60a8,8,0,0,0,0-16H48.40088A80.14164,80.14164,0,0,1,120,48.40088V60a8,8,0,0,0,16,0V48.40088A80.14164,80.14164,0,0,1,207.59912,120H196a8,8,0,0,0,0,16Z"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "40"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "20",
        x2: "128",
        y2: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "20",
        y1: "128",
        x2: "60",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "236",
        x2: "128",
        y2: "196",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "236",
        y1: "128",
        x2: "196",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "20",
        x2: "128",
        y2: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "20",
        y1: "128",
        x2: "60",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "236",
        x2: "128",
        y2: "196",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "236",
        y1: "128",
        x2: "196",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "20",
        x2: "128",
        y2: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "20",
        y1: "128",
        x2: "60",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "236",
        x2: "128",
        y2: "196",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "236",
        y1: "128",
        x2: "196",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Crosshair = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3U(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Crosshair.displayName = "Crosshair";

var renderPathFor$3V = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "76",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "92",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "76",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,28A100,100,0,1,0,228,128,100.113,100.113,0,0,0,128,28Zm8,183.60938V180a8,8,0,0,0-16,0v31.60938A84.13251,84.13251,0,0,1,44.39062,136H76a8,8,0,0,0,0-16H44.39062A84.13249,84.13249,0,0,1,120,44.39063V76a8,8,0,0,0,16,0V44.39063A84.13247,84.13247,0,0,1,211.60937,120H180a8,8,0,0,0,0,16h31.60937A84.13249,84.13249,0,0,1,136,211.60938Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "76",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "76",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "76",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CrosshairSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3V(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CrosshairSimple.displayName = "CrosshairSimple";

var renderPathFor$3W = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "129.06171",
        y1: "128",
        x2: "128",
        y2: "230.81036",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "218.904 76.627 129.062 128 37.103 76.616",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M37.10205,76.61578A7.99474,7.99474,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826A7.99524,7.99524,0,0,0,128,230.81054v-.00018L129.06171,128l-91.959-51.38385Z"
      })), React__default.createElement("line", {
        x1: "129.06171",
        y1: "128",
        x2: "128",
        y2: "230.81036",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "218.904 76.627 129.062 128 37.103 76.616",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.939,72.833c-.03173-.0586-.05664-.11914-.09033-.17749-.02636-.04663-.0581-.08814-.08593-.134a15.98749,15.98749,0,0,0-5.88965-5.78295l-84-47.47828a16.08654,16.08654,0,0,0-15.7461,0l-84,47.47852a15.99434,15.99434,0,0,0-5.96093,5.8999c-.01465.02588-.03223.04907-.04688.0752-.02588.0459-.04443.09375-.06934.13989A15.98459,15.98459,0,0,0,28,80.66772v94.6648a16.02531,16.02531,0,0,0,8.127,13.92871l84,47.478a15.97377,15.97377,0,0,0,7.30078,2.041c.16309.01172.32422.02808.48975.02979.02832.00049.05615.00049.08447.00049.22119,0,.43946-.01514.65625-.033a15.97571,15.97571,0,0,0,7.21485-2.03833l84-47.478A16.02531,16.02531,0,0,0,228,175.33252V80.66772A15.985,15.985,0,0,0,225.939,72.833ZM128,33.18945l75.813,42.85083L129.0166,118.81055,52.3291,75.96Zm8.13037,185.02564.8833-85.54663L212,89.79v85.54248Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "129.06171",
        y1: "128",
        x2: "128",
        y2: "230.81036",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "218.904 76.627 129.062 128 37.103 76.616",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "129.06171",
        y1: "128",
        x2: "128",
        y2: "230.81036",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "218.904 76.627 129.062 128 37.103 76.616",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "129.06171",
        y1: "128",
        x2: "128",
        y2: "230.81036",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "218.904 76.627 129.062 128 37.103 76.616",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Cube = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3W(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Cube.displayName = "Cube";

var renderPathFor$3X = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M104,168h36a20,20,0,0,0,0-40H116a20,20,0,0,1,0-40h36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M104,168h36a20,20,0,0,0,0-40H116a20,20,0,0,1,0-40h36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm12,152h-4v8a8,8,0,0,1-16,0v-8H104a8,8,0,0,1,0-16h36a12,12,0,0,0,0-24H116a28,28,0,0,1,0-56h4V72a8,8,0,0,1,16,0v8h16a8,8,0,0,1,0,16H116a12,12,0,0,0,0,24h24a28,28,0,0,1,0,56Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M104,168h36a20,20,0,0,0,0-40H116a20,20,0,0,1,0-40h36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M104,168h36a20,20,0,0,0,0-40H116a20,20,0,0,1,0-40h36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M104,168h36a20,20,0,0,0,0-40H116a20,20,0,0,1,0-40h36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CurrencyCircleDollar = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3X(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CurrencyCircleDollar.displayName = "CurrencyCircleDollar";

var renderPathFor$3Y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "64",
        x2: "192",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "120",
        x2: "208",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152,120v56a24,24,0,0,0,24,24h40V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M104,120v16a64,64,0,0,1-64,64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "64",
        x2: "192",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "120",
        x2: "208",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,120v56a24,24,0,0,0,24,24h40V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M104,120v16a64,64,0,0,1-64,64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56,64a8.00008,8.00008,0,0,1,8-8H192a8,8,0,0,1,0,16H64A8.00008,8.00008,0,0,1,56,64ZM216,168a8.00039,8.00039,0,0,0-8,8v16H176a16.01833,16.01833,0,0,1-16-16V128h48a8,8,0,0,0,0-16H48a8,8,0,0,0,0,16H96v8a56.0629,56.0629,0,0,1-56,56,8,8,0,0,0,0,16,72.08124,72.08124,0,0,0,72-72v-8h32v48a32.03667,32.03667,0,0,0,32,32h40a8.00039,8.00039,0,0,0,8-8V176A8.00039,8.00039,0,0,0,216,168Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "64",
        x2: "192",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "120",
        x2: "208",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M152,120v56a24,24,0,0,0,24,24h40V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M104,120v16a64,64,0,0,1-64,64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "64",
        x2: "192",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "120",
        x2: "208",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M152,120v56a24,24,0,0,0,24,24h40V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M104,120v16a64,64,0,0,1-64,64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "64",
        x2: "192",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "120",
        x2: "208",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,120v56a24,24,0,0,0,24,24h40V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M104,120v16a64,64,0,0,1-64,64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CurrencyCny = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3Y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CurrencyCny.displayName = "CurrencyCny";

var renderPathFor$3Z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M184,88a40,40,0,0,0-40-40H108a40,40,0,0,0,0,80h44a40,40,0,0,1,0,80H104a40,40,0,0,1-40-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M184,88a40,40,0,0,0-40-40H108a40,40,0,0,0,0,80h44a40,40,0,0,1,0,80H104a40,40,0,0,1-40-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M152,120H136V56h8a32.03635,32.03635,0,0,1,32,32,8,8,0,0,0,16,0,48.054,48.054,0,0,0-48-48h-8V24a8,8,0,0,0-16,0V40H108a48,48,0,0,0,0,96h12v64H104a32.03635,32.03635,0,0,1-32-32,8,8,0,0,0-16,0,48.054,48.054,0,0,0,48,48h16v16a8,8,0,0,0,16,0V216h16a48,48,0,0,0,0-96Zm-32,0H108a32,32,0,0,1,0-64h12Zm32,80H136V136h16a32,32,0,0,1,0,64Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M184,88a40,40,0,0,0-40-40H108a40,40,0,0,0,0,80h44a40,40,0,0,1,0,80H104a40,40,0,0,1-40-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M184,88a40,40,0,0,0-40-40H108a40,40,0,0,0,0,80h44a40,40,0,0,1,0,80H104a40,40,0,0,1-40-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M184,88a40,40,0,0,0-40-40H108a40,40,0,0,0,0,80h44a40,40,0,0,1,0,80H104a40,40,0,0,1-40-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CurrencyDollar = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3Z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CurrencyDollar.displayName = "CurrencyDollar";

var renderPathFor$3_ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "208",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M184,88a40,40,0,0,0-40-40H108a40,40,0,0,0,0,80h44a40,40,0,0,1,0,80H104a40,40,0,0,1-40-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "208",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M184,88a40,40,0,0,0-40-40H108a40,40,0,0,0,0,80h44a40,40,0,0,1,0,80H104a40,40,0,0,1-40-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,168a48.054,48.054,0,0,1-48,48H136v16a8,8,0,0,1-16,0V216H104a48.054,48.054,0,0,1-48-48,8,8,0,0,1,16,0,32.03635,32.03635,0,0,0,32,32h48a32,32,0,0,0,0-64H108a48,48,0,0,1,0-96h12V24a8,8,0,0,1,16,0V40h8a48.054,48.054,0,0,1,48,48,8,8,0,0,1-16,0,32.03635,32.03635,0,0,0-32-32H108a32,32,0,0,0,0,64h44A48.054,48.054,0,0,1,200,168Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "208",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M184,88a40,40,0,0,0-40-40H108a40,40,0,0,0,0,80h44a40,40,0,0,1,0,80H104a40,40,0,0,1-40-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "208",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M184,88a40,40,0,0,0-40-40H108a40,40,0,0,0,0,80h44a40,40,0,0,1,0,80H104a40,40,0,0,1-40-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "208",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M184,88a40,40,0,0,0-40-40H108a40,40,0,0,0,0,80h44a40,40,0,0,1,0,80H104a40,40,0,0,1-40-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CurrencyDollarSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3_(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CurrencyDollarSimple.displayName = "CurrencyDollarSimple";

var renderPathFor$3$ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M186.91167,194.91171A72,72,0,0,1,64,144V112A72,72,0,0,1,186.91167,61.08829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "108",
        x2: "136",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "148",
        x2: "120",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M186.91167,194.91171A72,72,0,0,1,64,144V112A72,72,0,0,1,186.91167,61.08829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "112",
        x2: "136",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "144",
        x2: "120",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192.56934,189.25488a7.99974,7.99974,0,0,1-.001,11.314A80.00019,80.00019,0,0,1,56.40088,152H40a8,8,0,0,1,0-16H56V120H40a8,8,0,0,1,0-16H56.40088A80.00019,80.00019,0,0,1,192.56836,55.43115a7.99984,7.99984,0,1,1-11.3125,11.31446A63.98841,63.98841,0,0,0,72.51758,104H136a8,8,0,0,1,0,16H72v16h48a8,8,0,0,1,0,16H72.51758a63.98841,63.98841,0,0,0,108.73828,37.25439A8.00093,8.00093,0,0,1,192.56934,189.25488Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M186.91167,194.91171A72,72,0,0,1,64,144V112A72,72,0,0,1,186.91167,61.08829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "112",
        x2: "136",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "144",
        x2: "120",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M186.91167,194.91171A72,72,0,0,1,64,144V112A72,72,0,0,1,186.91167,61.08829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "112",
        x2: "136",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "144",
        x2: "120",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M186.91167,194.91171A72,72,0,0,1,64,144V112A72,72,0,0,1,186.91167,61.08829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "112",
        x2: "136",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "144",
        x2: "120",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CurrencyEur = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$3$(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CurrencyEur.displayName = "CurrencyEur";

var renderPathFor$40 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("line", {
        x1: "56",
        y1: "132",
        x2: "136",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M184,208H56a36,36,0,0,0,36-36V84a44,44,0,0,1,75.11269-31.11271",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      })));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("line", {
        x1: "56",
        y1: "132",
        x2: "136",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M184,208H56a36,36,0,0,0,36-36V84a44,44,0,0,1,75.11269-31.11271",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      })));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,208a8.00008,8.00008,0,0,1-8,8H56a8,8,0,0,1,0-16,28.03146,28.03146,0,0,0,28-28V140H56a8,8,0,0,1,0-16H84V84a52,52,0,0,1,88.76953-36.76953A8.00018,8.00018,0,0,1,161.45508,58.544,35.99961,35.99961,0,0,0,100,84v40h36a8,8,0,0,1,0,16H100v32a43.79772,43.79772,0,0,1-10.083,28H184A8.00008,8.00008,0,0,1,192,208Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("line", {
        x1: "56",
        y1: "132",
        x2: "136",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M184,208H56a36,36,0,0,0,36-36V84a44,44,0,0,1,75.11269-31.11271",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      })));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("line", {
        x1: "56",
        y1: "132",
        x2: "136",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M184,208H56a36,36,0,0,0,36-36V84a44,44,0,0,1,75.11269-31.11271",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      })));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("line", {
        x1: "56",
        y1: "132",
        x2: "136",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M184,208H56a36,36,0,0,0,36-36V84a44,44,0,0,1,75.11269-31.11271",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      })));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CurrencyGbp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$40(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CurrencyGbp.displayName = "CurrencyGbp";

var renderPathFor$41 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "72",
        y1: "80",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "40",
        x2: "200",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M108,40a52,52,0,0,1,0,104H72l88,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "72",
        y1: "80",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "40",
        x2: "200",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M108,40a52,52,0,0,1,0,104H72l88,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,80a8.00039,8.00039,0,0,1-8,8H167.85156c.08789,1.32373.14844,2.65454.14844,4a60.06812,60.06812,0,0,1-60,60H92.69238l72.68946,66.08008a8.0006,8.0006,0,0,1-10.76368,11.83984l-88-80A8.0004,8.0004,0,0,1,72,136h36a44.04978,44.04978,0,0,0,44-44c0-1.34912-.0708-2.68164-.18994-4H72a8,8,0,0,1,0-16h75.17188A44.03678,44.03678,0,0,0,108,48H72a8,8,0,0,1,0-16H200a8,8,0,0,1,0,16H148.73535a60.16006,60.16006,0,0,1,15.82422,24H200A8.00039,8.00039,0,0,1,208,80Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "72",
        y1: "80",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "40",
        x2: "200",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M108,40a52,52,0,0,1,0,104H72l88,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "72",
        y1: "80",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "40",
        x2: "200",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M108,40a52,52,0,0,1,0,104H72l88,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "72",
        y1: "80",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "40",
        x2: "200",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M108,40a52,52,0,0,1,0,104H72l88,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CurrencyInr = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$41(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CurrencyInr.displayName = "CurrencyInr";

var renderPathFor$42 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "176",
        x2: "176",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "136",
        x2: "176",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("g", null, React__default.createElement("line", {
        x1: "128",
        y1: "136",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "200 48 128 136 56 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      })));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "168",
        x2: "176",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "136",
        x2: "176",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("g", null, React__default.createElement("line", {
        x1: "128",
        y1: "136",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "200 48 128 136 56 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      })));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M206.19141,53.06592,144.88184,128H176a8,8,0,0,1,0,16H136v16h40a8,8,0,0,1,0,16H136v40a8,8,0,0,1-16,0V176H80a8,8,0,0,1,0-16h40V144H80a8,8,0,0,1,0-16h31.11816L49.80859,53.06592A7.99982,7.99982,0,1,1,62.19141,42.93408L128,123.3667l65.80859-80.43262a7.99982,7.99982,0,1,1,12.38282,10.13184Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "168",
        x2: "176",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "136",
        x2: "176",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("g", null, React__default.createElement("line", {
        x1: "128",
        y1: "136",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "200 48 128 136 56 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      })));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "168",
        x2: "176",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "136",
        x2: "176",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("g", null, React__default.createElement("line", {
        x1: "128",
        y1: "136",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "200 48 128 136 56 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      })));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "168",
        x2: "176",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "136",
        x2: "176",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("g", null, React__default.createElement("line", {
        x1: "128",
        y1: "136",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "200 48 128 136 56 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      })));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CurrencyJpy = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$42(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CurrencyJpy.displayName = "CurrencyJpy";

var renderPathFor$43 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "24 72 76 200 128 72 180 200 232 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "136",
        x2: "240",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "24 72 76 200 128 72 180 200 232 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "152",
        x2: "240",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,144H211.38525l6.5-16H240a8,8,0,0,0,0-16H224.38525l15.02686-36.98926a8.00025,8.00025,0,0,0-14.82422-6.02148L207.11475,112h-54.2295L135.41211,68.98926a8.00039,8.00039,0,0,0-14.82422,0L103.11475,112H48.88525L31.41211,68.98926a8.00025,8.00025,0,0,0-14.82422,6.02148L31.61475,112H16a8,8,0,0,0,0,16H38.11475l6.5,16H16a8,8,0,0,0,0,16H51.11475l17.47314,43.01074a8.00039,8.00039,0,0,0,14.82422,0L100.88525,160h54.2295l17.47314,43.01074a8.00039,8.00039,0,0,0,14.82422,0L204.88525,160H240a8,8,0,0,0,0-16Zm-39.38477-16-6.5,16H165.88477l-6.5-16ZM128,93.25488,135.61523,112H120.38477ZM55.38477,128H96.61523l-6.5,16H61.88477ZM76,178.74512,68.38477,160H83.61523ZM107.38477,144l6.5-16h28.23046l6.5,16ZM180,178.74512,172.38477,160h15.23046Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "24 72 76 200 128 72 180 200 232 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "152",
        x2: "240",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "24 72 76 200 128 72 180 200 232 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "152",
        x2: "240",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "24 72 76 200 128 72 180 200 232 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "152",
        x2: "240",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "120",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CurrencyKrw = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$43(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CurrencyKrw.displayName = "CurrencyKrw";

var renderPathFor$44 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "56",
        y1: "184",
        x2: "144",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,216V40h60a52,52,0,0,1,0,104H56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "144",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,216V40h60a52,52,0,0,1,0,104H56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M148,152a60,60,0,0,0,0-120H88a8.00039,8.00039,0,0,0-8,8v96H56a8,8,0,0,0,0,16H80v16H56a8,8,0,0,0,0,16H80v32a8,8,0,0,0,16,0V184h48a8,8,0,0,0,0-16H96V152ZM96,48h52a44,44,0,0,1,0,88H96Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "144",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,216V40h60a52,52,0,0,1,0,104H56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "144",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,216V40h60a52,52,0,0,1,0,104H56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "144",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,216V40h60a52,52,0,0,1,0,104H56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var CurrencyRub = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$44(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
CurrencyRub.displayName = "CurrencyRub";

var renderPathFor$45 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M38.18466,48.47939l58.21413,155.2377a8,8,0,0,0,15.009-.075L134.729,139.50856a8,8,0,0,1,4.78441-4.7844l64.13348-23.32127a8,8,0,0,0,.07505-15.009L48.48428,38.17977A8,8,0,0,0,38.18466,48.47939Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "136.59053",
        y1: "136.58564",
        x2: "208.00488",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M38.18466,48.47939l58.21413,155.2377a8,8,0,0,0,15.009-.075L134.729,139.50856a8,8,0,0,1,4.78441-4.7844l64.13348-23.32127a8,8,0,0,0,.07505-15.009L48.48428,38.17977A8,8,0,0,0,38.18466,48.47939Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M38.18466,48.47939l58.21413,155.2377a8,8,0,0,0,15.009-.075L134.729,139.50856a8,8,0,0,1,4.78441-4.7844l64.13348-23.32127a8,8,0,0,0,.07505-15.009L48.48428,38.17977A8,8,0,0,0,38.18466,48.47939Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136.59053",
        y1: "136.58564",
        x2: "208.00488",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M150.54443,139.22559l55.83594-20.30469a15.99964,15.99964,0,0,0,.15039-30.01758L51.29346,30.68945A15.99937,15.99937,0,0,0,30.69482,51.28906v-.00049L88.90869,206.52588a15.85524,15.85524,0,0,0,14.97656,10.38232h.084a15.86,15.86,0,0,0,14.957-10.53222L139.23047,150.54l63.11767,63.11719a8.00053,8.00053,0,0,0,11.31446-11.31446Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M38.18466,48.47939l58.21413,155.2377a8,8,0,0,0,15.009-.075L134.729,139.50856a8,8,0,0,1,4.78441-4.7844l64.13348-23.32127a8,8,0,0,0,.07505-15.009L48.48428,38.17977A8,8,0,0,0,38.18466,48.47939Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "136.59053",
        y1: "136.58564",
        x2: "208.00488",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M38.18466,48.47939l58.21413,155.2377a8,8,0,0,0,15.009-.075L134.729,139.50856a8,8,0,0,1,4.78441-4.7844l64.13348-23.32127a8,8,0,0,0,.07505-15.009L48.48428,38.17977A8,8,0,0,0,38.18466,48.47939Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "136.59053",
        y1: "136.58564",
        x2: "208.00488",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M38.18466,48.47939l58.21413,155.2377a8,8,0,0,0,15.009-.075L134.729,139.50856a8,8,0,0,1,4.78441-4.7844l64.13348-23.32127a8,8,0,0,0,.07505-15.009L48.48428,38.17977A8,8,0,0,0,38.18466,48.47939Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136.59053",
        y1: "136.58564",
        x2: "208.00488",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Cursor = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$45(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Cursor.displayName = "Cursor";

var renderPathFor$46 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "80",
        rx: "88",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M40,80v48c0,26.50967,39.39894,48,88,48s88-21.49033,88-48V80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M40,128v48c0,26.50967,39.39894,48,88,48s88-21.49033,88-48V128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "80",
        rx: "88",
        ry: "48",
        opacity: "0.2"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "80",
        rx: "88",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M40,80v48c0,26.50967,39.39894,48,88,48s88-21.49033,88-48V80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M40,128v48c0,26.50967,39.39894,48,88,48s88-21.49033,88-48V128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24C74.168,24,32,48.59814,32,80v96c0,31.40186,42.168,56,96,56s96-24.59814,96-56V80C224,48.59814,181.832,24,128,24Zm80,104c0,9.61719-7.875,19.42871-21.60547,26.918C170.92822,163.354,150.18994,168,128,168s-42.92822-4.646-58.39453-13.082C55.875,147.42871,48,137.61719,48,128V111.35645C65.05994,126.3208,94.234,136,128,136s62.94006-9.6792,80-24.64355Zm-21.60547,74.918C170.92822,211.354,150.19043,216,128,216s-42.92822-4.646-58.39453-13.082C55.875,195.42871,48,185.61719,48,176V159.35645C65.05994,174.3208,94.234,184,128,184s62.94006-9.6792,80-24.64355V176C208,185.61719,200.125,195.42871,186.39453,202.918Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "80",
        rx: "88",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M40,80v48c0,26.50967,39.39894,48,88,48s88-21.49033,88-48V80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M40,128v48c0,26.50967,39.39894,48,88,48s88-21.49033,88-48V128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "80",
        rx: "88",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M40,80v48c0,26.50967,39.39894,48,88,48s88-21.49033,88-48V80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M40,128v48c0,26.50967,39.39894,48,88,48s88-21.49033,88-48V128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "80",
        rx: "88",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M40,80v48c0,26.50967,39.39894,48,88,48s88-21.49033,88-48V80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M40,128v48c0,26.50967,39.39894,48,88,48s88-21.49033,88-48V128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Database = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$46(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Database.displayName = "Database";

var renderPathFor$47 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "140",
        rx: "16",
        transform: "translate(256 236) rotate(180)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "148",
        x2: "224",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,152V64A16,16,0,0,1,48,48H208a16,16,0,0,1,16,16v88Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "152",
        x2: "224",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,40H48A24.0275,24.0275,0,0,0,24,64V176a24.0275,24.0275,0,0,0,24,24h72v16H96a8,8,0,0,0,0,16h64a8,8,0,0,0,0-16H136V200h72a24.0275,24.0275,0,0,0,24-24V64A24.0275,24.0275,0,0,0,208,40Zm0,144H48a8.00917,8.00917,0,0,1-8-8V160H216v16A8.00917,8.00917,0,0,1,208,184Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "152",
        x2: "224",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "152",
        x2: "224",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "152",
        x2: "224",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Desktop = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$47(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Desktop.displayName = "Desktop";

var renderPathFor$48 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M108,180H32a16,16,0,0,1-16-16V96A16,16,0,0,1,32,80h76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "108",
        y1: "216",
        x2: "68",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "204",
        y1: "76",
        x2: "180",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "204",
        y1: "112",
        x2: "180",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "144",
        y: "40",
        width: "96",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "180",
        x2: "88",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "144",
        y: "40",
        width: "96",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M112,184H32a16,16,0,0,1-16-16V96A16,16,0,0,1,32,80h80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "216",
        x2: "64",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "72",
        x2: "176",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "104",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "144",
        y: "40",
        width: "96",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "184",
        x2: "88",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120,80V184a8.00008,8.00008,0,0,1-8,8H96v16h16a8,8,0,0,1,0,16H64a8,8,0,0,1,0-16H80V192H32A24.0275,24.0275,0,0,1,8,168V96A24.0275,24.0275,0,0,1,32,72h80A8.00008,8.00008,0,0,1,120,80ZM248,48V208a16.01833,16.01833,0,0,1-16,16H152a16.01833,16.01833,0,0,1-16-16V48a16.01833,16.01833,0,0,1,16-16h80A16.01833,16.01833,0,0,1,248,48ZM204,180a12,12,0,1,0-12,12A12.01343,12.01343,0,0,0,204,180Zm20-76a8.00008,8.00008,0,0,0-8-8H168a8,8,0,0,0,0,16h48A8.00008,8.00008,0,0,0,224,104Zm0-32a8.00008,8.00008,0,0,0-8-8H168a8,8,0,0,0,0,16h48A8.00008,8.00008,0,0,0,224,72Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M112,184H32a16,16,0,0,1-16-16V96A16,16,0,0,1,32,80h80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "216",
        x2: "64",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "72",
        x2: "176",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "104",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "144",
        y: "40",
        width: "96",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "184",
        x2: "88",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M112,184H32a16,16,0,0,1-16-16V96A16,16,0,0,1,32,80h80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "216",
        x2: "64",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "72",
        x2: "176",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "104",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "144",
        y: "40",
        width: "96",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "184",
        x2: "88",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M112,184H32a16,16,0,0,1-16-16V96A16,16,0,0,1,32,80h80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "216",
        x2: "64",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "72",
        x2: "176",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "104",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "144",
        y: "40",
        width: "96",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "184",
        x2: "88",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DesktopTower = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$48(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DesktopTower.displayName = "DesktopTower";

var renderPathFor$49 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "64",
        y: "24",
        width: "128",
        height: "208",
        rx: "16",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "64",
        x2: "192",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "192",
        x2: "192",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "64",
        y: "56",
        width: "128",
        height: "144",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "64",
        y: "24",
        width: "128",
        height: "208",
        rx: "16",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "56",
        x2: "192",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "200",
        x2: "192",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,16H80A24.0275,24.0275,0,0,0,56,40V216a24.0275,24.0275,0,0,0,24,24h96a24.0275,24.0275,0,0,0,24-24V40A24.0275,24.0275,0,0,0,176,16ZM80,32h96a8.00917,8.00917,0,0,1,8,8v8H72V40A8.00917,8.00917,0,0,1,80,32Zm96,192H80a8.00917,8.00917,0,0,1-8-8v-8H184v8A8.00917,8.00917,0,0,1,176,224Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "64",
        y: "24",
        width: "128",
        height: "208",
        rx: "16",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "56",
        x2: "192",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "200",
        x2: "192",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "64",
        y: "24",
        width: "128",
        height: "208",
        rx: "16",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "56",
        x2: "192",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "200",
        x2: "192",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "64",
        y: "24",
        width: "128",
        height: "208",
        rx: "16",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "56",
        x2: "192",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "200",
        x2: "192",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DeviceMobile = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$49(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DeviceMobile.displayName = "DeviceMobile";

var renderPathFor$4a = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,16H80A24.0275,24.0275,0,0,0,56,40V216a24.0275,24.0275,0,0,0,24,24h96a24.0275,24.0275,0,0,0,24-24V40A24.0275,24.0275,0,0,0,176,16ZM128,72a12,12,0,1,1,12-12A12,12,0,0,1,128,72Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DeviceMobileCamera = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4a(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DeviceMobileCamera.displayName = "DeviceMobileCamera";

var renderPathFor$4b = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "64",
        x2: "152",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "56",
        x2: "160",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,16H80A24.0275,24.0275,0,0,0,56,40V216a24.0275,24.0275,0,0,0,24,24h96a24.0275,24.0275,0,0,0,24-24V40A24.0275,24.0275,0,0,0,176,16ZM160,64H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "56",
        x2: "160",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "56",
        x2: "160",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "64",
        width: "208",
        height: "128",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "56",
        x2: "160",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DeviceMobileSpeaker = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4b(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DeviceMobileSpeaker.displayName = "DeviceMobileSpeaker";

var renderPathFor$4c = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "72",
        x2: "208",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "184",
        x2: "208",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48",
        y: "64",
        width: "160",
        height: "128",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "64",
        x2: "208",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "192",
        x2: "208",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,24H64A24.0275,24.0275,0,0,0,40,48V208a24.0275,24.0275,0,0,0,24,24H192a24.0275,24.0275,0,0,0,24-24V48A24.0275,24.0275,0,0,0,192,24ZM64,40H192a8.00917,8.00917,0,0,1,8,8v8H56V48A8.00917,8.00917,0,0,1,64,40ZM192,216H64a8.00917,8.00917,0,0,1-8-8v-8H200v8A8.00917,8.00917,0,0,1,192,216Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "64",
        x2: "208",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "192",
        x2: "208",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "64",
        x2: "208",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "192",
        x2: "208",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "64",
        x2: "208",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "192",
        x2: "208",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DeviceTablet = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4c(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DeviceTablet.displayName = "DeviceTablet";

var renderPathFor$4d = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "76",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,24H64A24.0275,24.0275,0,0,0,40,48V208a24.0275,24.0275,0,0,0,24,24H192a24.0275,24.0275,0,0,0,24-24V48A24.0275,24.0275,0,0,0,192,24ZM128,80a12,12,0,1,1,12-12A12,12,0,0,1,128,80Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "68",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DeviceTabletCamera = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4d(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DeviceTabletCamera.displayName = "DeviceTabletCamera";

var renderPathFor$4e = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "72",
        x2: "160",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "64",
        x2: "160",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,24H64A24.0275,24.0275,0,0,0,40,48V208a24.0275,24.0275,0,0,0,24,24H192a24.0275,24.0275,0,0,0,24-24V48A24.0275,24.0275,0,0,0,192,24ZM160,72H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "64",
        x2: "160",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "64",
        x2: "160",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "64",
        x2: "160",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DeviceTabletSpeaker = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4e(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DeviceTabletSpeaker.displayName = "DeviceTabletSpeaker";

var renderPathFor$4f = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48.80404",
        y: "48.80404",
        width: "158.39192",
        height: "158.39192",
        rx: "8",
        transform: "translate(-53.01934 128) rotate(-45)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48.80404",
        y: "48.80404",
        width: "158.39192",
        height: "158.39192",
        rx: "8",
        transform: "translate(-53.01934 128) rotate(-45)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "48.80404",
        y: "48.80404",
        width: "158.39192",
        height: "158.39192",
        rx: "8",
        transform: "translate(-53.01934 128) rotate(-45)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,116.68652,139.31348,16a16.01779,16.01779,0,0,0-22.627,0L16,116.68652a16.01779,16.01779,0,0,0,0,22.627L116.68652,240a16.01779,16.01779,0,0,0,22.627,0L240,139.31348A16.01779,16.01779,0,0,0,240,116.68652Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48.80404",
        y: "48.80404",
        width: "158.39192",
        height: "158.39192",
        rx: "8",
        transform: "translate(-53.01934 128) rotate(-45)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48.80404",
        y: "48.80404",
        width: "158.39192",
        height: "158.39192",
        rx: "8",
        transform: "translate(-53.01934 128) rotate(-45)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48.80404",
        y: "48.80404",
        width: "158.39192",
        height: "158.39192",
        rx: "8",
        transform: "translate(-53.01934 128) rotate(-45)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Diamond = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4f(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Diamond.displayName = "Diamond";

var renderPathFor$4g = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "88",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "88",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,32H64A32.03667,32.03667,0,0,0,32,64V192a32.03667,32.03667,0,0,0,32,32H192a32.03667,32.03667,0,0,0,32-32V64A32.03667,32.03667,0,0,0,192,32ZM92,176a12,12,0,1,1,12-12A12,12,0,0,1,92,176Zm0-72a12,12,0,1,1,12-12A12,12,0,0,1,92,104Zm36,36a12,12,0,1,1,12-12A12,12,0,0,1,128,140Zm36,36a12,12,0,1,1,12-12A12,12,0,0,1,164,176Zm0-72a12,12,0,1,1,12-12A12,12,0,0,1,164,104Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DiceFive = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4g(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DiceFive.displayName = "DiceFive";

var renderPathFor$4h = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "96",
        cy: "96",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "96",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "96",
        cy: "160",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "160",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,32H64A32.03667,32.03667,0,0,0,32,64V192a32.03667,32.03667,0,0,0,32,32H192a32.03667,32.03667,0,0,0,32-32V64A32.03667,32.03667,0,0,0,192,32ZM100,168a12,12,0,1,1,12-12A12,12,0,0,1,100,168Zm0-56a12,12,0,1,1,12-12A12,12,0,0,1,100,112Zm56,56a12,12,0,1,1,12-12A12,12,0,0,1,156,168Zm0-56a12,12,0,1,1,12-12A12,12,0,0,1,156,112Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "156",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DiceFour = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4h(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DiceFour.displayName = "DiceFour";

var renderPathFor$4i = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,32H64A32.03667,32.03667,0,0,0,32,64V192a32.03667,32.03667,0,0,0,32,32H192a32.03667,32.03667,0,0,0,32-32V64A32.03667,32.03667,0,0,0,192,32ZM128,140a12,12,0,1,1,12-12A12,12,0,0,1,128,140Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DiceOne = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4i(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DiceOne.displayName = "DiceOne";

var renderPathFor$4j = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "96",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "96",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "96",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,32H64A32.03667,32.03667,0,0,0,32,64V192a32.03667,32.03667,0,0,0,32,32H192a32.03667,32.03667,0,0,0,32-32V64A32.03667,32.03667,0,0,0,192,32ZM92,184a12,12,0,1,1,12-12A12,12,0,0,1,92,184Zm0-44a12,12,0,1,1,12-12A12,12,0,0,1,92,140Zm0-44a12,12,0,1,1,12-12A12,12,0,0,1,92,96Zm72,88a12,12,0,1,1,12-12A12,12,0,0,1,164,184Zm0-44a12,12,0,1,1,12-12A12,12,0,0,1,164,140Zm0-44a12,12,0,1,1,12-12A12,12,0,0,1,164,96Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DiceSix = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4j(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DiceSix.displayName = "DiceSix";

var renderPathFor$4k = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "88",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,32H64A32.03667,32.03667,0,0,0,32,64V192a32.03667,32.03667,0,0,0,32,32H192a32.03667,32.03667,0,0,0,32-32V64A32.03667,32.03667,0,0,0,192,32ZM92,104a12,12,0,1,1,12-12A12,12,0,0,1,92,104Zm36,36a12,12,0,1,1,12-12A12,12,0,0,1,128,140Zm36,36a12,12,0,1,1,12-12A12,12,0,0,1,164,176Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DiceThree = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4k(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DiceThree.displayName = "DiceThree";

var renderPathFor$4l = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "104",
        cy: "104",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "152",
        cy: "152",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "108",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "148",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,32H64A32.03667,32.03667,0,0,0,32,64V192a32.03667,32.03667,0,0,0,32,32H192a32.03667,32.03667,0,0,0,32-32V64A32.03667,32.03667,0,0,0,192,32Zm-84,88a12,12,0,1,1,12-12A12,12,0,0,1,108,120Zm40,40a12,12,0,1,1,12-12A12,12,0,0,1,148,160Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "108",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "148",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "108",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "148",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "108",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "148",
        cy: "148",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DiceTwo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4l(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DiceTwo.displayName = "DiceTwo";

var renderPathFor$4m = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "60.11775",
        x2: "150.62742",
        y2: "105.37258",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M160,128a32,32,0,1,1-9.3726-22.62743h0l45.25483-45.25483h0A96,96,0,1,0,224,128Z"
      })), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "60.11775",
        x2: "150.62742",
        y2: "105.37258",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M202.16113,55.16748A7.401,7.401,0,0,0,200.833,53.8396a104.11084,104.11084,0,1,0,1.32812,1.32788ZM215.63257,120h-48.4375a39.77738,39.77738,0,0,0-5.83911-14.04236l34.23877-34.23889A87.608,87.608,0,0,1,215.63257,120ZM128,152a24,24,0,1,1,24-24A24.0275,24.0275,0,0,1,128,152Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "60.11775",
        x2: "150.62742",
        y2: "105.37258",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "60.11775",
        x2: "150.62742",
        y2: "105.37258",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "195.88225",
        y1: "60.11775",
        x2: "150.62742",
        y2: "105.37258",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Disc = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4m(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Disc.displayName = "Disc";

var renderPathFor$4n = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "64",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "192",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "64",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "192",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,128a8.00008,8.00008,0,0,1-8,8H40a8,8,0,0,1,0-16H216A8.00008,8.00008,0,0,1,224,128ZM128,80a16,16,0,1,0-16-16A16.01833,16.01833,0,0,0,128,80Zm0,96a16,16,0,1,0,16,16A16.01833,16.01833,0,0,0,128,176Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "64",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "192",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "64",
        r: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "192",
        r: "8"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "64",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "192",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "64",
        r: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "192",
        r: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "64",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "192",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Divide = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4n(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Divide.displayName = "Divide";

var renderPathFor$4o = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "60",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "60",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M60,48A12,12,0,1,0,72,60,12.01375,12.01375,0,0,0,60,48Zm68,0a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,128,48Zm68,24a12,12,0,1,0-12-12A12.01375,12.01375,0,0,0,196,72ZM60,184a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,60,184Zm68,0a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,128,184Zm68,0a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,196,184ZM60,116a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,60,116Zm68,0a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,128,116Zm68,0a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,196,116Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "60",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "60",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "60",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "60",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "196",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DotsNine = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4o(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DotsNine.displayName = "DotsNine";

var renderPathFor$4p = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "64",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "64",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M76,128a12,12,0,1,1-12-12A12.01375,12.01375,0,0,1,76,128Zm116-12a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,192,116Zm-64,0a12,12,0,1,0,12,12A12.01375,12.01375,0,0,0,128,116Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "64",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "64",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "64",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DotsThree = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4p(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DotsThree.displayName = "DotsThree";

var renderPathFor$4q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "80",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "80",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24ZM80,140a12,12,0,1,1,12-12A12.0006,12.0006,0,0,1,80,140Zm48,0a12,12,0,1,1,12-12A12.0006,12.0006,0,0,1,128,140Zm48,0a12,12,0,1,1,12-12A12.0006,12.0006,0,0,1,176,140Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "80",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "80",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "80",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DotsThreeCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DotsThreeCircle.displayName = "DotsThreeCircle";

var renderPathFor$4r = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232,128A104,104,0,1,0,128,232,104.12041,104.12041,0,0,0,232,128ZM116,80a12,12,0,1,1,12,12A12.0006,12.0006,0,0,1,116,80Zm0,48a12,12,0,1,1,12,12A12.0006,12.0006,0,0,1,116,128Zm0,48a12,12,0,1,1,12,12A12.0006,12.0006,0,0,1,116,176Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DotsThreeCircleVertical = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4r(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DotsThreeCircleVertical.displayName = "DotsThreeCircleVertical";

var renderPathFor$4s = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "208",
        cy: "128",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "48",
        cy: "128",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "24",
        opacity: "0.1"
      }), React__default.createElement("circle", {
        cx: "48",
        cy: "128",
        r: "24",
        opacity: "0.1"
      }), React__default.createElement("circle", {
        cx: "208",
        cy: "128",
        r: "24",
        opacity: "0.1"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "48",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "208",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32"
      }), React__default.createElement("circle", {
        cx: "48",
        cy: "128",
        r: "32"
      }), React__default.createElement("circle", {
        cx: "208",
        cy: "128",
        r: "32"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "48",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "208",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "48",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "208",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "48",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "208",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DotsThreeOutline = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4s(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DotsThreeOutline.displayName = "DotsThreeOutline";

var renderPathFor$4t = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "48",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "208",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "24",
        opacity: "0.1"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "48",
        r: "24",
        opacity: "0.1"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "208",
        r: "24",
        opacity: "0.1"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "48",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "208",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "48",
        r: "32"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "208",
        r: "32"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "48",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "208",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "48",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "208",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "48",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "208",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DotsThreeOutlineVertical = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4t(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DotsThreeOutlineVertical.displayName = "DotsThreeOutlineVertical";

var renderPathFor$4u = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "192",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "64",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "192",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "64",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,180a12,12,0,1,1-12,12A12.01375,12.01375,0,0,1,128,180ZM116,64a12,12,0,1,0,12-12A12.01375,12.01375,0,0,0,116,64Zm0,64a12,12,0,1,0,12-12A12.01375,12.01375,0,0,0,116,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "192",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "64",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "192",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "64",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99902",
        cy: "192",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.99902",
        cy: "64",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.99902",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DotsThreeVertical = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4u(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DotsThreeVertical.displayName = "DotsThreeVertical";

var renderPathFor$4v = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "80 80 128 128 176 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M184.56836,128H224a8,8,0,0,1,8,8v64a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8V136a8,8,0,0,1,8-8H71.43164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "128",
        width: "208",
        height: "80",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M176,128h48a8,8,0,0,1,8,8v64a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8V136a8,8,0,0,1,8-8H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "80 80 128 128 176 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M122.34326,133.65723c.02588.02588.05469.04785.08106.07324.16211.15771.32861.31152.50341.45508.09766.08008.20118.15039.30176.22558.1084.08106.21485.165.32764.24073.11621.07812.2373.1455.35693.21679.10449.0625.20655.12793.31446.18555.12011.06445.24414.11914.36669.17676.11426.0542.22657.11084.34327.15967.11816.04882.23925.08837.35937.13134.126.04541.251.09375.37988.13282.11963.03613.24122.063.36231.09326.13184.0332.26269.07031.397.09716.13965.02735.28028.04395.42041.064.11817.01709.23389.03906.353.05078.26269.02588.52588.04.78955.04s.52686-.01416.78955-.04c.11914-.01172.23486-.03369.353-.05078.14013-.02.28076-.03662.42041-.064.13428-.02685.26513-.064.397-.09716.12109-.03028.24268-.05713.36231-.09326.1289-.03907.2539-.08741.37988-.13282.12012-.043.24121-.08252.35937-.13134.1167-.04883.229-.10547.34327-.15967.12255-.05762.24658-.11231.36669-.17676.10791-.05762.21-.12305.31446-.18555.11963-.07129.24072-.13867.35693-.21679.11279-.07569.21924-.15967.32764-.24073.10058-.07519.2041-.1455.30176-.22558.17822-.14649.34765-.30225.51269-.46338.023-.023.04883-.042.07178-.06494l48-48a8.00018,8.00018,0,1,0-11.31348-11.31446L136,108.68652V24a8,8,0,0,0-16,0v84.68652L85.65674,74.34277A8.00018,8.00018,0,0,0,74.34326,85.65723Z"
      }), React__default.createElement("path", {
        d: "M224,120H169.94141L144.9707,144.9707a24.00066,24.00066,0,0,1-33.9414,0L86.05859,120H32a16.01833,16.01833,0,0,0-16,16v64a16.01833,16.01833,0,0,0,16,16H224a16.01833,16.01833,0,0,0,16-16V136A16.01833,16.01833,0,0,0,224,120Zm-35.99951,60a12,12,0,1,1,12-12A12,12,0,0,1,188.00049,180Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,128h48a8,8,0,0,1,8,8v64a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8V136a8,8,0,0,1,8-8H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "80 80 128 128 176 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,128h48a8,8,0,0,1,8,8v64a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8V136a8,8,0,0,1,8-8H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "80 80 128 128 176 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,128h48a8,8,0,0,1,8,8v64a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8V136a8,8,0,0,1,8-8H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "24",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "80 80 128 128 176 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Download = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4v(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Download.displayName = "Download";

var renderPathFor$4w = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "86 110 128 152 170 110",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "39.97056",
        x2: "128",
        y2: "151.97056",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,136v72a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "86 110 128 152 170 110",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "39.97056",
        x2: "128",
        y2: "151.97056",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,136v72a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M122.34326,157.65723a8.00063,8.00063,0,0,0,11.31348,0l42-42a8.00018,8.00018,0,1,0-11.31348-11.31446L136,132.6864V39.9707a8,8,0,1,0-16,0v92.7157L91.65674,104.34277a8.00018,8.00018,0,0,0-11.31348,11.31446Z"
      }), React__default.createElement("path", {
        d: "M224,128a8.00039,8.00039,0,0,0-8,8v72H40V136a8,8,0,0,0-16,0v72a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V136A8.00039,8.00039,0,0,0,224,128Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "86 110 128 152 170 110",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "39.97056",
        x2: "128",
        y2: "151.97056",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,136v72a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "86 110 128 152 170 110",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "39.97056",
        x2: "128",
        y2: "151.97056",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,136v72a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "86 110 128 152 170 110",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "39.97056",
        x2: "128",
        y2: "151.97056",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,136v72a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DownloadSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4w(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DownloadSimple.displayName = "DownloadSimple";

var renderPathFor$4x = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M71.0247,205.27116a159.91145,159.91145,0,0,1,136.98116-77.27311q8.09514,0,15.99054.78906",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M188.0294,53.09083A159.68573,159.68573,0,0,1,64.00586,111.99805a160.8502,160.8502,0,0,1-30.15138-2.83671",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M85.93041,41.68508a159.92755,159.92755,0,0,1,78.99267,138.00723,160.35189,160.35189,0,0,1-4.73107,38.77687",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M71.0247,205.27116a159.91145,159.91145,0,0,1,136.98116-77.27311q8.09514,0,15.99054.78906",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M188.0294,53.09083A159.68573,159.68573,0,0,1,64.00586,111.99805a160.8502,160.8502,0,0,1-30.15138-2.83671",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M85.93041,41.68508a159.92755,159.92755,0,0,1,78.99267,138.00723,160.35189,160.35189,0,0,1-4.73107,38.77687",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232.00342,128.65915c.00146-.22022.0083-.439.0083-.65918a103.83918,103.83918,0,0,0-38.33057-80.58106c-.18408-.18262-.37695-.35888-.582-.52637a8.12111,8.12111,0,0,0-.7085-.51367A103.842,103.842,0,0,0,83.0166,34.24606a8.0373,8.0373,0,0,0-1.27734.63428A104.35855,104.35855,0,0,0,26.03662,107.5444c-.0083.04-.021.07813-.02881.11865-.00732.03809-.00928.07617-.01611.11426A103.9536,103.9536,0,0,0,65.583,211.125a8.02091,8.02091,0,0,0,1.311.99023c.03662.022.0752.03613.11182.05762a103.8479,103.8479,0,0,0,95.25683,14.02539,7.98994,7.98994,0,0,0,1.1919-.4209A104.18006,104.18006,0,0,0,232,128.94186C232.00146,128.84713,232.00488,128.7529,232.00342,128.65915Zm-16.34326-8.48145c-2.54834-.11426-5.10059-.17969-7.64258-.17969a168.47807,168.47807,0,0,0-43.93408,5.83887,166.75984,166.75984,0,0,0-13.46485-29.83545,168.19741,168.19741,0,0,0,38.20264-31.55224A87.80676,87.80676,0,0,1,215.66016,120.1777ZM176.2915,54.46481a152.145,152.145,0,0,1-34.31494,28.05713,169.1832,169.1832,0,0,0-38.63281-38.998A87.90076,87.90076,0,0,1,176.2915,54.46481ZM85.66016,50.88327a153.04813,153.04813,0,0,1,42.03222,39.1792A151.82346,151.82346,0,0,1,64.01758,103.998a153.98693,153.98693,0,0,1-20.27735-1.35107A88.414,88.414,0,0,1,85.66016,50.88327ZM40.01172,128a88.58228,88.58228,0,0,1,.52978-9.63526,169.97006,169.97006,0,0,0,23.47608,1.6333,167.76959,167.76959,0,0,0,72.52051-16.39795,150.78511,150.78511,0,0,1,12.3164,27.13477,166.5083,166.5083,0,0,0-24.59277,11.59912A169.09239,169.09239,0,0,0,69.18994,193.393,87.79837,87.79837,0,0,1,40.01172,128Zm42.00244,74.99121A153.04128,153.04128,0,0,1,132.249,156.19772a150.44232,150.44232,0,0,1,20.94971-9.98144,152.47261,152.47261,0,0,1,3.73584,33.47607A152.93446,152.93446,0,0,1,153.4375,212.25a87.90959,87.90959,0,0,1-71.42334-9.25879Zm89.05762,1.72949a169.55889,169.55889,0,0,0,1.86279-25.02832,168.49829,168.49829,0,0,0-4.45215-38.4751,152.48818,152.48818,0,0,1,39.53516-5.21924c2.53125,0,5.07422.063,7.61035.188A88.1393,88.1393,0,0,1,171.07178,204.72067Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M71.0247,205.27116a159.91145,159.91145,0,0,1,136.98116-77.27311q8.09514,0,15.99054.78906",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M188.0294,53.09083A159.68573,159.68573,0,0,1,64.00586,111.99805a160.8502,160.8502,0,0,1-30.15138-2.83671",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M85.93041,41.68508a159.92755,159.92755,0,0,1,78.99267,138.00723,160.35189,160.35189,0,0,1-4.73107,38.77687",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M71.0247,205.27116a159.91145,159.91145,0,0,1,136.98116-77.27311q8.09514,0,15.99054.78906",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M188.0294,53.09083A159.68573,159.68573,0,0,1,64.00586,111.99805a160.8502,160.8502,0,0,1-30.15138-2.83671",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M85.93041,41.68508a159.92755,159.92755,0,0,1,78.99267,138.00723,160.35189,160.35189,0,0,1-4.73107,38.77687",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M71.0247,205.27116a159.91145,159.91145,0,0,1,136.98116-77.27311q8.09514,0,15.99054.78906",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M188.0294,53.09083A159.68573,159.68573,0,0,1,64.00586,111.99805a160.8502,160.8502,0,0,1-30.15138-2.83671",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M85.93041,41.68508a159.92755,159.92755,0,0,1,78.99267,138.00723,160.35189,160.35189,0,0,1-4.73107,38.77687",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DribbbleLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4x(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DribbbleLogo.displayName = "DribbbleLogo";

var renderPathFor$4y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M168,152a40,40,0,0,1-40,40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,152a48,48,0,0,1-48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M174.03662,55.75049a254.574,254.574,0,0,0-41.44873-38.3042,7.99885,7.99885,0,0,0-9.17578,0,254.574,254.574,0,0,0-41.44873,38.3042C54.51074,87.3208,40,120.60352,40,152a88,88,0,0,0,176,0C216,120.60352,201.48926,87.3208,174.03662,55.75049ZM128,208a8,8,0,0,1,0-16,40.04521,40.04521,0,0,0,40-40,8,8,0,0,1,16,0A56.06353,56.06353,0,0,1,128,208Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M176,152a48,48,0,0,1-48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M176,152a48,48,0,0,1-48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,152a48,48,0,0,1-48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Drop = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Drop.displayName = "Drop";

var renderPathFor$4z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "127.99999",
        y1: "87.99999",
        x2: "206.65864",
        y2: "166.65864",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "127.99999",
        y1: "147.99999",
        x2: "186.53165",
        y2: "206.53165",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,232a80,80,0,0,0,80-80c0-72-80-128-80-128Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,232a80,80,0,0,0,80-80c0-72-80-128-80-128Z"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.99999",
        y1: "71.99999",
        x2: "208",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.99999",
        y1: "119.99999",
        x2: "198.26945",
        y2: "190.26945",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("g", null, React__default.createElement("line", {
        x1: "127.99999",
        y1: "167.99999",
        x2: "176.00281",
        y2: "216.00281",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.99999",
        y1: "167.99999",
        x2: "176.00281",
        y2: "216.00281",
        fill: "#231f20"
      })));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "127.99999",
        y1: "71.99999",
        x2: "208",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "127.99999",
        y1: "119.99999",
        x2: "198.26945",
        y2: "190.26945",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("g", null, React__default.createElement("line", {
        x1: "127.99999",
        y1: "167.99999",
        x2: "176.00281",
        y2: "216.00281",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "127.99999",
        y1: "167.99999",
        x2: "176.00281",
        y2: "216.00281",
        fill: "#231f20"
      })));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,152c0-72-80-128-80-128S48,80,48,152a80,80,0,0,0,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "232",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99999",
        y1: "71.99999",
        x2: "208",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99999",
        y1: "119.99999",
        x2: "198.26945",
        y2: "190.26945",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("g", null, React__default.createElement("line", {
        x1: "127.99999",
        y1: "167.99999",
        x2: "176.00281",
        y2: "216.00281",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99999",
        y1: "167.99999",
        x2: "176.00281",
        y2: "216.00281",
        fill: "#231f20"
      })));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DropHalf = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DropHalf.displayName = "DropHalf";

var renderPathFor$4A = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.12157,38.3683,45.03989,118.45222A8,8,0,0,0,50.80376,132H205.19624a8,8,0,0,0,5.76387-13.54778L133.87843,38.3683A8,8,0,0,0,122.12157,38.3683Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "108",
        y: "100",
        width: "40",
        height: "176",
        rx: "8",
        transform: "translate(-60 316) rotate(-90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.12157,38.3683,44.39345,122.57376A8,8,0,0,0,50.27188,136H205.72812a8,8,0,0,0,5.87843-13.42624L133.87843,38.3683A8,8,0,0,0,122.12157,38.3683Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "108",
        y: "100",
        width: "40",
        height: "176",
        rx: "8",
        transform: "translate(-60 316) rotate(-90)",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M122.12157,38.3683,44.39345,122.57376A8,8,0,0,0,50.27188,136H205.72812a8,8,0,0,0,5.87843-13.42624L133.87843,38.3683A8,8,0,0,0,122.12157,38.3683Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "108",
        y: "100",
        width: "40",
        height: "176",
        rx: "8",
        transform: "translate(-60 316) rotate(-90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M35.61523,134.41724a15.79789,15.79789,0,0,1,2.90039-17.26978l77.72657-84.20532h.001a15.99956,15.99956,0,0,1,23.51368,0l77.72851,84.20532A16.0003,16.0003,0,0,1,205.72852,144H50.27148A15.79772,15.79772,0,0,1,35.61523,134.41724ZM208,160H48a16.01833,16.01833,0,0,0-16,16v24a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V176A16.01833,16.01833,0,0,0,208,160Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.12157,38.3683,44.39345,122.57376A8,8,0,0,0,50.27188,136H205.72812a8,8,0,0,0,5.87843-13.42624L133.87843,38.3683A8,8,0,0,0,122.12157,38.3683Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "108",
        y: "100",
        width: "40",
        height: "176",
        rx: "8",
        transform: "translate(-60 316) rotate(-90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.12157,38.3683,44.39345,122.57376A8,8,0,0,0,50.27188,136H205.72812a8,8,0,0,0,5.87843-13.42624L133.87843,38.3683A8,8,0,0,0,122.12157,38.3683Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "108",
        y: "100",
        width: "40",
        height: "176",
        rx: "8",
        transform: "translate(-60 316) rotate(-90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.12157,38.3683,44.39345,122.57376A8,8,0,0,0,50.27188,136H205.72812a8,8,0,0,0,5.87843-13.42624L133.87843,38.3683A8,8,0,0,0,122.12157,38.3683Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "108",
        y: "100",
        width: "40",
        height: "176",
        rx: "8",
        transform: "translate(-60 316) rotate(-90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Eject = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4A(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Eject.displayName = "Eject";

var renderPathFor$4B = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 56 128 144 32 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,56H224a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V56A0,0,0,0,1,32,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "110.54541",
        y1: "128.00013",
        x2: "34.4668",
        y2: "197.73926",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "221.53418",
        y1: "197.73926",
        x2: "145.45424",
        y2: "127.99964",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "224.006 56 128.006 144 32.006 56 224.006 56",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "224 56 128 144 32 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,56H224a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V56A0,0,0,0,1,32,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "110.54541",
        y1: "128.00013",
        x2: "34.4668",
        y2: "197.73926",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "221.53418",
        y1: "197.73926",
        x2: "145.45424",
        y2: "127.99964",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M231.99023,55.80933q-.00511-.22192-.02246-.44312-.01391-.18054-.03564-.35864c-.01709-.13819-.03858-.27564-.063-.41309-.022-.124-.0459-.24707-.07324-.36889-.02979-.13038-.064-.25953-.1001-.38843-.03467-.12329-.07031-.24536-.11035-.366-.042-.126-.08887-.25-.13721-.374-.0459-.11865-.09326-.23609-.14453-.35156-.05469-.12207-.11377-.24195-.17432-.36158-.05761-.11352-.11669-.22583-.17919-.33618-.06543-.114-.13428-.22607-.20508-.33765-.07178-.11254-.14551-.2229-.22266-.33154-.07226-.10229-.148-.20263-.22558-.30224-.0879-.11206-.17872-.221-.272-.32813-.04394-.05054-.082-.10425-.12744-.154-.03857-.042-.08105-.07764-.1206-.11865-.0962-.10108-.19629-.198-.29786-.29395-.09423-.08887-.189-.177-.28662-.26074-.09619-.082-.19531-.15967-.29541-.23731-.10937-.085-.21826-.16919-.33105-.24755-.09766-.06812-.19873-.13135-.29932-.19507-.11914-.0752-.23779-.15015-.35986-.21851-.10645-.05957-.21582-.11352-.32471-.16821-.1206-.0603-.24023-.1211-.36328-.175-.11963-.05274-.24219-.09863-.36475-.14551-.11767-.04492-.23486-.09057-.354-.12964-.12939-.04272-.26172-.07837-.39355-.1145-.11866-.03223-.23633-.0647-.35547-.09131-.13184-.02954-.26563-.05273-.39991-.07568-.12646-.02149-.25293-.04248-.38037-.05786-.12646-.01538-.2539-.02564-.38232-.03491-.13965-.01026-.2793-.01832-.41943-.02125C224.1123,48.00732,224.05713,48,224,48H32c-.05371,0-.10547.00708-.15918.00806-.14746.00293-.29492.01123-.44189.02221-.12159.00928-.24219.0188-.36182.03321-.13428.01611-.26758.03808-.40137.06128-.12744.022-.25488.0437-.37988.07177-.126.02808-.25.06226-.375.09644-.126.03467-.25195.0686-.37549.10913-.125.041-.248.08862-.37158.136-.1167.04492-.23389.08886-.34815.13891-.12744.05591-.252.1189-.377.18189-.105.05273-.21.10424-.312.16137-.125.07007-.24707.147-.36914.22437-.09766.062-.19629.12353-.291.1897-.11474.07959-.22558.165-.33642.25146-.09864.07642-.19629.15308-.291.23413-.09863.08423-.19385.17285-.28955.26294-.10107.09522-.20019.1919-.29639.29224-.03906.04126-.082.07715-.1206.11914-.04541.0498-.0835.10351-.12744.154-.09326.10718-.18408.21607-.272.32813-.07763.09961-.15332.2-.22558.30224-.07715.10864-.15088.219-.22266.33154-.0708.11158-.13965.22364-.20508.33765-.0625.11035-.12158.22266-.17919.33618-.06055.11963-.11963.23951-.17432.36158-.05127.11547-.09863.23291-.14453.35156-.04834.124-.09522.248-.13721.374-.04.12061-.07568.24268-.11035.366-.03613.1289-.07031.25805-.1001.38843-.02734.12182-.05127.24487-.07324.36889-.02441.13745-.0459.2749-.063.41309q-.022.17834-.03564.35864-.01758.22156-.02246.44312C24.0083,55.87329,24,55.93555,24,56V192a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V56C232,55.93555,231.9917,55.87329,231.99023,55.80933ZM40,74.18628l58.70605,53.814L40,181.814ZM52.56738,192l57.97852-53.14673,12.04785,11.04395a8.00113,8.00113,0,0,0,10.8125,0L145.45459,138.853,203.43311,192ZM157.294,128l58.70751-53.81519.00782,107.63672Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 56 128 144 32 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,56H224a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V56A0,0,0,0,1,32,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "110.54541",
        y1: "128.00013",
        x2: "34.4668",
        y2: "197.73926",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "221.53418",
        y1: "197.73926",
        x2: "145.45424",
        y2: "127.99964",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 56 128 144 32 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,56H224a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V56A0,0,0,0,1,32,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "110.54541",
        y1: "128.00013",
        x2: "34.4668",
        y2: "197.73926",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "221.53418",
        y1: "197.73926",
        x2: "145.45424",
        y2: "127.99964",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "224 56 128 144 32 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,56H224a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V56A0,0,0,0,1,32,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "110.54541",
        y1: "128.00013",
        x2: "34.4668",
        y2: "197.73926",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "221.53418",
        y1: "197.73926",
        x2: "145.45424",
        y2: "127.99964",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Envelope = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4B(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Envelope.displayName = "Envelope";

var renderPathFor$4C = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,96V200a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V96l96-64Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "110.54541",
        y1: "152.00008",
        x2: "34.4668",
        y2: "205.73921",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "221.53418",
        y1: "205.73921",
        x2: "145.45424",
        y2: "151.99959",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "224 96 145.455 152 110.545 152 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "224 96 145.455 152 110.545 152 32 96 128 32 224 96",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M32,96V200a8,8,0,0,0,8,8H216a8,8,0,0,0,8-8V96L128,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "110.54541",
        y1: "152.00008",
        x2: "34.4668",
        y2: "205.73921",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "221.53418",
        y1: "205.73921",
        x2: "145.45424",
        y2: "151.99959",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 96 145.455 152 110.545 152 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M231.99512,95.92334a7.926,7.926,0,0,0-.22608-1.8147c-.0166-.06909-.03759-.13672-.05615-.20532q-.09154-.33618-.2124-.666c-.03028-.08129-.061-.16186-.09326-.24218-.0835-.20459-.17725-.40625-.27832-.606-.03955-.07764-.07618-.15625-.11768-.23267-.11914-.21679-.25146-.429-.39307-.63745-.03125-.04614-.05761-.09521-.08984-.14062l-.01465-.023a8.19273,8.19273,0,0,0-.55469-.6897c-.04345-.04834-.0913-.09228-.13574-.13965-.16845-.17944-.34228-.35083-.52344-.51172-.061-.05371-.124-.10473-.18652-.15673q-.27686-.23071-.56933-.43311c-.03711-.02563-.06934-.05591-.10645-.08081l-96-64a8.00131,8.00131,0,0,0-8.875,0l-96,64c-.03613.02393-.06689.05322-.102.07764q-.29736.20508-.57666.43847c-.061.05078-.12256.10035-.18164.15284-.18311.16235-.35889.3352-.52832.5166-.04346.0459-.08985.08886-.13233.13574a8.114,8.114,0,0,0-.55517.69043l-.01465.023c-.03223.04541-.05859.09448-.08984.14062-.14161.2085-.27393.42066-.39307.63745-.0415.07642-.07813.155-.11768.23267-.10107.19971-.19482.40137-.27832.606-.03222.08032-.063.16089-.09326.24218q-.12157.33-.2124.666c-.01856.0686-.03955.13623-.05615.20532a7.926,7.926,0,0,0-.22608,1.8147C24.00439,95.94922,24,95.97412,24,96V200a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V96C232,95.97412,231.99561,95.94922,231.99512,95.92334ZM40,111.52881l56.72266,40.44092L40,192.03662ZM113.08594,160h29.82812L199.543,200H56.45752Zm46.1914-8.03027L216,111.52881v80.50732Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,96V200a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V96l96-64Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "110.54541",
        y1: "152.00008",
        x2: "34.4668",
        y2: "205.73921",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "221.53418",
        y1: "205.73921",
        x2: "145.45424",
        y2: "151.99959",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "224 96 145.455 152 110.545 152 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,96V200a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V96l96-64Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "110.54541",
        y1: "152.00008",
        x2: "34.4668",
        y2: "205.73921",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "221.53418",
        y1: "205.73921",
        x2: "145.45424",
        y2: "151.99959",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "224 96 145.455 152 110.545 152 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,96V200a8,8,0,0,0,8,8H216a8,8,0,0,0,8-8V96L128,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "110.54541",
        y1: "152.00008",
        x2: "34.4668",
        y2: "205.73921",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "221.53418",
        y1: "205.73921",
        x2: "145.45424",
        y2: "151.99959",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 96 145.455 152 110.545 152 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var EnvelopeOpen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4C(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
EnvelopeOpen.displayName = "EnvelopeOpen";

var renderPathFor$4D = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,56H224a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V56A0,0,0,0,1,32,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "224 56 128 144 32 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "224 56 128 144 32 56 224 56",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M32,56H224a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V56A0,0,0,0,1,32,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 56 128 144 32 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M231.99121,55.80933q-.00513-.22192-.02246-.44312-.01392-.18054-.03564-.35864c-.01709-.13819-.03858-.27564-.063-.41284-.022-.12427-.0459-.24756-.07325-.36963-.02978-.12989-.064-.25855-.0996-.38721-.03467-.12353-.07081-.24634-.11133-.36743-.04151-.12549-.08789-.24927-.13623-.3728-.04639-.1189-.09375-.23682-.14551-.35279-.0542-.12133-.11279-.24072-.17334-.35986-.05811-.11426-.11719-.2273-.18066-.33814-.06446-.11328-.13282-.2246-.20362-.33544-.07178-.11329-.146-.22461-.22363-.334-.07227-.10156-.147-.20117-.22461-.30029-.08838-.11255-.1792-.22193-.273-.32959-.04394-.05029-.08154-.10376-.12695-.15332-.03858-.042-.08106-.07764-.12012-.11841-.09668-.10107-.19678-.19849-.29834-.29443-.09424-.08887-.189-.17676-.28662-.26026-.09619-.08227-.19531-.15991-.29541-.23755-.10938-.085-.21826-.16919-.33106-.24755-.09765-.06812-.19873-.13135-.29931-.19507-.11914-.0752-.23779-.15015-.35938-.21851-.10693-.05981-.21679-.11377-.32666-.16894-.11963-.05982-.23877-.12012-.36084-.17383-.12109-.05347-.2456-.1001-.37011-.14771-.11475-.0437-.2295-.08838-.3462-.12671-.1333-.04394-.269-.08081-.40527-.11767-.11426-.031-.228-.0625-.34326-.08838-.13574-.03027-.27344-.0542-.41162-.07764-.12256-.02075-.24414-.041-.36719-.05615-.13135-.01611-.26318-.02661-.396-.03613-.13476-.00977-.26953-.01758-.40429-.02051-.05908-.00122-.1167-.00879-.17578-.00879h-192c-.05469,0-.10743.00708-.16211.0083-.14551.00293-.29.011-.43506.022-.12354.009-.2461.0188-.36768.03345-.13281.01611-.26465.03784-.39648.06055-.12891.02221-.25781.04443-.38477.07251-.124.02783-.24609.06152-.36914.09521-.12793.03491-.25586.06958-.38135.11084-.124.04053-.24511.08765-.36718.13428-.11768.04541-.23584.0896-.35108.14014-.127.05566-.25146.11865-.37646.18139-.105.05274-.21.10449-.312.16187-.12549.07007-.24756.147-.36963.22436-.09766.06177-.1958.123-.29053.18921-.11475.07984-.22607.16553-.33691.2522-.09864.07642-.19629.15283-.29053.23364-.09863.08423-.19385.17285-.28906.2627-.10157.09546-.20069.19238-.29737.293-.03906.041-.08154.07666-.12011.11865-.04541.04956-.083.103-.127.15332-.09375.10766-.18457.217-.27295.32959-.07763.09912-.15234.19873-.22461.30029-.07763.10938-.15185.2207-.22363.334-.0708.11084-.13916.22216-.20361.33544-.06348.11084-.12256.22388-.18067.33814-.06054.11914-.11914.23853-.17334.35986-.05175.116-.09912.23389-.1455.35279-.04834.12353-.09473.24731-.13623.3728-.04053.12109-.07666.2439-.11133.36743-.03565.12866-.06983.25732-.09961.38721-.02735.12207-.05127.24536-.07324.36963-.02442.1372-.0459.27465-.063.41284q-.022.17834-.03565.35864-.01758.22156-.02246.44312c-.00146.064-.00976.12622-.00976.19067V192a16.01833,16.01833,0,0,0,16,16h176a16.01833,16.01833,0,0,0,16-16V56C232.001,55.93555,231.99268,55.87329,231.99121,55.80933ZM216.001,192h-176V74.18652l82.59375,75.71094a8.0018,8.0018,0,0,0,10.8125,0l82.59521-75.7124.0083,117.81445Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,56H224a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V56A0,0,0,0,1,32,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "224 56 128 144 32 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,56H224a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V56A0,0,0,0,1,32,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "224 56 128 144 32 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,56H224a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V56A0,0,0,0,1,32,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 56 128 144 32 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var EnvelopeSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4D(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
EnvelopeSimple.displayName = "EnvelopeSimple";

var renderPathFor$4E = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,96V200a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V96l96-64Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "224 96 145.455 152 110.545 152 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "224 96 145.455 152 110.545 152 32 96 128 32 224 96",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M32,96V200a8,8,0,0,0,8,8H216a8,8,0,0,0,8-8V96L128,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 96 145.455 152 110.545 152 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M231.99512,95.92334a7.928,7.928,0,0,0-.22608-1.81494c-.0166-.06885-.03759-.13672-.05615-.20508q-.09154-.33618-.2124-.666c-.03028-.08154-.061-.16162-.09326-.24218-.0835-.20459-.17725-.40625-.27832-.606-.03955-.07764-.07618-.15625-.11768-.23242-.11914-.21729-.25146-.4292-.39307-.6377-.03125-.04638-.05761-.09521-.08984-.14062l-.01465-.023a8.1872,8.1872,0,0,0-.55469-.68945c-.04345-.04883-.0913-.09278-.13574-.13965-.16845-.17969-.34228-.35108-.52344-.51172-.061-.0542-.124-.105-.18652-.15723q-.27686-.23-.56933-.4331c-.03711-.02539-.06934-.05567-.10645-.08057l-96-64a8.00131,8.00131,0,0,0-8.875,0l-96,64c-.03613.02393-.06689.05322-.102.07764q-.29736.20508-.57666.43847c-.061.05078-.12256.10059-.18164.15284-.18311.1621-.35889.335-.52832.5166-.04346.0459-.08985.08886-.13233.13574a8.114,8.114,0,0,0-.55517.69043l-.01465.023c-.03223.04541-.05859.09424-.08984.14062-.14161.2085-.27393.42041-.39307.6377-.0415.07617-.07813.15478-.11768.23242-.10107.19971-.19482.40137-.27832.606-.03222.08056-.063.16064-.09326.24218q-.12157.33033-.2124.666c-.01856.06836-.03955.13623-.05615.20508a7.928,7.928,0,0,0-.22608,1.81494C24.00439,95.94922,24,95.97412,24,96V200a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V96C232,95.97412,231.99561,95.94922,231.99512,95.92334ZM40,200V111.52881l65.90137,46.98486A8.00118,8.00118,0,0,0,110.5459,160h34.9082a8.00118,8.00118,0,0,0,4.64453-1.48633L216,111.52881V200Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,96V200a8,8,0,0,0,8,8H216a8,8,0,0,0,8-8V96L128,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "224 96 145.455 152 110.545 152 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,96V200a8,8,0,0,0,8,8H216a8,8,0,0,0,8-8V96L128,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "224 96 145.455 152 110.545 152 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,96V200a8,8,0,0,0,8,8H216a8,8,0,0,0,8-8V96L128,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "224 96 145.455 152 110.545 152 32 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var EnvelopeSimpleOpen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4E(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
EnvelopeSimpleOpen.displayName = "EnvelopeSimpleOpen";

var renderPathFor$4F = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "160",
        x2: "216",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "96",
        x2: "216",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "160",
        x2: "216",
        y2: "160",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "96",
        x2: "216",
        y2: "96",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M216,152H40a8,8,0,0,0,0,16H216a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M40,104H216a8,8,0,0,0,0-16H40a8,8,0,0,0,0,16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "160",
        x2: "216",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "96",
        x2: "216",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "160",
        x2: "216",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "96",
        x2: "216",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "160",
        x2: "216",
        y2: "160",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "96",
        x2: "216",
        y2: "96",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Equals = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4F(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Equals.displayName = "Equals";

var renderPathFor$4G = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "91.55018",
        y1: "99.54921",
        x2: "159.43243",
        y2: "167.43146",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M216.00049,215.83348H72.07L34.98164,178.74517a16,16,0,0,1,0-22.62742L148.11873,42.98066a16,16,0,0,1,22.62741,0L216.001,88.2355a16,16,0,0,1,0,22.62742L111.03042,215.83347",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M111.03042,215.83347H72.07L34.98164,178.74517a16,16,0,0,1,0-22.62742L91.55018,99.54921l67.88225,67.88225Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "91.55018",
        y1: "99.54921",
        x2: "159.43243",
        y2: "167.43146",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M216.00049,215.83348H72.07L34.98164,178.74517a16,16,0,0,1,0-22.62742L148.11873,42.98066a16,16,0,0,1,22.62741,0L216.001,88.2355a16,16,0,0,1,0,22.62742L111.03042,215.83347",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.001,207.833H130.34375l34.72949-34.72949.0166-.01465.01465-.0166,56.55371-56.55274a24.02962,24.02962,0,0,0,0-33.94141L176.40332,37.32324a24.0007,24.0007,0,0,0-33.94141,0L85.90283,93.88232l-.01025.00928-.00928.01026L29.32422,150.46094a24.00066,24.00066,0,0,0,0,33.9414l37.08887,37.08789a8.00232,8.00232,0,0,0,5.65722,2.34278H216.001a8,8,0,0,0,0-16ZM153.77637,48.6377a7.99708,7.99708,0,0,1,11.3125,0l45.25488,45.25488a8.00888,8.00888,0,0,1,0,11.31347l-50.91113,50.91114L102.86475,99.54932Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "91.55018",
        y1: "99.54921",
        x2: "159.43243",
        y2: "167.43146",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M216.00049,215.83348H72.07L34.98164,178.74517a16,16,0,0,1,0-22.62742L148.11873,42.98066a16,16,0,0,1,22.62741,0L216.001,88.2355a16,16,0,0,1,0,22.62742L111.03042,215.83347",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "91.55018",
        y1: "99.54921",
        x2: "159.43243",
        y2: "167.43146",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M216.00049,215.83348H72.07L34.98164,178.74517a16,16,0,0,1,0-22.62742L148.11873,42.98066a16,16,0,0,1,22.62741,0L216.001,88.2355a16,16,0,0,1,0,22.62742L111.03042,215.83347",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "91.55018",
        y1: "99.54921",
        x2: "159.43243",
        y2: "167.43146",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M216.00049,215.83348H72.07L34.98164,178.74517a16,16,0,0,1,0-22.62742L148.11873,42.98066a16,16,0,0,1,22.62741,0L216.001,88.2355a16,16,0,0,1,0,22.62742L111.03042,215.83347",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Eraser = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4G(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Eraser.displayName = "Eraser";

var renderPathFor$4H = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,55.99219C48,55.99219,16,128,16,128s32,71.99219,112,71.99219S240,128,240,128,208,55.99219,128,55.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M127.99414,55.99231c-80,0-112,72.00781-112,72.00781s32,71.99219,112,71.99219,112-71.99219,112-71.99219S207.99414,55.99231,127.99414,55.99231Zm0,112.0083a40,40,0,1,1,40-40A40.0001,40.0001,0,0,1,127.99414,168.00061Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M127.99414,55.99219c-80,0-112,72.00781-112,72.00781s32,71.99219,112,71.99219,112-71.99219,112-71.99219S207.99414,55.99219,127.99414,55.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "128.00061",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M247.31055,124.75061c-.35157-.79-8.81934-19.57617-27.65332-38.41113C194.57324,61.25256,162.87793,47.99182,128,47.99182S61.42676,61.25256,36.34277,86.33948c-18.834,18.835-27.30175,37.62109-27.65332,38.41113a8.00282,8.00282,0,0,0,0,6.49805c.35157.791,8.82032,19.57226,27.6543,38.40429C61.42773,194.734,93.12207,207.99182,128,207.99182S194.57227,194.734,219.65625,169.653c18.834-18.832,27.30273-37.61328,27.6543-38.40429A8.00282,8.00282,0,0,0,247.31055,124.75061ZM128,92.00061a36,36,0,1,1-36,36A36.04061,36.04061,0,0,1,128,92.00061Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,55.99219C48,55.99219,16,128,16,128s32,71.99219,112,71.99219S240,128,240,128,208,55.99219,128,55.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128.00061",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,55.99219C48,55.99219,16,128,16,128s32,71.99219,112,71.99219S240,128,240,128,208,55.99219,128,55.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128.00061",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,55.99219C48,55.99219,16,128,16,128s32,71.99219,112,71.99219S240,128,240,128,208,55.99219,128,55.99219Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128.00061",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Eye = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4H(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Eye.displayName = "Eye";

var renderPathFor$4I = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "201.14971",
        y1: "127.30467",
        x2: "223.95961",
        y2: "166.81257",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "154.18201",
        y1: "149.26298",
        x2: "161.29573",
        y2: "189.60689",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "101.72972",
        y1: "149.24366",
        x2: "94.61483",
        y2: "189.59423",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "54.80859",
        y1: "127.27241",
        x2: "31.88882",
        y2: "166.97062",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M31.99943,104.87509C48.81193,125.68556,79.63353,152,128,152c48.36629,0,79.18784-26.31424,96.00039-47.12468",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "201.14971",
        y1: "127.30467",
        x2: "223.95961",
        y2: "166.81257",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "154.18201",
        y1: "149.26298",
        x2: "161.29573",
        y2: "189.60689",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "101.72972",
        y1: "149.24366",
        x2: "94.61483",
        y2: "189.59423",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "54.80859",
        y1: "127.27241",
        x2: "31.88882",
        y2: "166.97062",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M31.99943,104.87509C48.81193,125.68556,79.63353,152,128,152c48.36629,0,79.18784-26.31424,96.00039-47.12468",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M211.50122,129.23535a147.78919,147.78919,0,0,0,18.72144-19.333,7.99973,7.99973,0,0,0-12.44532-10.05468,128.72532,128.72532,0,0,1-21.28466,20.9541c-.05372.03808-.103.08008-.15528.11963A109.58952,109.58952,0,0,1,128,144a109.59068,109.59068,0,0,1-68.35156-23.08887c-.061-.04638-.11841-.0957-.18115-.14062A128.70627,128.70627,0,0,1,38.22168,99.84766a7.99972,7.99972,0,1,0-12.44531,10.05468,147.761,147.761,0,0,0,18.68188,19.29834l-19.49731,33.77a7.99959,7.99959,0,1,0,13.85547,8l18.49-32.02539a123.57956,123.57956,0,0,0,35.24438,16.28174l-5.81445,32.978a8.00124,8.00124,0,0,0,6.49023,9.26758,8.12,8.12,0,0,0,1.39844.12207,8.00272,8.00272,0,0,0,7.86914-6.61231l5.71729-32.42724a136.26072,136.26072,0,0,0,39.4873.01367l5.71826,32.42724a8.00278,8.00278,0,0,0,7.86914,6.61133,8.13106,8.13106,0,0,0,1.39942-.12207,8.00173,8.00173,0,0,0,6.48925-9.26855l-5.813-32.96436a123.56028,123.56028,0,0,0,35.28808-16.27832l18.38233,31.83838a7.99959,7.99959,0,0,0,13.85547-8Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "201.14971",
        y1: "127.30467",
        x2: "223.95961",
        y2: "166.81257",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "154.18201",
        y1: "149.26298",
        x2: "161.29573",
        y2: "189.60689",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "101.72972",
        y1: "149.24366",
        x2: "94.61483",
        y2: "189.59423",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "54.80859",
        y1: "127.27241",
        x2: "31.88882",
        y2: "166.97062",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M31.99943,104.87509C48.81193,125.68556,79.63353,152,128,152c48.36629,0,79.18784-26.31424,96.00039-47.12468",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "201.14971",
        y1: "127.30467",
        x2: "223.95961",
        y2: "166.81257",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "154.18201",
        y1: "149.26298",
        x2: "161.29573",
        y2: "189.60689",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "101.72972",
        y1: "149.24366",
        x2: "94.61483",
        y2: "189.59423",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "54.80859",
        y1: "127.27241",
        x2: "31.88882",
        y2: "166.97062",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M31.99943,104.87509C48.81193,125.68556,79.63353,152,128,152c48.36629,0,79.18784-26.31424,96.00039-47.12468",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "201.14971",
        y1: "127.30467",
        x2: "223.95961",
        y2: "166.81257",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "154.18201",
        y1: "149.26298",
        x2: "161.29573",
        y2: "189.60689",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "101.72972",
        y1: "149.24366",
        x2: "94.61483",
        y2: "189.59423",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "54.80859",
        y1: "127.27241",
        x2: "31.88882",
        y2: "166.97062",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M31.99943,104.87509C48.81193,125.68556,79.63353,152,128,152c48.36629,0,79.18784-26.31424,96.00039-47.12468",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var EyeClosed = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4I(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
EyeClosed.displayName = "EyeClosed";

var renderPathFor$4J = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M73.99446,68.59357C33.22519,89.23912,16,128,16,128s32,71.99219,112,71.99219a118.0238,118.0238,0,0,0,53.99756-12.59461",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M214.40925,163.58516C232.12131,145.72513,240,128,240,128S208,55.99219,128,55.99219q-5.64912,0-10.9808.46371",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,56C48,56,16,128.00781,16,128.00781S48,200,128,200s112-71.99219,112-71.99219S208,56,128,56Zm0,112.0083a40,40,0,1,1,40-40A40.0001,40.0001,0,0,1,128,168.0083Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M154.9071,157.59781a40.00028,40.00028,0,0,1-53.8142-59.19562",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M73.99446,68.59357C33.22519,89.23912,16,128,16,128s32,71.99219,112,71.99219a118.0238,118.0238,0,0,0,53.99756-12.59461",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208.60953,169.09937C230.41132,149.5722,240,128,240,128S208,55.99219,128,55.99219a125.31923,125.31923,0,0,0-20.68221,1.68414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M135.52737,88.70779a40.02413,40.02413,0,0,1,32.29785,35.52875",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M247.31055,124.75842c-.35157-.79-8.81934-19.57519-27.65332-38.41113C194.57324,61.26038,162.87793,47.99963,128,47.99963a133.97063,133.97063,0,0,0-21.99512,1.793,8.00028,8.00028,0,0,0-4.60254,13.27246L202.69336,174.485a8.00126,8.00126,0,0,0,11.25781.57715c22.8125-20.43359,32.93946-42.86035,33.35938-43.80566A8.00282,8.00282,0,0,0,247.31055,124.75842Z"
      }), React__default.createElement("path", {
        d: "M53.91992,34.6178A8.0006,8.0006,0,1,0,42.08008,45.38147l19.24121,21.165c-36.321,22.291-51.93628,56.648-52.63184,58.21191a8.00282,8.00282,0,0,0,0,6.49805c.35157.791,8.82032,19.57226,27.6543,38.4043,25.084,25.081,56.77832,38.33886,91.65625,38.33886a126.97091,126.97091,0,0,0,52.06567-10.834l22.01441,24.21582a8.0006,8.0006,0,0,0,11.83984-10.76367ZM128,164.00012a35.98594,35.98594,0,0,1-29.52319-56.582l47.20459,51.9248A35.78086,35.78086,0,0,1,128,164.00012Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M154.9071,157.59781a40.00028,40.00028,0,0,1-53.8142-59.19562",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M73.99446,68.59357C33.22519,89.23912,16,128,16,128s32,71.99219,112,71.99219a118.0238,118.0238,0,0,0,53.99756-12.59461",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M208.60953,169.09937C230.41132,149.5722,240,128,240,128S208,55.99219,128,55.99219a125.31923,125.31923,0,0,0-20.68221,1.68414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M135.52737,88.70779a40.02413,40.02413,0,0,1,32.29785,35.52875",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M154.9071,157.59781a40.00028,40.00028,0,0,1-53.8142-59.19562",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M73.99446,68.59357C33.22519,89.23912,16,128,16,128s32,71.99219,112,71.99219a118.0238,118.0238,0,0,0,53.99756-12.59461",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M208.60953,169.09937C230.41132,149.5722,240,128,240,128S208,55.99219,128,55.99219a125.31923,125.31923,0,0,0-20.68221,1.68414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M135.52737,88.70779a40.02413,40.02413,0,0,1,32.29785,35.52875",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40.00122",
        x2: "208",
        y2: "216.00122",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M154.9071,157.599a40.00028,40.00028,0,0,1-53.8142-59.19562",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M73.99446,68.59479C33.22519,89.24034,16,128.00122,16,128.00122s32,71.99219,112,71.99219a118.0238,118.0238,0,0,0,53.99756-12.59461",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208.60953,169.10059C230.41132,149.57342,240,128.00122,240,128.00122S208,55.99341,128,55.99341a125.31923,125.31923,0,0,0-20.68221,1.68414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M135.52737,88.709a40.02411,40.02411,0,0,1,32.29785,35.52874",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var EyeSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4J(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
EyeSlash.displayName = "EyeSlash";

var renderPathFor$4K = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M158.62742,142.62742l-56,56a31.98729,31.98729,0,0,1-30.91154,8.28721L48.31361,217.131A8,8,0,0,1,39.456,215.456h0a5.74381,5.74381,0,0,1-1.20256-6.35955l10.832-24.81212a31.9873,31.9873,0,0,1,8.28715-30.91177l56-56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M187.799,107.799l4.88728,4.88728a16,16,0,0,1,0,22.62742l-15.02944,15.02944a8,8,0,0,1-11.3137,0l-60.6863-60.6863a8,8,0,0,1,0-11.3137l15.02944-15.02944a16,16,0,0,1,22.62742,0l4.8873,4.8873,19.58813-19.58813c10.78822-10.78822,28.36591-11.4491,39.44579-.96065A28.00039,28.00039,0,0,1,207.799,87.799Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M179.799,115.799l4.88728,4.88728a16,16,0,0,1,0,22.62742l-7.02944,7.02944a8,8,0,0,1-11.3137,0l-60.6863-60.6863a8,8,0,0,1,0-11.3137l7.02944-7.02944a16,16,0,0,1,22.62742,0l4.8873,4.8873,27.58813-27.58813c10.78822-10.78822,28.36591-11.4491,39.44579-.96065A28.00039,28.00039,0,0,1,207.799,87.799Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M179.799,115.799l4.88728,4.88728a16,16,0,0,1,0,22.62742l-7.02944,7.02944a8,8,0,0,1-11.3137,0l-60.6863-60.6863a8,8,0,0,1,0-11.3137l7.02944-7.02944a16,16,0,0,1,22.62742,0l4.8873,4.8873,27.58813-27.58813c10.78822-10.78822,28.36591-11.4491,39.44579-.96065A28.00039,28.00039,0,0,1,207.799,87.799Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M158.62742,142.62742l-56,56a31.98729,31.98729,0,0,1-30.91154,8.28721L48.31361,217.131A8,8,0,0,1,39.456,215.456h0a5.74381,5.74381,0,0,1-1.20256-6.35955l10.832-24.81212a31.9873,31.9873,0,0,1,8.28715-30.91177l56-56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.99658,67.50391a35.73557,35.73557,0,0,0-11.26172-25.66114c-14.01806-13.2705-36.71875-12.771-50.60254,1.11328L140.18408,64.90479a24.02939,24.02939,0,0,0-33.15429.75195L100,72.68652a16.01779,16.01779,0,0,0,0,22.627l2.05908,2.05908L51.71533,147.71582a40.15638,40.15638,0,0,0-11.01074,35.771l-9.78271,22.40869a13.66329,13.66329,0,0,0,2.87744,15.21728,15.915,15.915,0,0,0,11.27929,4.70313,16.077,16.077,0,0,0,6.43555-1.353l20.999-9.16748a40.15391,40.15391,0,0,0,35.771-11.01123l50.34326-50.34326L160.68652,156a16.01779,16.01779,0,0,0,22.627,0l7.02978-7.02979a24.02843,24.02843,0,0,0,.752-33.15429l22.36036-22.36035A35.71726,35.71726,0,0,0,223.99658,67.50391ZM96.9707,192.9707a24.09567,24.09567,0,0,1-23.1914,6.21436,8.0052,8.0052,0,0,0-5.26416.39746L47.044,208.95605l9.37353-21.47119a8.00234,8.00234,0,0,0,.39746-5.26416,24.0986,24.0986,0,0,1,6.21436-23.1914L113.37256,108.686l33.9414,33.9414Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M179.799,115.799l4.88728,4.88728a16,16,0,0,1,0,22.62742l-7.02944,7.02944a8,8,0,0,1-11.3137,0l-60.6863-60.6863a8,8,0,0,1,0-11.3137l7.02944-7.02944a16,16,0,0,1,22.62742,0l4.8873,4.8873,27.58813-27.58813c10.78822-10.78822,28.36591-11.4491,39.44579-.96065A28.00039,28.00039,0,0,1,207.799,87.799Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M158.62742,142.62742l-56,56a31.98729,31.98729,0,0,1-30.91154,8.28721L48.31361,217.131A8,8,0,0,1,39.456,215.456h0a5.74381,5.74381,0,0,1-1.20256-6.35955l10.832-24.81212a31.9873,31.9873,0,0,1,8.28715-30.91177l56-56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M179.799,115.799l4.88728,4.88728a16,16,0,0,1,0,22.62742l-7.02944,7.02944a8,8,0,0,1-11.3137,0l-60.6863-60.6863a8,8,0,0,1,0-11.3137l7.02944-7.02944a16,16,0,0,1,22.62742,0l4.8873,4.8873,27.58813-27.58813c10.78822-10.78822,28.36591-11.4491,39.44579-.96065A28.00039,28.00039,0,0,1,207.799,87.799Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M158.62742,142.62742l-56,56a31.98729,31.98729,0,0,1-30.91154,8.28721L48.31361,217.131A8,8,0,0,1,39.456,215.456h0a5.74381,5.74381,0,0,1-1.20256-6.35955l10.832-24.81212a31.9873,31.9873,0,0,1,8.28715-30.91177l56-56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M179.799,115.799l4.88728,4.88728a16,16,0,0,1,0,22.62742l-7.02944,7.02944a8,8,0,0,1-11.3137,0l-60.6863-60.6863a8,8,0,0,1,0-11.3137l7.02944-7.02944a16,16,0,0,1,22.62742,0l4.8873,4.8873,27.58813-27.58813c10.78822-10.78822,28.36591-11.4491,39.44579-.96065A28.00039,28.00039,0,0,1,207.799,87.799Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M158.62742,142.62742l-56,56a31.98729,31.98729,0,0,1-30.91154,8.28721L48.31361,217.131A8,8,0,0,1,39.456,215.456h0a5.74381,5.74381,0,0,1-1.20256-6.35955l10.832-24.81212a31.9873,31.9873,0,0,1,8.28715-30.91177l56-56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Eyedropper = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4K(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Eyedropper.displayName = "Eyedropper";

var renderPathFor$4L = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,136c0,50.95006-66.22217,68.789-78.16566,71.59207a8.00537,8.00537,0,0,1-3.66868,0C114.22217,204.789,48,186.95006,48,136V77.41626a8,8,0,0,1,5.02887-7.42781l72-28.8a8,8,0,0,1,5.94226,0l72,28.8A8,8,0,0,1,208,77.41626Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "108",
        x2: "168",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "144",
        x2: "168",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M205.40982,152H220a24,24,0,0,0,24-24V104a24,24,0,0,0-24-24H208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M50.59121,152H36a24,24,0,0,1-24-24V104A24,24,0,0,1,36,80H48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M216,136c0,51.50493-74.43964,69.17367-86.39,71.67832a7.80809,7.80809,0,0,1-3.21992,0C114.43964,205.17367,40,187.50493,40,136V77.60342a8,8,0,0,1,5.26606-7.51835l80-29.09091a8,8,0,0,1,5.46788,0l80,29.09091A8,8,0,0,1,216,77.60342Z"
      })), React__default.createElement("path", {
        d: "M216,136c0,51.50493-74.43964,69.17367-86.39,71.67832a7.80809,7.80809,0,0,1-3.21992,0C114.43964,205.17367,40,187.50493,40,136V77.60342a8,8,0,0,1,5.26606-7.51835l80-29.09091a8,8,0,0,1,5.46788,0l80,29.09091A8,8,0,0,1,216,77.60342Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112",
        x2: "168",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "144",
        x2: "168",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M213.40982,152H224a24,24,0,0,0,24-24V104a24,24,0,0,0-24-24h-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M42.59121,152H32A24,24,0,0,1,8,128V104A24,24,0,0,1,32,80h8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,72h-1.03125a16.03948,16.03948,0,0,0-9.501-9.43311l-80-29.0913a16.02485,16.02485,0,0,0-10.93554,0l-80,29.09082A16.04022,16.04022,0,0,0,33.03125,72H32A32.03635,32.03635,0,0,0,0,104v24a32.03635,32.03635,0,0,0,32,32h5.19678c6.561,14.38086,19.25537,26.99854,37.63183,37.20752,21.02246,11.67871,43.52491,16.96045,49.91944,18.30029a15.72388,15.72388,0,0,0,6.50293,0c6.3955-1.33984,28.898-6.62158,49.92041-18.30029,18.37646-10.209,31.0708-22.82666,37.63183-37.20752H224a32.03635,32.03635,0,0,0,32-32V104A32.03635,32.03635,0,0,0,224,72ZM32,144a16.01833,16.01833,0,0,1-16-16V104A16.01833,16.01833,0,0,1,32,88v48a58.66962,58.66962,0,0,0,.55273,8Zm136,8H88a8,8,0,0,1,0-16h80a8,8,0,0,1,0,16Zm0-32H88a8,8,0,0,1,0-16h80a8,8,0,0,1,0,16Zm72,8a16.01833,16.01833,0,0,1-16,16h-.55273A58.66962,58.66962,0,0,0,224,136V88a16.01833,16.01833,0,0,1,16,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,136c0,51.50493-74.43964,69.17367-86.39,71.67832a7.80809,7.80809,0,0,1-3.21992,0C114.43964,205.17367,40,187.50493,40,136V77.60342a8,8,0,0,1,5.26606-7.51835l80-29.09091a8,8,0,0,1,5.46788,0l80,29.09091A8,8,0,0,1,216,77.60342Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112",
        x2: "168",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "144",
        x2: "168",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M213.40982,152H224a24,24,0,0,0,24-24V104a24,24,0,0,0-24-24h-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M42.59121,152H32A24,24,0,0,1,8,128V104A24,24,0,0,1,32,80h8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,136c0,51.50493-74.43964,69.17367-86.39,71.67832a7.80809,7.80809,0,0,1-3.21992,0C114.43964,205.17367,40,187.50493,40,136V77.60342a8,8,0,0,1,5.26606-7.51835l80-29.09091a8,8,0,0,1,5.46788,0l80,29.09091A8,8,0,0,1,216,77.60342Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112",
        x2: "168",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "144",
        x2: "168",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M213.40982,152H224a24,24,0,0,0,24-24V104a24,24,0,0,0-24-24h-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M42.59121,152H32A24,24,0,0,1,8,128V104A24,24,0,0,1,32,80h8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,136c0,51.50493-74.43964,69.17367-86.39,71.67832a7.80809,7.80809,0,0,1-3.21992,0C114.43964,205.17367,40,187.50493,40,136V77.60342a8,8,0,0,1,5.26606-7.51835l80-29.09091a8,8,0,0,1,5.46788,0l80,29.09091A8,8,0,0,1,216,77.60342Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112",
        x2: "168",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "144",
        x2: "168",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M213.40982,152H224a24,24,0,0,0,24-24V104a24,24,0,0,0-24-24h-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M42.59121,152H32A24,24,0,0,1,8,128V104A24,24,0,0,1,32,80h8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FaceMask = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4L(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FaceMask.displayName = "FaceMask";

var renderPathFor$4M = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M168,88.00094H152a24,24,0,0,0-24,24v112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "144.00094",
        x2: "160",
        y2: "144.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,88.00094H152a24,24,0,0,0-24,24v112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "144.00094",
        x2: "160",
        y2: "144.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24a104.0018,104.0018,0,0,0-8,207.69531V152.00094H96a8,8,0,0,1,0-16h24v-24a32.03667,32.03667,0,0,1,32-32h16a8,8,0,0,1,0,16H152a16.01833,16.01833,0,0,0-16,16v24h24a8,8,0,0,1,0,16H136v79.69434A104.0018,104.0018,0,0,0,128,24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M168,88.00094H152a24,24,0,0,0-24,24v112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "144.00094",
        x2: "160",
        y2: "144.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M168,88.00094H152a24,24,0,0,0-24,24v112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "144.00094",
        x2: "160",
        y2: "144.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,88.00094H152a24,24,0,0,0-24,24v112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "144.00094",
        x2: "160",
        y2: "144.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FacebookLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4M(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FacebookLogo.displayName = "FacebookLogo";

var renderPathFor$4N = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.00098",
        y1: "124",
        x2: "128.0011",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128.0011",
        y1: "40",
        x2: "128.00098",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200.00098",
        y1: "204",
        x2: "200.00181",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200.00181",
        y1: "40",
        x2: "200.00098",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "224.00098",
        y1: "164",
        x2: "176.00098",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "56.00098",
        y1: "172",
        x2: "56.00039",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "56.00039",
        y1: "40",
        x2: "56.00098",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "32.00098",
        y1: "132",
        x2: "80.00098",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152.00098",
        y1: "84",
        x2: "104.00098",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.00098",
        y1: "120",
        x2: "128.0011",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128.0011",
        y1: "40",
        x2: "128.00098",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200.00098",
        y1: "200",
        x2: "200.00181",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200.00181",
        y1: "40",
        x2: "200.00098",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224.00098",
        y1: "168",
        x2: "176.00098",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56.00098",
        y1: "168",
        x2: "56.00039",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56.00039",
        y1: "40",
        x2: "56.00098",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32.00098",
        y1: "136",
        x2: "80.00098",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152.00098",
        y1: "88",
        x2: "104.00098",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M128.001,111.99988a8.00008,8.00008,0,0,0-8,8v96a8,8,0,0,0,16,0v-96A8.00008,8.00008,0,0,0,128.001,111.99988Z"
      }), React__default.createElement("path", {
        d: "M200.001,191.99988a7.99987,7.99987,0,0,0-8,8.00049l.001,16a8,8,0,0,0,16-.001l-.001-16A8,8,0,0,0,200.001,191.99988Z"
      }), React__default.createElement("path", {
        d: "M224.001,159.99988h-16l.001-120a8,8,0,1,0-16,0l-.001,120h-16a8,8,0,0,0,0,16h48a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M56.001,159.99988a8.00039,8.00039,0,0,0-8,8l-.00049,48a8,8,0,0,0,16,0l.00049-48A8.00009,8.00009,0,0,0,56.001,159.99988Z"
      }), React__default.createElement("path", {
        d: "M80.001,127.99988h-16l-.00049-88a8,8,0,0,0-16,0l.00049,88h-16a8,8,0,0,0,0,16h48a8,8,0,1,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M152.001,79.99988h-16v-40a8,8,0,1,0-16,0v40h-16a8,8,0,0,0,0,16h48a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.00098",
        y1: "120",
        x2: "128.0011",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128.0011",
        y1: "40",
        x2: "128.00098",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200.00098",
        y1: "200",
        x2: "200.00181",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200.00181",
        y1: "40",
        x2: "200.00098",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "224.00098",
        y1: "168",
        x2: "176.00098",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56.00098",
        y1: "168",
        x2: "56.00039",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56.00039",
        y1: "40",
        x2: "56.00098",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "32.00098",
        y1: "136",
        x2: "80.00098",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152.00098",
        y1: "88",
        x2: "104.00098",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.00098",
        y1: "120",
        x2: "128.0011",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128.0011",
        y1: "40",
        x2: "128.00098",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200.00098",
        y1: "200",
        x2: "200.00181",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200.00181",
        y1: "40",
        x2: "200.00098",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "224.00098",
        y1: "168",
        x2: "176.00098",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56.00098",
        y1: "168",
        x2: "56.00039",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56.00039",
        y1: "40",
        x2: "56.00098",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "32.00098",
        y1: "136",
        x2: "80.00098",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152.00098",
        y1: "88",
        x2: "104.00098",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.00098",
        y1: "120",
        x2: "128.0011",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128.0011",
        y1: "40",
        x2: "128.00098",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200.00098",
        y1: "200",
        x2: "200.00181",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200.00181",
        y1: "40",
        x2: "200.00098",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224.00098",
        y1: "168",
        x2: "176.00098",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56.00098",
        y1: "168",
        x2: "56.00039",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56.00039",
        y1: "40",
        x2: "56.00098",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32.00098",
        y1: "136",
        x2: "80.00098",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152.00098",
        y1: "88",
        x2: "104.00098",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Faders = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4N(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Faders.displayName = "Faders";

var renderPathFor$4O = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "131.99902",
        y1: "171.99304",
        x2: "39.99902",
        y2: "171.99317",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "215.99902",
        y1: "171.99317",
        x2: "171.99902",
        y2: "171.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "67.99902",
        y1: "83.99304",
        x2: "39.99902",
        y2: "83.99246",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "215.99902",
        y1: "83.99246",
        x2: "107.99902",
        y2: "83.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "107.99902",
        y1: "59.99304",
        x2: "107.99902",
        y2: "107.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "171.99902",
        y1: "195.99304",
        x2: "171.99902",
        y2: "147.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "135.99902",
        y1: "171.99304",
        x2: "39.99902",
        y2: "171.99317",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "215.99902",
        y1: "171.99317",
        x2: "167.99902",
        y2: "171.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "71.99902",
        y1: "83.99304",
        x2: "39.99902",
        y2: "83.99246",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "215.99902",
        y1: "83.99246",
        x2: "103.99902",
        y2: "83.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.99902",
        y1: "59.99304",
        x2: "103.99902",
        y2: "107.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "167.99902",
        y1: "195.99304",
        x2: "167.99902",
        y2: "147.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M135.999,163.99353h-96a8,8,0,0,0,0,16h96a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M215.999,163.99353h-40v-16a8,8,0,0,0-16,0v48a8,8,0,0,0,16,0v-16h40a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M39.999,91.99255l32,.001a8,8,0,0,0,0-16l-32-.001a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M103.999,115.99353a8.00039,8.00039,0,0,0,8-8v-16l104-.001a8,8,0,1,0,0-16l-104,.001v-16a8,8,0,1,0-16,0v48A8.00039,8.00039,0,0,0,103.999,115.99353Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "135.99902",
        y1: "171.99304",
        x2: "39.99902",
        y2: "171.99317",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "215.99902",
        y1: "171.99317",
        x2: "167.99902",
        y2: "171.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "71.99902",
        y1: "83.99304",
        x2: "39.99902",
        y2: "83.99246",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "215.99902",
        y1: "83.99246",
        x2: "103.99902",
        y2: "83.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "103.99902",
        y1: "59.99304",
        x2: "103.99902",
        y2: "107.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "167.99902",
        y1: "195.99304",
        x2: "167.99902",
        y2: "147.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "135.99902",
        y1: "171.99304",
        x2: "39.99902",
        y2: "171.99317",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "215.99902",
        y1: "171.99317",
        x2: "167.99902",
        y2: "171.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "71.99902",
        y1: "83.99304",
        x2: "39.99902",
        y2: "83.99246",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "215.99902",
        y1: "83.99246",
        x2: "103.99902",
        y2: "83.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "103.99902",
        y1: "59.99304",
        x2: "103.99902",
        y2: "107.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "167.99902",
        y1: "195.99304",
        x2: "167.99902",
        y2: "147.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "135.99902",
        y1: "171.99304",
        x2: "39.99902",
        y2: "171.99317",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "215.99902",
        y1: "171.99317",
        x2: "167.99902",
        y2: "171.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "71.99902",
        y1: "83.99304",
        x2: "39.99902",
        y2: "83.99246",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "215.99902",
        y1: "83.99246",
        x2: "103.99902",
        y2: "83.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.99902",
        y1: "59.99304",
        x2: "103.99902",
        y2: "107.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "167.99902",
        y1: "195.99304",
        x2: "167.99902",
        y2: "147.99304",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FadersHorizontal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4O(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FadersHorizontal.displayName = "FadersHorizontal";

var renderPathFor$4P = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "88 156 124 128 88 100 88 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "144 156 180 128 144 100 144 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "88 156 124 128 88 100 88 156"
      }), React__default.createElement("polygon", {
        points: "144 156 180 128 144 100 144 156"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32a96,96,0,1,0,96,96A95.99991,95.99991,0,0,0,128,32ZM80,160V96l48,32Zm64,0V96l48,32Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "80 160 128 128 80 96 80 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "144 160 192 128 144 96 144 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm68.4375,110.65625-48,32A8.00016,8.00016,0,0,1,136,160V128a7.99943,7.99943,0,0,1-3.5625,6.65625l-48,32A8.00016,8.00016,0,0,1,72,160V96a8.00016,8.00016,0,0,1,12.4375-6.65625l48,32A7.99943,7.99943,0,0,1,136,128V96a8.00016,8.00016,0,0,1,12.4375-6.65625l48,32a7.99959,7.99959,0,0,1,0,13.3125Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "84 160 132 128 84 96 84 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "140 160 188 128 140 96 140 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "84 160 132 128 84 96 84 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "140 160 188 128 140 96 140 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "80 160 128 128 80 96 80 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "144 160 192 128 144 96 144 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FastForwardCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4P(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FastForwardCircle.displayName = "FastForwardCircle";

var renderPathFor$4Q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "162",
        cy: "128",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,94V26.00089H94a34,34,0,0,0,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,161.99911V94H94a34,34,0,0,0,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,94V26.00089h34a34,34,0,0,1,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,161.99911v34.00044A34,34,0,1,1,94,162Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "162",
        cy: "128",
        r: "34",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,94V26.00089H94a34,34,0,0,0,0,68Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,161.99911v34.00044A34,34,0,1,1,94,162Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "162",
        cy: "128",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,94V26.00089H94a34,34,0,0,0,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,161.99911V94H94a34,34,0,0,0,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,94V26.00089h34a34,34,0,0,1,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,161.99911v34.00044A34,34,0,1,1,94,162Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M186.61523,94.00049A41.97934,41.97934,0,0,0,162,18.001H94A41.97934,41.97934,0,0,0,69.38477,94.00049a41.93894,41.93894,0,0,0,.00048,67.99939A41.9892,41.9892,0,1,0,136,195.99951V160.948a41.97356,41.97356,0,1,0,50.61523-66.94751ZM188,60.001a26.02916,26.02916,0,0,1-25.98047,25.99951L162,86l-.03857.001L136,86V34.001h26A26.02947,26.02947,0,0,1,188,60.001ZM162,154a25.99952,25.99952,0,0,1-.03857-51.999H162l.019-.00049A25.99976,25.99976,0,0,1,162,154Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "162",
        cy: "128",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,94V26.00089H94a34,34,0,0,0,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,161.99911V94H94a34,34,0,0,0,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,94V26.00089h34a34,34,0,0,1,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,161.99911v34.00044A34,34,0,1,1,94,162Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "162",
        cy: "128",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,94V26.00089H94a34,34,0,0,0,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,161.99911V94H94a34,34,0,0,0,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,94V26.00089h34a34,34,0,0,1,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,161.99911v34.00044A34,34,0,1,1,94,162Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "162",
        cy: "128",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,94V26.00089H94a34,34,0,0,0,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,161.99911V94H94a34,34,0,0,0,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,94V26.00089h34a34,34,0,0,1,0,68Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,161.99911v34.00044A34,34,0,1,1,94,162Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FigmaLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4Q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FigmaLogo.displayName = "FigmaLogo";

var renderPathFor$4R = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "148 32 148 92 208.008 92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "152 32 152 88 208.008 88 152 32",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.58936,82.2749,157.65723,26.34277c-.08008-.08007-.167-.15039-.25-.22656-.10791-.09912-.21289-.20166-.32618-.29492-.07519-.06152-.15576-.11524-.23291-.17432-.13085-.10009-.26025-.20166-.397-.29394-.062-.04151-.12793-.07617-.19043-.11573-.15869-.10009-.31738-.1997-.4834-.28906-.04492-.02392-.09179-.04248-.13672-.06543-.1875-.09668-.377-.18945-.57275-.271-.03027-.0127-.0625-.022-.09326-.03418-.21045-.08448-.42383-.16358-.64258-.23-.03174-.00977-.06445-.01563-.09619-.02491-.2168-.063-.436-.12109-.66064-.166-.07129-.01416-.145-.02051-.2168-.03272-.18555-.03222-.37012-.06494-.55908-.08349A7.91349,7.91349,0,0,0,152,24H55.99219a16.01833,16.01833,0,0,0-16,16V216a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V88.15479c.001-.05225.00781-.10254.00781-.15479A7.97147,7.97147,0,0,0,213.58936,82.2749ZM152,88V43.31348L196.68555,88Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var File = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4R(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
File.displayName = "File";

var renderPathFor$4S = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "148 32 148 92 208.008 92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "100 156 128 184 156 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "124",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "152 32 152 88 208.008 88 152 32",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "100 156 128 184 156 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.58936,82.2749,157.65723,26.34277c-.08008-.08007-.167-.15039-.25-.22656-.10791-.09912-.21289-.20166-.32618-.29492-.07519-.06152-.15576-.11524-.23291-.17432-.13085-.10009-.26025-.20166-.397-.29394-.062-.04151-.12793-.07617-.19043-.11573-.15869-.10009-.31738-.1997-.4834-.28906-.04492-.02392-.09179-.04248-.13672-.06543-.1875-.09668-.377-.18945-.57275-.271-.03027-.0127-.0625-.022-.09326-.03418-.21045-.08448-.42383-.16358-.64258-.23-.03174-.00977-.06445-.01563-.09619-.02491-.2168-.063-.436-.12109-.66064-.166-.07129-.01416-.145-.02051-.2168-.03272-.18555-.03222-.37012-.06494-.55908-.08349A7.91349,7.91349,0,0,0,152,24H55.99219a16.01833,16.01833,0,0,0-16,16V216a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V88.15479c.001-.05225.00781-.10254.00781-.15479A7.97147,7.97147,0,0,0,213.58936,82.2749Zm-51.93262,79.38233-28,28c-.023.02313-.04883.04223-.07178.06506-.165.16089-.33447.317-.51269.46326-.09766.08032-.20118.15039-.30176.22534-.1084.08111-.21485.1654-.32764.241-.11621.07794-.2373.1455-.35693.21667-.10449.06244-.20655.12817-.31446.18585-.12011.06439-.24414.119-.36669.17676-.11426.05389-.22657.1109-.34327.15942-.11816.049-.23925.08838-.35937.13135-.126.04541-.251.09387-.37988.133-.11963.03613-.24122.06262-.36231.09308-.13184.03338-.26269.07037-.397.097-.13965.02765-.28028.044-.42041.06415-.11817.01691-.23389.03925-.353.051C128.52686,191.986,128.26367,192,128,192s-.52686-.014-.78955-.03986c-.11914-.01171-.23486-.03405-.353-.051-.14013-.02014-.28076-.0365-.42041-.06415-.13428-.02667-.26513-.06366-.397-.097-.12109-.03046-.24268-.057-.36231-.09308-.1289-.03913-.2539-.08759-.37988-.133-.12012-.043-.24121-.0824-.35937-.13135-.1167-.04852-.229-.10553-.34327-.15942-.12255-.0578-.24658-.11237-.36669-.17676-.10791-.05768-.21-.12341-.31446-.18585-.11963-.07117-.24072-.13873-.35693-.21667-.11279-.07557-.21924-.15986-.32764-.241-.10058-.075-.2041-.145-.30176-.22534-.1748-.14374-.3413-.29718-.50341-.455-.02637-.02563-.05518-.04724-.08106-.0733l-28-28a8,8,0,0,1,11.31348-11.314L120,164.68652V120a8,8,0,0,1,16,0v44.68652l14.34326-14.34326a8,8,0,0,1,11.31348,11.314ZM152,88V43.31348L196.68555,88Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "100 156 128 184 156 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "100 156 128 184 156 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "100 156 128 184 156 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FileArrowDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4S(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FileArrowDown.displayName = "FileArrowDown";

var renderPathFor$4T = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "148 32 148 92 208.008 92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "152 32 152 88 208.008 88 152 32",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.58936,82.2749,157.65723,26.34277c-.08008-.08007-.167-.15039-.25-.22656-.10791-.09912-.21289-.20166-.32618-.29492-.07519-.06152-.15576-.11524-.23291-.17432-.13085-.10009-.26025-.20166-.397-.29394-.062-.04151-.12793-.07617-.19043-.11573-.15869-.10009-.31738-.1997-.4834-.28906-.04492-.02392-.09179-.04248-.13672-.06543-.1875-.09668-.377-.18945-.57275-.271-.03027-.0127-.0625-.022-.09326-.03418-.21045-.08448-.42383-.16358-.64258-.23-.03174-.00977-.06445-.01563-.09619-.02491-.2168-.063-.436-.12109-.66064-.166-.07129-.01416-.145-.02051-.2168-.03272-.18555-.03222-.37012-.06494-.55908-.08349A7.91349,7.91349,0,0,0,152,24H55.99219a16.01833,16.01833,0,0,0-16,16V216a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V88.15479c.001-.05225.00781-.10254.00781-.15479A7.97147,7.97147,0,0,0,213.58936,82.2749ZM152,160H104a8,8,0,0,1,0-16h48a8,8,0,0,1,0,16Zm0-72V43.31348L196.68555,88Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FileMinus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4T(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FileMinus.displayName = "FileMinus";

var renderPathFor$4U = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "148 32 148 92 208.008 92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "152 32 152 88 208.008 88 152 32",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.58936,82.2749,157.65723,26.34277c-.08008-.08007-.167-.15039-.25-.22656-.10791-.09912-.21289-.20166-.32618-.29492-.07519-.06152-.15576-.11524-.23291-.17432-.13085-.10009-.26025-.20166-.397-.29394-.062-.04151-.12793-.07617-.19043-.11573-.15869-.10009-.31738-.1997-.4834-.28906-.04492-.02392-.09179-.04248-.13672-.06543-.1875-.09668-.377-.18945-.57275-.271-.03027-.0127-.0625-.022-.09326-.03418-.21045-.08448-.42383-.16358-.64258-.23-.03174-.00977-.06445-.01563-.09619-.02491-.2168-.063-.436-.12109-.66064-.166-.07129-.01416-.145-.02051-.2168-.03272-.18555-.03222-.37012-.06494-.55908-.08349A7.91349,7.91349,0,0,0,152,24H55.99219a16.01833,16.01833,0,0,0-16,16V216a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V88.15479c.001-.05225.00781-.10254.00781-.15479A7.97147,7.97147,0,0,0,213.58936,82.2749ZM152,160H136v16a8,8,0,0,1-16,0V160H104a8,8,0,0,1,0-16h16V128a8,8,0,0,1,16,0v16h16a8,8,0,0,1,0,16Zm0-72V43.31348L196.68555,88Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "152",
        x2: "152",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FilePlus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4U(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FilePlus.displayName = "FilePlus";

var renderPathFor$4V = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "148 32 148 92 208.008 92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "123.9941",
        cy: "148",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "140.96467",
        y1: "164.97053",
        x2: "159.79313",
        y2: "183.79899",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "152 32 152 88 208.008 88 152 32",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "143.79313",
        y1: "167.79899",
        x2: "159.79313",
        y2: "183.79899",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "123.99414",
        cy: "148",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.58936,82.2749,157.65723,26.34277c-.08008-.08007-.167-.15039-.25-.22656-.10791-.09912-.21289-.20166-.32618-.29492-.07519-.06152-.15576-.11524-.23291-.17432-.13085-.10009-.26025-.20166-.397-.29394-.062-.04151-.12793-.07617-.19043-.11573-.15869-.10009-.31738-.1997-.4834-.28906-.04492-.02392-.09179-.04248-.13672-.06543-.1875-.09668-.377-.18945-.57275-.271-.03027-.0127-.0625-.022-.09326-.03418-.21045-.08448-.42383-.16358-.64258-.23-.03174-.00977-.06445-.01563-.09619-.02491-.2168-.063-.436-.12109-.66064-.166-.07129-.01416-.145-.02051-.2168-.03272-.18555-.03222-.37012-.06494-.55908-.08349A7.91349,7.91349,0,0,0,152,24H55.99219a16.01833,16.01833,0,0,0-16,16V216a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V88.15479c.001-.05225.00781-.10254.00781-.15479A7.97147,7.97147,0,0,0,213.58936,82.2749ZM165.44971,189.45605a8.00061,8.00061,0,0,1-11.31348,0l-10.98511-10.9851a35.95132,35.95132,0,1,1,11.32093-11.307l10.97766,10.97766A8.00032,8.00032,0,0,1,165.44971,189.45605ZM152,88V43.31348L196.68555,88Z"
      }), React__default.createElement("path", {
        d: "M123.99414,128.00977a19.98432,19.98432,0,1,0,14.14209,5.84863A19.93593,19.93593,0,0,0,123.99414,128.00977Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "143.79313",
        y1: "167.79899",
        x2: "159.79313",
        y2: "183.79899",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "123.99414",
        cy: "148",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "143.79313",
        y1: "167.79899",
        x2: "159.79313",
        y2: "183.79899",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "123.99414",
        cy: "148",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "143.79313",
        y1: "167.79899",
        x2: "159.79313",
        y2: "183.79899",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "123.99414",
        cy: "148",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FileSearch = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4V(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FileSearch.displayName = "FileSearch";

var renderPathFor$4W = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "148 32 148 92 208.008 92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "132",
        x2: "160",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "172",
        x2: "160",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "152 32 152 88 208.008 88 152 32",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "136",
        x2: "160",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "168",
        x2: "160",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.58936,82.2749,157.65723,26.34277c-.08008-.08007-.167-.15039-.25-.22656-.10791-.09912-.21289-.20166-.32618-.29492-.07519-.06152-.15576-.11524-.23291-.17432-.13085-.10009-.26025-.20166-.397-.29394-.062-.04151-.12793-.07617-.19043-.11573-.15869-.10009-.31738-.1997-.4834-.28906-.04492-.02392-.09179-.04248-.13672-.06543-.1875-.09668-.377-.18945-.57275-.271-.03027-.0127-.0625-.022-.09326-.03418-.21045-.08448-.42383-.16358-.64258-.23-.03174-.00977-.06445-.01563-.09619-.02491-.2168-.063-.436-.12109-.66064-.166-.07129-.01416-.145-.02051-.2168-.03272-.18555-.03222-.37012-.06494-.55908-.08349A7.91349,7.91349,0,0,0,152,24H55.99219a16.01833,16.01833,0,0,0-16,16V216a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V88.15479c.001-.05225.00781-.10254.00781-.15479A7.97147,7.97147,0,0,0,213.58936,82.2749ZM160,176H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm0-32H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm-8-56V43.31348L196.68555,88Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "136",
        x2: "160",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "168",
        x2: "160",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "136",
        x2: "160",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "168",
        x2: "160",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "136",
        x2: "160",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "168",
        x2: "160",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FileText = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4W(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FileText.displayName = "FileText";

var renderPathFor$4X = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "148 32 148 92 208.008 92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "103.98242",
        y1: "128",
        x2: "151.98242",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "151.98242",
        y1: "128",
        x2: "103.98242",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "152 32 152 88 208.008 88 152 32",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.9707",
        y1: "128",
        x2: "151.9707",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "151.9707",
        y1: "128",
        x2: "103.9707",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.58936,82.2749,157.65723,26.34277c-.08008-.08007-.167-.15039-.25-.22656-.10791-.09912-.21289-.20166-.32618-.29492-.07519-.06152-.15576-.11524-.23291-.17432-.13085-.10009-.26025-.20166-.397-.29394-.062-.04151-.12793-.07617-.19043-.11573-.15869-.10009-.31738-.1997-.4834-.28906-.04492-.02392-.09179-.04248-.13672-.06543-.1875-.09668-.377-.18945-.57275-.271-.03027-.0127-.0625-.022-.09326-.03418-.21045-.08448-.42383-.16358-.64258-.23-.03174-.00977-.06445-.01563-.09619-.02491-.2168-.063-.436-.12109-.66064-.166-.07129-.01416-.145-.02051-.2168-.03272-.18555-.03222-.37012-.06494-.55908-.08349A7.91349,7.91349,0,0,0,152,24H55.99219a16.01833,16.01833,0,0,0-16,16V216a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V88.15479c.001-.05225.00781-.10254.00781-.15479A7.97147,7.97147,0,0,0,213.58936,82.2749Zm-55.96192,88.06836A7.99984,7.99984,0,1,1,146.314,181.65674L127.9707,163.31348l-18.34326,18.34326A7.99984,7.99984,0,1,1,98.314,170.34326L116.65723,152,98.314,133.65674a7.99984,7.99984,0,1,1,11.31348-11.31348l18.34326,18.34326L146.314,122.34326a7.99984,7.99984,0,1,1,11.31348,11.31348L139.28418,152ZM152,88V43.31348L196.68555,88Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "103.98828",
        y1: "128",
        x2: "151.98828",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "151.98828",
        y1: "128",
        x2: "103.98828",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "103.99414",
        y1: "128",
        x2: "151.99414",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "151.99414",
        y1: "128",
        x2: "103.99414",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,224.00005H55.99219a8,8,0,0,1-8-8V40a8,8,0,0,1,8-8L152,32l56,56v128A8,8,0,0,1,200,224.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "152 32 152 88 208.008 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "152",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "128",
        x2: "104",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FileX = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4X(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FileX.displayName = "FileX";

var renderPathFor$4Y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M107.99406,128.00837a20,20,0,1,1,40,0,211.06573,211.06573,0,0,1-24.95471,99.87857",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M127.99406,68.00837a60,60,0,0,1,60,60q0,12.14234-1.128,24.00022",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M51.34928,192.22271a131.40267,131.40267,0,0,0,16.64478-64.21434,59.85046,59.85046,0,0,1,19.99759-44.72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M103.31853,168.00854a170.97437,170.97437,0,0,1-20.308,49.32367",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M179.79526,192.00879a250.02989,250.02989,0,0,1-8.39355,26.119",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M22.276,160.00875a91.80964,91.80964,0,0,0,5.71806-32.00038l.0118.0001a100,100,0,0,1,200,0l-.0118-.0001a293.00937,293.00937,0,0,1-7.03556,64.00068",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M50.68905,184.92207a127.4728,127.4728,0,0,0,13.31718-56.913A63.88065,63.88065,0,0,1,88.0059,78.04632",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128.00623,128.009a191.13407,191.13407,0,0,1-23.97573,92.98042",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M96.00623,128.009a32,32,0,0,1,64,0A223.13818,223.13818,0,0,1,138.731,223.41536",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M218.56486,184.00845a289.42035,289.42035,0,0,0,5.441-56,96,96,0,0,0-192,0,95.845,95.845,0,0,1-5.46267,32.00025",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.80577,160.00843a158.95129,158.95129,0,0,1-18.1147,47.84483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M120.00621,64.50418a64.051,64.051,0,0,1,72,63.50485,258.52451,258.52451,0,0,1-1.98054,31.99945",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M183.94126,192.00844q-2.2851,8.87835-5.18116,17.5",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M128.00586,24.00842a104.11791,104.11791,0,0,0-104,104A87.786,87.786,0,0,1,19,157.34241a8.00025,8.00025,0,1,0,15.08594,5.332,103.74958,103.74958,0,0,0,5.91992-34.666,88,88,0,0,1,176,0,282.27848,282.27848,0,0,1-5.29,54.45313,7.99962,7.99962,0,1,0,15.69727,3.09375,298.25279,298.25279,0,0,0,5.59277-57.54688A104.11791,104.11791,0,0,0,128.00586,24.00842Z"
      }), React__default.createElement("path", {
        d: "M93.00977,84.2887A8.00025,8.00025,0,0,0,83.00195,71.80432,71.69909,71.69909,0,0,0,56.00586,128.0094,118.80142,118.80142,0,0,1,43.52637,181.361,7.99964,7.99964,0,1,0,57.85254,188.484,134.64637,134.64637,0,0,0,72.00586,128.0094,55.77314,55.77314,0,0,1,93.00977,84.2887Z"
      }), React__default.createElement("path", {
        d: "M128.00586,120.0094a8.00039,8.00039,0,0,0-8,8A184.12954,184.12954,0,0,1,97.03418,217.11a7.99993,7.99993,0,1,0,13.99219,7.75977,200.16824,200.16824,0,0,0,24.97949-96.86035A8.00039,8.00039,0,0,0,128.00586,120.0094Z"
      }), React__default.createElement("path", {
        d: "M128.00586,88.0094a40.04583,40.04583,0,0,0-40,40,8,8,0,0,0,16,0,24,24,0,0,1,48,0,214.09658,214.09658,0,0,1-20.51074,91.99512,8,8,0,1,0,14.47265,6.82226,229.98738,229.98738,0,0,0,22.03809-98.81738A40.04583,40.04583,0,0,0,128.00586,88.0094Z"
      }), React__default.createElement("path", {
        d: "M94.39648,152.16858a8.00778,8.00778,0,0,0-9.43066,6.249,150.78976,150.78976,0,0,1-17.2041,45.4375,8.00031,8.00031,0,1,0,13.85937,7.9961,166.73312,166.73312,0,0,0,19.02442-50.252A7.99971,7.99971,0,0,0,94.39648,152.16858Z"
      }), React__default.createElement("path", {
        d: "M128.00586,56.0094a72.92874,72.92874,0,0,0-8.99121.55664A8.00012,8.00012,0,1,0,120.99707,72.443a56.70946,56.70946,0,0,1,7.00879-.43359,56.0629,56.0629,0,0,1,56,56,251.41194,251.41194,0,0,1-1.919,31.00879,8,8,0,1,0,15.877,1.98047,267.59018,267.59018,0,0,0,2.042-32.98926A72.08124,72.08124,0,0,0,128.00586,56.0094Z"
      }), React__default.createElement("path", {
        d: "M185.93555,184.26135a7.99377,7.99377,0,0,0-9.74121,5.75293c-1.46485,5.68848-3.15332,11.39063-5.01856,16.94824a7.9999,7.9999,0,1,0,15.168,5.0918c1.9873-5.91992,3.78613-11.99316,5.34473-18.05176A7.999,7.999,0,0,0,185.93555,184.26135Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M50.68905,184.92207a127.4728,127.4728,0,0,0,13.31718-56.913A63.88065,63.88065,0,0,1,88.0059,78.04632",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128.00623,128.009a191.13407,191.13407,0,0,1-23.97573,92.98042",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M96.00623,128.009a32,32,0,0,1,64,0A223.13818,223.13818,0,0,1,138.731,223.41536",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M218.56486,184.00845a289.42035,289.42035,0,0,0,5.441-56,96,96,0,0,0-192,0,95.845,95.845,0,0,1-5.46267,32.00025",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M92.80577,160.00843a158.95129,158.95129,0,0,1-18.1147,47.84483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M120.00621,64.50418a64.051,64.051,0,0,1,72,63.50485,258.52451,258.52451,0,0,1-1.98054,31.99945",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M183.94126,192.00844q-2.2851,8.87835-5.18116,17.5",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M50.68905,184.92207a127.4728,127.4728,0,0,0,13.31718-56.913A63.88065,63.88065,0,0,1,88.0059,78.04632",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128.00623,128.009a191.13407,191.13407,0,0,1-23.97573,92.98042",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M96.00623,128.009a32,32,0,0,1,64,0A223.13818,223.13818,0,0,1,138.731,223.41536",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M218.56486,184.00845a289.42035,289.42035,0,0,0,5.441-56,96,96,0,0,0-192,0,95.845,95.845,0,0,1-5.46267,32.00025",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M92.80577,160.00843a158.95129,158.95129,0,0,1-18.1147,47.84483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M120.00621,64.50418a64.051,64.051,0,0,1,72,63.50485,258.52451,258.52451,0,0,1-1.98054,31.99945",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M183.94126,192.00844q-2.2851,8.87835-5.18116,17.5",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M50.68905,184.92207a127.4728,127.4728,0,0,0,13.31718-56.913A63.88065,63.88065,0,0,1,88.0059,78.04632",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128.00623,128.009a191.13407,191.13407,0,0,1-23.97573,92.98042",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M96.00623,128.009a32,32,0,0,1,64,0A223.13818,223.13818,0,0,1,138.731,223.41536",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M218.56486,184.00845a289.42035,289.42035,0,0,0,5.441-56,96,96,0,0,0-192,0,95.845,95.845,0,0,1-5.46267,32.00025",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.80577,160.00843a158.95129,158.95129,0,0,1-18.1147,47.84483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M120.00621,64.50418a64.051,64.051,0,0,1,72,63.50485,258.52451,258.52451,0,0,1-1.98054,31.99945",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M183.94126,192.00844q-2.2851,8.87835-5.18116,17.5",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Fingerprint = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4Y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Fingerprint.displayName = "Fingerprint";

var renderPathFor$4Z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M175.98828,128.009a239.296,239.296,0,0,1-17.934,91.1974",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M163.76327,96.006a48.00042,48.00042,0,0,0-83.775,32.003,143.35055,143.35055,0,0,1-17.98007,69.73221",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M95.98767,37.47183A96.06707,96.06707,0,0,1,223.98828,128.009a288.94528,288.94528,0,0,1-7.13641,63.99948",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M23.28359,168.00907a95.64559,95.64559,0,0,0,8.70469-40A95.76081,95.76081,0,0,1,63.988,56.45385",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M110.567,208.009q-3.04226,6.62844-6.56532,12.97841",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M127.97656,128.00842a192.34737,192.34737,0,0,1-6.0489,48.00023",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M175.97656,128.009a239.296,239.296,0,0,1-17.934,91.1974",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M163.75156,96.006a48.00043,48.00043,0,0,0-83.775,32.003,143.35055,143.35055,0,0,1-17.98007,69.73221",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M95.976,37.47183A96.06707,96.06707,0,0,1,223.97656,128.009a288.94528,288.94528,0,0,1-7.13641,63.99948",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M23.27187,168.00907a95.64559,95.64559,0,0,0,8.70469-40A95.76081,95.76081,0,0,1,63.97631,56.45385",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M110.55525,208.009q-3.04226,6.62844-6.56531,12.97841",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M127.96484,128.00842a192.34737,192.34737,0,0,1-6.0489,48.00023",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M175.98242,120.0094a8.00039,8.00039,0,0,0-8,8,230.70455,230.70455,0,0,1-17.333,88.15527,8.00032,8.00032,0,1,0,14.79883,6.084,246.6394,246.6394,0,0,0,18.53418-94.23926A8.00039,8.00039,0,0,0,175.98242,120.0094Z"
      }), React__default.createElement("path", {
        d: "M127.98242,88.0094a40.06442,40.06442,0,0,1,29.81445,13.333,8.00032,8.00032,0,1,0,11.92188-10.67188A56.00093,56.00093,0,0,0,71.98242,128.0094,136.088,136.088,0,0,1,55.00586,193.861a7.99993,7.99993,0,1,0,13.99219,7.75977A152.12935,152.12935,0,0,0,87.98242,128.0094,40.04583,40.04583,0,0,1,127.98242,88.0094Z"
      }), React__default.createElement("path", {
        d: "M69.31738,62.41467A7.99966,7.99966,0,1,0,58.64746,50.4928a104.15766,104.15766,0,0,0-34.665,77.5166,87.28655,87.28655,0,0,1-7.97558,36.66308,7.9997,7.9997,0,1,0,14.541,6.67383,103.15936,103.15936,0,0,0,9.43457-43.33691A88.1429,88.1429,0,0,1,69.31738,62.41467Z"
      }), React__default.createElement("path", {
        d: "M127.98242,24.0094a103.7636,103.7636,0,0,0-34.667,5.91992,8.00025,8.00025,0,0,0,5.332,15.08594,88.06652,88.06652,0,0,1,117.335,82.99414,281.58357,281.58357,0,0,1-6.93847,62.22851,8.00013,8.00013,0,1,0,15.60351,3.541,297.64323,297.64323,0,0,0,7.335-65.76953A104.11791,104.11791,0,0,0,127.98242,24.0094Z"
      }), React__default.createElement("path", {
        d: "M113.89844,200.73889a8.00188,8.00188,0,0,0-10.60742,3.93359c-1.92676,4.19727-4.044,8.38086-6.291,12.43555a7.99945,7.99945,0,1,0,13.99219,7.75781c2.44336-4.40625,4.74511-8.95507,6.83984-13.51953A7.999,7.999,0,0,0,113.89844,200.73889Z"
      }), React__default.createElement("path", {
        d: "M127.9707,120.00842a8.00039,8.00039,0,0,0-8,8,184.6862,184.6862,0,0,1-5.79687,46.00586,8.00008,8.00008,0,1,0,15.49512,3.98828,200.70138,200.70138,0,0,0,6.30175-49.99414A8.00039,8.00039,0,0,0,127.9707,120.00842Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M175.99414,128.009a239.296,239.296,0,0,1-17.934,91.1974",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M163.76913,96.006a48.00042,48.00042,0,0,0-83.775,32.003,143.35045,143.35045,0,0,1-17.98008,69.73221",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M95.99353,37.47183A96.06707,96.06707,0,0,1,223.99414,128.009a288.94528,288.94528,0,0,1-7.13641,63.99948",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M23.28945,168.00907a95.64559,95.64559,0,0,0,8.70469-40A95.76081,95.76081,0,0,1,63.99389,56.45385",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M110.57283,208.009q-3.04225,6.62844-6.56532,12.97841",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M127.98242,128.00842a192.34737,192.34737,0,0,1-6.0489,48.00023",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,128.009a239.296,239.296,0,0,1-17.934,91.1974",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M163.775,96.006A48.00042,48.00042,0,0,0,80,128.009a143.35045,143.35045,0,0,1-17.98008,69.73221",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M95.99938,37.47183A96.06708,96.06708,0,0,1,224,128.009a288.94528,288.94528,0,0,1-7.13641,63.99948",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M23.29531,168.00907A95.64559,95.64559,0,0,0,32,128.009,95.76081,95.76081,0,0,1,63.99975,56.45385",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M110.57869,208.009q-3.04225,6.62844-6.56532,12.97841",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M127.98828,128.00842a192.34737,192.34737,0,0,1-6.0489,48.00023",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176.00586,128.009a239.296,239.296,0,0,1-17.934,91.1974",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M163.78085,96.006a48.00042,48.00042,0,0,0-83.775,32.003,143.35045,143.35045,0,0,1-17.98008,69.73221",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M96.00524,37.47183A96.06708,96.06708,0,0,1,224.00586,128.009a288.94587,288.94587,0,0,1-7.13641,63.99948",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M23.30117,168.00907a95.64559,95.64559,0,0,0,8.70469-40A95.76078,95.76078,0,0,1,64.00561,56.45385",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M110.58455,208.009q-3.04225,6.62844-6.56532,12.97841",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M127.99414,128.00842a192.34737,192.34737,0,0,1-6.0489,48.00023",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FingerprintSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4Z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FingerprintSimple.displayName = "FingerprintSimple";

var renderPathFor$4_ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "56",
        y: "100.00002",
        width: "144",
        height: "80",
        rx: "32",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "140",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "96",
        cy: "140",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M20,64a24,24,0,1,1,48,0H188a24,24,0,0,1,48,0v88a64,64,0,0,1-64,64H84a64,64,0,0,1-64-64Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,40a23.99994,23.99994,0,0,0-24,24H72a24,24,0,0,0-48,0v80a64,64,0,0,0,64,64h80a64,64,0,0,0,64-64V64A23.99994,23.99994,0,0,0,208,40Zm-8,104a32,32,0,0,1-32,32H88a32.00034,32.00034,0,0,1-32-32v-8a32,32,0,0,1,32-32h80a31.99971,31.99971,0,0,1,32,32Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "56",
        y: "104.00002",
        width: "144",
        height: "72",
        rx: "32",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "140",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "140",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M24,64a24,24,0,0,1,48,0H184a24,24,0,0,1,48,0v80a64,64,0,0,1-64,64H88a64,64,0,0,1-64-64Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,140a12,12,0,1,1-12-12A12.01343,12.01343,0,0,1,176,140ZM92,128a12,12,0,1,0,12,12A12.01343,12.01343,0,0,0,92,128ZM240,64v80a72.08124,72.08124,0,0,1-72,72H88a72.08124,72.08124,0,0,1-72-72V64a32.00221,32.00221,0,0,1,62.98779-8h98.02442A32.00221,32.00221,0,0,1,240,64Zm-40,72a31.99971,31.99971,0,0,0-32-32H88a32,32,0,0,0-32,32v8a32.00034,32.00034,0,0,0,32,32h80a32,32,0,0,0,32-32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "56",
        y: "104.00002",
        width: "144",
        height: "72",
        rx: "32",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "140",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "140",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M24,64a24,24,0,0,1,48,0H184a24,24,0,0,1,48,0v80a64,64,0,0,1-64,64H88a64,64,0,0,1-64-64Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "56",
        y: "104.00002",
        width: "144",
        height: "72",
        rx: "32",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "140",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "140",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M24,64a24,24,0,0,1,48,0H184a24,24,0,0,1,48,0v80a64,64,0,0,1-64,64H88a64,64,0,0,1-64-64Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "56",
        y: "104.00002",
        width: "144",
        height: "72",
        rx: "32",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "140",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "140",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M24,64a24,24,0,0,1,48,0H184a24,24,0,0,1,48,0v80a64,64,0,0,1-64,64H88a64,64,0,0,1-64-64Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FinnTheHuman = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4_(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FinnTheHuman.displayName = "FinnTheHuman";

var renderPathFor$4$ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,112,69.58177,85.48233C57.3119,104.73352,48,127.43557,48,152a80,80,0,0,0,160,0c0-72-72-128-72-128Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,112,69.58177,85.48233C57.3119,104.73352,48,127.43557,48,152a80,80,0,0,0,160,0c0-72-72-128-72-128Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M104,112,69.58177,85.48233C57.3119,104.73352,48,127.43557,48,152a80,80,0,0,0,160,0c0-72-72-128-72-128Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,152a88,88,0,0,1-176,0c0-23.2168,7.68311-47.043,22.83545-70.81738a7.99928,7.99928,0,0,1,11.62842-2.03711l25.75537,19.84277,28.26221-77.72266a7.99985,7.99985,0,0,1,12.43017-3.58007C143.97754,20.06934,216,76.9502,216,152Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,112,69.58177,85.48233C57.3119,104.73352,48,127.43557,48,152a80,80,0,0,0,160,0c0-72-72-128-72-128Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,112,69.58177,85.48233C57.3119,104.73352,48,127.43557,48,152a80,80,0,0,0,160,0c0-72-72-128-72-128Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,112,69.58177,85.48233C57.3119,104.73352,48,127.43557,48,152a80,80,0,0,0,160,0c0-72-72-128-72-128Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Fire = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$4$(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Fire.displayName = "Fire";

var renderPathFor$50 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,160H40a8,8,0,0,1-8-8V104a8,8,0,0,1,8-8H96V40a8,8,0,0,1,8-8h48a8,8,0,0,1,8,8V96h56a8,8,0,0,1,8,8v48a8,8,0,0,1-8,8H160v56a8,8,0,0,1-8,8H104a8,8,0,0,1-8-8V160Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M96,160H40a8,8,0,0,1-8-8V104a8,8,0,0,1,8-8H96V40a8,8,0,0,1,8-8h48a8,8,0,0,1,8,8V96h56a8,8,0,0,1,8,8v48a8,8,0,0,1-8,8H160v56a8,8,0,0,1-8,8H104a8,8,0,0,1-8-8V160Z"
      })), React__default.createElement("path", {
        d: "M96,160H40a8,8,0,0,1-8-8V104a8,8,0,0,1,8-8H96V40a8,8,0,0,1,8-8h48a8,8,0,0,1,8,8V96h56a8,8,0,0,1,8,8v48a8,8,0,0,1-8,8H160v56a8,8,0,0,1-8,8H104a8,8,0,0,1-8-8V160Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232,104v48a16.01833,16.01833,0,0,1-16,16H168v48a16.01833,16.01833,0,0,1-16,16H104a16.01833,16.01833,0,0,1-16-16V168H40a16.01833,16.01833,0,0,1-16-16V104A16.01833,16.01833,0,0,1,40,88H88V40a16.01833,16.01833,0,0,1,16-16h48a16.01833,16.01833,0,0,1,16,16V88h48A16.01833,16.01833,0,0,1,232,104Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,160H40a8,8,0,0,1-8-8V104a8,8,0,0,1,8-8H96V40a8,8,0,0,1,8-8h48a8,8,0,0,1,8,8V96h56a8,8,0,0,1,8,8v48a8,8,0,0,1-8,8H160v56a8,8,0,0,1-8,8H104a8,8,0,0,1-8-8V160Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,160H40a8,8,0,0,1-8-8V104a8,8,0,0,1,8-8H96V40a8,8,0,0,1,8-8h48a8,8,0,0,1,8,8V96h56a8,8,0,0,1,8,8v48a8,8,0,0,1-8,8H160v56a8,8,0,0,1-8,8H104a8,8,0,0,1-8-8V160Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,160H40a8,8,0,0,1-8-8V104a8,8,0,0,1,8-8H96V40a8,8,0,0,1,8-8h48a8,8,0,0,1,8,8V96h56a8,8,0,0,1,8,8v48a8,8,0,0,1-8,8H160v56a8,8,0,0,1-8,8H104a8,8,0,0,1-8-8V160Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FirstAid = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$50(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FirstAid.displayName = "FirstAid";

var renderPathFor$51 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "116",
        x2: "128",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "144",
        x2: "100",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V52a16,16,0,0,0-16-16H104A16,16,0,0,0,88,52V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "116",
        x2: "128",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "144",
        x2: "100",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.00781,64H176V56a24.0275,24.0275,0,0,0-24-24H104A24.0275,24.0275,0,0,0,80,56v8H40.00781a16.01833,16.01833,0,0,0-16,16V208a16.01833,16.01833,0,0,0,16,16h176a16.01833,16.01833,0,0,0,16-16V80A16.01833,16.01833,0,0,0,216.00781,64ZM96,56a8.00917,8.00917,0,0,1,8-8h48a8.00917,8.00917,0,0,1,8,8v8H96Zm60,96H136v20a8,8,0,0,1-16,0V152H100a8,8,0,0,1,0-16h20V116a8,8,0,0,1,16,0v20h20a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "116",
        x2: "128",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "144",
        x2: "100",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "116",
        x2: "128",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "144",
        x2: "100",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,72V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "116",
        x2: "128",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "144",
        x2: "100",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FirstAidKit = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$51(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FirstAidKit.displayName = "FirstAidKit";

var renderPathFor$52 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216.00452",
        x2: "40",
        y2: "48.00452",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M39.99951,168.00452c64-48,112,48,176,0v-120c-64,48-112-48-176,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M39.99951,168.00452c64-48,112,48,176,0v-120c-64,48-112-48-176,0Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "216.00452",
        x2: "40",
        y2: "48.00452",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M39.99951,168.00452c64-48,112,48,176,0v-120c-64,48-112-48-176,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.57764,40.84924a7.99605,7.99605,0,0,0-8.37793.75489c-28.29981,21.22558-52.28223,10.94726-80.04883-.95313-28.24414-12.10449-60.25488-25.81934-95.95117.95313-.04737.0354-.08838.07568-.13428.11181-.11084.08692-.21777.17676-.32373.26929-.09912.08667-.19727.17407-.291.26465-.0874.08423-.17138.17138-.25488.25952-.1001.10547-.19873.21142-.292.32129-.0708.08349-.1377.16968-.20508.25586-.09277.11865-.18457.23779-.26953.36084-.06348.09082-.12158.18457-.18115.27807-.07715.12232-.1543.24439-.22461.37036-.06006.10694-.11475.217-.16992.32715-.05811.1167-.11719.23291-.16944.35181-.05566.126-.105.25513-.15429.38428-.04151.10913-.0835.218-.12012.32861-.04541.137-.084.27661-.12207.417-.03028.11084-.06055.22119-.08594.33325-.03027.13526-.05518.27271-.07861.41065-.02149.12524-.042.25024-.05762.37646-.01514.12427-.02588.24927-.03564.37525-.01075.14575-.01856.2915-.022.43774-.001.05615-.0083.11035-.0083.16651v168a8,8,0,0,0,16,0V172.13879c26.92334-18.16259,50.13623-8.22973,76.84863,3.21924,16.26368,6.96973,33.7754,14.47559,52.52247,14.47461,13.80859,0,28.2871-4.07226,43.42871-15.42773a8.00094,8.00094,0,0,0,3.20019-6.40039v-120A8.00023,8.00023,0,0,0,219.57764,40.84924Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216.00452",
        x2: "40",
        y2: "48.00452",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M39.99951,168.00452c64-48,112,48,176,0v-120c-64,48-112-48-176,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216.00452",
        x2: "40",
        y2: "48.00452",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M39.99951,168.00452c64-48,112,48,176,0v-120c-64,48-112-48-176,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216.00452",
        x2: "40",
        y2: "48.00452",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M39.99951,168.00452c64-48,112,48,176,0v-120c-64,48-112-48-176,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Flag = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$52(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Flag.displayName = "Flag";

var renderPathFor$53 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M72.00244,24h112a8,8,0,0,1,8,8V77.33333a8,8,0,0,1-1.6,4.8l-20.8,27.73334a8,8,0,0,0-1.6,4.8V224a8,8,0,0,1-8,8h-64a8,8,0,0,1-8-8V114.66667a8,8,0,0,0-1.6-4.8l-20.8-27.73334a8,8,0,0,1-1.6-4.8V32A8,8,0,0,1,72.00244,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128.00244",
        y1: "120",
        x2: "128.00244",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "64.00244",
        y1: "64",
        x2: "192.00244",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192.00244,77.33333a8,8,0,0,1-1.6,4.8l-20.8,27.73334a8,8,0,0,0-1.6,4.8V224a8,8,0,0,1-8,8h-64a8,8,0,0,1-8-8V114.66667a8,8,0,0,0-1.6-4.8l-20.8-27.73334a8,8,0,0,1-1.6-4.8V64h128Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M72.00244,24h112a8,8,0,0,1,8,8V77.33333a8,8,0,0,1-1.6,4.8l-20.8,27.73334a8,8,0,0,0-1.6,4.8V224a8,8,0,0,1-8,8h-64a8,8,0,0,1-8-8V114.66667a8,8,0,0,0-1.6-4.8l-20.8-27.73334a8,8,0,0,1-1.6-4.8V32A8,8,0,0,1,72.00244,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128.00244",
        y1: "120",
        x2: "128.00244",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "64.00244",
        y1: "64",
        x2: "192.00244",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M184.00244,16h-112a16.01833,16.01833,0,0,0-16,16V77.333a16.10105,16.10105,0,0,0,3.2002,9.60058l20.7998,27.7334V224a16.01833,16.01833,0,0,0,16,16h64a16.01833,16.01833,0,0,0,16-16l-.001-109.334,20.80274-27.7334a16.10719,16.10719,0,0,0,3.19824-9.59961V32A16.01833,16.01833,0,0,0,184.00244,16Zm-48,136a8,8,0,0,1-16,0V120a8,8,0,0,1,16,0ZM71.99805,56l-.00537-24H184.00244l.00049,24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M72.00244,24h112a8,8,0,0,1,8,8V77.33333a8,8,0,0,1-1.6,4.8l-20.8,27.73334a8,8,0,0,0-1.6,4.8V224a8,8,0,0,1-8,8h-64a8,8,0,0,1-8-8V114.66667a8,8,0,0,0-1.6-4.8l-20.8-27.73334a8,8,0,0,1-1.6-4.8V32A8,8,0,0,1,72.00244,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128.00244",
        y1: "120",
        x2: "128.00244",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "64.00244",
        y1: "64",
        x2: "192.00244",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M72.00244,24h112a8,8,0,0,1,8,8V77.33333a8,8,0,0,1-1.6,4.8l-20.8,27.73334a8,8,0,0,0-1.6,4.8V224a8,8,0,0,1-8,8h-64a8,8,0,0,1-8-8V114.66667a8,8,0,0,0-1.6-4.8l-20.8-27.73334a8,8,0,0,1-1.6-4.8V32A8,8,0,0,1,72.00244,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128.00244",
        y1: "120",
        x2: "128.00244",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "64.00244",
        y1: "64",
        x2: "192.00244",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M72.00244,24h112a8,8,0,0,1,8,8V77.33333a8,8,0,0,1-1.6,4.8l-20.8,27.73334a8,8,0,0,0-1.6,4.8V224a8,8,0,0,1-8,8h-64a8,8,0,0,1-8-8V114.66667a8,8,0,0,0-1.6-4.8l-20.8-27.73334a8,8,0,0,1-1.6-4.8V32A8,8,0,0,1,72.00244,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128.00244",
        y1: "120",
        x2: "128.00244",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "64.00244",
        y1: "64",
        x2: "192.00244",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Flashlight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$53(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Flashlight.displayName = "Flashlight";

var renderPathFor$54 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,91.31371V208a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H164.68629a8,8,0,0,1,5.65686,2.34315l43.3137,43.3137A8,8,0,0,1,216,91.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "156",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "156 92.009 100 92.009 100 40.009",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.65674,85.65686,170.34326,42.34314a8.00052,8.00052,0,0,0-5.657-2.343H48a7.99993,7.99993,0,0,0-8,8v160a8.00009,8.00009,0,0,0,8,8H208a8.00009,8.00009,0,0,0,8-8V91.3136A7.99918,7.99918,0,0,0,213.65674,85.65686Zm-85.65088,98.352a28,28,0,1,1,28-28A28,28,0,0,1,128.00586,184.00891Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M216,91.31371V208a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H164.68629a8,8,0,0,1,5.65686,2.34315l43.3137,43.3137A8,8,0,0,1,216,91.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128.00586",
        cy: "156.00903",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 96.009 96 96.009 96 40.009",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.31445,79.99963,176.001,36.68811a15.88944,15.88944,0,0,0-11.31446-4.68848h-60.687L104,32.0094v56h56a8,8,0,0,1,0,16H96a8.00039,8.00039,0,0,1-8-8v-64l.00049-.00977H48a16.01833,16.01833,0,0,0-16,16v160a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V91.31409A15.898,15.898,0,0,0,219.31445,79.99963ZM128.00586,176.0094a20,20,0,1,1,20-20A20.02229,20.02229,0,0,1,128.00586,176.0094Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,91.31371V208a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H164.68629a8,8,0,0,1,5.65686,2.34315l43.3137,43.3137A8,8,0,0,1,216,91.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128.00586",
        cy: "156.00903",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "160 96.009 96 96.009 96 40.009",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,91.31371V208a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H164.68629a8,8,0,0,1,5.65686,2.34315l43.3137,43.3137A8,8,0,0,1,216,91.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128.00586",
        cy: "156.00903",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "160 96.009 96 96.009 96 40.009",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,91.31371V208a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H164.68629a8,8,0,0,1,5.65686,2.34315l43.3137,43.3137A8,8,0,0,1,216,91.31371Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128.00586",
        cy: "156.00903",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 96.009 96 96.009 96 40.009",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FloppyDisk = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$54(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FloppyDisk.displayName = "FloppyDisk";

var renderPathFor$55 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M98.38675,46.68509,128,80H32V52a8,8,0,0,1,8-8H92.40747A8,8,0,0,1,98.38675,46.68509Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M98.34315,50.34315,128,80H32V56a8,8,0,0,1,8-8H92.68629A8,8,0,0,1,98.34315,50.34315Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99512,71.99805h-84.6875l-27.3125-27.3125a15.8907,15.8907,0,0,0-11.3125-4.6875H39.99512a16.01581,16.01581,0,0,0-16,16V200.61523a15.404,15.404,0,0,0,15.39062,15.38282h177.5a15.13062,15.13062,0,0,0,15.10938-15.10938V87.99805A16.01582,16.01582,0,0,0,215.99512,71.99805Zm-176-16h52.6875l16,16H39.99512Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Folder = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$55(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Folder.displayName = "Folder";

var renderPathFor$56 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,80V52a8,8,0,0,1,8-8H92.40747a8,8,0,0,1,5.97928,2.68509L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M98.34315,50.34315,128,80H32V56a8,8,0,0,1,8-8H92.68629A8,8,0,0,1,98.34315,50.34315Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99512,71.99805h-84.6875l-27.3125-27.3125a15.8907,15.8907,0,0,0-11.3125-4.6875H39.99512a16.01581,16.01581,0,0,0-16,16V200.61523a15.404,15.404,0,0,0,15.39062,15.38282h177.5a15.13062,15.13062,0,0,0,15.10938-15.10938V87.99805A16.01582,16.01582,0,0,0,215.99512,71.99805Zm-176-16h52.6875l16,16H39.99512Zm112,96.00195h-48a8,8,0,1,1,0-16h48a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FolderMinus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$56(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FolderMinus.displayName = "FolderMinus";

var renderPathFor$57 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99512,71.99805H130.65625L102.917,51.19336a16.07363,16.07363,0,0,0-9.57812-3.19531H39.99512a16.01581,16.01581,0,0,0-16,16v136a16.01582,16.01582,0,0,0,16,16h176a16.01583,16.01583,0,0,0,16-16v-112A16.01582,16.01582,0,0,0,215.99512,71.99805Zm-176-8H93.33887l21.32617,15.999-21.3418,16.001H39.99512Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FolderNotch = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$57(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FolderNotch.displayName = "FolderNotch";

var renderPathFor$58 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "103.99707",
        y1: "148",
        x2: "151.99707",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.99121",
        y1: "148",
        x2: "151.99121",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99512,71.99805H130.65625L102.917,51.19336a16.07363,16.07363,0,0,0-9.57812-3.19531H39.99512a16.01581,16.01581,0,0,0-16,16v136a16.01582,16.01582,0,0,0,16,16h176a16.01583,16.01583,0,0,0,16-16v-112A16.01582,16.01582,0,0,0,215.99512,71.99805Zm-176,24v-32H93.33887l21.32617,15.999-21.3418,16.001ZM151.99707,156h-48a8,8,0,0,1,0-16h48a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "103.99707",
        y1: "148",
        x2: "151.99707",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "103.99707",
        y1: "148",
        x2: "151.99707",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.99707",
        y1: "148",
        x2: "151.99707",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FolderNotchMinus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$58(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FolderNotchMinus.displayName = "FolderNotchMinus";

var renderPathFor$59 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,208V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H200a8,8,0,0,1,8,8v24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,208l29.93872-71.10446A8,8,0,0,1,69.3118,132h48.266a8,8,0,0,0,4.43761-1.3436l19.9692-13.3128A8,8,0,0,1,146.42221,116h82.32506a8,8,0,0,1,7.556,10.62816L208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M69.416,128h48.16162a8.00257,8.00257,0,0,0,4.438-1.34375l19.96876-13.3125A8.00257,8.00257,0,0,1,146.42236,112H208V88a7.99977,7.99977,0,0,0-8-8H130.6665a7.9995,7.9995,0,0,1-4.7998-1.6001L98.1333,57.6001A7.9995,7.9995,0,0,0,93.3335,56H40a7.99977,7.99977,0,0,0-8,8V208l29.98828-74.97119A8.00025,8.00025,0,0,1,69.416,128Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M32,208V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H200a8,8,0,0,1,8,8v24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,208l29.98845-74.97113A8,8,0,0,1,69.41626,128h48.16153a8,8,0,0,0,4.43761-1.3436l19.9692-13.3128A8,8,0,0,1,146.42221,112h82.47838a8,8,0,0,1,7.58947,10.52982L208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M241.88037,110.64453A16.03934,16.03934,0,0,0,228.90039,104H216V88a16.01833,16.01833,0,0,0-16-16H130.667l-27.7334-20.7998A16.10323,16.10323,0,0,0,93.333,48H40A16.01833,16.01833,0,0,0,24,64V208a8.06184,8.06184,0,0,0,.04541.8457c.00293.02735.00928.0542.0127.08155a7.86829,7.86829,0,0,0,.13818.81543c.01562.07226.03711.14306.05517.21484.05665.22559.12159.44775.19727.665.02734.07812.05566.15527.08545.23242q.126.33033.28076.64551c.03076.064.05908.12842.09229.1914a7.98135,7.98135,0,0,0,1.01318,1.49952c.06055.07129.12451.13769.1875.20654.14063.15381.28662.30176.43945.44434.07276.06787.145.13525.22022.20068.17187.14844.3501.28808.53418.42187.05469.04.10693.084.16308.12207a7.91673,7.91673,0,0,0,.77246.47168c.0254.01368.05225.02442.07764.0376a7.86248,7.86248,0,0,0,.73779.33594c.07129.02832.14405.05322.2168.07959q.31715.11572.64649.20459c.085.023.16894.04541.25439.06543.21875.05127.44092.09131.666.124.08154.01221.16259.02783.24462.0376A8.04614,8.04614,0,0,0,32,216H208a8.00117,8.00117,0,0,0,7.58984-5.47021l28.48926-85.47022A16.03873,16.03873,0,0,0,241.88037,110.64453ZM93.333,64l27.7334,20.7998A16.10323,16.10323,0,0,0,130.667,88H200v16H146.42188a15.9479,15.9479,0,0,0-8.875,2.6875L117.57812,120H69.416a15.92344,15.92344,0,0,0-14.85547,10.05762L40,166.45947V64Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,208V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H200a8,8,0,0,1,8,8v24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,208l29.98845-74.97113A8,8,0,0,1,69.41626,128h48.16153a8,8,0,0,0,4.43761-1.3436l19.9692-13.3128A8,8,0,0,1,146.42221,112h82.47838a8,8,0,0,1,7.58947,10.52982L208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,208V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H200a8,8,0,0,1,8,8v24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,208l29.98845-74.97113A8,8,0,0,1,69.41626,128h48.16153a8,8,0,0,0,4.43761-1.3436l19.9692-13.3128A8,8,0,0,1,146.42221,112h82.47838a8,8,0,0,1,7.58947,10.52982L208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,208V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H200a8,8,0,0,1,8,8v24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,208l29.98845-74.97113A8,8,0,0,1,69.41626,128h48.16153a8,8,0,0,0,4.43761-1.3436l19.9692-13.3128A8,8,0,0,1,146.42221,112h82.47838a8,8,0,0,1,7.58947,10.52982L208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FolderNotchOpen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$59(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FolderNotchOpen.displayName = "FolderNotchOpen";

var renderPathFor$5a = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "103.99707",
        y1: "148",
        x2: "151.99707",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "127.99707",
        y1: "124",
        x2: "127.99707",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.99121",
        y1: "148",
        x2: "151.99121",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99121",
        y1: "124",
        x2: "127.99121",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99512,71.99805H130.65625L102.917,51.19336a16.07363,16.07363,0,0,0-9.57812-3.19531H39.99512a16.01581,16.01581,0,0,0-16,16v136a16.01582,16.01582,0,0,0,16,16h176a16.01583,16.01583,0,0,0,16-16v-112A16.01582,16.01582,0,0,0,215.99512,71.99805Zm-176,24v-32H93.33887l21.32617,15.999-21.3418,16.001ZM151.99707,156h-16v16a8,8,0,0,1-16,0V156h-16a8,8,0,0,1,0-16h16V124a8,8,0,0,1,16,0v16h16a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "103.99707",
        y1: "148",
        x2: "151.99707",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.99707",
        y1: "124",
        x2: "127.99707",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "103.99707",
        y1: "148",
        x2: "151.99707",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "127.99707",
        y1: "124",
        x2: "127.99707",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,80h88a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H40a8.02352,8.02352,0,0,1-8-8V104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M93.33333,104H32V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6L128,80,98.13333,102.4A8,8,0,0,1,93.33333,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.99707",
        y1: "148",
        x2: "151.99707",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99707",
        y1: "124",
        x2: "127.99707",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FolderNotchPlus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5a(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FolderNotchPlus.displayName = "FolderNotchPlus";

var renderPathFor$5b = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,208V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H200a8,8,0,0,1,8,8v24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,208l30.13154-86.62816A8,8,0,0,1,69.68751,116H228.74727a8,8,0,0,1,7.556,10.62816L208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,208l30.17661-90.52982A8,8,0,0,1,69.76607,112H208V88a8,8,0,0,0-8-8H130.66667a8,8,0,0,1-4.8-1.6L98.13333,57.6a8,8,0,0,0-4.8-1.6H40a8,8,0,0,0-8,8Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M32,208V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H200a8,8,0,0,1,8,8v24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,208l30.17661-90.52982A8,8,0,0,1,69.76607,112H228.90059a8,8,0,0,1,7.58947,10.52982L208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M241.88037,110.64453A16.03934,16.03934,0,0,0,228.90039,104H216V88a16.01833,16.01833,0,0,0-16-16H130.667l-27.7334-20.7998A16.10323,16.10323,0,0,0,93.333,48H40A16.01833,16.01833,0,0,0,24,64V208c0,.05127.00684.10059.00781.15137.002.1123.00977.22412.0166.33642.01172.19043.02832.37891.05274.56592q.02051.15234.04639.30371c.03515.20459.07861.40576.1289.605.021.08252.04.16553.064.24756.06836.23877.14843.47217.23779.70117.0166.042.02978.08545.04687.12793a7.867,7.867,0,0,0,.39014.81592c.01563.02881.03467.05566.05078.084q.1919.33912.41553.65625c.019.02686.0332.05567.05225.08252.03564.04883.07763.09082.11377.13916.12255.16163.24951.31885.38378.47022.06836.07764.13672.1543.20752.22851.14161.14844.29.29.44287.42725.064.05713.125.11768.19043.17285a7.94692,7.94692,0,0,0,.69581.52832l.01953.01172a7.96822,7.96822,0,0,0,.73632.43311c.064.0332.12989.0625.19483.09375.19971.09765.40332.18847.61182.26953.0791.03027.1582.05859.23828.08691q.30176.1062.61377.188c.08447.02246.168.04541.25293.06494.21386.04883.43164.08643.65185.11817.0791.01123.15674.02685.23633.03613A8.06189,8.06189,0,0,0,32,216H208a8.00117,8.00117,0,0,0,7.58984-5.47021l28.48926-85.47022A16.039,16.039,0,0,0,241.88037,110.64453ZM93.333,64l27.7334,20.7998A16.10323,16.10323,0,0,0,130.667,88H200v16H69.76611a15.98037,15.98037,0,0,0-15.1792,10.94043L40,158.70166V64Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,208V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H200a8,8,0,0,1,8,8v24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,208l30.17661-90.52982A8,8,0,0,1,69.76607,112H228.90059a8,8,0,0,1,7.58947,10.52982L208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,208V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H200a8,8,0,0,1,8,8v24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,208l30.17661-90.52982A8,8,0,0,1,69.76607,112H228.90059a8,8,0,0,1,7.58947,10.52982L208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,208V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H200a8,8,0,0,1,8,8v24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,208l30.17661-90.52982A8,8,0,0,1,69.76607,112H228.90059a8,8,0,0,1,7.58947,10.52982L208,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FolderOpen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5b(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FolderOpen.displayName = "FolderOpen";

var renderPathFor$5c = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,80V52a8,8,0,0,1,8-8H92.40747a8,8,0,0,1,5.97928,2.68509L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M98.34315,50.34315,128,80H32V56a8,8,0,0,1,8-8H92.68629A8,8,0,0,1,98.34315,50.34315Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.99414",
        y1: "144",
        x2: "151.99414",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "120",
        x2: "127.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99512,71.99805h-84.6875l-27.3125-27.3125a15.8907,15.8907,0,0,0-11.3125-4.6875H39.99512a16.01581,16.01581,0,0,0-16,16V200.61523a15.404,15.404,0,0,0,15.39062,15.38282h177.5a15.13062,15.13062,0,0,0,15.10938-15.10938V87.99805A16.01582,16.01582,0,0,0,215.99512,71.99805Zm-176-16h52.6875l16,16H39.99512Zm112,96.00195h-16v16a8,8,0,1,1-16,0V152h-16a8,8,0,1,1,0-16h16V120a8,8,0,1,1,16,0v16h16a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.88889,208H39.38462A7.40633,7.40633,0,0,1,32,200.61538V80H216a8,8,0,0,1,8,8V200.88889A7.11111,7.11111,0,0,1,216.88889,208Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,80V56a8,8,0,0,1,8-8H92.68629a8,8,0,0,1,5.65686,2.34315L128,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FolderPlus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5c(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FolderPlus.displayName = "FolderPlus";

var renderPathFor$5d = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99512,71.99805H130.667l-27.75-20.80469a16.07363,16.07363,0,0,0-9.57812-3.19531H39.99512a16.01581,16.01581,0,0,0-16,16v136a16.01582,16.01582,0,0,0,16,16H216.88574a15.13062,15.13062,0,0,0,15.10938-15.10938V87.99805A16.01582,16.01582,0,0,0,215.99512,71.99805Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FolderSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5d(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FolderSimple.displayName = "FolderSimple";

var renderPathFor$5e = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "103.99414",
        y1: "144",
        x2: "151.99414",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99512,71.99805H130.667l-27.75-20.80469a16.07363,16.07363,0,0,0-9.57812-3.19531H39.99512a16.01581,16.01581,0,0,0-16,16v136a16.01582,16.01582,0,0,0,16,16H216.88574a15.13062,15.13062,0,0,0,15.10938-15.10938V87.99805A16.01582,16.01582,0,0,0,215.99512,71.99805ZM151.99414,152h-48a8,8,0,0,1,0-16h48a8,8,0,1,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FolderSimpleMinus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5e(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FolderSimpleMinus.displayName = "FolderSimpleMinus";

var renderPathFor$5f = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.99414",
        y1: "144",
        x2: "151.99414",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "120",
        x2: "127.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99512,71.99805H130.667l-27.75-20.80469a16.07363,16.07363,0,0,0-9.57812-3.19531H39.99512a16.01581,16.01581,0,0,0-16,16v136a16.01582,16.01582,0,0,0,16,16H216.88574a15.13062,15.13062,0,0,0,15.10938-15.10938V87.99805A16.01582,16.01582,0,0,0,215.99512,71.99805ZM152,152H136v16a8,8,0,0,1-16,0V152H104a8,8,0,0,1,0-16h16V120a8,8,0,0,1,16,0v16h16a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88V200.88889A7.11111,7.11111,0,0,1,216.88889,208H40a8,8,0,0,1-8-8V64a8,8,0,0,1,8-8H93.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H216A8,8,0,0,1,224,88Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "144",
        x2: "152",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "120",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FolderSimplePlus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5f(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FolderSimplePlus.displayName = "FolderSimplePlus";

var renderPathFor$5g = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M196,116v88.88889A7.11111,7.11111,0,0,1,188.88889,212H36a8,8,0,0,1-8-8V92a8,8,0,0,1,8-8H81.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H188A8,8,0,0,1,196,116Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M68,84V52a8,8,0,0,1,8-8h45.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H228a8,8,0,0,1,8,8v88.88889A7.11111,7.11111,0,0,1,228.88889,172H196",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,72H154.6665a7.99938,7.99938,0,0,1-4.7998-1.6L122.1333,49.6a7.99938,7.99938,0,0,0-4.7998-1.6H72a7.99993,7.99993,0,0,0-8,8V80H85.3335a7.99938,7.99938,0,0,1,4.7998,1.6l27.7334,20.8a7.99938,7.99938,0,0,0,4.7998,1.6H192a7.99993,7.99993,0,0,1,8,8v64h24.88867A7.1111,7.1111,0,0,0,232,168.88892V80A7.99993,7.99993,0,0,0,224,72Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M200,112v88.88889A7.11111,7.11111,0,0,1,192.88889,208H40a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8H85.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H192A8,8,0,0,1,200,112Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M64,80V56a8,8,0,0,1,8-8h45.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H224a8,8,0,0,1,8,8v88.88889A7.11111,7.11111,0,0,1,224.88889,176H200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,64H154.667l-27.7334-20.7998A16.10323,16.10323,0,0,0,117.333,40H72A16.01833,16.01833,0,0,0,56,56V72H40A16.01833,16.01833,0,0,0,24,88V200a16.01833,16.01833,0,0,0,16,16H192.88867A15.12831,15.12831,0,0,0,208,200.88867V184h16.88867A15.12831,15.12831,0,0,0,240,168.88867V80A16.01833,16.01833,0,0,0,224,64Zm0,104H208V112a16.01833,16.01833,0,0,0-16-16H122.667L94.93359,75.2002A16.10323,16.10323,0,0,0,85.333,72H72V56h45.333l27.7334,20.7998A16.10323,16.10323,0,0,0,154.667,80H224Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,112v88.88889A7.11111,7.11111,0,0,1,192.88889,208H40a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8H85.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H192A8,8,0,0,1,200,112Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M64,80V56a8,8,0,0,1,8-8h45.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H224a8,8,0,0,1,8,8v88.88889A7.11111,7.11111,0,0,1,224.88889,176H200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,112v88.88889A7.11111,7.11111,0,0,1,192.88889,208H40a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8H85.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H192A8,8,0,0,1,200,112Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M64,80V56a8,8,0,0,1,8-8h45.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H224a8,8,0,0,1,8,8v88.88889A7.11111,7.11111,0,0,1,224.88889,176H200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,112v88.88889A7.11111,7.11111,0,0,1,192.88889,208H40a8,8,0,0,1-8-8V88a8,8,0,0,1,8-8H85.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H192A8,8,0,0,1,200,112Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M64,80V56a8,8,0,0,1,8-8h45.33333a8,8,0,0,1,4.8,1.6l27.73334,20.8a8,8,0,0,0,4.8,1.6H224a8,8,0,0,1,8,8v88.88889A7.11111,7.11111,0,0,1,224.88889,176H200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Folders = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5g(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Folders.displayName = "Folders";

var renderPathFor$5h = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "84",
        y1: "32",
        x2: "84",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "84",
        y1: "116",
        x2: "84",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M120,32V80a36,36,0,0,1-72,0V32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M204,160H148S160,48,204,32V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M204,160H148S160,48,204,32",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "84",
        y1: "32",
        x2: "84",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "84",
        y1: "116",
        x2: "84",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M112,32l8,48a36,36,0,0,1-72,0l8-48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M204,160H148S160,48,204,32V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M127.98877,79.77539c-.00439-.14453-.00977-.28906-.022-.43457-.01221-.146-.03028-.29-.04981-.43359-.01074-.07422-.01367-.14795-.02588-.22266l-8-48a8,8,0,1,0-15.78222,2.63086L110.55615,72H92V32a8,8,0,0,0-16,0V72H57.44385l6.44726-38.68457a8,8,0,1,0-15.78222-2.63086l-8,48c-.01221.07471-.01514.14844-.02588.22266-.01953.14355-.0376.28759-.04981.43359-.0122.14551-.01758.29-.022.43457C40.00928,79.85059,40,79.92432,40,80c0,.07129.00488.14111.00537.21191.00147.04932.00147.09815.00391.147A44.06056,44.06056,0,0,0,76,123.25781V224a8,8,0,0,0,16,0V123.25781a44.06056,44.06056,0,0,0,35.99072-42.89892c.00244-.04883.00244-.09766.00391-.147C127.99512,80.14111,128,80.07129,128,80,128,79.92432,127.99072,79.85059,127.98877,79.77539Z"
      }), React__default.createElement("path", {
        d: "M211.99268,31.8584c-.00245-.165-.01172-.33008-.02491-.49561-.00879-.1123-.019-.22363-.03271-.33447-.01709-.13818-.03858-.27637-.063-.41455-.02441-.13916-.05127-.27686-.08252-.41309-.02539-.10839-.05371-.2163-.0835-.32422-.04443-.16064-.09228-.31884-.14648-.47509-.01514-.04492-.0249-.09033-.041-.13526-.01806-.04834-.041-.09326-.05957-.14111q-.09081-.23511-.19531-.46191-.06738-.148-.14062-.292-.09888-.19335-.208-.38037c-.06445-.11181-.13037-.22168-.19971-.32959-.06592-.10156-.13476-.20019-.20508-.29883-.08447-.11914-.17041-.23584-.26123-.34912-.0664-.08349-.13574-.16406-.20507-.24463-.1001-.11523-.20166-.229-.30762-.33789-.07422-.07617-.15137-.14941-.22852-.22265-.10644-.10156-.21386-.20117-.32568-.29639-.08984-.07666-.18311-.14892-.27637-.22168-.10449-.08105-.20947-.16162-.31787-.23779-.11084-.07764-.2251-.15039-.33984-.22217-.09717-.061-.19434-.12256-.29444-.1792-.13037-.07422-.26367-.14258-.39843-.20947-.09229-.0459-.18409-.0918-.27832-.13428-.14161-.06348-.28565-.12109-.43165-.17676-.09667-.03662-.19287-.07324-.2915-.10644-.13965-.04737-.28174-.08887-.4248-.12842-.11426-.03174-.228-.06152-.34327-.08838-.12695-.02881-.25537-.05371-.38427-.07666-.14063-.02539-.28076-.04687-.42285-.06445-.10889-.01319-.21827-.02393-.32862-.03321q-.24535-.01977-.49365-.0249C204.10352,24.00684,204.05273,24,204,24c-.04834,0-.0957.00635-.14355.00732-.16407.00293-.32813.01172-.49268.02491-.11279.00879-.22461.019-.33594.03271-.13818.01709-.27588.03858-.41406.063-.13916.02441-.27686.05127-.41309.083-.10839.0249-.2163.05322-.32422.083-.16064.04394-.31884.09228-.47509.14648-.04492.01514-.09033.0249-.13526.041-.09863.03613-.1958.0791-.29394.11572-.03711.01513-.0752.02832-.11231.04394-20.60986,7.74561-37.11474,33.0293-49.05713,75.17823a398.22183,398.22183,0,0,0-11.75683,59.32812A8.00051,8.00051,0,0,0,148,168h48v56a8,8,0,0,0,16,0V32C212,31.95215,211.99365,31.90625,211.99268,31.8584Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "84",
        y1: "32",
        x2: "84",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "84",
        y1: "116",
        x2: "84",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M112,32l8,48a36,36,0,0,1-72,0l8-48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M204,160H148S160,48,204,32V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "84",
        y1: "32",
        x2: "84",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "84",
        y1: "116",
        x2: "84",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M112,32l8,48a36,36,0,0,1-72,0l8-48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M204,160H148S160,48,204,32V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "84",
        y1: "32",
        x2: "84",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "84",
        y1: "116",
        x2: "84",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M112,32l8,48a36,36,0,0,1-72,0l8-48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M204,160H148S160,48,204,32V224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ForkKnife = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5h(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ForkKnife.displayName = "ForkKnife";

var renderPathFor$5i = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "56 100 56 168 128 236 128 168 200 168 56 32 200 32 200 100 56 100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "56 100 56 168 128 236 128 168 200 168 56 32 200 32 200 100 56 100",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "56 100 56 168 128 236 128 168 200 168 56 32 200 32 200 100 56 100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,100V32a8.00008,8.00008,0,0,0-8-8H56a8,8,0,0,0-5.49316,13.81592L107.87793,92H56a8.00008,8.00008,0,0,0-8,8v68a7.99941,7.99941,0,0,0,2.50684,5.81592l72,68A7.99984,7.99984,0,0,0,136,236V176h64a8,8,0,0,0,5.49316-13.81592L148.12207,108H200A8.00008,8.00008,0,0,0,208,100Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "56 100 56 168 128 236 128 168 200 168 56 32 200 32 200 100 56 100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "56 100 56 168 128 236 128 168 200 168 56 32 200 32 200 100 56 100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "56 100 56 168 128 236 128 168 200 168 56 32 200 32 200 100 56 100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FramerLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5i(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FramerLogo.displayName = "FramerLogo";

var renderPathFor$5j = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M42.08441,48H213.91559a8,8,0,0,1,5.91952,13.38138l-65.75463,72.33009A8,8,0,0,0,152,139.09285v56.62568a8,8,0,0,1-3.5624,6.6564l-32,21.33334A8,8,0,0,1,104,217.05186v-77.959a8,8,0,0,0-2.08048-5.38138L36.16489,61.38138A8,8,0,0,1,42.08441,48Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M42.08441,48H213.91559a8,8,0,0,1,5.91952,13.38138l-65.75463,72.33009A8,8,0,0,0,152,139.09285v56.62568a8,8,0,0,1-3.5624,6.6564l-32,21.33334A8,8,0,0,1,104,217.05186v-77.959a8,8,0,0,0-2.08048-5.38138L36.16489,61.38138A8,8,0,0,1,42.08441,48Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M42.08441,48H213.91559a8,8,0,0,1,5.91952,13.38138l-65.75463,72.33009A8,8,0,0,0,152,139.09285v56.62568a8,8,0,0,1-3.5624,6.6564l-32,21.33334A8,8,0,0,1,104,217.05186v-77.959a8,8,0,0,0-2.08048-5.38138L36.16489,61.38138A8,8,0,0,1,42.08441,48Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M228.54736,49.52637A15.80639,15.80639,0,0,0,213.91553,40H42.08447A16.00043,16.00043,0,0,0,30.24561,66.76367L96,139.09277v77.959a15.99388,15.99388,0,0,0,24.875,13.3125l31.99951-21.332A15.96822,15.96822,0,0,0,160,195.71875v-56.625l65.75488-72.331A15.80708,15.80708,0,0,0,228.54736,49.52637Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M42.08441,48H213.91559a8,8,0,0,1,5.91952,13.38138l-65.75463,72.33009A8,8,0,0,0,152,139.09285v56.62568a8,8,0,0,1-3.5624,6.6564l-32,21.33334A8,8,0,0,1,104,217.05186v-77.959a8,8,0,0,0-2.08048-5.38138L36.16489,61.38138A8,8,0,0,1,42.08441,48Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M42.08441,48H213.91559a8,8,0,0,1,5.91952,13.38138l-65.75463,72.33009A8,8,0,0,0,152,139.09285v56.62568a8,8,0,0,1-3.5624,6.6564l-32,21.33334A8,8,0,0,1,104,217.05186v-77.959a8,8,0,0,0-2.08048-5.38138L36.16489,61.38138A8,8,0,0,1,42.08441,48Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M42.08441,48H213.91559a8,8,0,0,1,5.91952,13.38138l-65.75463,72.33009A8,8,0,0,0,152,139.09285v56.62568a8,8,0,0,1-3.5624,6.6564l-32,21.33334A8,8,0,0,1,104,217.05186v-77.959a8,8,0,0,0-2.08048-5.38138L36.16489,61.38138A8,8,0,0,1,42.08441,48Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Funnel = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5j(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Funnel.displayName = "Funnel";

var renderPathFor$5k = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "128",
        x2: "192",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "80",
        x2: "232",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "176",
        x2: "152",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "128",
        x2: "192",
        y2: "128",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "80",
        x2: "232",
        y2: "80",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "176",
        x2: "152",
        y2: "176",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M192,120H64a8,8,0,0,0,0,16H192a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M232,72H24a8,8,0,0,0,0,16H232a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M152,168H104a8,8,0,0,0,0,16h48a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "128",
        x2: "192",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "80",
        x2: "232",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "176",
        x2: "152",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "128",
        x2: "192",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "80",
        x2: "232",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "176",
        x2: "152",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "64",
        y1: "128",
        x2: "192",
        y2: "128",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "80",
        x2: "232",
        y2: "80",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "176",
        x2: "152",
        y2: "176",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var FunnelSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5k(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
FunnelSimple.displayName = "FunnelSimple";

var renderPathFor$5l = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152",
        y1: "108",
        x2: "184",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "108",
        x2: "104",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "92",
        x2: "88",
        y2: "124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M172.01831,55.7398,84.00446,56A52.01509,52.01509,0,0,0,32.78594,98.96873l.00852.00156-16.3644,84.16289A28.00192,28.00192,0,0,0,63.80532,207.796l-.00165-.00173L107.03924,160l64.97907-.2602a52,52,0,0,0,0-104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M223.22831,98.71009l16.351,84.42309A28.00192,28.00192,0,0,1,192.204,207.796l.00166-.00173L149,159.832",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M149,159.832l23.01835-.09217a52.04589,52.04589,0,0,0,51.21853-61.03119l-.00853.00148,16.351,84.42309A28.00192,28.00192,0,0,1,192.204,207.796l.00166-.00173L149,159.832Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "108",
        x2: "184",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "108",
        x2: "104",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "92",
        x2: "88",
        y2: "124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M172.01831,55.7398,84.00446,56A52.01509,52.01509,0,0,0,32.78594,98.96873l.00852.00156-16.3644,84.16289A28.00192,28.00192,0,0,0,63.80532,207.796l-.00165-.00173L107.03924,160l64.97907-.2602a52,52,0,0,0,0-104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M223.22831,98.71009l16.351,84.42309A28.00192,28.00192,0,0,1,192.204,207.796l.00166-.00173L149,159.832",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M247.45752,181.74316c-.00781-.04394-.01611-.08789-.02441-.13183L231.08252,97.18848c-.01221-.06348-.0321-.123-.0459-.186a60.08639,60.08639,0,0,0-59.01855-49.26221h-.02344L84.00439,48A59.86832,59.86832,0,0,0,24.90625,97.58887c-.0127.07226-.02441.14551-.03516.21777L8.57715,181.60547c-.00879.0459-.01709.0918-.02539.13769A36.00238,36.00238,0,0,0,69.45752,213.457q.21753-.2168.416-.44726l40.729-45.02442,34.84961-.13916,40.67139,45.14893q.20361.2373.42822.46191a36.00125,36.00125,0,0,0,60.90576-31.71387ZM104,116H96v8a8,8,0,0,1-16,0v-8H72a8,8,0,0,1,0-16h8V92a8,8,0,0,1,16,0v8h8a8,8,0,0,1,0,16Zm40-8a8.00008,8.00008,0,0,1,8-8h32a8,8,0,0,1,0,16H152A8.00008,8.00008,0,0,1,144,108Zm71.47754,99.69141a20.03371,20.03371,0,0,1-17.45606-5.39453l-31.11169-34.53614,5.10828-.02051a60.00525,60.00525,0,0,0,50.94067-28.34961l8.75269,45.19239A20.02155,20.02155,0,0,1,215.47754,207.69141Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152",
        y1: "108",
        x2: "184",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "108",
        x2: "104",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "92",
        x2: "88",
        y2: "124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M172.01831,55.7398,84.00446,56A52.01509,52.01509,0,0,0,32.78594,98.96873l.00852.00156-16.3644,84.16289A28.00192,28.00192,0,0,0,63.80532,207.796l-.00165-.00173L107.03924,160l64.97907-.2602a52,52,0,0,0,0-104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M223.22831,98.71009l16.351,84.42309A28.00192,28.00192,0,0,1,192.204,207.796l.00166-.00173L149,159.832",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152",
        y1: "108",
        x2: "184",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "108",
        x2: "104",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "92",
        x2: "88",
        y2: "124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M172.01831,55.7398,84.00446,56A52.01509,52.01509,0,0,0,32.78594,98.96873l.00852.00156-16.3644,84.16289A28.00192,28.00192,0,0,0,63.80532,207.796l-.00165-.00173L107.03924,160l64.97907-.2602a52,52,0,0,0,0-104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M223.22831,98.71009l16.351,84.42309A28.00192,28.00192,0,0,1,192.204,207.796l.00166-.00173L149,159.832",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152",
        y1: "108",
        x2: "184",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "108",
        x2: "104",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "92",
        x2: "88",
        y2: "124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M172.01831,55.7398,84.00446,56A52.01509,52.01509,0,0,0,32.78594,98.96873l.00852.00156-16.3644,84.16289A28.00192,28.00192,0,0,0,63.80532,207.796l-.00165-.00173L107.03924,160l64.97907-.2602a52,52,0,0,0,0-104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M223.22831,98.71009l16.351,84.42309A28.00192,28.00192,0,0,1,192.204,207.796l.00166-.00173L149,159.832",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GameController = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5l(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GameController.displayName = "GameController";

var renderPathFor$5m = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M216.001,120.001l10.30713-15.4603a8.18367,8.18367,0,0,0,1.07094-6.86806,103.18961,103.18961,0,0,0-7.652-18.50824,8.14437,8.14437,0,0,0-5.60531-4.08483l-18.23792-3.64791L184.57031,60.11816l-3.64788-18.23862a8.14452,8.14452,0,0,0-4.08517-5.60564,103.21306,103.21306,0,0,0-18.50891-7.65085,8.18366,8.18366,0,0,0-6.868,1.07071L136.001,40h-16L104.54162,29.69376a8.18369,8.18369,0,0,0-6.868-1.07071,103.21412,103.21412,0,0,0-18.50876,7.65077,8.1445,8.1445,0,0,0-4.08522,5.60591l-3.647,18.23746L60.11816,71.43164l-18.23762,3.647a8.14428,8.14428,0,0,0-5.60569,4.08493,103.19818,103.19818,0,0,0-7.652,18.50915,8.18354,8.18354,0,0,0,1.0709,6.86786L40,120v16L29.6937,151.45945a8.18369,8.18369,0,0,0-1.07072,6.86784,103.1749,103.1749,0,0,0,7.65075,18.50925,8.1448,8.1448,0,0,0,5.60561,4.08487l18.23882,3.64793,11.31348,11.31347,3.64709,18.2387a8.14473,8.14473,0,0,0,4.08479,5.60582A103.14826,103.14826,0,0,0,97.672,227.37827a8.18362,8.18362,0,0,0,6.86744-1.07079L120,216.001h16l15.46031,10.30714a8.18353,8.18353,0,0,0,6.868,1.07073,103.18533,103.18533,0,0,0,18.5082-7.65063,8.14479,8.14479,0,0,0,4.08487-5.6056l3.64793-18.23883,11.31347-11.31445,18.23862-3.64708a8.14431,8.14431,0,0,0,5.6057-4.08491,103.18916,103.18916,0,0,0,7.65192-18.508,8.18367,8.18367,0,0,0-1.07094-6.86806L216.001,136.001Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.001,136.001v-16l10.30761-15.46a8.18339,8.18339,0,0,0,1.07032-6.86817,103.25262,103.25262,0,0,0-7.65137-18.50879,8.14738,8.14738,0,0,0-5.60547-4.085l-18.23828-3.64746L184.57031,60.11816l-3.64746-18.23828a8.14916,8.14916,0,0,0-4.085-5.60644,103.22723,103.22723,0,0,0-18.50977-7.65039,8.18466,8.18466,0,0,0-6.86718,1.07031L136.001,40h-16L104.542,29.69336a8.1863,8.1863,0,0,0-6.86816-1.07031A103.18841,103.18841,0,0,0,79.165,36.27344a8.14352,8.14352,0,0,0-4.085,5.60644L71.43262,60.11719,60.11816,71.43164,41.88086,75.0791a8.14174,8.14174,0,0,0-5.60547,4.085,103.154,103.154,0,0,0-7.65234,18.50879,8.18373,8.18373,0,0,0,1.07129,6.86817L40,120v16L29.69434,151.459a8.18374,8.18374,0,0,0-1.07129,6.86817,103.15966,103.15966,0,0,0,7.65136,18.50976,8.14535,8.14535,0,0,0,5.60547,4.085l18.23828,3.64746,11.31348,11.31347,3.64746,18.23828a8.14352,8.14352,0,0,0,4.085,5.60645,103.06694,103.06694,0,0,0,18.50781,7.65039,8.18635,8.18635,0,0,0,6.86817-1.07031L120,216.001h16l15.46094,10.30761a8.18467,8.18467,0,0,0,6.86718,1.07032,103.24856,103.24856,0,0,0,18.50879-7.65039,8.14735,8.14735,0,0,0,4.085-5.60547l3.64747-18.23926,11.31347-11.31445,18.23926-3.64746a8.14178,8.14178,0,0,0,5.60547-4.085,103.21317,103.21317,0,0,0,7.65137-18.50781,8.18336,8.18336,0,0,0-1.07032-6.86816Zm-88,48a56,56,0,1,1,56-56A56.00027,56.00027,0,0,1,128.001,184.001Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128.00098",
        cy: "128.00049",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M216.001,120.001l10.30713-15.4603a8.18367,8.18367,0,0,0,1.07094-6.86806,103.18961,103.18961,0,0,0-7.652-18.50824,8.14437,8.14437,0,0,0-5.60531-4.08483l-18.23792-3.64791L184.57031,60.11816l-3.64788-18.23862a8.14452,8.14452,0,0,0-4.08517-5.60564,103.21306,103.21306,0,0,0-18.50891-7.65085,8.18366,8.18366,0,0,0-6.868,1.07071L136.001,40h-16L104.54162,29.69376a8.18369,8.18369,0,0,0-6.868-1.07071,103.21412,103.21412,0,0,0-18.50876,7.65077,8.1445,8.1445,0,0,0-4.08522,5.60591l-3.647,18.23746L60.11816,71.43164l-18.23762,3.647a8.14428,8.14428,0,0,0-5.60569,4.08493,103.19818,103.19818,0,0,0-7.652,18.50915,8.18354,8.18354,0,0,0,1.0709,6.86786L40,120v16L29.6937,151.45945a8.18369,8.18369,0,0,0-1.07072,6.86784,103.1749,103.1749,0,0,0,7.65075,18.50925,8.1448,8.1448,0,0,0,5.60561,4.08487l18.23882,3.64793,11.31348,11.31347,3.64709,18.2387a8.14473,8.14473,0,0,0,4.08479,5.60582A103.14826,103.14826,0,0,0,97.672,227.37827a8.18362,8.18362,0,0,0,6.86744-1.07079L120,216.001h16l15.46031,10.30714a8.18353,8.18353,0,0,0,6.868,1.07073,103.18533,103.18533,0,0,0,18.5082-7.65063,8.14479,8.14479,0,0,0,4.08487-5.6056l3.64793-18.23883,11.31347-11.31445,18.23862-3.64708a8.14431,8.14431,0,0,0,5.6057-4.08491,103.18916,103.18916,0,0,0,7.65192-18.508,8.18367,8.18367,0,0,0-1.07094-6.86806L216.001,136.001Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232.96484,147.02344l-8.96093-13.44531V122.42188l8.95312-13.42969a16.29268,16.29268,0,0,0,2.07813-13.64063,111.35623,111.35623,0,0,0-8.25-19.96093,16.10264,16.10264,0,0,0-11.09375-8.15625L199.832,64.0625l-7.89062-7.89062L188.76953,40.3125a16.087,16.087,0,0,0-8.17187-11.10156,111.876,111.876,0,0,0-19.9375-8.24219,16.1518,16.1518,0,0,0-13.64063,2.07031L133.582,32H122.42578l-13.44531-8.96094a16.07924,16.07924,0,0,0-13.625-2.07031,111.35633,111.35633,0,0,0-19.96094,8.25A16.03535,16.03535,0,0,0,67.23828,40.3125L64.06641,56.17188,56.17578,64.0625l-15.875,3.17188a16.04953,16.04953,0,0,0-11.08594,8.16406,111.902,111.902,0,0,0-8.25,19.94531,16.11138,16.11138,0,0,0,2.07032,13.63281l8.96875,13.44532v11.15625l-8.97657,13.45312a16.11465,16.11465,0,0,0-2.0625,13.625,111.27469,111.27469,0,0,0,8.25,19.92969,16.02367,16.02367,0,0,0,11.09375,8.17969l15.86719,3.17187,7.89063,7.89063,3.17187,15.85156a15.99408,15.99408,0,0,0,8.15625,11.10937,110.83629,110.83629,0,0,0,19.94531,8.23438,15.93362,15.93362,0,0,0,13.64063-2.0625L122.42578,224H133.582l13.4375,8.96094a16.27,16.27,0,0,0,9.01563,2.76562,15.88124,15.88124,0,0,0,4.625-.69531,111.48249,111.48249,0,0,0,19.92968-8.24219,15.97484,15.97484,0,0,0,8.17188-11.09375l3.17187-15.86718,7.89844-7.89063,15.86719-3.17187a16.11139,16.11139,0,0,0,11.09375-8.17188,111.43838,111.43838,0,0,0,8.24219-19.9375A16.28784,16.28784,0,0,0,232.96484,147.02344ZM128.001,176.001a48,48,0,1,1,48-48A48.0005,48.0005,0,0,1,128.001,176.001Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00098",
        cy: "128.00049",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M216.001,120.001l10.30713-15.4603a8.18367,8.18367,0,0,0,1.07094-6.86806,103.18961,103.18961,0,0,0-7.652-18.50824,8.14437,8.14437,0,0,0-5.60531-4.08483l-18.23792-3.64791L184.57031,60.11816l-3.64788-18.23862a8.14452,8.14452,0,0,0-4.08517-5.60564,103.21306,103.21306,0,0,0-18.50891-7.65085,8.18366,8.18366,0,0,0-6.868,1.07071L136.001,40h-16L104.54162,29.69376a8.18369,8.18369,0,0,0-6.868-1.07071,103.21412,103.21412,0,0,0-18.50876,7.65077,8.1445,8.1445,0,0,0-4.08522,5.60591l-3.647,18.23746L60.11816,71.43164l-18.23762,3.647a8.14428,8.14428,0,0,0-5.60569,4.08493,103.19818,103.19818,0,0,0-7.652,18.50915,8.18354,8.18354,0,0,0,1.0709,6.86786L40,120v16L29.6937,151.45945a8.18369,8.18369,0,0,0-1.07072,6.86784,103.1749,103.1749,0,0,0,7.65075,18.50925,8.1448,8.1448,0,0,0,5.60561,4.08487l18.23882,3.64793,11.31348,11.31347,3.64709,18.2387a8.14473,8.14473,0,0,0,4.08479,5.60582A103.14826,103.14826,0,0,0,97.672,227.37827a8.18362,8.18362,0,0,0,6.86744-1.07079L120,216.001h16l15.46031,10.30714a8.18353,8.18353,0,0,0,6.868,1.07073,103.18533,103.18533,0,0,0,18.5082-7.65063,8.14479,8.14479,0,0,0,4.08487-5.6056l3.64793-18.23883,11.31347-11.31445,18.23862-3.64708a8.14431,8.14431,0,0,0,5.6057-4.08491,103.18916,103.18916,0,0,0,7.65192-18.508,8.18367,8.18367,0,0,0-1.07094-6.86806L216.001,136.001Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00098",
        cy: "128.00049",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M216.001,120.001l10.30713-15.4603a8.18367,8.18367,0,0,0,1.07094-6.86806,103.18961,103.18961,0,0,0-7.652-18.50824,8.14437,8.14437,0,0,0-5.60531-4.08483l-18.23792-3.64791L184.57031,60.11816l-3.64788-18.23862a8.14452,8.14452,0,0,0-4.08517-5.60564,103.21306,103.21306,0,0,0-18.50891-7.65085,8.18366,8.18366,0,0,0-6.868,1.07071L136.001,40h-16L104.54162,29.69376a8.18369,8.18369,0,0,0-6.868-1.07071,103.21412,103.21412,0,0,0-18.50876,7.65077,8.1445,8.1445,0,0,0-4.08522,5.60591l-3.647,18.23746L60.11816,71.43164l-18.23762,3.647a8.14428,8.14428,0,0,0-5.60569,4.08493,103.19818,103.19818,0,0,0-7.652,18.50915,8.18354,8.18354,0,0,0,1.0709,6.86786L40,120v16L29.6937,151.45945a8.18369,8.18369,0,0,0-1.07072,6.86784,103.1749,103.1749,0,0,0,7.65075,18.50925,8.1448,8.1448,0,0,0,5.60561,4.08487l18.23882,3.64793,11.31348,11.31347,3.64709,18.2387a8.14473,8.14473,0,0,0,4.08479,5.60582A103.14826,103.14826,0,0,0,97.672,227.37827a8.18362,8.18362,0,0,0,6.86744-1.07079L120,216.001h16l15.46031,10.30714a8.18353,8.18353,0,0,0,6.868,1.07073,103.18533,103.18533,0,0,0,18.5082-7.65063,8.14479,8.14479,0,0,0,4.08487-5.6056l3.64793-18.23883,11.31347-11.31445,18.23862-3.64708a8.14431,8.14431,0,0,0,5.6057-4.08491,103.18916,103.18916,0,0,0,7.65192-18.508,8.18367,8.18367,0,0,0-1.07094-6.86806L216.001,136.001Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00098",
        cy: "128.00049",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M216.001,120.001l10.30713-15.4603a8.18367,8.18367,0,0,0,1.07094-6.86806,103.18961,103.18961,0,0,0-7.652-18.50824,8.14437,8.14437,0,0,0-5.60531-4.08483l-18.23792-3.64791L184.57031,60.11816l-3.64788-18.23862a8.14452,8.14452,0,0,0-4.08517-5.60564,103.21306,103.21306,0,0,0-18.50891-7.65085,8.18366,8.18366,0,0,0-6.868,1.07071L136.001,40h-16L104.54162,29.69376a8.18369,8.18369,0,0,0-6.868-1.07071,103.21412,103.21412,0,0,0-18.50876,7.65077,8.1445,8.1445,0,0,0-4.08522,5.60591l-3.647,18.23746L60.11816,71.43164l-18.23762,3.647a8.14428,8.14428,0,0,0-5.60569,4.08493,103.19818,103.19818,0,0,0-7.652,18.50915,8.18354,8.18354,0,0,0,1.0709,6.86786L40,120v16L29.6937,151.45945a8.18369,8.18369,0,0,0-1.07072,6.86784,103.1749,103.1749,0,0,0,7.65075,18.50925,8.1448,8.1448,0,0,0,5.60561,4.08487l18.23882,3.64793,11.31348,11.31347,3.64709,18.2387a8.14473,8.14473,0,0,0,4.08479,5.60582A103.14826,103.14826,0,0,0,97.672,227.37827a8.18362,8.18362,0,0,0,6.86744-1.07079L120,216.001h16l15.46031,10.30714a8.18353,8.18353,0,0,0,6.868,1.07073,103.18533,103.18533,0,0,0,18.5082-7.65063,8.14479,8.14479,0,0,0,4.08487-5.6056l3.64793-18.23883,11.31347-11.31445,18.23862-3.64708a8.14431,8.14431,0,0,0,5.6057-4.08491,103.18916,103.18916,0,0,0,7.65192-18.508,8.18367,8.18367,0,0,0-1.07094-6.86806L216.001,136.001Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Gear = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5m(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Gear.displayName = "Gear";

var renderPathFor$5n = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M55.792,178.92871l-1.1969,18.5649a8.114,8.114,0,0,0,2.47714,6.44109A100.5923,100.5923,0,0,0,97.7073,227.39512a8.11363,8.11363,0,0,0,6.81671-1.07505l15.4788-10.31856,16,0,15.47922,10.319a8.114,8.114,0,0,0,6.81672,1.07529,100.5925,100.5925,0,0,0,40.63486-23.4608,8.11362,8.11362,0,0,0,2.47733-6.441l-1.19674-18.56431,8-13.85642,16.67612-8.24591a8.114,8.114,0,0,0,4.33958-5.36581,100.59233,100.59233,0,0,0-.00021-46.92121,8.11366,8.11366,0,0,0-4.33938-5.36592l-16.67554-8.24575-8-13.85644,1.1969-18.5649a8.114,8.114,0,0,0-2.47713-6.4411,100.59255,100.59255,0,0,0-40.63508-23.46042,8.11362,8.11362,0,0,0-6.8167,1.07506L136.004,39.99947l-16,0-15.47923-10.319a8.114,8.114,0,0,0-6.81671-1.07528A100.59233,100.59233,0,0,0,57.0732,52.066a8.11361,8.11361,0,0,0-2.47733,6.441L55.7926,77.07124l-8,13.85643-16.67612,8.2459a8.114,8.114,0,0,0-4.33959,5.36581,100.59255,100.59255,0,0,0,.00022,46.92122,8.11362,8.11362,0,0,0,4.33938,5.36591L47.792,165.07227Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M229.23193,104.54053a8.11523,8.11523,0,0,0-4.33935-5.36621L208.2168,90.92871l-8-13.85644,1.19677-18.565a8.11228,8.11228,0,0,0-2.477-6.44091A100.58443,100.58443,0,0,0,158.30176,28.606a8.11334,8.11334,0,0,0-6.8169,1.075l-15.479,10.3186h-16l-15.479-10.31909a8.1135,8.1135,0,0,0-6.8169-1.0752A100.59248,100.59248,0,0,0,57.0752,52.06592a8.11427,8.11427,0,0,0-2.47754,6.44092l1.19677,18.56445-8,13.85644L31.11816,99.17358a8.11442,8.11442,0,0,0-4.33935,5.36573,100.58745,100.58745,0,0,0,.00049,46.92114,8.1132,8.1132,0,0,0,4.33886,5.36621L47.794,165.07227l8,13.85644-1.19678,18.56494a8.11393,8.11393,0,0,0,2.477,6.44092A100.58191,100.58191,0,0,0,97.70947,227.395a8.11256,8.11256,0,0,0,6.81641-1.075l15.479-10.31861h16l15.479,10.3191a8.11344,8.11344,0,0,0,6.81689,1.07519,100.59274,100.59274,0,0,0,40.63477-23.46069,8.11435,8.11435,0,0,0,2.47754-6.44092l-1.19678-18.56445,8-13.85645,16.67627-8.24585a8.113,8.113,0,0,0,4.33935-5.36572,100.59609,100.59609,0,0,0,0-46.92114Zm-101.22607,79.46a56,56,0,1,1,56-56A56.00011,56.00011,0,0,1,128.00586,184.00049Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128.00586",
        cy: "128.00049",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M55.794,178.92871,54.597,197.49361a8.114,8.114,0,0,0,2.47714,6.44109,100.59225,100.59225,0,0,0,40.63508,23.46042,8.11362,8.11362,0,0,0,6.8167-1.07505l15.4788-10.31856,16,0,15.47923,10.319a8.11394,8.11394,0,0,0,6.81671,1.07529,100.59233,100.59233,0,0,0,40.63486-23.4608,8.11362,8.11362,0,0,0,2.47733-6.441l-1.19674-18.56431,8-13.85642,16.67612-8.24591a8.114,8.114,0,0,0,4.33958-5.36581,100.59233,100.59233,0,0,0-.00021-46.92121,8.11366,8.11366,0,0,0-4.33938-5.36592L208.2168,90.92871l-8-13.85644,1.1969-18.5649a8.114,8.114,0,0,0-2.47714-6.4411,100.5926,100.5926,0,0,0-40.63507-23.46042,8.11364,8.11364,0,0,0-6.81671,1.07506L136.006,39.99947l-16,0-15.47922-10.319A8.114,8.114,0,0,0,97.71,28.60517,100.59233,100.59233,0,0,0,57.07515,52.066a8.11361,8.11361,0,0,0-2.47733,6.441l1.19674,18.56431-8,13.85643L31.1184,99.17357a8.114,8.114,0,0,0-4.33958,5.36581A100.59237,100.59237,0,0,0,26.779,151.4606a8.11362,8.11362,0,0,0,4.33938,5.36591L47.794,165.07227Z",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M237.01953,102.71436a16.0391,16.0391,0,0,0-8.582-10.71143l-14.50488-7.17188-5.57715-9.66113,1.041-16.14844a16.03889,16.03889,0,0,0-4.98486-12.7871,108.58051,108.58051,0,0,0-43.79736-25.28663,16.04445,16.04445,0,0,0-13.56787,2.07666L133.583,31.99951H122.42676L108.96387,23.0249A16.03516,16.03516,0,0,0,95.396,20.94678,108.5825,108.5825,0,0,0,51.59912,46.23291a16.037,16.037,0,0,0-4.98584,12.78857L47.6543,75.169l-5.57813,9.66113L27.57129,92.00244a16.03826,16.03826,0,0,0-8.582,10.71094,108.5845,108.5845,0,0,0,0,50.57324,16.03912,16.03912,0,0,0,8.582,10.71143l14.50488,7.17187,5.57715,9.66113-1.041,16.14844a16.03892,16.03892,0,0,0,4.98487,12.78711,108.58047,108.58047,0,0,0,43.79736,25.28662,16.03514,16.03514,0,0,0,13.56787-2.07666l13.46338-8.9751H133.582l13.46289,8.97461a16.20761,16.20761,0,0,0,8.99707,2.75342,15.79613,15.79613,0,0,0,4.5708-.67529,108.5825,108.5825,0,0,0,43.79688-25.28613,16.037,16.037,0,0,0,4.98584-12.78858l-1.041-16.14746,5.57813-9.66113,14.50488-7.17236a16.0383,16.0383,0,0,0,8.582-10.71094,108.5845,108.5845,0,0,0,0-50.57324Zm-61.01465,25.28613a48,48,0,1,1-48-48A48.05437,48.05437,0,0,1,176.00488,128.00049Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00293",
        cy: "128.00049",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M55.791,178.92871l-1.1969,18.5649a8.11392,8.11392,0,0,0,2.47713,6.44109,100.59225,100.59225,0,0,0,40.63508,23.46042,8.11362,8.11362,0,0,0,6.8167-1.07505l15.4788-10.31856,16,0,15.47923,10.319a8.11394,8.11394,0,0,0,6.81671,1.07529,100.59233,100.59233,0,0,0,40.63486-23.4608,8.11362,8.11362,0,0,0,2.47733-6.441l-1.19673-18.56431,8-13.85642,16.67612-8.24591a8.114,8.114,0,0,0,4.33958-5.36581,100.59233,100.59233,0,0,0-.00021-46.92121,8.11366,8.11366,0,0,0-4.33938-5.36592l-16.67553-8.24575-8-13.85644,1.1969-18.5649a8.114,8.114,0,0,0-2.47714-6.4411,100.5926,100.5926,0,0,0-40.63507-23.46042,8.11364,8.11364,0,0,0-6.81671,1.07506l-15.4788,10.31856-16,0-15.47922-10.319a8.114,8.114,0,0,0-6.81672-1.07528A100.59233,100.59233,0,0,0,57.07222,52.066a8.11361,8.11361,0,0,0-2.47733,6.441l1.19674,18.56431-8,13.85643-16.67612,8.2459a8.114,8.114,0,0,0-4.33958,5.36581,100.59237,100.59237,0,0,0,.00021,46.92122,8.11362,8.11362,0,0,0,4.33938,5.36591L47.791,165.07227Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00195",
        cy: "128.00049",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M55.79,178.92871l-1.1969,18.5649a8.114,8.114,0,0,0,2.47713,6.44109,100.59225,100.59225,0,0,0,40.63508,23.46042,8.11363,8.11363,0,0,0,6.81671-1.07505l15.47879-10.31856,16,0,15.47922,10.319a8.114,8.114,0,0,0,6.81672,1.07529,100.5925,100.5925,0,0,0,40.63486-23.4608,8.11369,8.11369,0,0,0,2.47733-6.441l-1.19674-18.56431,8-13.85642,16.67613-8.24591a8.114,8.114,0,0,0,4.33958-5.36581,100.59251,100.59251,0,0,0-.00022-46.92121,8.11366,8.11366,0,0,0-4.33938-5.36592l-16.67553-8.24575-8-13.85644,1.1969-18.5649a8.114,8.114,0,0,0-2.47713-6.4411,100.59255,100.59255,0,0,0-40.63508-23.46042,8.11364,8.11364,0,0,0-6.81671,1.07506L136.00208,39.99947l-16,0-15.47922-10.319a8.114,8.114,0,0,0-6.81672-1.07528A100.5925,100.5925,0,0,0,57.07124,52.066a8.11365,8.11365,0,0,0-2.47733,6.441l1.19674,18.56431-8,13.85643-16.67613,8.2459a8.114,8.114,0,0,0-4.33958,5.36581,100.59255,100.59255,0,0,0,.00022,46.92122,8.11362,8.11362,0,0,0,4.33938,5.36591L47.79,165.07227Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00098",
        cy: "128.00049",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M55.78906,178.92871l-1.1969,18.5649a8.114,8.114,0,0,0,2.47714,6.44109,100.5923,100.5923,0,0,0,40.63507,23.46042,8.11363,8.11363,0,0,0,6.81671-1.07505l15.4788-10.31856,16,0,15.47922,10.319a8.114,8.114,0,0,0,6.81672,1.07529,100.59233,100.59233,0,0,0,40.63486-23.4608,8.11362,8.11362,0,0,0,2.47733-6.441l-1.19674-18.56431,8-13.85642,16.67612-8.24591a8.114,8.114,0,0,0,4.33958-5.36581,100.59233,100.59233,0,0,0-.00021-46.92121,8.11366,8.11366,0,0,0-4.33938-5.36592l-16.67554-8.24575-8-13.85644,1.1969-18.5649a8.114,8.114,0,0,0-2.47713-6.4411A100.59255,100.59255,0,0,0,158.2966,28.60585a8.11362,8.11362,0,0,0-6.8167,1.07506L136.0011,39.99947l-16,0-15.47923-10.319a8.114,8.114,0,0,0-6.81671-1.07528A100.59233,100.59233,0,0,0,57.07027,52.066a8.11361,8.11361,0,0,0-2.47733,6.441l1.19673,18.56431-8,13.85643-16.67612,8.2459a8.114,8.114,0,0,0-4.33958,5.36581,100.59237,100.59237,0,0,0,.00021,46.92122,8.11362,8.11362,0,0,0,4.33938,5.36591l16.67553,8.24576Z",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GearSix = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5n(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GearSix.displayName = "GearSix";

var renderPathFor$5o = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "136",
        y1: "72",
        x2: "136",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "228 72 180 72 180 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M72,132H96v20a32,32,0,0,1-64,0V104a32.0045,32.0045,0,0,1,62.99185-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "136",
        y1: "72",
        x2: "136",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "228 72 180 72 180 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M72,128H96v24a32,32,0,0,1-64,0V104a32.0045,32.0045,0,0,1,62.99185-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M136,64a8.00039,8.00039,0,0,0-8,8V184a8,8,0,0,0,16,0V72A8.00039,8.00039,0,0,0,136,64Z"
      }), React__default.createElement("path", {
        d: "M228,64H180a8.00039,8.00039,0,0,0-8,8V184a8,8,0,0,0,16,0V136h28a8,8,0,0,0,0-16H188V80h40a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M96,120H72a8,8,0,0,0,0,16H88v16a24,24,0,0,1-48,0V104a24.00492,24.00492,0,0,1,47.24512-6.00586,7.99961,7.99961,0,1,0,15.49414-3.98828A40.00446,40.00446,0,0,0,24,104v48a40,40,0,0,0,80,0V128A8.00039,8.00039,0,0,0,96,120Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "136",
        y1: "72",
        x2: "136",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "228 72 180 72 180 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M72,128H96v24a32,32,0,0,1-64,0V104a32.0045,32.0045,0,0,1,62.99185-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "136",
        y1: "72",
        x2: "136",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "228 72 180 72 180 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M72,128H96v24a32,32,0,0,1-64,0V104a32.0045,32.0045,0,0,1,62.99185-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "136",
        y1: "72",
        x2: "136",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "228 72 180 72 180 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "180",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M72,128H96v24a32,32,0,0,1-64,0V104a32.0045,32.0045,0,0,1,62.99185-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Gif = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5o(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Gif.displayName = "Gif";

var renderPathFor$5p = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "80",
        width: "192",
        height: "48",
        rx: "7.99999",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,128v72a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M173.25483,68.68629C161.94113,80,128,80,128,80s0-33.94113,11.31371-45.25483a24,24,0,0,1,33.94112,33.94112Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M82.74517,68.68629C94.05887,80,128,80,128,80s0-33.94113-11.31371-45.25483A24,24,0,0,0,82.74517,68.68629Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "80",
        width: "192",
        height: "48",
        rx: "7.99999",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,128v72a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M173.25483,68.68629C161.94113,80,128,80,128,80s0-33.94113,11.31371-45.25483a24,24,0,0,1,33.94112,33.94112Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M82.74517,68.68629C94.05887,80,128,80,128,80s0-33.94113-11.31371-45.25483A24,24,0,0,0,82.74517,68.68629Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,128v72a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V128Z",
        opacity: "0.2"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,72H181.03271a31.99968,31.99968,0,0,0-47.37646-42.91162A30.99155,30.99155,0,0,0,128,37.2998a31.01227,31.01227,0,0,0-5.65723-8.21191A31.99948,31.99948,0,0,0,74.96729,72H40A16.01817,16.01817,0,0,0,24,88v32a16.01817,16.01817,0,0,0,16,16v64a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V136a16.01817,16.01817,0,0,0,16-16V88A16.01817,16.01817,0,0,0,216,72ZM144.96973,40.4021a16.00019,16.00019,0,1,1,22.62793,22.62744c-4.94043,4.94116-19.22559,7.71582-31.25684,8.6294C137.25488,59.62671,140.0293,45.34277,144.96973,40.4021Zm-56.56836,0a16.0194,16.0194,0,0,1,22.62793-.00024c4.9414,4.94116,7.71582,19.22631,8.62988,31.25683-12.03223-.91382-26.31641-3.68848-31.25684-8.62915A16.01925,16.01925,0,0,1,88.40137,40.4021ZM216,120H136v72a8,8,0,0,1-16,0V120H40V88h80v32h16V88h80l.00977,31.99951Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "80",
        width: "192",
        height: "48",
        rx: "7.99999",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,128v72a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M173.25483,68.68629C161.94113,80,128,80,128,80s0-33.94113,11.31371-45.25483a24,24,0,0,1,33.94112,33.94112Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M82.74517,68.68629C94.05887,80,128,80,128,80s0-33.94113-11.31371-45.25483A24,24,0,0,0,82.74517,68.68629Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "80",
        width: "192",
        height: "48",
        rx: "7.99999",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,128v72a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M173.25483,68.68629C161.94113,80,128,80,128,80s0-33.94113,11.31371-45.25483a24,24,0,0,1,33.94112,33.94112Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M82.74517,68.68629C94.05887,80,128,80,128,80s0-33.94113-11.31371-45.25483A24,24,0,0,0,82.74517,68.68629Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "80",
        width: "192",
        height: "48",
        rx: "7.99999",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M208,128v72a8,8,0,0,1-8,8H56a8,8,0,0,1-8-8V128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M173.25483,68.68629C161.94113,80,128,80,128,80s0-33.94113,11.31371-45.25483a24,24,0,0,1,33.94112,33.94112Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M82.74517,68.68629C94.05887,80,128,80,128,80s0-33.94113-11.31371-45.25483A24,24,0,0,0,82.74517,68.68629Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Gift = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5p(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Gift.displayName = "Gift";

var renderPathFor$5q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M68,160v-8.00018a23.99955,23.99955,0,0,1,23.99951-23.99909l72.001-.00146A23.99955,23.99955,0,0,0,188,104.00018V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "68",
        y1: "96",
        x2: "68",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M67.98779,160v-8.00018A23.99955,23.99955,0,0,1,91.9873,128.00073l72.001-.00146a23.99955,23.99955,0,0,0,23.99951-23.99909V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "67.98779",
        y1: "96",
        x2: "67.98779",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224.00049,67.99756a36,36,0,1,0-44,35.09289v.9076a16.01865,16.01865,0,0,1-16,16l-72.001.00146a31.80375,31.80375,0,0,0-15.999,4.29444v-21.2035a36,36,0,1,0-16,0V152.9071a36,36,0,1,0,16,0v-.90759a16.01844,16.01844,0,0,1,15.999-16l72.001-.00146a32.0373,32.0373,0,0,0,32-32v-.9076A36.05514,36.05514,0,0,0,224.00049,67.99756Zm-176,0a20,20,0,1,1,20,20A20.0226,20.0226,0,0,1,48.00049,67.99756ZM88.00049,188a20,20,0,1,1-20-20A20.0226,20.0226,0,0,1,88.00049,188Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M68,160v-8.00018a23.99955,23.99955,0,0,1,23.99951-23.99909l72.001-.00146A23.99955,23.99955,0,0,0,188,104.00018V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "68",
        y1: "96",
        x2: "68",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M68,160v-8.00018a23.99955,23.99955,0,0,1,23.99951-23.99909l72.001-.00146A23.99955,23.99955,0,0,0,188,104.00018V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "68",
        y1: "96",
        x2: "68",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M68,160v-8.00018a23.99955,23.99955,0,0,1,23.99951-23.99909l72.001-.00146A23.99955,23.99955,0,0,0,188,104.00018V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "68",
        y1: "96",
        x2: "68",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GitBranch = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GitBranch.displayName = "GitBranch";

var renderPathFor$5r = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00244",
        cy: "128",
        r: "52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "12.00244",
        y1: "128",
        x2: "76.00244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "180.00244",
        y1: "128",
        x2: "244.00244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00244",
        cy: "128",
        r: "52",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128.00244",
        cy: "128",
        r: "52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "8.00244",
        y1: "128",
        x2: "76.00244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "180.00244",
        y1: "128",
        x2: "248.00244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M248.00244,120H187.45312a59.98446,59.98446,0,0,0-118.90136,0H8.00244a8,8,0,0,0,0,16H68.55176a59.98446,59.98446,0,0,0,118.90136,0h60.54932a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00244",
        cy: "128",
        r: "52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "8.00244",
        y1: "128",
        x2: "76.00244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "180.00244",
        y1: "128",
        x2: "248.00244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00244",
        cy: "128",
        r: "52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "8.00244",
        y1: "128",
        x2: "76.00244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "180.00244",
        y1: "128",
        x2: "248.00244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00244",
        cy: "128",
        r: "52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "8.00244",
        y1: "128",
        x2: "76.00244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "180.00244",
        y1: "128",
        x2: "248.00244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GitCommit = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5r(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GitCommit.displayName = "GitCommit";

var renderPathFor$5s = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "196.00244",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M196.00244,160l-.00163-40.11889a48,48,0,0,0-14.05888-33.93918L144,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "144 88 144 48 184 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M60,96l.00163,40.11889a48,48,0,0,0,14.05888,33.93918L112.00244,208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "112.002 168 112.002 208 72.002 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "196.00244",
        cy: "188",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "68",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "196.00244",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M196.00244,160l-.00163-40.11889a48,48,0,0,0-14.05888-33.93918L144,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 88 144 48 184 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M60,96l.00163,40.11889a48,48,0,0,0,14.05888,33.93918L112.00244,208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "112.002 168 112.002 208 72.002 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M204.002,152.907l-.00146-33.02612a55.63313,55.63313,0,0,0-16.40137-39.5957L163.31445,56h20.686a8,8,0,0,0,0-16h-40c-.14893,0-.29444.01416-.44141.02222-.11133.0061-.22314.00622-.334.017-.17188.01648-.33985.046-.50879.07325-.08789.01428-.17725.02331-.26514.04052-.168.033-.33105.0774-.49512.12073-.08837.02319-.17773.042-.26562.06824-.15283.046-.30078.10229-.44971.1571-.09717.03589-.1958.06739-.29248.10718-.13428.05542-.26318.12-.39355.1825-.10694.0509-.21485.098-.31934.15393-.1206.06421-.23486.1372-.35107.20727-.1084.06494-.21826.12586-.32373.19641-.11768.079-.229.16675-.34229.25159-.09668.07239-.19629.13965-.29.2168-.1499.123-.291.25586-.43115.3894-.05029.04773-.10449.08936-.15381.13867-.05957.05945-.10986.12415-.167.18506-.12207.12964-.24512.2583-.3584.396-.09424.115-.17773.236-.26514.355-.06689.09106-.13769.179-.20068.273-.0874.13037-.16406.26538-.24268.39941-.05322.09058-.11084.17871-.16064.27149-.07129.13281-.13184.26928-.19482.405-.04737.10168-.09864.20117-.14161.30517-.05419.13013-.09814.26318-.145.39551-.04052.1145-.085.22729-.12011.34424-.04.13208-.06983.26611-.103.3999-.02978.11987-.06348.238-.08789.36011-.03076.15429-.04981.31006-.07129.4657-.01416.10327-.03418.20459-.04443.30908q-.03955.39752-.04.79736V88a8,8,0,0,0,16,0V67.31482l24.28418,24.28479a39.731,39.731,0,0,1,11.71582,28.28125l.00146,33.02637a35.99994,35.99994,0,1,0,16-.00025Z"
      }), React__default.createElement("path", {
        d: "M112.00244,160a8.00039,8.00039,0,0,0-8,8v20.68555L79.71728,164.40039a39.73582,39.73582,0,0,1-11.71582-28.28125l-.001-33.02624a35.99974,35.99974,0,1,0-16,.00012l.001,33.0271a55.63733,55.63733,0,0,0,16.40137,39.59472L92.688,200H72.00244a8,8,0,1,0,0,16h40c.26367,0,.52734-.014.78955-.03992.11817-.01159.23242-.03369.34912-.05041.1416-.02027.28418-.03687.42481-.0647.13281-.02637.26123-.06274.3916-.0957.123-.03076.24658-.05786.36816-.09473.12647-.03833.24854-.08569.37207-.13.12305-.04395.24659-.0846.36768-.13465.11328-.047.22168-.10217.332-.15405.127-.05957.2544-.116.37842-.18237.10205-.05481.19922-.11731.29834-.17627.12549-.07422.25146-.14527.37353-.22681.10352-.06946.20069-.14722.30078-.22119.10987-.0813.22168-.158.32813-.24561.144-.11792.27881-.246.41406-.37353.05518-.05249.11475-.09851.169-.15283.05664-.0564.10449-.11792.15869-.17554.12549-.13281.251-.26538.36719-.40649.09131-.11072.17138-.22718.25537-.34156.07031-.0957.14453-.188.21094-.28686.085-.12659.15917-.25782.23583-.38806.05567-.09436.11524-.18616.167-.28309.06933-.12915.12842-.26184.18994-.39379.04931-.10547.10205-.20874.147-.31665.05225-.12647.09522-.25562.14063-.38428.042-.11817.0874-.2345.124-.35523.03906-.1289.06787-.25976.10059-.39013.03076-.12305.06543-.24414.09033-.36939.02978-.15137.04834-.30444.06933-.457.01465-.106.03516-.21.0459-.31714q.03956-.39769.04-.79712V168A8.00039,8.00039,0,0,0,112.00244,160Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "196.00244",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M196.00244,160l-.00163-40.11889a48,48,0,0,0-14.05888-33.93918L144,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "144 88 144 48 184 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M60,96l.00163,40.11889a48,48,0,0,0,14.05888,33.93918L112.00244,208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "112.002 168 112.002 208 72.002 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "196.00244",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M196.00244,160l-.00163-40.11889a48,48,0,0,0-14.05888-33.93918L144,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "144 88 144 48 184 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M60,96l.00163,40.11889a48,48,0,0,0,14.05888,33.93918L112.00244,208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "112.002 168 112.002 208 72.002 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "196.00244",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M196.00244,160l-.00163-40.11889a48,48,0,0,0-14.05888-33.93918L144,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144 88 144 48 184 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M60,96l.00163,40.11889a48,48,0,0,0,14.05888,33.93918L112.00244,208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "112.002 168 112.002 208 72.002 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GitDiff = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5s(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GitDiff.displayName = "GitDiff";

var renderPathFor$5t = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M68,95.99756v8.002a24,24,0,0,0,24.00049,24l72-.00146a24,24,0,0,0,23.99951-24V95.99756",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128.00244",
        y1: "128",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "67.99756",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M68,95.99756v8.002a24,24,0,0,0,24.00049,24l72-.00146a24,24,0,0,0,23.99951-24V95.99756",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128.00244",
        y1: "128",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224.00049,67.99756a36,36,0,1,0-44,35.09289v.9076a16.01865,16.01865,0,0,1-16,16l-72,.00146a15.99994,15.99994,0,0,1-16-16v-.90906a36,36,0,1,0-16,0v.90906a31.99909,31.99909,0,0,0,32,32L120.002,135.999l-.001,16.908a35.99993,35.99993,0,1,0,16,.00019l.001-16.90857,27.99854-.00055a32.0373,32.0373,0,0,0,32-32v-.9076A36.05514,36.05514,0,0,0,224.00049,67.99756ZM148.00049,188a20,20,0,1,1-20-20A20.02229,20.02229,0,0,1,148.00049,188Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M68,95.99756v8.002a24,24,0,0,0,24.00049,24l72-.00146a24,24,0,0,0,23.99951-24V95.99756",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128.00244",
        y1: "128",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M68,95.99756v8.002a24,24,0,0,0,24.00049,24l72-.00146a24,24,0,0,0,23.99951-24V95.99756",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128.00244",
        y1: "128",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "67.99756",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M68,95.99756v8.002a24,24,0,0,0,24.00049,24l72-.00146a24,24,0,0,0,23.99951-24V95.99756",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128.00244",
        y1: "128",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GitFork = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5t(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GitFork.displayName = "GitFork";

var renderPathFor$5u = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "67.99512",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "67.99512",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "187.99756",
        cy: "140",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M159.99756,144H130.47711a48,48,0,0,1-36.87462-17.27115L67.99512,96v64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "67.99023",
        cy: "68",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "67.99023",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "67.99023",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "187.99268",
        cy: "140",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M159.99268,144H130.47223a48,48,0,0,1-36.87462-17.27115L67.99023,96v64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M187.99268,104a36.04766,36.04766,0,0,0-35.77247,32h-21.748a39.89636,39.89636,0,0,1-30.72949-14.39258L82.51123,100.93005a35.99422,35.99422,0,1,0-22.52148,2.16285v49.8142a36,36,0,1,0,16,0V118.09668l11.46191,13.75293A55.84986,55.84986,0,0,0,130.47217,152h23.585a35.99769,35.99769,0,1,0,33.93555-48ZM87.98975,188a20,20,0,1,1-20-20A20.02229,20.02229,0,0,1,87.98975,188Zm100.00293-28a20,20,0,1,1,20-20A20.02229,20.02229,0,0,1,187.99268,160Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "67.99756",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "67.99756",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "140",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M160,144H130.47956a48,48,0,0,1-36.87463-17.27115L67.99756,96v64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "188.00244",
        cy: "140",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M160.00244,144H130.482a48,48,0,0,1-36.87462-17.27115L68,96v64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188.00244",
        cy: "140",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M160.00244,144H130.482a48,48,0,0,1-36.87462-17.27115L68,96v64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GitMerge = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5u(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GitMerge.displayName = "GitMerge";

var renderPathFor$5v = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "68",
        y1: "96",
        x2: "68",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "188.00244",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M188.00244,160l-.00163-40.11889a48,48,0,0,0-14.05888-33.93918L136,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "136 88 136 48 176 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "68",
        cy: "68",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "188.00244",
        cy: "188",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188.00244",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "68",
        y1: "96",
        x2: "68",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M188.00244,160l-.00163-40.11889a48,48,0,0,0-14.05888-33.93918L136,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "136 88 136 48 176 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M104.00049,68a36,36,0,1,0-44,35.0929v49.8142a36,36,0,1,0,16,0V103.0929A36.05516,36.05516,0,0,0,104.00049,68Zm-16,120a20,20,0,1,1-20-20A20.0226,20.0226,0,0,1,88.00049,188Z"
      }), React__default.createElement("path", {
        d: "M196.002,152.907l-.00146-33.02563a55.63508,55.63508,0,0,0-16.40137-39.59619L155.31445,56h20.686a8,8,0,0,0,0-16h-40c-.01563,0-.03028.00226-.0459.00232-.24756.0014-.49463.01318-.74121.03747-.12842.01252-.25293.0362-.3794.05469-.13086.01929-.2622.03418-.39257.05994-.145.02862-.28516.068-.42725.10431-.11035.02826-.22168.052-.33057.085-.14013.04224-.2749.0943-.41162.14386-.10937.03961-.21972.07538-.32763.12-.12745.05268-.24952.11432-.37354.17328-.11279.05347-.22656.10328-.33691.16236-.11914.0636-.23243.13574-.34766.20508-.1084.0653-.21875.12652-.3252.19751-.12353.08264-.23974.17443-.35839.26367-.09082.06823-.18409.1311-.27246.20361-.1875.15381-.36622.31714-.53907.487-.01562.0152-.03222.02783-.04785.04315-.02051.02051-.0376.04321-.05762.06391-.16357.16711-.32177.33941-.47021.52032-.083.10059-.15527.20648-.23193.31006-.07862.10571-.16065.20862-.23438.3183-.08057.12072-.15088.24591-.22461.36993-.05957.1-.12207.19757-.17724.30036-.06788.12591-.125.25531-.18506.384-.05078.1084-.10547.21466-.15137.32568-.05127.12463-.09326.25189-.13867.37848-.04248.11987-.08887.238-.126.36047-.03857.12775-.06738.25757-.09912.38678-.03125.124-.06592.24622-.09131.37244-.02978.15088-.04785.30328-.06933.45544-.01465.10645-.03516.21094-.0459.31867q-.03955.39752-.04.79706V88a8,8,0,0,0,16,0V67.31415l24.28418,24.28448a39.73874,39.73874,0,0,1,11.71582,28.28321l.00146,33.02533a36.00007,36.00007,0,1,0,16-.00019Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "68",
        y1: "96",
        x2: "68",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "188.00244",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M188.00244,160l-.00163-40.11889a48,48,0,0,0-14.05888-33.93918L136,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "136 88 136 48 176 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "68",
        y1: "96",
        x2: "68",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "188.00244",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M188.00244,160l-.00163-40.11889a48,48,0,0,0-14.05888-33.93918L136,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "136 88 136 48 176 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "68",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "68",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "68",
        y1: "96",
        x2: "68",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188.00244",
        cy: "188",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M188.00244,160l-.00163-40.11889a48,48,0,0,0-14.05888-33.93918L136,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "136 88 136 48 176 48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GitPullRequest = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5v(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GitPullRequest.displayName = "GitPullRequest";

var renderPathFor$5w = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M84,232a24,24,0,0,0,24-24V160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M172,232a24,24,0,0,1-24-24V160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152,160h16a24,24,0,0,1,24,24v8a24,24,0,0,0,24,24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M104,160H88a24,24,0,0,0-24,24v8a24,24,0,0,1-24,24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M64.51166,76.70377A51.90056,51.90056,0,0,1,68,32a51.9599,51.9599,0,0,1,43.82469,23.9988V56h32.35061V55.9988A51.9599,51.9599,0,0,1,188,32a51.90056,51.90056,0,0,1,3.48834,44.70377l0,0A47.77872,47.77872,0,0,1,200,104v8a48,48,0,0,1-48,48H104a48,48,0,0,1-48-48v-8a47.77872,47.77872,0,0,1,8.51163-27.29627Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M64.51166,76.70377A51.90056,51.90056,0,0,1,68,32a51.9599,51.9599,0,0,1,43.82469,23.9988V56h32.35061V55.9988A51.9599,51.9599,0,0,1,188,32a51.90056,51.90056,0,0,1,3.48834,44.70377l0,0A47.77872,47.77872,0,0,1,200,104v8a48,48,0,0,1-48,48H104a48,48,0,0,1-48-48v-8a47.77872,47.77872,0,0,1,8.51163-27.29627Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M84,232a24,24,0,0,0,24-24V160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M172,232a24,24,0,0,1-24-24V160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,160h16a24,24,0,0,1,24,24v8a24,24,0,0,0,24,24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M104,160H88a24,24,0,0,0-24,24v8a24,24,0,0,1-24,24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M64.51166,76.70377A51.90056,51.90056,0,0,1,68,32a51.9599,51.9599,0,0,1,43.82469,23.9988V56h32.35061V55.9988A51.9599,51.9599,0,0,1,188,32a51.90056,51.90056,0,0,1,3.48834,44.70377l0,0A47.77872,47.77872,0,0,1,200,104v8a48,48,0,0,1-48,48H104a48,48,0,0,1-48-48v-8a47.77872,47.77872,0,0,1,8.51163-27.29627Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,216a8.00039,8.00039,0,0,1-8,8,32.03667,32.03667,0,0,1-32-32v-8a16.01833,16.01833,0,0,0-16-16H156v40a16.01833,16.01833,0,0,0,16,16,8,8,0,0,1,0,16,32.03667,32.03667,0,0,1-32-32V168H116v40a32.03667,32.03667,0,0,1-32,32,8,8,0,0,1,0-16,16.01833,16.01833,0,0,0,16-16V168H88a16.01833,16.01833,0,0,0-16,16v8a32.03667,32.03667,0,0,1-32,32,8,8,0,0,1,0-16,16.01833,16.01833,0,0,0,16-16v-8a31.9949,31.9949,0,0,1,14.78076-26.95068A55.951,55.951,0,0,1,48,112v-8a55.67143,55.67143,0,0,1,7.68945-28.33789A59.73846,59.73846,0,0,1,61.07178,28,7.99908,7.99908,0,0,1,68,24a59.74863,59.74863,0,0,1,48.00684,23.999L139.99316,48A59.7461,59.7461,0,0,1,188,24a7.99908,7.99908,0,0,1,6.92822,4,59.73846,59.73846,0,0,1,5.38233,47.66211A55.67143,55.67143,0,0,1,208,104v8a55.951,55.951,0,0,1-22.78076,45.04932A31.9949,31.9949,0,0,1,200,184v8a16.01833,16.01833,0,0,0,16,16A8.00039,8.00039,0,0,1,224,216Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M84,232a24,24,0,0,0,24-24V160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M172,232a24,24,0,0,1-24-24V160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M152,160h16a24,24,0,0,1,24,24v8a24,24,0,0,0,24,24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M104,160H88a24,24,0,0,0-24,24v8a24,24,0,0,1-24,24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M64.51166,76.70377A51.90056,51.90056,0,0,1,68,32a51.9599,51.9599,0,0,1,43.82469,23.9988V56h32.35061V55.9988A51.9599,51.9599,0,0,1,188,32a51.90056,51.90056,0,0,1,3.48834,44.70377l0,0A47.77872,47.77872,0,0,1,200,104v8a48,48,0,0,1-48,48H104a48,48,0,0,1-48-48v-8a47.77872,47.77872,0,0,1,8.51163-27.29627Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M84,232a24,24,0,0,0,24-24V160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M172,232a24,24,0,0,1-24-24V160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M152,160h16a24,24,0,0,1,24,24v8a24,24,0,0,0,24,24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M104,160H88a24,24,0,0,0-24,24v8a24,24,0,0,1-24,24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M64.51166,76.70377A51.90056,51.90056,0,0,1,68,32a51.9599,51.9599,0,0,1,43.82469,23.9988V56h32.35061V55.9988A51.9599,51.9599,0,0,1,188,32a51.90056,51.90056,0,0,1,3.48834,44.70377l0,0A47.77872,47.77872,0,0,1,200,104v8a48,48,0,0,1-48,48H104a48,48,0,0,1-48-48v-8a47.77872,47.77872,0,0,1,8.51163-27.29627Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M84,232a24,24,0,0,0,24-24V160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M172,232a24,24,0,0,1-24-24V160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,160h16a24,24,0,0,1,24,24v8a24,24,0,0,0,24,24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M104,160H88a24,24,0,0,0-24,24v8a24,24,0,0,1-24,24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M64.51166,76.70377A51.90056,51.90056,0,0,1,68,32a51.9599,51.9599,0,0,1,43.82469,23.9988V56h32.35061V55.9988A51.9599,51.9599,0,0,1,188,32a51.90056,51.90056,0,0,1,3.48834,44.70377l0,0A47.77872,47.77872,0,0,1,200,104v8a48,48,0,0,1-48,48H104a48,48,0,0,1-48-48v-8a47.77872,47.77872,0,0,1,8.51163-27.29627Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GithubLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5w(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GithubLogo.displayName = "GithubLogo";

var renderPathFor$5x = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "37.46679",
        y1: "96",
        x2: "218.53174",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "37.47057",
        y1: "160",
        x2: "218.53448",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "40",
        ry: "93.42294",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "37.46679",
        y1: "96",
        x2: "218.53174",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "37.47057",
        y1: "160",
        x2: "218.53448",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "40",
        ry: "93.42294",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.86035,163.20862a7.94949,7.94949,0,0,0,.373-1.05676,104.00629,104.00629,0,0,0-.01026-68.33094,7.96,7.96,0,0,0-.35546-1.00793A104.17669,104.17669,0,0,0,128.042,24.00086L128,23.96423l-.042.03663A104.17672,104.17672,0,0,0,30.13623,92.80164a7.94362,7.94362,0,0,0-.36475,1.03454,104.00383,104.00383,0,0,0,.01319,68.36658,7.975,7.975,0,0,0,.34179.968,104.17624,104.17624,0,0,0,97.83057,68.8291l.043.0376.043-.0376A104.1768,104.1768,0,0,0,225.86035,163.20862ZM128,45.559a110.409,110.409,0,0,1,25.52246,42.44141H102.47754A110.409,110.409,0,0,1,128,45.559ZM102.478,168.00037H153.522A110.41425,110.41425,0,0,1,128,210.44177,110.41425,110.41425,0,0,1,102.478,168.00037Zm-4.18848-16a126.93369,126.93369,0,0,1,0-48h59.4209a126.93369,126.93369,0,0,1,0,48Zm75.73877-48h38.645a88.23665,88.23665,0,0,1,0,48h-38.645a147.05417,147.05417,0,0,0,0-48Zm32.34375-16H170.40771A127.43992,127.43992,0,0,0,146.2749,41.91406,88.31787,88.31787,0,0,1,206.37207,88.00037ZM146.27441,214.08679a127.44456,127.44456,0,0,0,24.13282-46.08642h35.96484A88.31753,88.31753,0,0,1,146.27441,214.08679Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "37.46679",
        y1: "96",
        x2: "218.53174",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "37.47057",
        y1: "160",
        x2: "218.53448",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "40",
        ry: "93.42294",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "37.46679",
        y1: "96",
        x2: "218.53174",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "37.47057",
        y1: "160",
        x2: "218.53448",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "40",
        ry: "93.42294",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "37.46679",
        y1: "96",
        x2: "218.53174",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "37.47057",
        y1: "160",
        x2: "218.53448",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "40",
        ry: "93.42294",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Globe = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5x(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Globe.displayName = "Globe";

var renderPathFor$5y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M49.58637,183.394l11.37462-6.8665a7.02529,7.02529,0,0,0,3.28258-7.264L57.78366,133.5254a7.02532,7.02532,0,0,1,.73377-4.59159L69.2028,109.1759a7.02534,7.02534,0,0,1,1.76935-2.12663L87.32841,93.85874a7.02531,7.02531,0,0,1,7.79577-.6871l7.194,3.95672a7.02526,7.02526,0,0,1,3.21026,3.73719l1.37392,3.747a7.0253,7.0253,0,0,0,12.70317,1.05368l4.72184-8.30535a7.0253,7.0253,0,0,1,9.91638-2.43085l14.41444,9.30136a7.02531,7.02531,0,0,0,10.6005-7.70074v0a7.02529,7.02529,0,0,1,3.76539-8.13792l19.865-9.481a7.0253,7.0253,0,0,0,3.88287-7.6139l-4.094-22.20695",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M191.42925,200.05385l-14.56838-14.59728a7.02532,7.02532,0,0,0-4.97256-2.06259H160.45318a7.0253,7.0253,0,0,1-6.95036-8.0487l2.38076-16.16881a7.02529,7.02529,0,0,1,3.70069-5.20513l23.863-12.45024a7.02529,7.02529,0,0,1,7.92292.983L216.61,164.99034",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M49.585,183.39491A96.011,96.011,0,0,1,182.68191,49.08523l-.004.00566,4.094,22.20695a7.0253,7.0253,0,0,1-3.88287,7.6139l-19.865,9.481a7.02529,7.02529,0,0,0-3.76539,8.13792v0a7.02531,7.02531,0,0,1-10.6005,7.70074l-14.41444-9.30136a7.0253,7.0253,0,0,0-9.91638,2.43085l-4.72184,8.30535a7.0253,7.0253,0,0,1-12.70317-1.05368l-1.37392-3.747a7.02526,7.02526,0,0,0-3.21026-3.73719l-7.194-3.95672a7.02531,7.02531,0,0,0-7.79577.6871L70.97215,107.04927a7.02534,7.02534,0,0,0-1.76935,2.12663L58.51743,128.93381a7.02532,7.02532,0,0,0-.73377,4.59159l6.45991,35.73807a7.02529,7.02529,0,0,1-3.28258,7.264L49.58637,183.394Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M216.61374,164.992a96.23676,96.23676,0,0,1-25.18035,35.06655l-.00414-.0047-14.56838-14.59728a7.02532,7.02532,0,0,0-4.97256-2.06259H160.45318a7.0253,7.0253,0,0,1-6.95036-8.0487l2.38076-16.16881a7.02529,7.02529,0,0,1,3.70069-5.20513l23.863-12.45024a7.02529,7.02529,0,0,1,7.92292.983L216.61,164.99034Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M49.58637,183.394l11.37462-6.8665a7.02529,7.02529,0,0,0,3.28258-7.264L57.78366,133.5254a7.02532,7.02532,0,0,1,.73377-4.59159L69.2028,109.1759a7.02534,7.02534,0,0,1,1.76935-2.12663L87.32841,93.85874a7.02531,7.02531,0,0,1,7.79577-.6871l7.194,3.95672a7.02526,7.02526,0,0,1,3.21026,3.73719l1.37392,3.747a7.0253,7.0253,0,0,0,12.70317,1.05368l4.72184-8.30535a7.0253,7.0253,0,0,1,9.91638-2.43085l14.41444,9.30136a7.02531,7.02531,0,0,0,10.6005-7.70074v0a7.02529,7.02529,0,0,1,3.76539-8.13792l19.865-9.481a7.0253,7.0253,0,0,0,3.88287-7.6139l-4.094-22.20695",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M191.42925,200.05385l-14.56838-14.59728a7.02532,7.02532,0,0,0-4.97256-2.06259H160.45318a7.0253,7.0253,0,0,1-6.95036-8.0487l2.38076-16.16881a7.02529,7.02529,0,0,1,3.70069-5.20513l23.863-12.45024a7.02529,7.02529,0,0,1,7.92292.983L216.61,164.99034",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.773,168.53662a7.92728,7.92728,0,0,0,.44287-1.07471A103.91111,103.91111,0,0,0,187.89355,43.02539a8.05382,8.05382,0,0,0-1.38037-.958A103.94638,103.94638,0,0,0,42.62012,187.30957c.041.07275.07422.147.11718.21875a8.05384,8.05384,0,0,0,.80762,1.09082,103.86034,103.86034,0,0,0,152.56934,17.9082,7.99043,7.99043,0,0,0,.96631-.81152c.07568-.07568.14111-.15771.21338-.23535A104.48686,104.48686,0,0,0,223.773,168.53662ZM61.4834,185.55615l3.61133-2.18017a15.10574,15.10574,0,0,0,7.02148-15.53516L65.7168,132.43848,76.147,113.15332l15.69434-12.65723,6.30224,3.46582,1.248,3.4043a15.02456,15.02456,0,0,0,27.168,2.25391l4.21289-7.40918,13.54785,8.74218a15.02626,15.02626,0,0,0,22.85938-15.67968l19.15527-9.1416a15.04446,15.04446,0,0,0,8.43018-15.39356,87.89427,87.89427,0,0,1,18.17724,80.26953l-16.25049-14.47754a15.10505,15.10505,0,0,0-16.94482-2.10156l-23.86182,12.44922a15.06688,15.06688,0,0,0-7.9165,11.13379l-2.38037,16.168a15.02409,15.02409,0,0,0,14.86475,17.21386H171.4834l7.95019,7.96583A87.85432,87.85432,0,0,1,61.4834,185.55615Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M49.58637,183.394l11.37462-6.8665a7.02529,7.02529,0,0,0,3.28258-7.264L57.78366,133.5254a7.02532,7.02532,0,0,1,.73377-4.59159L69.2028,109.1759a7.02534,7.02534,0,0,1,1.76935-2.12663L87.32841,93.85874a7.02531,7.02531,0,0,1,7.79577-.6871l7.194,3.95672a7.02526,7.02526,0,0,1,3.21026,3.73719l1.37392,3.747a7.0253,7.0253,0,0,0,12.70317,1.05368l4.72184-8.30535a7.0253,7.0253,0,0,1,9.91638-2.43085l14.41444,9.30136a7.02531,7.02531,0,0,0,10.6005-7.70074v0a7.02529,7.02529,0,0,1,3.76539-8.13792l19.865-9.481a7.0253,7.0253,0,0,0,3.88287-7.6139l-4.094-22.20695",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M191.42925,200.05385l-14.56838-14.59728a7.02532,7.02532,0,0,0-4.97256-2.06259H160.45318a7.0253,7.0253,0,0,1-6.95036-8.0487l2.38076-16.16881a7.02529,7.02529,0,0,1,3.70069-5.20513l23.863-12.45024a7.02529,7.02529,0,0,1,7.92292.983L216.61,164.99034",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M49.58637,183.394l11.37462-6.8665a7.02529,7.02529,0,0,0,3.28258-7.264L57.78366,133.5254a7.02532,7.02532,0,0,1,.73377-4.59159L69.2028,109.1759a7.02534,7.02534,0,0,1,1.76935-2.12663L87.32841,93.85874a7.02531,7.02531,0,0,1,7.79577-.6871l7.194,3.95672a7.02526,7.02526,0,0,1,3.21026,3.73719l1.37392,3.747a7.0253,7.0253,0,0,0,12.70317,1.05368l4.72184-8.30535a7.0253,7.0253,0,0,1,9.91638-2.43085l14.41444,9.30136a7.02531,7.02531,0,0,0,10.6005-7.70074v0a7.02529,7.02529,0,0,1,3.76539-8.13792l19.865-9.481a7.0253,7.0253,0,0,0,3.88287-7.6139l-4.094-22.20695",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M191.42925,200.05385l-14.56838-14.59728a7.02532,7.02532,0,0,0-4.97256-2.06259H160.45318a7.0253,7.0253,0,0,1-6.95036-8.0487l2.38076-16.16881a7.02529,7.02529,0,0,1,3.70069-5.20513l23.863-12.45024a7.02529,7.02529,0,0,1,7.92292.983L216.61,164.99034",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M49.58637,183.394l11.37462-6.8665a7.02529,7.02529,0,0,0,3.28258-7.264L57.78366,133.5254a7.02532,7.02532,0,0,1,.73377-4.59159L69.2028,109.1759a7.02534,7.02534,0,0,1,1.76935-2.12663L87.32841,93.85874a7.02531,7.02531,0,0,1,7.79577-.6871l7.194,3.95672a7.02526,7.02526,0,0,1,3.21026,3.73719l1.37392,3.747a7.0253,7.0253,0,0,0,12.70317,1.05368l4.72184-8.30535a7.0253,7.0253,0,0,1,9.91638-2.43085l14.41444,9.30136a7.02531,7.02531,0,0,0,10.6005-7.70074v0a7.02529,7.02529,0,0,1,3.76539-8.13792l19.865-9.481a7.0253,7.0253,0,0,0,3.88287-7.6139l-4.094-22.20695",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M191.42925,200.05385l-14.56838-14.59728a7.02532,7.02532,0,0,0-4.97256-2.06259H160.45318a7.0253,7.0253,0,0,1-6.95036-8.0487l2.38076-16.16881a7.02529,7.02529,0,0,1,3.70069-5.20513l23.863-12.45024a7.02529,7.02529,0,0,1,7.92292.983L216.61,164.99034",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GlobeHemisphereEast = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GlobeHemisphereEast.displayName = "GlobeHemisphereEast";

var renderPathFor$5z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M214.16458,170.37222l-54.28632-33.38846a7.99993,7.99993,0,0,0-3.12236-1.114l-22.81867-3.07595a8,8,0,0,0-8.37592,4.67178l-13.69878,30.73831a8,8,0,0,0,1.433,8.68736l18.79995,20.33464a8,8,0,0,1,1.98022,6.9502l-3.8294,19.79638",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M64.95216,55.60635,56.00794,76.75607a8,8,0,0,0-.12321,5.92293l11.49086,30.66819a8,8,0,0,0,5.81037,5.01448l21.42993,4.60592a8,8,0,0,1,5.5197,4.3358l3.80564,7.862a8,8,0,0,0,7.20075,4.51442h13.43256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152.45823,35.14852l9.33366,16.7184a8,8,0,0,1-1.6191,9.83314L133.26192,86.0376a8.00033,8.00033,0,0,1-1.49868,1.06968l-12.24176,6.76034a8,8,0,0,1-3.86737.9969H94.30873a8,8,0,0,0-7.37259,4.89437l-8.32721,19.76833",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M130.24636,223.97423a96.01036,96.01036,0,0,0,83.92-53.60107l-.00178-.00094-54.28632-33.38846a7.99993,7.99993,0,0,0-3.12236-1.114l-22.81867-3.07595a8,8,0,0,0-8.37592,4.67178l-13.69878,30.73831a8,8,0,0,0,1.433,8.68736l18.79995,20.33464a8,8,0,0,1,1.98022,6.9502l-3.8294,19.79638Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M64.95216,55.60635,56.00794,76.75607a8,8,0,0,0-.12321,5.92293l11.49086,30.66819a8,8,0,0,0,5.81037,5.01448l5.423,1.16555,8.32721-19.76833a8,8,0,0,1,7.37259-4.89437h21.34538a8,8,0,0,0,3.86737-.9969l12.24176-6.76034a8.00033,8.00033,0,0,0,1.49868-1.06968l26.91087-24.33754a8,8,0,0,0,1.6191-9.83314l-9.33366-16.7184.00122-.00463A96.18805,96.18805,0,0,0,64.95081,55.60478Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M214.16458,170.37222l-54.28632-33.38846a7.99993,7.99993,0,0,0-3.12236-1.114l-22.81867-3.07595a8,8,0,0,0-8.37592,4.67178l-13.69878,30.73831a8,8,0,0,0,1.433,8.68736l18.79995,20.33464a8,8,0,0,1,1.98022,6.9502l-3.8294,19.79638",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M64.95216,55.60635,56.00794,76.75607a8,8,0,0,0-.12321,5.92293l11.49086,30.66819a8,8,0,0,0,5.81037,5.01448l21.42993,4.60592a8,8,0,0,1,5.5197,4.3358l3.80564,7.862a8,8,0,0,0,7.20075,4.51442h13.43256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152.45823,35.14852l9.33366,16.7184a8,8,0,0,1-1.6191,9.83314L133.26192,86.0376a8.00033,8.00033,0,0,1-1.49868,1.06968l-12.24176,6.76034a8,8,0,0,1-3.86737.9969H94.30873a8,8,0,0,0-7.37259,4.89437l-8.32721,19.76833",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.59668,173.31348A103.97882,103.97882,0,0,0,154.84473,27.51953c-.18018-.05615-.36231-.10449-.5459-.14795A103.90813,103.90813,0,0,0,60.3916,49.041a7.94439,7.94439,0,0,0-1.33545,1.168A103.94993,103.94993,0,0,0,128,232c.73584,0,1.46875-.0127,2.20117-.02783.01807,0,.03613.00244.05371.00244.03516,0,.06885-.00391.10352-.0044A104.12933,104.12933,0,0,0,220.96387,174.585l.01465-.02148A7.967,7.967,0,0,0,221.59668,173.31348ZM216,128a87.57766,87.57766,0,0,1-5.53125,30.70654L164.06836,130.168a15.90244,15.90244,0,0,0-6.24365-2.22656l-22.81836-3.07618a16.10781,16.10781,0,0,0-15.32178,6.81446h-8.543l-3.80469-7.86035a15.89556,15.89556,0,0,0-11.04-8.67286l-6.56739-1.41113,4.5791-10.87109H115.6543a16.02745,16.02745,0,0,0,7.73437-1.99414l12.24317-6.76074a16.03672,16.03672,0,0,0,2.99609-2.1377l26.91064-24.33789a15.90675,15.90675,0,0,0,4.4336-16.96289A88.07506,88.07506,0,0,1,216,128ZM40,128a87.46223,87.46223,0,0,1,9.46094-39.665l10.42334,27.82031a15.93042,15.93042,0,0,0,11.6206,10.02735l5.5127,1.18506.04541.00976,15.87158,3.41162,3.80566,7.86133a16.09155,16.09155,0,0,0,14.40186,9.0293H112.251l-7.69532,17.26758a15.98365,15.98365,0,0,0,2.86622,17.375l18.79931,20.334-2.56006,13.23584A88.10889,88.10889,0,0,1,40,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M214.16458,170.37222l-54.28632-33.38846a7.99993,7.99993,0,0,0-3.12236-1.114l-22.81867-3.07595a8,8,0,0,0-8.37592,4.67178l-13.69878,30.73831a8,8,0,0,0,1.433,8.68736l18.79995,20.33464a8,8,0,0,1,1.98022,6.9502l-3.8294,19.79638",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M64.95216,55.60635,56.00794,76.75607a8,8,0,0,0-.12321,5.92293l11.49086,30.66819a8,8,0,0,0,5.81037,5.01448l21.42993,4.60592a8,8,0,0,1,5.5197,4.3358l3.80564,7.862a8,8,0,0,0,7.20075,4.51442h13.43256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M152.45823,35.14852l9.33366,16.7184a8,8,0,0,1-1.6191,9.83314L133.26192,86.0376a8.00033,8.00033,0,0,1-1.49868,1.06968l-12.24176,6.76034a8,8,0,0,1-3.86737.9969H94.30873a8,8,0,0,0-7.37259,4.89437l-8.32721,19.76833",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M214.16458,170.37222l-54.28632-33.38846a7.99993,7.99993,0,0,0-3.12236-1.114l-22.81867-3.07595a8,8,0,0,0-8.37592,4.67178l-13.69878,30.73831a8,8,0,0,0,1.433,8.68736l18.79995,20.33464a8,8,0,0,1,1.98022,6.9502l-3.8294,19.79638",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M64.95216,55.60635,56.00794,76.75607a8,8,0,0,0-.12321,5.92293l11.49086,30.66819a8,8,0,0,0,5.81037,5.01448l21.42993,4.60592a8,8,0,0,1,5.5197,4.3358l3.80564,7.862a8,8,0,0,0,7.20075,4.51442h13.43256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M152.45823,35.14852l9.33366,16.7184a8,8,0,0,1-1.6191,9.83314L133.26192,86.0376a8.00033,8.00033,0,0,1-1.49868,1.06968l-12.24176,6.76034a8,8,0,0,1-3.86737.9969H94.30873a8,8,0,0,0-7.37259,4.89437l-8.32721,19.76833",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M214.16458,170.37222l-54.28632-33.38846a7.99993,7.99993,0,0,0-3.12236-1.114l-22.81867-3.07595a8,8,0,0,0-8.37592,4.67178l-13.69878,30.73831a8,8,0,0,0,1.433,8.68736l18.79995,20.33464a8,8,0,0,1,1.98022,6.9502l-3.8294,19.79638",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M64.95216,55.60635,56.00794,76.75607a8,8,0,0,0-.12321,5.92293l11.49086,30.66819a8,8,0,0,0,5.81037,5.01448l21.42993,4.60592a8,8,0,0,1,5.5197,4.3358l3.80564,7.862a8,8,0,0,0,7.20075,4.51442h13.43256",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152.45823,35.14852l9.33366,16.7184a8,8,0,0,1-1.6191,9.83314L133.26192,86.0376a8.00033,8.00033,0,0,1-1.49868,1.06968l-12.24176,6.76034a8,8,0,0,1-3.86737.9969H94.30873a8,8,0,0,0-7.37259,4.89437l-8.32721,19.76833",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GlobeHemisphereWest = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GlobeHemisphereWest.displayName = "GlobeHemisphereWest";

var renderPathFor$5A = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "128",
        x2: "224",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "40",
        ry: "93.42294",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "128",
        x2: "224",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "40",
        ry: "93.42294",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232,128.00037A104.11767,104.11767,0,0,0,128.042,24.00086L128,23.96423l-.042.03663a103.99952,103.99952,0,0,0-.001,207.999l.043.0376.043-.0376A104.11763,104.11763,0,0,0,232,128.00037Zm-16.36768-8h-39.853c-1.5918-29.637-12.01123-57.01758-29.5044-78.08643A88.1919,88.1919,0,0,1,215.63232,120.00037Zm-119.37353,16h63.48242C157.93164,164.75623,146.44678,191.703,128,210.44177,109.55322,191.703,98.06836,164.75623,96.25879,136.00037Zm0-16C98.06836,91.24353,109.55322,64.29675,128,45.559c18.44678,18.73779,29.93164,45.68457,31.74121,74.44141Zm50.01562,94.08642c17.49317-21.06933,27.9126-48.45044,29.50489-78.08642h39.853A88.19181,88.19181,0,0,1,146.27441,214.08679Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "128",
        x2: "224",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "40",
        ry: "93.42294",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "128",
        x2: "224",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "40",
        ry: "93.42294",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "128",
        x2: "224",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "40",
        ry: "93.42294",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GlobeSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5A(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GlobeSimple.displayName = "GlobeSimple";

var renderPathFor$5B = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M201.53911,169.53264A104,104,0,0,1,54.46089,22.45443",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "235.99353",
        x2: "160",
        y2: "235.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "199.99353",
        x2: "128",
        y2: "235.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "95.99353",
        r: "72",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "95.99353",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M201.53911,169.53264A104,104,0,0,1,54.46089,22.45443",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "231.99353",
        x2: "160",
        y2: "231.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "199.99353",
        x2: "128",
        y2: "231.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "128",
        cy: "95.99316",
        r: "80"
      }), React__default.createElement("path", {
        d: "M207.19629,175.18945A8.00052,8.00052,0,0,0,195.88184,163.875,95.99942,95.99942,0,1,1,60.11816,28.11133,8.00052,8.00052,0,0,0,48.80371,16.79688,112.00314,112.00314,0,0,0,120,207.71v16.2832H96a8,8,0,0,0,0,16h64a8,8,0,0,0,0-16H136V207.71A111.16718,111.16718,0,0,0,207.19629,175.18945Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "95.99353",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M201.53911,169.53264A104,104,0,0,1,54.46089,22.45443",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "231.99353",
        x2: "160",
        y2: "231.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "199.99353",
        x2: "128",
        y2: "231.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "95.99353",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M201.53911,169.53264A104,104,0,0,1,54.46089,22.45443",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "231.99353",
        x2: "160",
        y2: "231.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "199.99353",
        x2: "128",
        y2: "231.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "95.99353",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M201.53911,169.53264A104,104,0,0,1,54.46089,22.45443",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "231.99353",
        x2: "160",
        y2: "231.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "199.99353",
        x2: "128",
        y2: "231.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GlobeStand = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5B(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GlobeStand.displayName = "GlobeStand";

var renderPathFor$5C = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128h88a88,88,0,1,1-25.77461-62.2254",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128h88a88,88,0,1,1-25.77461-62.2254",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm0,184A80,80,0,1,1,184.56836,71.43164a7.99984,7.99984,0,1,1-11.31348,11.31348A63.99718,63.99718,0,1,0,191.50244,136H128a8,8,0,0,1,0-16h72a8.00008,8.00008,0,0,1,8,8A80.09041,80.09041,0,0,1,128,208Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128h88a88,88,0,1,1-25.77461-62.2254",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128h88a88,88,0,1,1-25.77461-62.2254",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128h88a88,88,0,1,1-25.77461-62.2254",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GoogleLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5C(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GoogleLogo.displayName = "GoogleLogo";

var renderPathFor$5D = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M39.8134,224.14386a8.01831,8.01831,0,0,0,12.06378,6.771L219.71391,134.8442a7.763,7.763,0,0,0,0-13.6884L51.87718,25.08518a8.01831,8.01831,0,0,0-12.06378,6.771Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "42.23444",
        y1: "26.23444",
        x2: "175.91527",
        y2: "159.91527",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "42.23498",
        y1: "229.76502",
        x2: "175.91497",
        y2: "96.08503",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M42.23345,26.2334a7.65514,7.65514,0,0,0-2.42,5.62274V224.14386a7.65467,7.65467,0,0,0,2.40789,5.61122l.01369.00994L144,128,42.23444,26.23444Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M39.8134,224.14386a8.01831,8.01831,0,0,0,12.06378,6.771L219.71391,134.8442a7.763,7.763,0,0,0,0-13.6884L51.87718,25.08518a8.01831,8.01831,0,0,0-12.06378,6.771Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "42.23444",
        y1: "26.23444",
        x2: "175.91527",
        y2: "159.91527",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "42.23498",
        y1: "229.76502",
        x2: "175.91497",
        y2: "96.08503",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.63476,114.18213l-167.7832-96.04a15.98949,15.98949,0,0,0-16.123.0459,15.66312,15.66312,0,0,0-7.915,13.66846v192.2871a15.66312,15.66312,0,0,0,7.915,13.66846,15.98874,15.98874,0,0,0,16.12305.0459l167.7832-96.04a15.76194,15.76194,0,0,0,0-27.63574ZM144,139.31348l18.85644,18.85644L74.666,208.64746ZM74.65478,47.34082,162.85742,97.8291,144,116.68652ZM177.24707,149.93359,155.31348,128l21.93457-21.93408L215.56738,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M39.8134,224.14386a8.01831,8.01831,0,0,0,12.06378,6.771L219.71391,134.8442a7.763,7.763,0,0,0,0-13.6884L51.87718,25.08518a8.01831,8.01831,0,0,0-12.06378,6.771Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "42.23444",
        y1: "26.23444",
        x2: "175.91527",
        y2: "159.91527",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "42.23498",
        y1: "229.76502",
        x2: "175.91497",
        y2: "96.08503",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M39.8134,224.14386a8.01831,8.01831,0,0,0,12.06378,6.771L219.71391,134.8442a7.763,7.763,0,0,0,0-13.6884L51.87718,25.08518a8.01831,8.01831,0,0,0-12.06378,6.771Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "42.23444",
        y1: "26.23444",
        x2: "175.91527",
        y2: "159.91527",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "42.23498",
        y1: "229.76502",
        x2: "175.91497",
        y2: "96.08503",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M39.8134,224.14386a8.01831,8.01831,0,0,0,12.06378,6.771L219.71391,134.8442a7.763,7.763,0,0,0,0-13.6884L51.87718,25.08518a8.01831,8.01831,0,0,0-12.06378,6.771Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "42.23444",
        y1: "26.23444",
        x2: "175.91527",
        y2: "159.91527",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "42.23498",
        y1: "229.76502",
        x2: "175.91497",
        y2: "96.08503",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GooglePlayLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5D(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GooglePlayLogo.displayName = "GooglePlayLogo";

var renderPathFor$5E = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "44",
        width: "168",
        height: "168",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "44",
        x2: "128",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "212",
        y1: "128",
        x2: "44",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128H44V52a8,8,0,0,1,8-8h76Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "44",
        y: "44",
        width: "168",
        height: "168",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "44",
        x2: "128",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "212",
        y1: "128",
        x2: "44",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M204,36H52A16.01833,16.01833,0,0,0,36,52V204a16.01833,16.01833,0,0,0,16,16H204a16.01833,16.01833,0,0,0,16-16V52A16.01833,16.01833,0,0,0,204,36Zm.00439,92H128V52h76ZM52,128h76v76H52Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "44",
        width: "168",
        height: "168",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "44",
        x2: "128",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "212",
        y1: "128",
        x2: "44",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "44",
        width: "168",
        height: "168",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "44",
        x2: "128",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "212",
        y1: "128",
        x2: "44",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "44",
        width: "168",
        height: "168",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "44",
        x2: "128",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "212",
        y1: "128",
        x2: "44",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var GridFour = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5E(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
GridFour.displayName = "GridFour";

var renderPathFor$5F = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,120V68a20,20,0,0,1,40,0v84a80,80,0,0,1-80,80c-44.18278,0-64-24-96.56854-92.71349a20,20,0,1,1,34.641-20L88,157.26608V52a20,20,0,0,1,40,0v68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M168,120V36a20,20,0,0,0-40,0v84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M128,52V36a20,20,0,0,1,40,0V68a20,20,0,0,1,40,0v84a80,80,0,0,1-80,80c-44.18278,0-64-24-96.56854-92.71349a20,20,0,1,1,34.641-20L88,157.26608V52a20,20,0,0,1,40,0Z"
      })), React__default.createElement("path", {
        d: "M168,120V68a20,20,0,0,1,40,0v84a80,80,0,0,1-80,80c-44.18278,0-64-24-96.56854-92.71349a20,20,0,1,1,34.641-20L88,157.26608V52a20,20,0,0,1,40,0v68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,120V36a20,20,0,0,0-40,0v84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188,40a27.82979,27.82979,0,0,0-12,2.707V36a27.99792,27.99792,0,0,0-54.64209-8.60278A27.992,27.992,0,0,0,80,52v75.41016l-6.999-12.12354a28.00028,28.00028,0,0,0-48.6709,27.69629C56.77832,211.39941,78.39355,240,128,240a88.09957,88.09957,0,0,0,88-88V68A28.03146,28.03146,0,0,0,188,40Zm12,112a72.08124,72.08124,0,0,1-72,72c-20.17871,0-34.22656-5.45459-46.97461-18.23828-12.499-12.53369-24.77246-32.78565-42.36426-69.90137q-.13916-.293-.30175-.57422a12.00011,12.00011,0,0,1,20.78515-11.99951l21.92774,37.97949a7.9997,7.9997,0,0,0,14.92773-4V52a12,12,0,0,1,24,0v68a8,8,0,0,0,16,0V36a12,12,0,0,1,24,0v84a8,8,0,0,0,16,0V68a12,12,0,0,1,24,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,120V68a20,20,0,0,1,40,0v84a80,80,0,0,1-80,80c-44.18278,0-64-24-96.56854-92.71349a20,20,0,1,1,34.641-20L88,157.26608V52a20,20,0,0,1,40,0v68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M168,120V36a20,20,0,0,0-40,0v84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,120V68a20,20,0,0,1,40,0v84a80,80,0,0,1-80,80c-44.18278,0-64-24-96.56854-92.71349a20,20,0,1,1,34.641-20L88,157.26608V52a20,20,0,0,1,40,0v68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M168,120V36a20,20,0,0,0-40,0v84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,120V68a20,20,0,0,1,40,0v84a80,80,0,0,1-80,80c-44.18278,0-64-24-96.56854-92.71349a20,20,0,1,1,34.641-20L88,157.26608V52a20,20,0,0,1,40,0v68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,120V36a20,20,0,0,0-40,0v84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Hand = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5F(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Hand.displayName = "Hand";

var renderPathFor$5G = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104a24,24,0,0,1-48,0V64a24,24,0,0,1,48,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,64a24,24,0,0,1,48,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,176a40,40,0,0,1,40-40H152a24,24,0,0,1-24-24V96a8,8,0,0,1,8-8h64a24,24,0,0,1,24,24v16a96,96,0,0,1-192,0V88a24,24,0,0,1,48,0v16a24,24,0,0,1-48,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,64a24,24,0,0,1,48,0V88h24a24,24,0,0,1,24,24v16a96,96,0,0,1-192,0V88a24,24,0,0,1,48,0V64a24,24,0,0,1,48,0",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,104a24,24,0,0,1-48,0V64a24,24,0,0,1,48,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,64a24,24,0,0,1,48,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,176a40,40,0,0,1,40-40H152a24,24,0,0,1-24-24V96a8,8,0,0,1,8-8h64a24,24,0,0,1,24,24v16a96,96,0,0,1-192,0V88a24,24,0,0,1,48,0v16a24,24,0,0,1-48,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,80H184V64a31.97943,31.97943,0,0,0-56-21.13208A31.97443,31.97443,0,0,0,72.20508,60.4231,31.978,31.978,0,0,0,24,88v40a104,104,0,0,0,208,0V112A32.03635,32.03635,0,0,0,200,80ZM152,48a16.01833,16.01833,0,0,1,16,16V80H136V64A16.01833,16.01833,0,0,1,152,48ZM88,64a16,16,0,0,1,32,0v40a16,16,0,0,1-32,0V64ZM40,88a16,16,0,0,1,32,0v16a16,16,0,0,1-32,0Zm88,128a88.10627,88.10627,0,0,1-87.9209-84.249A31.94065,31.94065,0,0,0,80,125.13208a31.92587,31.92587,0,0,0,44.58057,3.34595,32.23527,32.23527,0,0,0,11.79443,11.4414A47.906,47.906,0,0,0,120,176a8,8,0,0,0,16,0,32.03635,32.03635,0,0,1,32-32,8,8,0,0,0,0-16H152a16.01833,16.01833,0,0,1-16-16V96h64a16.01833,16.01833,0,0,1,16,16v16A88.09957,88.09957,0,0,1,128,216Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104a24,24,0,0,1-48,0V64a24,24,0,0,1,48,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,64a24,24,0,0,1,48,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,176a40,40,0,0,1,40-40H152a24,24,0,0,1-24-24V96a8,8,0,0,1,8-8h64a24,24,0,0,1,24,24v16a96,96,0,0,1-192,0V88a24,24,0,0,1,48,0v16a24,24,0,0,1-48,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104a24,24,0,0,1-48,0V64a24,24,0,0,1,48,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,64a24,24,0,0,1,48,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,176a40,40,0,0,1,40-40H152a24,24,0,0,1-24-24V96a8,8,0,0,1,8-8h64a24,24,0,0,1,24,24v16a96,96,0,0,1-192,0V88a24,24,0,0,1,48,0v16a24,24,0,0,1-48,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104a24,24,0,0,1-48,0V64a24,24,0,0,1,48,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,64a24,24,0,0,1,48,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,176a40,40,0,0,1,40-40H152a24,24,0,0,1-24-24V96a8,8,0,0,1,8-8h64a24,24,0,0,1,24,24v16a96,96,0,0,1-192,0V88a24,24,0,0,1,48,0v16a24,24,0,0,1-48,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HandFist = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5G(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HandFist.displayName = "HandFist";

var renderPathFor$5H = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,124V92a20,20,0,0,0-40,0v56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M168,124V92a20,20,0,0,0-40,0v32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,148V116H68a20,20,0,0,0-20,20v16a80,80,0,0,0,160,0V108a20,20,0,0,0-40,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M88,116H68a20,20,0,0,0-20,20v16a80,80,0,0,0,160,0V108a20,20,0,0,0-40,0V92a20,20,0,0,0-40,0,20,20,0,0,0-40,0Z"
      })), React__default.createElement("path", {
        d: "M128,124V92a20,20,0,0,0-40,0v56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,124V92a20,20,0,0,0-40,0v32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,148V116H68a20,20,0,0,0-20,20v16a80,80,0,0,0,160,0V108a20,20,0,0,0-40,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188,80a27.82885,27.82885,0,0,0-13.35791,3.39716A27.97426,27.97426,0,0,0,128,72.43066,27.9817,27.9817,0,0,0,80,92v16H68a28.03146,28.03146,0,0,0-28,28v16a88,88,0,0,0,176,0V108A28.03146,28.03146,0,0,0,188,80Zm12,72a72,72,0,0,1-144,0V136a12.01343,12.01343,0,0,1,12-12H80v24a8,8,0,0,0,16,0V92a12,12,0,0,1,24,0v32a8,8,0,0,0,16,0V92a12,12,0,0,1,24,0v32a8,8,0,0,0,16,0V108a12,12,0,0,1,24,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,124V92a20,20,0,0,0-40,0v56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M168,124V92a20,20,0,0,0-40,0v32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,148V116H68a20,20,0,0,0-20,20v16a80,80,0,0,0,160,0V108a20,20,0,0,0-40,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,124V92a20,20,0,0,0-40,0v56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M168,124V92a20,20,0,0,0-40,0v32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,148V116H68a20,20,0,0,0-20,20v16a80,80,0,0,0,160,0V108a20,20,0,0,0-40,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,124V92a20,20,0,0,0-40,0v56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,124V92a20,20,0,0,0-40,0v32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,148V116H68a20,20,0,0,0-20,20v16a80,80,0,0,0,160,0V108a20,20,0,0,0-40,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HandGrabbing = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5H(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HandGrabbing.displayName = "HandGrabbing";

var renderPathFor$5I = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104V52a20,20,0,0,1,40,0v80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,112V36a20,20,0,0,1,40,0v68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,172a40,40,0,0,1,40-40V112a20,20,0,0,1,40,0v40a80,80,0,0,1-160,0V76a20,20,0,0,1,40,0v36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,112a20,20,0,0,1,40,0v40a80,80,0,0,1-160,0V76a20,20,0,0,1,40,0V36a20,20,0,0,1,40,0V52a20,20,0,0,1,40,0Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,104V52a20,20,0,0,1,40,0v80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,112V36a20,20,0,0,1,40,0v68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,172a40,40,0,0,1,40-40V112a20,20,0,0,1,40,0v40a80,80,0,0,1-160,0V76a20,20,0,0,1,40,0v36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188,84a27.83152,27.83152,0,0,0-12,2.707V52a27.992,27.992,0,0,0-41.35791-24.60278A27.99792,27.99792,0,0,0,80,36V50.707A27.991,27.991,0,0,0,40,76v76a88,88,0,0,0,176,0V112A28.03146,28.03146,0,0,0,188,84Zm12,68a72,72,0,0,1-144,0V76a12,12,0,0,1,24,0v36a8,8,0,0,0,16,0V36a12,12,0,0,1,24,0v68a8,8,0,0,0,16,0V52a12,12,0,0,1,24,0v72.6665A48.07871,48.07871,0,0,0,120,172a8,8,0,0,0,16,0,32.03635,32.03635,0,0,1,32-32,8.00008,8.00008,0,0,0,8-8V112a12,12,0,0,1,24,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104V52a20,20,0,0,1,40,0v80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,112V36a20,20,0,0,1,40,0v68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,172a40,40,0,0,1,40-40V112a20,20,0,0,1,40,0v40a80,80,0,0,1-160,0V76a20,20,0,0,1,40,0v36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104V52a20,20,0,0,1,40,0v80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,112V36a20,20,0,0,1,40,0v68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,172a40,40,0,0,1,40-40V112a20,20,0,0,1,40,0v40a80,80,0,0,1-160,0V76a20,20,0,0,1,40,0v36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104V52a20,20,0,0,1,40,0v80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,112V36a20,20,0,0,1,40,0v68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,172a40,40,0,0,1,40-40V112a20,20,0,0,1,40,0v40a80,80,0,0,1-160,0V76a20,20,0,0,1,40,0v36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HandPalm = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5I(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HandPalm.displayName = "HandPalm";

var renderPathFor$5J = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104V36a20,20,0,0,0-40,0V157.26608L66.07247,119.28651a20,20,0,1,0-34.641,20C64,208,83.81722,232,128,232a80,80,0,0,0,80-80V112a20,20,0,0,0-40,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M168,112V100a20,20,0,0,0-40,0v4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,112V100a20,20,0,0,0-40,0V36a20,20,0,0,0-40,0V157.26608L66.07247,119.28651a20,20,0,1,0-34.641,20C64,208,83.81722,232,128,232a80,80,0,0,0,80-80V112a20,20,0,0,0-40,0Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,104V36a20,20,0,0,0-40,0V157.26608L66.07247,119.28651a20,20,0,1,0-34.641,20C64,208,83.81722,232,128,232a80,80,0,0,0,80-80V112a20,20,0,0,0-40,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,112V100a20,20,0,0,0-40,0v4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188,84a27.82842,27.82842,0,0,0-14.6416,4.145A27.97776,27.97776,0,0,0,136,74.707V36a28,28,0,0,0-56,0v91.41016l-6.999-12.12354a28.00028,28.00028,0,0,0-48.6709,27.69629C56.77832,211.39941,78.39355,240,128,240a88.09957,88.09957,0,0,0,88-88V112A28.03146,28.03146,0,0,0,188,84Zm12,68a72.08124,72.08124,0,0,1-72,72c-20.17871,0-34.22656-5.45459-46.97461-18.23828-12.499-12.53369-24.77246-32.78565-42.36426-69.90137q-.13916-.293-.30175-.57422a12.00011,12.00011,0,0,1,20.78515-11.99951l21.92774,37.97949a7.9997,7.9997,0,0,0,14.92773-4V36a12,12,0,0,1,24,0v68a8,8,0,0,0,16,0v-4a12,12,0,0,1,24,0v12a8,8,0,0,0,16,0,12,12,0,0,1,24,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104V36a20,20,0,0,0-40,0V157.26608L66.07247,119.28651a20,20,0,1,0-34.641,20C64,208,83.81722,232,128,232a80,80,0,0,0,80-80V112a20,20,0,0,0-40,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M168,112V100a20,20,0,0,0-40,0v4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104V36a20,20,0,0,0-40,0V157.26608L66.07247,119.28651a20,20,0,1,0-34.641,20C64,208,83.81722,232,128,232a80,80,0,0,0,80-80V112a20,20,0,0,0-40,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M168,112V100a20,20,0,0,0-40,0v4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104V36a20,20,0,0,0-40,0V157.26608L66.07247,119.28651a20,20,0,1,0-34.641,20C64,208,83.81722,232,128,232a80,80,0,0,0,80-80V112a20,20,0,0,0-40,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,112V100a20,20,0,0,0-40,0v4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HandPointing = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5J(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HandPointing.displayName = "HandPointing";

var renderPathFor$5K = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M119.99332,106.41921l-26-45.03332a20,20,0,0,1,34.641-20l40,69.282",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M89.35231,133.34742l-38-65.81793a20,20,0,1,1,34.641-20l34,58.88972",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M153.99332,165.30894a40,40,0,0,1,14.641-54.641l-10-17.32051a20,20,0,1,1,34.641-20l20,34.641a80,80,0,1,1-138.56406,80l-38-65.81793a20,20,0,0,1,34.641-20l18,31.17692",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      })), React__default.createElement("path", {
        d: "M176,22.99A59.97614,59.97614,0,0,1,227.96152,53",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M66.93521,240.00025A119.74962,119.74962,0,0,1,40.0943,207.99",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M158.63434,93.34742a20,20,0,1,1,34.641-20l20,34.641a80,80,0,1,1-138.56406,80l-38-65.81793a20,20,0,0,1,34.641-20l-20-34.641a20,20,0,1,1,34.641-20l8,13.8564a20,20,0,0,1,34.641-20Z",
        opacity: "0.2"
      }), React__default.createElement("g", null, React__default.createElement("path", {
        d: "M119.99332,106.41921l-26-45.03332a20,20,0,0,1,34.641-20l40,69.282",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M89.35231,133.34742l-38-65.81793a20,20,0,1,1,34.641-20l34,58.88972",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M153.99332,165.30894a40,40,0,0,1,14.641-54.641l-10-17.32051a20,20,0,1,1,34.641-20l20,34.641a80,80,0,1,1-138.56406,80l-38-65.81793a20,20,0,0,1,34.641-20l18,31.17692",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      })), React__default.createElement("path", {
        d: "M81.09415,240.0027A111.54975,111.54975,0,0,1,48,203.99065",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,31A51.97065,51.97065,0,0,1,221.0258,57.00434",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220.20312,103.98828l-19.999-34.64062a28.02682,28.02682,0,0,0-47.29834-1.92243l-17.34326-30.04a27.99212,27.99212,0,0,0-48.11328-.63549A28.003,28.003,0,0,0,44.4248,71.5293l7.35352,12.73663A27.99166,27.99166,0,0,0,29.7832,126.17041l38,65.81787a87.99976,87.99976,0,1,0,152.41992-88ZM213.54,166.62354A72.00058,72.00058,0,0,1,81.63867,183.98828l-37.999-65.81738a11.99994,11.99994,0,0,1,20.78418-12.00049l18,31.17725a8.01625,8.01625,0,0,0,.55566.82623c.05274.07.1084.13617.16309.204q.23657.2926.4956.5578c.0586.0603.11621.12207.17627.1803a8.00346,8.00346,0,0,0,.72412.62359l.01758.012a8.0088,8.0088,0,0,0,.76807.50262c.07519.04346.15088.08325.22705.12421q.31714.17148.64844.313c.07373.03149.1455.06524.22021.09454a8.05256,8.05256,0,0,0,.88867.29571c.01953.00519.03955.00782.05909.01288a8.05171,8.05171,0,0,0,.85449.16712c.08545.01226.1709.02105.25683.03058q.36036.03992.72412.04675c.05274.001.1045.01019.15723.01019.02539,0,.05127-.0047.07666-.00494a7.94421,7.94421,0,0,0,.93018-.05963c.0249-.00318.0498-.00965.0747-.01307a7.93311,7.93311,0,0,0,.84131-.16473c.08985-.0224.17823-.049.26758-.07465q.33692-.09659.66748-.22454c.08692-.03351.17383-.06482.26026-.10157a7.95946,7.95946,0,0,0,3.80175-11.35833l-18-31.17774-.0039-.00647L58.28027,63.52881A12.00012,12.00012,0,0,1,79.06543,51.5293l7.9834,13.82818.01562.02826,26,45.03369a8,8,0,1,0,13.85645-8l-25.999-45.03369a12.00023,12.00023,0,1,1,20.78515-12l29.99756,51.95752.00244.0044,6.3291,10.96338a48.025,48.025,0,0,0-10.9707,60.998,7.99959,7.99959,0,1,0,13.85547-8,32.00043,32.00043,0,0,1,11.71387-43.71289,7.96868,7.96868,0,0,0,.66992-.43329c.18017-.12921.34961-.26849.51562-.41009.03174-.02692.06641-.05048.09766-.07788.19092-.16761.37109-.344.543-.52668l.01611-.01586q.25928-.27687.48779-.575l.01758-.02087c.14453-.1886.27783-.384.4043-.5835.01318-.021.02832-.0404.0415-.06152.11377-.18286.21533-.37158.31348-.5622.022-.04248.04736-.08258.06885-.12548.0874-.17847.16308-.36206.2373-.54621.02344-.05877.05225-.115.07471-.17444.08056-.215.14892-.43408.21094-.655.0083-.03028.0205-.059.0288-.08942.00782-.02966.01172-.05988.01954-.0896.05664-.22278.10742-.44714.145-.67419.01171-.06977.01513-.14.0249-.2099.02636-.18915.05224-.3783.06494-.56922.00391-.05823.00146-.11633.00391-.17456.00927-.20325.01611-.40661.00976-.61078-.00146-.03888-.00732-.07739-.00879-.11621-.01025-.2218-.02588-.44366-.05469-.66522-.00341-.02515-.00976-.04981-.01318-.07489-.03271-.23193-.07275-.46344-.126-.69373-.00683-.02783-.0166-.05481-.02294-.08252-.05469-.22387-.11573-.4469-.19043-.66772-.022-.06525-.05127-.12811-.0752-.19281-.06641-.18012-.13184-.36029-.21191-.53735a7.98085,7.98085,0,0,0-.36475-.7121l-10-17.3208a12.00012,12.00012,0,0,1,20.78516-11.99951l20,34.64062A71.53255,71.53255,0,0,1,213.54,166.62354ZM87.668,244.56152a7.999,7.999,0,0,1-11.13281,2.01563,118.949,118.949,0,0,1-35.46289-38.58643,7.99959,7.99959,0,1,1,13.85546-8,103.08083,103.08083,0,0,0,30.72461,33.438A8.00009,8.00009,0,0,1,87.668,244.56152ZM168,30.99268A8.00009,8.00009,0,0,1,176,23h.00781A60.21143,60.21143,0,0,1,227.9541,53.00439a8.00044,8.00044,0,1,1-13.85742,8A44.16357,44.16357,0,0,0,175.99219,39,8,8,0,0,1,168,30.99268Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M119.99332,106.41921l-26-45.03332a20,20,0,0,1,34.641-20l40,69.282",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M89.35231,133.34742l-38-65.81793a20,20,0,1,1,34.641-20l34,58.88972",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M153.99332,165.30894a40,40,0,0,1,14.641-54.641l-10-17.32051a20,20,0,1,1,34.641-20l20,34.641a80,80,0,1,1-138.56406,80l-38-65.81793a20,20,0,0,1,34.641-20l18,31.17692",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      })), React__default.createElement("path", {
        d: "M81.09415,240.0027A111.54975,111.54975,0,0,1,48,203.99065",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M176,31A51.97065,51.97065,0,0,1,221.0258,57.00434",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M119.99332,106.41921l-26-45.03332a20,20,0,0,1,34.641-20l40,69.282",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M89.35231,133.34742l-38-65.81793a20,20,0,1,1,34.641-20l34,58.88972",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M153.99332,165.30894a40,40,0,0,1,14.641-54.641l-10-17.32051a20,20,0,1,1,34.641-20l20,34.641a80,80,0,1,1-138.56406,80l-38-65.81793a20,20,0,0,1,34.641-20l18,31.17692",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      })), React__default.createElement("path", {
        d: "M81.09415,240.0027A111.54975,111.54975,0,0,1,48,203.99065",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M176,31A51.97065,51.97065,0,0,1,221.0258,57.00434",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M119.99332,106.41921l-26-45.03332a20,20,0,0,1,34.641-20l40,69.282",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M89.35231,133.34742l-38-65.81793a20,20,0,1,1,34.641-20l34,58.88972",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M153.99332,165.30894a40,40,0,0,1,14.641-54.641l-10-17.32051a20,20,0,1,1,34.641-20l20,34.641a80,80,0,1,1-138.56406,80l-38-65.81793a20,20,0,0,1,34.641-20l18,31.17692",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      })), React__default.createElement("path", {
        d: "M81.09415,240.0027A111.54975,111.54975,0,0,1,48,203.99065",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,31A51.97065,51.97065,0,0,1,221.0258,57.00434",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HandWaving = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5K(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HandWaving.displayName = "HandWaving";

var renderPathFor$5L = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.83966,72H47.16034a8,8,0,0,0-7.95107,7.11655l-14.22222,128A8,8,0,0,0,32.93812,216H223.06188a8,8,0,0,0,7.95107-8.88345l-14.22222-128A8,8,0,0,0,208.83966,72Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,72a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.83966,72H47.16034a8,8,0,0,0-7.95107,7.11655l-14.22222,128A8,8,0,0,0,32.93812,216H223.06188a8,8,0,0,0,7.95107-8.88345l-14.22222-128A8,8,0,0,0,208.83966,72Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M208.83966,72H47.16034a8,8,0,0,0-7.95107,7.11655l-14.22222,128A8,8,0,0,0,32.93812,216H223.06188a8,8,0,0,0,7.95107-8.88345l-14.22222-128A8,8,0,0,0,208.83966,72Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,72a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M238.96387,206.2334,224.74219,78.23291A15.98372,15.98372,0,0,0,208.83984,64h-33.519a47.99073,47.99073,0,0,0-94.6416,0h-33.519A15.98375,15.98375,0,0,0,31.25781,78.2334l-14.22168,128A16.00031,16.00031,0,0,0,32.93848,224h190.123a16.00031,16.00031,0,0,0,15.90235-17.7666ZM128,40a32.05773,32.05773,0,0,1,30.9873,24H97.0127A32.05773,32.05773,0,0,1,128,40Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.83966,72H47.16034a8,8,0,0,0-7.95107,7.11655l-14.22222,128A8,8,0,0,0,32.93812,216H223.06188a8,8,0,0,0,7.95107-8.88345l-14.22222-128A8,8,0,0,0,208.83966,72Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,72a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.83966,72H47.16034a8,8,0,0,0-7.95107,7.11655l-14.22222,128A8,8,0,0,0,32.93812,216H223.06188a8,8,0,0,0,7.95107-8.88345l-14.22222-128A8,8,0,0,0,208.83966,72Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,72a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.83966,72H47.16034a8,8,0,0,0-7.95107,7.11655l-14.22222,128A8,8,0,0,0,32.93812,216H223.06188a8,8,0,0,0,7.95107-8.88345l-14.22222-128A8,8,0,0,0,208.83966,72Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,72a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Handbag = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5L(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Handbag.displayName = "Handbag";

var renderPathFor$5M = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M236.71765,121.78477,212,134.14359l-32-61.282,24.9693-12.48465a8,8,0,0,1,10.66912,3.45246l24.59293,47.097A8,8,0,0,1,236.71765,121.78477Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M44,133.0718,19.28235,120.713a8,8,0,0,1-3.5137-10.85838l24.59293-47.097A8,8,0,0,1,51.0307,59.30511L76,71.78976Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M212,134.14359l-12,18.718L163.20286,189.6587a8,8,0,0,1-7.59714,2.10429L97.64881,177.27376a7.99992,7.99992,0,0,1-2.98764-1.45911L44,133.0718",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M200,152.86156l-44-32-12.8,9.6a32,32,0,0,1-38.4,0L99.37926,126.396a8,8,0,0,1-.85685-12.05686l39.13444-39.13444a8,8,0,0,1,5.65686-2.34315H180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M76.57437,71.78976l47.32-14.96153a8,8,0,0,1,5.537.39169L164,72.86156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M108,220.86156,77.86056,213.3267a7.99993,7.99993,0,0,1-3.308-1.7233L52,192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      })));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M200,152.86156,163.20286,189.6587a8,8,0,0,1-7.59714,2.10429L97.64881,177.27376a7.99992,7.99992,0,0,1-2.98764-1.45911L40,133.0718l32.57437-61.282,51.32-14.96153a8,8,0,0,1,5.537.39169L164,72.86156H143.31371a8,8,0,0,0-5.65686,2.34315L98.52241,114.33915a8,8,0,0,0,.85685,12.05686L104.8,130.46156a32,32,0,0,0,38.4,0l12.8-9.6Z"
      })), React__default.createElement("circle", {
        cx: "-112",
        cy: "-108",
        r: "119.97997",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24",
        opacity: "0.1"
      }), React__default.createElement("path", {
        d: "M240.71765,121.78477,216,134.14359l-32-61.282,24.9693-12.48465a8,8,0,0,1,10.66912,3.45246l24.59293,47.097A8,8,0,0,1,240.71765,121.78477Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M40,133.0718,15.28235,120.713a8,8,0,0,1-3.5137-10.85838l24.59293-47.097A8,8,0,0,1,47.0307,59.30511L72,71.78976Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M216,134.14359l-16,18.718L163.20286,189.6587a8,8,0,0,1-7.59714,2.10429L97.64881,177.27376a7.99992,7.99992,0,0,1-2.98764-1.45911L40,133.0718",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,152.86156l-44-32-12.8,9.6a32,32,0,0,1-38.4,0L99.37926,126.396a8,8,0,0,1-.85685-12.05686l39.13444-39.13444a8,8,0,0,1,5.65686-2.34315H184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M72.57437,71.78976l51.32-14.96153a8,8,0,0,1,5.537.39169L164,72.86156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M112,212.86156,81.86056,205.3267a7.99993,7.99993,0,0,1-3.308-1.7233L56,184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M119.76074,214.80176a7.98886,7.98886,0,0,1-9.70117,5.82031l-30.13965-7.53418a16.0992,16.0992,0,0,1-6.61719-3.44727L50.752,190.03809a8,8,0,0,1,10.4961-12.07618l22.55273,19.60352,30.13965,7.53516A7.99856,7.99856,0,0,1,119.76074,214.80176Zm132.60156-95.2461a15.88206,15.88206,0,0,1-8.0664,9.38428L221.02783,140.574l-14.94678,17.48553c-.05224.061-.10937.11725-.16308.17664-.04932.05413-.09815.10785-.14844.16034-.03808.03985-.07324.08245-.1123.12152l-36.79688,36.79834a16.0981,16.0981,0,0,1-11.35058,4.67968,15.8477,15.8477,0,0,1-3.84473-.47265L95.708,185.03418a15.9025,15.9025,0,0,1-5.97559-2.918L35.7041,139.86829l-24-12.00013a16.0014,16.0014,0,0,1-7.02734-21.7163L29.26953,59.05469A16.07985,16.07985,0,0,1,50.6084,52.1499l22.375,11.18744L121.65527,49.148a16.01609,16.01609,0,0,1,11.07325.78271l32.99707,14.93067H182.1123l23.28028-11.63965A16.07317,16.07317,0,0,1,226.73047,60.127l24.59277,47.09619A15.87906,15.87906,0,0,1,252.3623,119.55566Zm-64.63916,34.26886-31.6499-23.01788L148,136.86133a40.20558,40.20558,0,0,1-48,0l-5.4209-4.06543a16.00034,16.00034,0,0,1-1.71387-24.11328L132,69.54785a16.1947,16.1947,0,0,1,1.8335-1.55548l-7.69971-3.48407L77.41016,78.71265,50.17432,130.872,99.58887,169.5127l57.957,14.48925Zm18.68311-20.76959-27.25439-52.1936h-15.1294l-.02734.002c-.0127,0-.02491-.00189-.03711-.002H143.31348l-39.13379,39.13476,5.41992,4.06543a24.1254,24.1254,0,0,0,28.80078,0l12.79981-9.60009a7.99783,7.99783,0,0,1,9.50488-.06983l38.019,27.65027Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240.71765,121.78477,216,134.14359l-32-61.282,24.9693-12.48465a8,8,0,0,1,10.66912,3.45246l24.59293,47.097A8,8,0,0,1,240.71765,121.78477Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M40,133.0718,15.28235,120.713a8,8,0,0,1-3.5137-10.85838l24.59293-47.097A8,8,0,0,1,47.0307,59.30511L72,71.78976Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M216,134.14359l-16,18.718L163.20286,189.6587a8,8,0,0,1-7.59714,2.10429L97.64881,177.27376a7.99992,7.99992,0,0,1-2.98764-1.45911L40,133.0718",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M200,152.86156l-44-32-12.8,9.6a32,32,0,0,1-38.4,0L99.37926,126.396a8,8,0,0,1-.85685-12.05686l39.13444-39.13444a8,8,0,0,1,5.65686-2.34315H184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M72.57437,71.78976l51.32-14.96153a8,8,0,0,1,5.537.39169L164,72.86156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M112,212.86156,81.86056,205.3267a7.99993,7.99993,0,0,1-3.308-1.7233L56,184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240.71765,121.78477,216,134.14359l-32-61.282,24.9693-12.48465a8,8,0,0,1,10.66912,3.45246l24.59293,47.097A8,8,0,0,1,240.71765,121.78477Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M40,133.0718,15.28235,120.713a8,8,0,0,1-3.5137-10.85838l24.59293-47.097A8,8,0,0,1,47.0307,59.30511L72,71.78976Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M216,134.14359l-16,18.718L163.20286,189.6587a8,8,0,0,1-7.59714,2.10429L97.64881,177.27376a7.99992,7.99992,0,0,1-2.98764-1.45911L40,133.0718",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M200,152.86156l-44-32-12.8,9.6a32,32,0,0,1-38.4,0L99.37926,126.396a8,8,0,0,1-.85685-12.05686l39.13444-39.13444a8,8,0,0,1,5.65686-2.34315H184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M72.57437,71.78976l51.32-14.96153a8,8,0,0,1,5.537.39169L164,72.86156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M112,212.86156,81.86056,205.3267a7.99993,7.99993,0,0,1-3.308-1.7233L56,184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240.71765,121.78477,216,134.14359l-32-61.282,24.9693-12.48465a8,8,0,0,1,10.66912,3.45246l24.59293,47.097A8,8,0,0,1,240.71765,121.78477Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M40,133.0718,15.28235,120.713a8,8,0,0,1-3.5137-10.85838l24.59293-47.097A8,8,0,0,1,47.0307,59.30511L72,71.78976Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M216,134.14359l-16,18.718L163.20286,189.6587a8,8,0,0,1-7.59714,2.10429L97.64881,177.27376a7.99992,7.99992,0,0,1-2.98764-1.45911L40,133.0718",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M200,152.86156l-44-32-12.8,9.6a32,32,0,0,1-38.4,0L99.37926,126.396a8,8,0,0,1-.85685-12.05686l39.13444-39.13444a8,8,0,0,1,5.65686-2.34315H184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M72.57437,71.78976l51.32-14.96153a8,8,0,0,1,5.537.39169L164,72.86156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M112,212.86156,81.86056,205.3267a7.99993,7.99993,0,0,1-3.308-1.7233L56,184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Handshake = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5M(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Handshake.displayName = "Handshake";

var renderPathFor$5N = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "72",
        width: "208",
        height: "112",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "72",
        width: "208",
        height: "112",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "24",
        y: "72",
        width: "208",
        height: "112",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,64H32A16.01833,16.01833,0,0,0,16,80v96a16.01833,16.01833,0,0,0,16,16H224a16.01833,16.01833,0,0,0,16-16V80A16.01833,16.01833,0,0,0,224,64Zm-35.99951,76a12,12,0,1,1,12-12A12,12,0,0,1,188.00049,140Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "72",
        width: "208",
        height: "112",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "72",
        width: "208",
        height: "112",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "72",
        width: "208",
        height: "112",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HardDrive = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5N(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HardDrive.displayName = "HardDrive";

var renderPathFor$5O = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "176",
        cy: "88",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "160",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "128",
        x2: "40",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "64",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "64",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M208,40H48A16.01833,16.01833,0,0,0,32,56v48a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V56A16.01833,16.01833,0,0,0,208,40ZM180.00049,92a12,12,0,1,1,12-12A12,12,0,0,1,180.00049,92Z"
      }), React__default.createElement("path", {
        d: "M208,136H48a16.01833,16.01833,0,0,0-16,16v48a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V152A16.01833,16.01833,0,0,0,208,136Zm-27.99951,52a12,12,0,1,1,12-12A12,12,0,0,1,180.00049,188Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HardDrives = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5O(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HardDrives.displayName = "HardDrives";

var renderPathFor$5P = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "43.63636",
        y1: "96",
        x2: "224",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "144",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "40",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "160",
        x2: "212.36376",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "43.63636",
        y1: "96",
        x2: "224",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "144",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "40",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "160",
        x2: "212.36376",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,88H175.40381l8.46728-46.56934a8.00005,8.00005,0,1,0-15.74218-2.86132L159.1416,88H111.40381l8.46728-46.56934a8.00005,8.00005,0,1,0-15.74218-2.86132L95.1416,88H43.63672a8,8,0,0,0,0,16h48.5957l-8.72754,48H32a8,8,0,0,0,0,16H80.59619l-8.46728,46.56934a8.00005,8.00005,0,1,0,15.74218,2.86132L96.8584,168h47.73779l-8.46728,46.56934a8.00005,8.00005,0,1,0,15.74218,2.86132L160.8584,168h51.50488a8,8,0,1,0,0-16h-48.5957l8.72754-48H224a8,8,0,0,0,0-16Zm-76.49512,64H99.76758l8.72754-48h47.7373Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "43.63636",
        y1: "96",
        x2: "224",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "144",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "40",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "160",
        x2: "212.36376",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "43.63636",
        y1: "96",
        x2: "224",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "144",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "40",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "160",
        x2: "212.36376",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "43.63636",
        y1: "96",
        x2: "224",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "40",
        x2: "144",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "40",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "160",
        x2: "212.36376",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Hash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5P(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Hash.displayName = "Hash";

var renderPathFor$5Q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "96",
        x2: "216",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "160",
        x2: "216",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "40",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "40",
        x2: "96",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "96",
        x2: "216",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "160",
        x2: "216",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "40",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "40",
        x2: "96",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,152H168V104h48a8,8,0,0,0,0-16H168V40a8,8,0,0,0-16,0V88H104V40a8,8,0,0,0-16,0V88H40a8,8,0,0,0,0,16H88v48H40a8,8,0,0,0,0,16H88v48a8,8,0,0,0,16,0V168h48v48a8,8,0,0,0,16,0V168h48a8,8,0,0,0,0-16Zm-112,0V104h48v48Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "96",
        x2: "216",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "160",
        x2: "216",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "40",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "40",
        x2: "96",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "96",
        x2: "216",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "160",
        x2: "216",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "40",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "40",
        x2: "96",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "96",
        x2: "216",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "160",
        x2: "216",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "40",
        x2: "160",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "40",
        x2: "96",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HashStraight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5Q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HashStraight.displayName = "HashStraight";

var renderPathFor$5R = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.45581,136h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16V136A96.0001,96.0001,0,0,0,128.7279,40.0027,96.00009,96.00009,0,0,0,32,136v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V152a16,16,0,0,0-16-16H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,136v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V152a16,16,0,0,0-16-16Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M225.45581,136h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M225.45581,136h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16V136A96.0001,96.0001,0,0,0,128.7279,40.0027,96.00009,96.00009,0,0,0,32,136v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V152a16,16,0,0,0-16-16H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M202.7207,62.1875A103.28167,103.28167,0,0,0,129.46289,32c-.24414,0-.49121.001-.73535.00244A104.00025,104.00025,0,0,0,24,136v56a24.0275,24.0275,0,0,0,24,24H64a24.0275,24.0275,0,0,0,24-24V152a24.0275,24.0275,0,0,0-24-24H40.35547A88.01928,88.01928,0,0,1,128.668,48.00244c.041.00049.07812.00049.11914,0A88.01738,88.01738,0,0,1,217.10059,128H193.45605a24.0275,24.0275,0,0,0-24,24v40a24.0275,24.0275,0,0,0,24,24h16a24.0275,24.0275,0,0,0,24-24V136A103.28343,103.28343,0,0,0,202.7207,62.1875Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.45581,136h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16V136A96.0001,96.0001,0,0,0,128.7279,40.0027,96.00009,96.00009,0,0,0,32,136v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V152a16,16,0,0,0-16-16H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.45581,136h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16V136A96.0001,96.0001,0,0,0,128.7279,40.0027,96.00009,96.00009,0,0,0,32,136v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V152a16,16,0,0,0-16-16H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.45581,136h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16V136A96.0001,96.0001,0,0,0,128.7279,40.0027,96.00009,96.00009,0,0,0,32,136v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V152a16,16,0,0,0-16-16H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Headphones = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5R(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Headphones.displayName = "Headphones";

var renderPathFor$5S = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.45581,128h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16V128A96.0001,96.0001,0,0,0,128.7279,32.0027,96.00009,96.00009,0,0,0,32,128v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V144a16,16,0,0,0-16-16H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M225.45581,184v24a32,32,0,0,1-32,32H136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,128v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V144a16,16,0,0,0-16-16Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M225.45581,128h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M225.45581,128h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16V128A96.0001,96.0001,0,0,0,128.7279,32.0027,96.00009,96.00009,0,0,0,32,128v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V144a16,16,0,0,0-16-16H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M225.45581,184v24a32,32,0,0,1-32,32H136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M233.45605,128v80a40.04551,40.04551,0,0,1-40,40H136a8,8,0,0,1,0-16h57.45605a24.0275,24.0275,0,0,0,24-24v-1.376a23.89418,23.89418,0,0,1-8,1.376h-16a24.0275,24.0275,0,0,1-24-24V144a24.0275,24.0275,0,0,1,24-24h23.64454a88.01738,88.01738,0,0,0-88.31348-79.99756c-.041.00049-.07813.00049-.11914,0A88.01928,88.01928,0,0,0,40.35547,120H64a24.0275,24.0275,0,0,1,24,24v40a24.0275,24.0275,0,0,1-24,24H48a24.0275,24.0275,0,0,1-24-24V128A104.00025,104.00025,0,0,1,128.72754,24.00244c.24414-.00146.49121-.00244.73535-.00244A104.00007,104.00007,0,0,1,233.45605,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.45581,128h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16V128A96.0001,96.0001,0,0,0,128.7279,32.0027,96.00009,96.00009,0,0,0,32,128v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V144a16,16,0,0,0-16-16H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M225.45581,184v24a32,32,0,0,1-32,32H136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.45581,128h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16V128A96.0001,96.0001,0,0,0,128.7279,32.0027,96.00009,96.00009,0,0,0,32,128v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V144a16,16,0,0,0-16-16H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M225.45581,184v24a32,32,0,0,1-32,32H136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.45581,128h-32a16,16,0,0,0-16,16v40a16,16,0,0,0,16,16h16a16,16,0,0,0,16-16V128A96.0001,96.0001,0,0,0,128.7279,32.0027,96.00009,96.00009,0,0,0,32,128v56a16,16,0,0,0,16,16H64a16,16,0,0,0,16-16V144a16,16,0,0,0-16-16H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M225.45581,184v24a32,32,0,0,1-32,32H136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Headset = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5S(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Headset.displayName = "Headset";

var renderPathFor$5T = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128.01758,216s-100-56-100-124A52.00881,52.00881,0,0,1,128.01766,71.965l-.0002.00008A52.00882,52.00882,0,0,1,228.01758,92C228.01758,160,128.01758,216,128.01758,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128.0293,216s-100-56-100-124A52.00881,52.00881,0,0,1,128.02938,71.965l-.0002.00008A52.00882,52.00882,0,0,1,228.0293,92C228.0293,160,128.0293,216,128.0293,216Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128.0293,216s-100-56-100-124A52.00881,52.00881,0,0,1,128.02938,71.965l-.0002.00008A52.00882,52.00882,0,0,1,228.0293,92C228.0293,160,128.0293,216,128.0293,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176.02344,32a59.85506,59.85506,0,0,0-48,23.95947A60.02029,60.02029,0,0,0,20.02344,92c0,71.86279,99.84082,128.6001,104.09082,130.98a8.00089,8.00089,0,0,0,7.81836,0A317.34027,317.34027,0,0,0,183.375,185.44629C218.30957,154.00488,236.02344,122.56494,236.02344,92A60.06812,60.06812,0,0,0,176.02344,32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128.01172,216s-100-56-100-124A52.00881,52.00881,0,0,1,128.0118,71.965l-.00019.00008A52.00881,52.00881,0,0,1,228.01172,92C228.01172,160,128.01172,216,128.01172,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128.00586,216s-100-56-100-124A52.00881,52.00881,0,0,1,128.00594,71.965l-.00019.00008A52.00881,52.00881,0,0,1,228.00586,92C228.00586,160,128.00586,216,128.00586,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,216S28,160,28,92A52.00881,52.00881,0,0,1,128.00008,71.965l-.00019.00008A52.00881,52.00881,0,0,1,228,92C228,160,128,216,128,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Heart = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5T(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Heart.displayName = "Heart";

var renderPathFor$5U = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M133.65683,211.88227l81.0323-81.0322c19.9104-19.91038,22.84784-52.666,4.00583-73.59029a52.0026,52.0026,0,0,0-75.46451-2.02934L127.99994,70.46082,114.85007,57.3109C94.93972,37.40047,62.18409,34.463,41.25979,53.305a52.00261,52.00261,0,0,0-2.02934,75.46452l83.11268,83.11272A8,8,0,0,0,133.65683,211.88227Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M133.65683,211.88227l81.0323-81.0322c19.9104-19.91038,22.84784-52.666,4.00583-73.59029a52.0026,52.0026,0,0,0-75.46451-2.02934L127.99994,70.46082,114.85007,57.3109C94.93972,37.40047,62.18409,34.463,41.25979,53.305a52.00261,52.00261,0,0,0-2.02934,75.46452l83.11268,83.11272A8,8,0,0,0,133.65683,211.88227Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M133.65683,211.88227l81.0323-81.0322c19.9104-19.91038,22.84784-52.666,4.00583-73.59029a52.0026,52.0026,0,0,0-75.46451-2.02934L127.99994,70.46082,114.85007,57.3109C94.93972,37.40047,62.18409,34.463,41.25979,53.305a52.00261,52.00261,0,0,0-2.02934,75.46452l83.11268,83.11272A8,8,0,0,0,133.65683,211.88227Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224.627,51.90625a59.54956,59.54956,0,0,0-43.0625-19.89063,60.69786,60.69786,0,0,0-43.98437,17.55469L128.002,59.14844l-7.5-7.49219c-23.32812-23.35156-61.29687-25.3125-84.57812-4.29687a59.974,59.974,0,0,0-2.34375,87.07031l83.10937,83.10937a16.013,16.013,0,0,0,22.625,0l81.03125-81.03125C243.68945,113.15625,245.61133,75.20312,224.627,51.90625Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M133.65683,211.88227l81.0323-81.0322c19.9104-19.91038,22.84784-52.666,4.00583-73.59029a52.0026,52.0026,0,0,0-75.46451-2.02934L127.99994,70.46082,114.85007,57.3109C94.93972,37.40047,62.18409,34.463,41.25979,53.305a52.00261,52.00261,0,0,0-2.02934,75.46452l83.11268,83.11272A8,8,0,0,0,133.65683,211.88227Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M133.65683,211.88227l81.0323-81.0322c19.9104-19.91038,22.84784-52.666,4.00583-73.59029a52.0026,52.0026,0,0,0-75.46451-2.02934L127.99994,70.46082,114.85007,57.3109C94.93972,37.40047,62.18409,34.463,41.25979,53.305a52.00261,52.00261,0,0,0-2.02934,75.46452l83.11268,83.11272A8,8,0,0,0,133.65683,211.88227Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M133.65683,211.88227l81.0323-81.0322c19.9104-19.91038,22.84784-52.666,4.00583-73.59029a52.0026,52.0026,0,0,0-75.46451-2.02934L127.99994,70.46082,114.85007,57.3109C94.93972,37.40047,62.18409,34.463,41.25979,53.305a52.00261,52.00261,0,0,0-2.02934,75.46452l83.11268,83.11272A8,8,0,0,0,133.65683,211.88227Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HeartStraight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5U(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HeartStraight.displayName = "HeartStraight";

var renderPathFor$5V = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "32 128 72 128 88 104 120 152 136 128 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M28.13612,88.20841a52.01064,52.01064,0,0,1,99.864-16.24342l-.00019.00008A52.00881,52.00881,0,0,1,228,92c0,68-100,124-100,124s-33.69291-18.868-61.96423-47.99889",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,216S28,160,28,92A52.00881,52.00881,0,0,1,128.00008,71.965l-.00019.00008A52.00881,52.00881,0,0,1,228,92C228,160,128,216,128,216Z",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "32 128 72 128 88 104 120 152 136 128 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M28.11427,95.99348Q28.00077,94.004,28,92A52.00881,52.00881,0,0,1,128.00008,71.965l-.00019.00008A52.00881,52.00881,0,0,1,228,92c0,68-100,124-100,124s-39.94466-22.369-69.34251-55.99891",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,32a59.85506,59.85506,0,0,0-48,23.95947A60.02029,60.02029,0,0,0,20,92a85.2156,85.2156,0,0,0,4.92969,28H67.71875l13.625-20.4375a7.99959,7.99959,0,0,1,13.3125,0L120,137.57764l9.34375-14.01514A7.99943,7.99943,0,0,1,136,120h24a8,8,0,0,1,0,16H140.28125l-13.625,20.4375a7.99959,7.99959,0,0,1-13.3125,0L88,118.42236,78.65625,132.4375A7.99943,7.99943,0,0,1,72,136H31.98389c26.65088,49.81006,88.77392,85.11328,92.10693,86.98a8.00089,8.00089,0,0,0,7.81836,0,317.34027,317.34027,0,0,0,51.44238-37.53369C218.28613,154.00488,236,122.56494,236,92A60.06812,60.06812,0,0,0,176,32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "32 128 72 128 88 104 120 152 136 128 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M28.11427,95.99348Q28.00077,94.004,28,92A52.00881,52.00881,0,0,1,128.00008,71.965l-.00019.00008A52.00881,52.00881,0,0,1,228,92c0,68-100,124-100,124s-39.94466-22.369-69.34251-55.99891",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "32 128 72 128 88 104 120 152 136 128 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M28.11427,95.99348Q28.00077,94.004,28,92A52.00881,52.00881,0,0,1,128.00008,71.965l-.00019.00008A52.00881,52.00881,0,0,1,228,92c0,68-100,124-100,124s-39.94466-22.369-69.34251-55.99891",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "32 128 72 128 88 104 120 152 136 128 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M28.11427,95.99348Q28.00077,94.004,28,92A52.00881,52.00881,0,0,1,128.00008,71.965l-.00019.00008A52.00881,52.00881,0,0,1,228,92c0,68-100,124-100,124s-39.94466-22.369-69.34251-55.99891",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Heartbeat = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5V(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Heartbeat.displayName = "Heartbeat";

var renderPathFor$5W = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.87305,66.73828l-84-47.478a16.08654,16.08654,0,0,0-15.7461,0l-84,47.47852A16.0255,16.0255,0,0,0,28,80.668V175.332a16.02688,16.02688,0,0,0,8.127,13.92969l84,47.478a16.08782,16.08782,0,0,0,15.7461,0l84-47.47852A16.0255,16.0255,0,0,0,228,175.332V80.668A16.02688,16.02688,0,0,0,219.87305,66.73828Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Hexagon = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5W(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Hexagon.displayName = "Hexagon";

var renderPathFor$5X = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,120a48,48,0,0,1-48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M63.99958,199.555a95.66337,95.66337,0,0,0,65.94315,24.42575c51.479-1.01726,93.33139-43.12958,94.04775-94.61366A96.00033,96.00033,0,0,0,128,32h-8V64L16,128l13.78709,19.11608a24.02393,24.02393,0,0,0,23.51449,9.61538c17.46763-2.95714,48.06093-4.71406,74.69861,11.26833L128,168,92.76585,217.32781",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "104",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.76616,217.32808a95.841,95.841,0,0,0,37.17657,6.65271c51.479-1.01726,93.33139-43.12958,94.04775-94.61366A96.00033,96.00033,0,0,0,128,32h-8V64L16,128l13.78709,19.11608a24.02393,24.02393,0,0,0,23.51449,9.61538c17.46763-2.95714,48.06093-4.71406,74.69861,11.26833L128,168Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M176,120a48,48,0,0,1-48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M63.99958,199.555a95.66337,95.66337,0,0,0,65.94315,24.42575c51.479-1.01726,93.33139-43.12958,94.04775-94.61366A96.00033,96.00033,0,0,0,128,32h-8V64L16,128l13.78709,19.11608a24.02393,24.02393,0,0,0,23.51449,9.61538c17.46763-2.95714,48.06093-4.71406,74.69861,11.26833L128,168,92.76585,217.32781",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "124",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M202.05273,54.97754A103.25474,103.25474,0,0,0,128,24h-8a8.00008,8.00008,0,0,0-8,8V59.52979L11.80762,121.18652a8.00037,8.00037,0,0,0-2.2959,11.49317L23.29883,151.7959a31.83519,31.83519,0,0,0,31.33789,12.82324c13.65137-2.31055,38.5918-4.23193,61.52441,6.19092L90.02246,207.40479a87.94423,87.94423,0,0,1-20.68652-13.81055,8.00031,8.00031,0,0,0-10.67188,11.92187A103.66141,103.66141,0,0,0,128.0127,232q1.043,0,2.08789-.02051A104.0011,104.0011,0,0,0,202.05273,54.97754ZM123.99976,112a12,12,0,1,1,12-12A12,12,0,0,1,123.99976,112Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,120a48,48,0,0,1-48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M63.99958,199.555a95.66337,95.66337,0,0,0,65.94315,24.42575c51.479-1.01726,93.33139-43.12958,94.04775-94.61366A96.00033,96.00033,0,0,0,128,32h-8V64L16,128l13.78709,19.11608a24.02393,24.02393,0,0,0,23.51449,9.61538c17.46763-2.95714,48.06093-4.71406,74.69861,11.26833L128,168,92.76585,217.32781",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "124",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,120a48,48,0,0,1-48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M63.99958,199.555a95.66337,95.66337,0,0,0,65.94315,24.42575c51.479-1.01726,93.33139-43.12958,94.04775-94.61366A96.00033,96.00033,0,0,0,128,32h-8V64L16,128l13.78709,19.11608a24.02393,24.02393,0,0,0,23.51449,9.61538c17.46763-2.95714,48.06093-4.71406,74.69861,11.26833L128,168,92.76585,217.32781",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "124",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,120a48,48,0,0,1-48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M63.99958,199.555a95.66337,95.66337,0,0,0,65.94315,24.42575c51.479-1.01726,93.33139-43.12958,94.04775-94.61366A96.00033,96.00033,0,0,0,128,32h-8V64L16,128l13.78709,19.11608a24.02393,24.02393,0,0,0,23.51449,9.61538c17.46763-2.95714,48.06093-4.71406,74.69861,11.26833L128,168,92.76585,217.32781",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "124",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Horse = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5X(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Horse.displayName = "Horse";

var renderPathFor$5Y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,75.64392V40.0033a16.02084,16.02084,0,0,0-16-16H72a16.02084,16.02084,0,0,0-16,16v36a16.08093,16.08093,0,0,0,6.40625,12.79687l52.26563,39.20313L62.39844,167.20642A16.07348,16.07348,0,0,0,56,180.0033v36a16.02085,16.02085,0,0,0,16,16H184a16.02085,16.02085,0,0,0,16-16V180.36267a16.033,16.033,0,0,0-6.35937-12.76562l-52.377-39.59375,52.377-39.59375A16.05549,16.05549,0,0,0,200,75.64392Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Hourglass = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5Y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Hourglass.displayName = "Hourglass";

var renderPathFor$5Z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "71.99548",
        x2: "192",
        y2: "71.99548",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V63.99548H192V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "63.99548",
        x2: "192",
        y2: "63.99548",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,75.64111V40a16.01833,16.01833,0,0,0-16-16H72A16.01833,16.01833,0,0,0,56,40V76a16.07553,16.07553,0,0,0,6.3999,12.7998L114.667,128l-52.2666,39.2002A16.07459,16.07459,0,0,0,56,180v36a16.01833,16.01833,0,0,0,16,16H184a16.01833,16.01833,0,0,0,16-16V180.35889a16.08452,16.08452,0,0,0-6.352-12.76416L141.2666,128l52.38184-39.59473A16.08547,16.08547,0,0,0,200,75.64111ZM184,40V63.99561H72V40Zm0,176H72V180l55.98145-41.98584L184,180.35889Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "63.99548",
        x2: "192",
        y2: "63.99548",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "63.99548",
        x2: "192",
        y2: "63.99548",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "63.99548",
        x2: "192",
        y2: "63.99548",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HourglassHigh = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5Z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HourglassHigh.displayName = "HourglassHigh";

var renderPathFor$5_ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "192",
        y1: "180.3588",
        x2: "64",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "192",
        y1: "180.3588",
        x2: "64",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,75.64111V40a16.01833,16.01833,0,0,0-16-16H72A16.01833,16.01833,0,0,0,56,40V76a16.07589,16.07589,0,0,0,6.3999,12.7998L114.667,128l-52.2666,39.2002a16.06134,16.06134,0,0,0-6.34814,11.92236A7.943,7.943,0,0,0,56,180v36a16.01833,16.01833,0,0,0,16,16H184a16.01833,16.01833,0,0,0,16-16V180.35889a8.04861,8.04861,0,0,0-.05273-.89307,16.06854,16.06854,0,0,0-6.29932-11.87061L141.2666,128l52.38184-39.595A16.08467,16.08467,0,0,0,200,75.64111ZM82.59717,172.052l45.38428-34.03784,45.36572,34.29248ZM184,75.64136l-56.01855,42.34448L72,76V40H184Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "192",
        y1: "180.3588",
        x2: "64",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "192",
        y1: "180.3588",
        x2: "64",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "192",
        y1: "180.3588",
        x2: "64",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HourglassLow = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5_(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HourglassLow.displayName = "HourglassLow";

var renderPathFor$5$ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "69.32731",
        y1: "83.99548",
        x2: "186.21472",
        y2: "83.99548",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "167.99548",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "128 128 180.923 87.995 74.661 87.995 128 128",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "167.99548",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "74.66065",
        y1: "87.99548",
        x2: "180.92301",
        y2: "87.99548",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M193.64844,88.40527A16.08547,16.08547,0,0,0,200,75.64111V40a16.01833,16.01833,0,0,0-16-16H72A16.01833,16.01833,0,0,0,56,40V76a16.07553,16.07553,0,0,0,6.3999,12.7998l18.127,13.59522.00048.00049L114.6665,128,62.40039,167.2002A16.07459,16.07459,0,0,0,56,180v36a16.01833,16.01833,0,0,0,16,16H184a16.01833,16.01833,0,0,0,16-16V180.35889a16.08452,16.08452,0,0,0-6.352-12.76416L141.2666,128l22.70459-17.16211ZM72,40H184V75.6416l-5.76025,4.354H77.32764L72,76ZM184,180.35889V216H72V180l48-36v23.99561a8,8,0,0,0,16,0V144.07568Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "74.66065",
        y1: "87.99548",
        x2: "180.92301",
        y2: "87.99548",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "167.99548",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "74.66065",
        y1: "87.99548",
        x2: "180.92301",
        y2: "87.99548",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "167.99548",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,128,67.2,82.4A8,8,0,0,1,64,76V40a8,8,0,0,1,8-8H184a8,8,0,0,1,8,8V75.6412a8,8,0,0,1-3.17594,6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,128,67.2,173.6A8,8,0,0,0,64,180v36a8,8,0,0,0,8,8H184a8,8,0,0,0,8-8V180.3588a8,8,0,0,0-3.17594-6.38188L128,128h0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "74.66065",
        y1: "87.99548",
        x2: "180.92301",
        y2: "87.99548",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "167.99548",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HourglassMedium = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$5$(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HourglassMedium.displayName = "HourglassMedium";

var renderPathFor$60 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M139.31543,127.99854,208,59.31348A15.9999,15.9999,0,0,0,196.68652,32H59.31348A15.9999,15.9999,0,0,0,48,59.31348l68.68457,68.688L48,196.68652A15.9999,15.9999,0,0,0,59.31348,224h137.373A15.9999,15.9999,0,0,0,208,196.68652Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HourglassSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$60(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HourglassSimple.displayName = "HourglassSimple";

var renderPathFor$61 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "80",
        x2: "176",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "128 128 184 72 72 72 128 128",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "72",
        x2: "184",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M139.31543,127.99854l50.34082-50.34107.001-.00122L208,59.31348A15.9999,15.9999,0,0,0,196.68652,32H59.31348A15.9999,15.9999,0,0,0,48,59.31348l68.68457,68.688L48,196.68652A15.9999,15.9999,0,0,0,59.31348,224h137.373A15.9999,15.9999,0,0,0,208,196.68652Zm57.36621-79.99366L180.68652,64H75.31982L59.32031,48ZM59.31836,207.99512l68.67969-68.67969L196.67969,208Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "72",
        x2: "184",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "72",
        x2: "184",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "72",
        x2: "184",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HourglassSimpleHigh = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$61(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HourglassSimpleHigh.displayName = "HourglassSimpleHigh";

var renderPathFor$62 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "176",
        x2: "80",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L176,176H80Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "176",
        x2: "80",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M139.31543,127.99854,208,59.31348A15.9999,15.9999,0,0,0,196.68652,32H59.31348A15.9999,15.9999,0,0,0,48,59.31348l68.68457,68.688L48,196.68652A15.9999,15.9999,0,0,0,59.31348,224h137.373A15.9999,15.9999,0,0,0,208,196.68652ZM59.32031,48l137.36133.00488L128.002,116.68457Zm68.67774,91.31543L156.68115,168H99.31348Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "176",
        x2: "80",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "176",
        x2: "80",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "176",
        x2: "80",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HourglassSimpleLow = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$62(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HourglassSimpleLow.displayName = "HourglassSimpleLow";

var renderPathFor$63 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "80",
        x2: "80",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("polygon", {
        points: "128 128 176 80 80 80 128 128"
      })), React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "80",
        x2: "80",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M139.31543,127.99854l34.34082-34.34107.001-.00122L208,59.31348A15.9999,15.9999,0,0,0,196.68652,32H59.31348A15.9999,15.9999,0,0,0,48,59.31348l68.68457,68.688L48,196.68652A15.9999,15.9999,0,0,0,59.31348,224h137.373A15.9999,15.9999,0,0,0,208,196.68652Zm57.36621-79.99366L172.68652,72H83.31934l-23.999-24ZM59.31836,207.99512,120,147.31348V168a8,8,0,0,0,16,0V147.31775L196.67969,208Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "80",
        x2: "80",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "80",
        x2: "80",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M59.31371,40H196.68629a8,8,0,0,1,5.65686,13.65685L53.65685,202.34315A8,8,0,0,0,59.31371,216H196.68629a8,8,0,0,0,5.65686-13.65685L53.65685,53.65685A8,8,0,0,1,59.31371,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "80",
        x2: "80",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HourglassSimpleMedium = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$63(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HourglassSimpleMedium.displayName = "HourglassSimpleMedium";

var renderPathFor$64 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M151.99414,207.99263v-48.001a8,8,0,0,0-8-8h-32a8,8,0,0,0-8,8v48.001a8,8,0,0,1-7.999,8l-47.99414.00632a8,8,0,0,1-8.001-8v-92.4604a8,8,0,0,1,2.61811-5.91906l79.9945-72.73477a8,8,0,0,1,10.76339-.00036l80.0055,72.73509A8,8,0,0,1,216,115.53887V207.999a8,8,0,0,1-8.001,8l-48.00586-.00632A8,8,0,0,1,151.99414,207.99263Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M151.99414,207.99263v-48.001a8,8,0,0,0-8-8h-32a8,8,0,0,0-8,8v48.001a8,8,0,0,1-7.999,8l-47.99414.00632a8,8,0,0,1-8.001-8v-92.4604a8,8,0,0,1,2.61811-5.91906l79.9945-72.73477a8,8,0,0,1,10.76339-.00036l80.0055,72.73509A8,8,0,0,1,216,115.53887V207.999a8,8,0,0,1-8.001,8l-48.00586-.00632A8,8,0,0,1,151.99414,207.99263Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M151.99414,207.99263v-48.001a8,8,0,0,0-8-8h-32a8,8,0,0,0-8,8v48.001a8,8,0,0,1-7.999,8l-47.99414.00632a8,8,0,0,1-8.001-8v-92.4604a8,8,0,0,1,2.61811-5.91906l79.9945-72.73477a8,8,0,0,1,10.76339-.00036l80.0055,72.73509A8,8,0,0,1,216,115.53887V207.999a8,8,0,0,1-8.001,8l-48.00586-.00632A8,8,0,0,1,151.99414,207.99263Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.76367,103.7002,138.75684,30.96436a15.93657,15.93657,0,0,0-21.52637.00146L37.2373,103.69971A16.03108,16.03108,0,0,0,32,115.53857V207.999a15.99994,15.99994,0,0,0,16.002,16l47.99317-.00732a7.99987,7.99987,0,0,0,7.999-8v-64h48v64a7.99988,7.99988,0,0,0,7.999,8l48.00489.00732H208a15.99994,15.99994,0,0,0,16-16v-92.46A16.03567,16.03567,0,0,0,218.76367,103.7002Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M151.99414,207.99263v-48.001a8,8,0,0,0-8-8h-32a8,8,0,0,0-8,8v48.001a8,8,0,0,1-7.999,8l-47.99414.00632a8,8,0,0,1-8.001-8v-92.4604a8,8,0,0,1,2.61811-5.91906l79.9945-72.73477a8,8,0,0,1,10.76339-.00036l80.0055,72.73509A8,8,0,0,1,216,115.53887V207.999a8,8,0,0,1-8.001,8l-48.00586-.00632A8,8,0,0,1,151.99414,207.99263Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M151.99414,207.99263v-48.001a8,8,0,0,0-8-8h-32a8,8,0,0,0-8,8v48.001a8,8,0,0,1-7.999,8l-47.99414.00632a8,8,0,0,1-8.001-8v-92.4604a8,8,0,0,1,2.61811-5.91906l79.9945-72.73477a8,8,0,0,1,10.76339-.00036l80.0055,72.73509A8,8,0,0,1,216,115.53887V207.999a8,8,0,0,1-8.001,8l-48.00586-.00632A8,8,0,0,1,151.99414,207.99263Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M151.99414,207.99263v-48.001a8,8,0,0,0-8-8h-32a8,8,0,0,0-8,8v48.001a8,8,0,0,1-7.999,8l-47.99414.00632a8,8,0,0,1-8.001-8v-92.4604a8,8,0,0,1,2.61811-5.91906l79.9945-72.73477a8,8,0,0,1,10.76339-.00036l80.0055,72.73509A8,8,0,0,1,216,115.53887V207.999a8,8,0,0,1-8.001,8l-48.00586-.00632A8,8,0,0,1,151.99414,207.99263Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var House = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$64(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
House.displayName = "House";

var renderPathFor$65 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.98242,216V115.53887a8,8,0,0,0-2.6185-5.91942l-80.0055-72.73509a8,8,0,0,0-10.76339.00036l-79.9945,72.73477a8,8,0,0,0-2.61811,5.91906V216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "15.98242",
        y1: "216",
        x2: "239.98242",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "151.977 215.992 151.977 151.992 103.977 151.992 103.977 215.992",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M151.96484,215.99158v-64h-48v64L39.9707,216V115.53855a8,8,0,0,1,2.61811-5.91906l79.9945-72.73477a8,8,0,0,1,10.76339-.00036l80.0055,72.73509a8,8,0,0,1,2.6185,5.91942V216Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M215.9707,216V115.53887a8,8,0,0,0-2.6185-5.91942L133.3467,36.88436a8,8,0,0,0-10.76339.00036l-79.9945,72.73477a8,8,0,0,0-2.61811,5.91906V216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "15.9707",
        y1: "216",
        x2: "239.9707",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "151.965 215.992 151.965 151.992 103.965 151.992 103.965 215.992",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M239.97656,208h-16V115.53882A16.03729,16.03729,0,0,0,218.74023,103.7L138.7334,30.96484a15.93607,15.93607,0,0,0-21.52637.001L37.21289,103.7a16.034,16.034,0,0,0-5.23633,11.83862V208h-16a8,8,0,0,0,0,16h224a8,8,0,0,0,0-16ZM103.99414,144h48v64h-48Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.98828,216V115.53887a8,8,0,0,0-2.6185-5.91942l-80.0055-72.73509a8,8,0,0,0-10.76339.00036l-79.9945,72.73477a8,8,0,0,0-2.61811,5.91906V216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "15.98828",
        y1: "216",
        x2: "239.98828",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "151.982 215.992 151.982 151.992 103.982 151.992 103.982 215.992",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99414,216V115.53887a8,8,0,0,0-2.6185-5.91942l-80.0055-72.73509a8,8,0,0,0-10.76339.00036l-79.9945,72.73477a8,8,0,0,0-2.61811,5.91906V216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "15.99414",
        y1: "216",
        x2: "239.99414",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "151.988 215.992 151.988 151.992 103.988 151.992 103.988 215.992",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,216V115.53887a8,8,0,0,0-2.6185-5.91942L133.376,36.88436a8,8,0,0,0-10.76339.00036l-79.9945,72.73477A8,8,0,0,0,40,115.53855V216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "216",
        x2: "240",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "151.994 215.992 151.994 151.992 103.994 151.992 103.994 215.992",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HouseLine = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$65(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HouseLine.displayName = "HouseLine";

var renderPathFor$66 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.3815,109.61945,133.376,36.88436a8,8,0,0,0-10.76339.00036l-79.9945,72.73477A8,8,0,0,0,40,115.53855V208a8,8,0,0,0,8,8H208a8,8,0,0,0,8-8V115.53887A8,8,0,0,0,213.3815,109.61945Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.3815,109.61945,133.376,36.88436a8,8,0,0,0-10.76339.00036l-79.9945,72.73477A8,8,0,0,0,40,115.53855V208a8,8,0,0,0,8,8H208a8,8,0,0,0,8-8V115.53887A8,8,0,0,0,213.3815,109.61945Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M213.3815,109.61945,133.376,36.88436a8,8,0,0,0-10.76339.00036l-79.9945,72.73477A8,8,0,0,0,40,115.53855V208a8,8,0,0,0,8,8H208a8,8,0,0,0,8-8V115.53887A8,8,0,0,0,213.3815,109.61945Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.76465,103.70117l-.001-.001L138.75684,30.96484a15.93607,15.93607,0,0,0-21.52637.001L37.23633,103.7002A16.03346,16.03346,0,0,0,32,115.53857V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V115.53906A16.03466,16.03466,0,0,0,218.76465,103.70117Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.3815,109.61945,133.376,36.88436a8,8,0,0,0-10.76339.00036l-79.9945,72.73477A8,8,0,0,0,40,115.53855V208a8,8,0,0,0,8,8H208a8,8,0,0,0,8-8V115.53887A8,8,0,0,0,213.3815,109.61945Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.3815,109.61945,133.376,36.88436a8,8,0,0,0-10.76339.00036l-79.9945,72.73477A8,8,0,0,0,40,115.53855V208a8,8,0,0,0,8,8H208a8,8,0,0,0,8-8V115.53887A8,8,0,0,0,213.3815,109.61945Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.3815,109.61945,133.376,36.88436a8,8,0,0,0-10.76339.00036l-79.9945,72.73477A8,8,0,0,0,40,115.53855V208a8,8,0,0,0,8,8H208a8,8,0,0,0,8-8V115.53887A8,8,0,0,0,213.3815,109.61945Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var HouseSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$66(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
HouseSimple.displayName = "HouseSimple";

var renderPathFor$67 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152",
        y1: "108",
        x2: "184",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "148",
        x2: "184",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "94.1004",
        cy: "116.00005",
        r: "22",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M72.1004,164a22,22,0,0,1,44,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,48H40a8,8,0,0,0-8,8V200a8,8,0,0,0,8,8H216a8,8,0,0,0,8-8V56A8,8,0,0,0,216,48ZM92.10046,144a24,24,0,1,1,24-24A23.99994,23.99994,0,0,1,92.10046,144Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "144",
        x2: "192",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92.10043",
        cy: "120",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M61.10869,167.99952a32.01032,32.01032,0,0,1,61.98292-.00215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M216,40H40A16.01833,16.01833,0,0,0,24,56V200a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V56A16.01833,16.01833,0,0,0,216,40ZM125.08643,175.74512a8.00256,8.00256,0,0,1-9.74219-5.75293,24.01011,24.01011,0,0,0-46.48779.00146,8.00008,8.00008,0,1,1-15.49512-3.98828,39.896,39.896,0,0,1,16.36023-23.16162,32.00008,32.00008,0,1,1,44.75793,0,39.89755,39.89755,0,0,1,16.35987,23.15918A8.00051,8.00051,0,0,1,125.08643,175.74512ZM192,152H152a8,8,0,0,1,0-16h40a8,8,0,0,1,0,16Zm0-32H152a8,8,0,0,1,0-16h40a8,8,0,0,1,0,16Z"
      }), React__default.createElement("circle", {
        cx: "92.10059",
        cy: "120",
        r: "16"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "144",
        x2: "192",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "92.10043",
        cy: "120",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M61.10869,167.99952a32.01032,32.01032,0,0,1,61.98292-.00215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "144",
        x2: "192",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "92.10043",
        cy: "120",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M61.10869,167.99952a32.01032,32.01032,0,0,1,61.98292-.00215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "144",
        x2: "192",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92.10043",
        cy: "120",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M61.10869,167.99952a32.01032,32.01032,0,0,1,61.98292-.00215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var IdentificationCard = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$67(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
IdentificationCard.displayName = "IdentificationCard";

var renderPathFor$68 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M32,167.99982l50.343-50.343a8,8,0,0,1,11.31371,0l44.68629,44.6863a8,8,0,0,0,11.31371,0l20.68629-20.6863a8,8,0,0,1,11.31371,0L223.99982,184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,167.99982l50.343-50.343a8,8,0,0,1,11.31371,0l44.68629,44.6863a8,8,0,0,0,11.31371,0l20.68629-20.6863a8,8,0,0,1,11.31371,0L223.99982,184,224,56a8,8,0,0,0-8-8H40a8,8,0,0,0-8,8Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M32,167.99982l50.343-50.343a8,8,0,0,1,11.31371,0l44.68629,44.6863a8,8,0,0,0,11.31371,0l20.68629-20.6863a8,8,0,0,1,11.31371,0L223.99982,184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168.00049,100.00012v.00342a12.00171,12.00171,0,1,1,0-.00342Zm63.999-44V199.99963a16.01833,16.01833,0,0,1-16,16h-176a16.01833,16.01833,0,0,1-16-16V56.00012a16.01834,16.01834,0,0,1,16-16h176A16.01833,16.01833,0,0,1,231.99951,56.00012Zm-15.9917,108.6933-.0083-108.6933h-176v92.68549L76.686,112.00012a16.019,16.019,0,0,1,22.62792,0l44.68653,44.68652L164.686,136.00012a16.019,16.019,0,0,1,22.62792,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M32,167.99982l50.343-50.343a8,8,0,0,1,11.31371,0l44.68629,44.6863a8,8,0,0,0,11.31371,0l20.68629-20.6863a8,8,0,0,1,11.31371,0L223.99982,184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M32,167.99982l50.343-50.343a8,8,0,0,1,11.31371,0l44.68629,44.6863a8,8,0,0,0,11.31371,0l20.68629-20.6863a8,8,0,0,1,11.31371,0L223.99982,184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M32,167.99982l50.343-50.343a8,8,0,0,1,11.31371,0l44.68629,44.6863a8,8,0,0,0,11.31371,0l20.68629-20.6863a8,8,0,0,1,11.31371,0L223.99982,184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "156",
        cy: "100",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Image = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$68(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Image.displayName = "Image";

var renderPathFor$69 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M215.99982,159.99982l-42.343-42.343a8,8,0,0,0-11.3137,0l-44.6863,44.6863a8,8,0,0,1-11.3137,0l-20.6863-20.6863a8,8,0,0,0-11.3137,0L40,176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,176V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V160l-.00018-.00018-42.343-42.343a8,8,0,0,0-11.3137,0l-44.6863,44.6863a8,8,0,0,1-11.3137,0l-20.6863-20.6863a8,8,0,0,0-11.3137,0Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "99.99951",
        cy: "92",
        r: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M215.99982,159.99982l-42.343-42.343a8,8,0,0,0-11.3137,0l-44.6863,44.6863a8,8,0,0,1-11.3137,0l-20.6863-20.6863a8,8,0,0,0-11.3137,0L40,176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "99.99951",
        cy: "92",
        r: "12"
      }), React__default.createElement("path", {
        d: "M208.00049,31.99963h-160a16.01833,16.01833,0,0,0-16,16V175.97369l-.001.0307.001,31.99524a16.01833,16.01833,0,0,0,16,16h160a16.01833,16.01833,0,0,0,16-16v-160A16.01834,16.01834,0,0,0,208.00049,31.99963Zm-28.68653,80a16.019,16.019,0,0,0-22.62792,0l-44.68555,44.68653L91.314,135.99963a16.02161,16.02161,0,0,0-22.62792,0L48.00049,156.68457V47.99963h160l.00586,92.6922Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M215.99982,159.99982l-42.343-42.343a8,8,0,0,0-11.3137,0l-44.6863,44.6863a8,8,0,0,1-11.3137,0l-20.6863-20.6863a8,8,0,0,0-11.3137,0L40,176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M215.99982,159.99982l-42.343-42.343a8,8,0,0,0-11.3137,0l-44.6863,44.6863a8,8,0,0,1-11.3137,0l-20.6863-20.6863a8,8,0,0,0-11.3137,0L40,176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M215.99982,159.99982l-42.343-42.343a8,8,0,0,0-11.3137,0l-44.6863,44.6863a8,8,0,0,1-11.3137,0l-20.6863-20.6863a8,8,0,0,0-11.3137,0L40,176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "100",
        cy: "92",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ImageSquare = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$69(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ImageSquare.displayName = "ImageSquare";

var renderPathFor$6a = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00146",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "120.001 120 128.001 120 128.001 176 136.001 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128.00146",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "84",
        r: "12"
      }), React__default.createElement("polyline", {
        points: "120 120 128 120 128 176 136 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128.00146,24a104,104,0,1,0,104,104A104.12041,104.12041,0,0,0,128.00146,24Zm-.001,48a12,12,0,1,1-12,12A12,12,0,0,1,128.00049,72Zm8.001,112h-8a7.99541,7.99541,0,0,1-8-8V128a8,8,0,0,1,0-16h8a7.99539,7.99539,0,0,1,8,8v48a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00098",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "120 120 128.001 120 128 176 136 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128.00098",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "120 120 128 120 128 176 136 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128.00049",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "120 120 128 120 128 176 136 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Info = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6a(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Info.displayName = "Info";

var renderPathFor$6b = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "34",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "32",
        y: "32",
        width: "192",
        height: "192",
        rx: "48",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M172,36H84A47.99987,47.99987,0,0,0,36,84v88a47.99988,47.99988,0,0,0,48,48h88a47.99988,47.99988,0,0,0,48-48V84A47.99987,47.99987,0,0,0,172,36ZM128,168a40,40,0,1,1,40-40A40.0001,40.0001,0,0,1,128,168Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "40",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "36",
        y: "36",
        width: "184",
        height: "184",
        rx: "48",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32"
      }), React__default.createElement("path", {
        d: "M172,28H84A56.06353,56.06353,0,0,0,28,84v88a56.06353,56.06353,0,0,0,56,56h88a56.06353,56.06353,0,0,0,56-56V84A56.06353,56.06353,0,0,0,172,28ZM128,176a48,48,0,1,1,48-48A48.05436,48.05436,0,0,1,128,176Zm52-88a12,12,0,1,1,12-12A12,12,0,0,1,180,88Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "36",
        y: "36",
        width: "184",
        height: "184",
        rx: "48",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "36",
        y: "36",
        width: "184",
        height: "184",
        rx: "48",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "40",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "36",
        y: "36",
        width: "184",
        height: "184",
        rx: "48",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var InstagramLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6b(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
InstagramLogo.displayName = "InstagramLogo";

var renderPathFor$6c = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "96",
        cy: "96",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "160",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "109.08829",
        y1: "109.08829",
        x2: "146.9117",
        y2: "146.9117",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,160a70.51259,70.51259,0,0,0,.73242,7.26758A70.51259,70.51259,0,0,0,96,168a71.99981,71.99981,0,0,0,72-72,70.51259,70.51259,0,0,0-.73242-7.26758A70.51259,70.51259,0,0,0,160,88,71.99981,71.99981,0,0,0,88,160Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "96",
        cy: "96",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "160",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M174.63477,81.36523a79.99168,79.99168,0,1,0-93.26954,93.26954,79.99168,79.99168,0,1,0,93.26954-93.26954ZM32,96A64.00385,64.00385,0,0,1,157.98779,80.05127,80.06522,80.06522,0,0,0,80.051,157.98779,64.1144,64.1144,0,0,1,32,96ZM160,224a64.11421,64.11421,0,0,1-61.98779-48.05127A80.06522,80.06522,0,0,0,175.949,98.01221,64.00389,64.00389,0,0,1,160,224Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "96",
        cy: "96",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "160",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "122.51701",
        y1: "98.51701",
        x2: "157.48457",
        y2: "133.48457",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "98.51562",
        y1: "122.51562",
        x2: "133.48323",
        y2: "157.48323",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "96",
        cy: "96",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "160",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "122.51701",
        y1: "98.51701",
        x2: "157.48457",
        y2: "133.48457",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "98.51562",
        y1: "122.51562",
        x2: "133.48323",
        y2: "157.48323",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "96",
        cy: "96",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "160",
        cy: "160",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "122.51701",
        y1: "98.51701",
        x2: "157.48457",
        y2: "133.48457",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "98.51562",
        y1: "122.51562",
        x2: "133.48323",
        y2: "157.48323",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Intersect = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6c(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Intersect.displayName = "Intersect";

var renderPathFor$6d = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220,176v32a8,8,0,0,1-8,8H188a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M76,176v32a8,8,0,0,1-8,8H44a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "96",
        x2: "240",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "136",
        x2: "128",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "136",
        x2: "168",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "136",
        x2: "88",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M220,176H36V96.00005l7.01877-49.13142A8,8,0,0,1,50.93836,40H205.06164a8,8,0,0,1,7.91959,6.86863L220,96.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220,176v32a8,8,0,0,1-8,8H188a8,8,0,0,1-8-8V176Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M76,176v32a8,8,0,0,1-8,8H44a8,8,0,0,1-8-8V176Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M36,96.00005l7.01877-49.13142A8,8,0,0,1,50.93836,40H205.06164a8,8,0,0,1,7.91959,6.86863L220,96.00005Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M220,176v32a8,8,0,0,1-8,8H188a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M76,176v32a8,8,0,0,1-8,8H44a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "96",
        x2: "240",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "128",
        x2: "144",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "128",
        x2: "112",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M220,176H36V96.00005l7.01877-49.13142A8,8,0,0,1,50.93836,40H205.06164a8,8,0,0,1,7.91959,6.86863L220,96.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "132",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "184",
        cy: "132",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,88H226.93848l-6.03809-42.26465A16.07879,16.07879,0,0,0,205.06152,32H50.93848A16.08053,16.08053,0,0,0,35.09863,45.7373L29.06128,88H16a8,8,0,0,0,0,16H28V208a16.01833,16.01833,0,0,0,16,16H68a16.01833,16.01833,0,0,0,16-16V184h20V128a8,8,0,0,1,16,0v56h16V128a8,8,0,0,1,16,0v56h20v24a16.01833,16.01833,0,0,0,16,16h24a16.01833,16.01833,0,0,0,16-16V104h12a8,8,0,0,0,0-16ZM68,208H44V184H68Zm4-64a12,12,0,1,1,12-12A12,12,0,0,1,72,144Zm112,0a12,12,0,1,1,12-12A12,12,0,0,1,184,144Zm28,64H188V184h24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220,176v32a8,8,0,0,1-8,8H188a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M76,176v32a8,8,0,0,1-8,8H44a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "96",
        x2: "240",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "128",
        x2: "144",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "128",
        x2: "112",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M220,176H36V96.00005l7.01877-49.13142A8,8,0,0,1,50.93836,40H205.06164a8,8,0,0,1,7.91959,6.86863L220,96.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "132",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "184",
        cy: "132",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220,176v32a8,8,0,0,1-8,8H188a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M76,176v32a8,8,0,0,1-8,8H44a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "96",
        x2: "240",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "128",
        x2: "144",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "128",
        x2: "112",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M220,176H36V96.00005l7.01877-49.13142A8,8,0,0,1,50.93836,40H205.06164a8,8,0,0,1,7.91959,6.86863L220,96.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "132",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "184",
        cy: "132",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220,176v32a8,8,0,0,1-8,8H188a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M76,176v32a8,8,0,0,1-8,8H44a8,8,0,0,1-8-8V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "96",
        x2: "240",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "128",
        x2: "144",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "128",
        x2: "112",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M220,176H36V96.00005l7.01877-49.13142A8,8,0,0,1,50.93836,40H205.06164a8,8,0,0,1,7.91959,6.86863L220,96.00005Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "132",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "184",
        cy: "132",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Jeep = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6d(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Jeep.displayName = "Jeep";

var renderPathFor$6e = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M93.16866,122.8328a71.93648,71.93648,0,1,1,40.0009,40.001l.00062-.00149L120.00244,176h-24v24h-24v24h-40V184l61.168-61.168Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M93.16866,122.8328a71.93648,71.93648,0,1,1,40.0009,40.001l.00062-.00149L120.00244,176h-24v24h-24v24h-40V184l61.168-61.168Z"
      })), React__default.createElement("path", {
        d: "M93.16866,122.8328a71.93648,71.93648,0,1,1,40.0009,40.001l.00062-.00149L120.00244,176h-24v24h-24v24h-40V184l61.168-61.168Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M160.00244,16A80.05817,80.05817,0,0,0,83.91357,120.77539L26.34521,178.34277A8.00235,8.00235,0,0,0,24.00244,184v40a8.00039,8.00039,0,0,0,8,8h40a8.00039,8.00039,0,0,0,8-8V208h16a8.00039,8.00039,0,0,0,8-8V184h16a8.00235,8.00235,0,0,0,5.65723-2.34277l9.56738-9.56836A80.00922,80.00922,0,1,0,160.00244,16ZM180,92a16,16,0,1,1,16-16A16.00016,16.00016,0,0,1,180,92Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M93.16866,122.8328a71.93648,71.93648,0,1,1,40.0009,40.001l.00062-.00149L120.00244,176h-24v24h-24v24h-40V184l61.168-61.168Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M93.16866,122.8328a71.93648,71.93648,0,1,1,40.0009,40.001l.00062-.00149L120.00244,176h-24v24h-24v24h-40V184l61.168-61.168Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M93.16866,122.8328a71.93648,71.93648,0,1,1,40.0009,40.001l.00062-.00149L120.00244,176h-24v24h-24v24h-40V184l61.168-61.168Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "76",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Key = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6e(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Key.displayName = "Key";

var renderPathFor$6f = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "56",
        width: "208",
        height: "144",
        rx: "8.48528",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "128",
        x2: "192",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "92",
        x2: "192",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "164",
        x2: "72",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "108",
        y1: "164",
        x2: "148",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "164",
        x2: "192",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "56",
        width: "208",
        height: "144",
        rx: "8.48528",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "24",
        y: "56",
        width: "208",
        height: "144",
        rx: "8.48528",
        strokeWidth: "16.97056",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "128",
        x2: "200",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "96",
        x2: "200",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "160",
        x2: "64",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "160",
        x2: "160",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "192",
        y1: "160",
        x2: "200",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.51465,47.51465H32.48535a16.99025,16.99025,0,0,0-16.9707,16.9707v127.0293a16.99025,16.99025,0,0,0,16.9707,16.9707h191.0293a16.99025,16.99025,0,0,0,16.9707-16.9707V64.48535A16.99025,16.99025,0,0,0,223.51465,47.51465ZM64,168H56a8,8,0,0,1,0-16h8a8,8,0,0,1,0,16Zm96,0H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm40,0h-8a8,8,0,0,1,0-16h8a8,8,0,0,1,0,16Zm0-32H56a8,8,0,0,1,0-16H200a8,8,0,0,1,0,16Zm0-32H56a8,8,0,0,1,0-16H200a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "56",
        width: "208",
        height: "144",
        rx: "8.48528",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "128",
        x2: "200",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "96",
        x2: "200",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "160",
        x2: "64",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "160",
        x2: "160",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "192",
        y1: "160",
        x2: "200",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "56",
        width: "208",
        height: "144",
        rx: "8.48528",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "128",
        x2: "200",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "96",
        x2: "200",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "160",
        x2: "64",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "160",
        x2: "160",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "192",
        y1: "160",
        x2: "200",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "56",
        width: "208",
        height: "144",
        rx: "8.48528",
        strokeWidth: "16.97056",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "128",
        x2: "200",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "96",
        x2: "200",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "160",
        x2: "64",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "160",
        x2: "160",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "192",
        y1: "160",
        x2: "200",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Keyboard = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6f(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Keyboard.displayName = "Keyboard";

var renderPathFor$6g = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,168V72A16,16,0,0,1,56,56H200a16,16,0,0,1,16,16v96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M24,168H232a0,0,0,0,1,0,0v24a16,16,0,0,1-16,16H40a16,16,0,0,1-16-16V168a0,0,0,0,1,0,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "96",
        x2: "112",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,176V72A16,16,0,0,1,56,56H200a16,16,0,0,1,16,16V176Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M40,176V72A16,16,0,0,1,56,56H200a16,16,0,0,1,16,16V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M24,176H232a0,0,0,0,1,0,0v16a16,16,0,0,1-16,16H40a16,16,0,0,1-16-16V176A0,0,0,0,1,24,176Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "88",
        x2: "112",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232,168h-8V72a24.0275,24.0275,0,0,0-24-24H56A24.0275,24.0275,0,0,0,32,72v96H24a8.00008,8.00008,0,0,0-8,8v16a24.0275,24.0275,0,0,0,24,24H216a24.0275,24.0275,0,0,0,24-24V176A8.00008,8.00008,0,0,0,232,168ZM112,72h32a8,8,0,0,1,0,16H112a8,8,0,0,1,0-16ZM224,192a8.00917,8.00917,0,0,1-8,8H40a8.00917,8.00917,0,0,1-8-8v-8H224Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,176V72A16,16,0,0,1,56,56H200a16,16,0,0,1,16,16V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M24,176H232a0,0,0,0,1,0,0v16a16,16,0,0,1-16,16H40a16,16,0,0,1-16-16V176A0,0,0,0,1,24,176Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "88",
        x2: "112",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,176V72A16,16,0,0,1,56,56H200a16,16,0,0,1,16,16V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M24,176H232a0,0,0,0,1,0,0v16a16,16,0,0,1-16,16H40a16,16,0,0,1-16-16V176A0,0,0,0,1,24,176Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "88",
        x2: "112",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,176V72A16,16,0,0,1,56,56H200a16,16,0,0,1,16,16V176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M24,176H232a0,0,0,0,1,0,0v16a16,16,0,0,1-16,16H40a16,16,0,0,1-16-16V176A0,0,0,0,1,24,176Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "88",
        x2: "112",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Laptop = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6g(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Laptop.displayName = "Laptop";

var renderPathFor$6h = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "24",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M46.783,209.217A128.08756,128.08756,0,0,1,209.217,46.783,128.08756,128.08756,0,0,1,46.783,209.217Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M46.783,209.217A128.08756,128.08756,0,0,1,209.217,46.783,128.08756,128.08756,0,0,1,46.783,209.217Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "24",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M46.783,209.217A128.08756,128.08756,0,0,1,209.217,46.783,128.08756,128.08756,0,0,1,46.783,209.217Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M39.209,211.792q-.80968-2.382-1.5249-4.78991L18.34326,226.34277a8.00018,8.00018,0,0,0,11.31348,11.31446L48.99805,218.3158q-2.40619-.71943-4.78955-1.52478A8.00059,8.00059,0,0,1,39.209,211.792Z"
      }), React__default.createElement("path", {
        d: "M216.791,44.2085A7.99794,7.99794,0,0,0,211.7915,39.209,135.76626,135.76626,0,0,0,168,32C93.00928,32,32,93.00928,32,168a135.916,135.916,0,0,0,5.68408,39.00208L154.34326,90.34326a7.99984,7.99984,0,0,1,11.31348,11.31348L48.99805,218.3158A135.92719,135.92719,0,0,0,88,224c74.99072,0,136-61.00977,136-136A135.76626,135.76626,0,0,0,216.791,44.2085Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "24",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M46.783,209.217A128.08756,128.08756,0,0,1,209.217,46.783,128.08756,128.08756,0,0,1,46.783,209.217Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "24",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M46.783,209.217A128.08756,128.08756,0,0,1,209.217,46.783,128.08756,128.08756,0,0,1,46.783,209.217Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "24",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M46.783,209.217A128.08756,128.08756,0,0,1,209.217,46.783,128.08756,128.08756,0,0,1,46.783,209.217Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Leaf = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6h(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Leaf.displayName = "Leaf";

var renderPathFor$6i = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96.00244",
        y1: "196",
        x2: "160.00244",
        y2: "196",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104.00244",
        y1: "232",
        x2: "152.00244",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M75.0867,164.00066a80,80,0,1,1,105.82906.00214",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M79.99554,168.00067a80,80,0,1,1,96.014-.00013",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "96.00244",
        y1: "200",
        x2: "160.00244",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104.00244",
        y1: "232",
        x2: "152.00244",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M79.99554,168.00067a80,80,0,1,1,96.014-.00013",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M160.00244,192h-64a8,8,0,1,0,0,16h64a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M152.00244,224h-48a8,8,0,1,0,0,16h48a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M128.00244,16a88.00456,88.00456,0,0,0-52.8125,158.39746,8.00073,8.00073,0,0,0,4.80567,1.60352h96.01367a8.0007,8.0007,0,0,0,4.80566-1.60352A88.00456,88.00456,0,0,0,128.00244,16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96.00244",
        y1: "200",
        x2: "160.00244",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104.00244",
        y1: "232",
        x2: "152.00244",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M79.99554,168.00067a80,80,0,1,1,96.014-.00013",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96.00244",
        y1: "200",
        x2: "160.00244",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104.00244",
        y1: "232",
        x2: "152.00244",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M79.99554,168.00067a80,80,0,1,1,96.014-.00013",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96.00244",
        y1: "200",
        x2: "160.00244",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104.00244",
        y1: "232",
        x2: "152.00244",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M79.99554,168.00067a80,80,0,1,1,96.014-.00013",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Lightbulb = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6i(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Lightbulb.displayName = "Lightbulb";

var renderPathFor$6j = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "96 239.992 112 159.992 48 135.992 160 15.992 144 95.992 208 119.992 96 239.992",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "96 239.992 112 159.992 48 135.992 160 15.992 144 95.992 208 119.992 96 239.992",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "96 239.992 112 159.992 48 135.992 160 15.992 144 95.992 208 119.992 96 239.992",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.78857,118.16406a8.00125,8.00125,0,0,0-4.97949-5.6626L153.17871,90.89014l14.666-73.3291a8.00018,8.00018,0,0,0-13.69336-7.02735l-112,120a7.99995,7.99995,0,0,0,3.03955,12.94922l57.63037,21.61133-14.666,73.3291a7.99991,7.99991,0,0,0,13.69336,7.02734l112-120A8.00057,8.00057,0,0,0,215.78857,118.16406Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "96 239.992 112 159.992 48 135.992 160 15.992 144 95.992 208 119.992 96 239.992",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "96 239.992 112 159.992 48 135.992 160 15.992 144 95.992 208 119.992 96 239.992",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "96 239.992 112 159.992 48 135.992 160 15.992 144 95.992 208 119.992 96 239.992",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Lightning = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6j(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Lightning.displayName = "Lightning";

var renderPathFor$6k = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40.00391",
        x2: "208",
        y2: "216.00391",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "163.777 167.359 96 239.977 112 159.977 48 135.976 92.198 88.622",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "119.583 59.281 160 15.977 144 95.976 208 119.977 191.162 138.018",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "96 239.969 112 159.969 48 135.969 160 15.969 144 95.969 208 119.969 96 239.969",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "39.99609",
        x2: "208",
        y2: "215.99609",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "163.777 167.351 96 239.969 112 159.969 48 135.969 92.198 88.614",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "114.106 65.141 160 15.969 144 95.969 208 119.969 185.685 143.878",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M53.91943,34.61475A7.99991,7.99991,0,1,0,42.08057,45.37744l39.24072,43.1648-39.16992,41.968a8.00053,8.00053,0,0,0,3.03955,12.94922l57.63037,21.61133-14.666,73.3291a7.99991,7.99991,0,0,0,13.69336,7.02735l61.85083-66.26892,38.38111,42.21911a7.99991,7.99991,0,1,0,11.83886-10.76269Z"
      }), React__default.createElement("path", {
        d: "M179.76562,149.25928a8.00013,8.00013,0,0,0,5.86719,2.61865h.05225a8.00073,8.00073,0,0,0,5.84863-2.5415l22.31494-23.90918a7.99994,7.99994,0,0,0-3.03955-12.94922L153.17871,90.8667l14.666-73.3291a8.00018,8.00018,0,0,0-13.69336-7.02735l-45.894,49.17237a8.00006,8.00006,0,0,0-.0708,10.83984Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "39.99609",
        x2: "208",
        y2: "215.99609",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "163.777 167.351 96 239.969 112 159.969 48 135.969 92.198 88.614",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "114.106 65.141 160 15.969 144 95.969 208 119.969 185.685 143.878",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "39.99609",
        x2: "208",
        y2: "215.99609",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "163.777 167.351 96 239.969 112 159.969 48 135.969 92.198 88.614",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "114.106 65.141 160 15.969 144 95.969 208 119.969 185.685 143.878",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "39.99609",
        x2: "208",
        y2: "215.99609",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "163.777 167.351 96 239.969 112 159.969 48 135.969 92.198 88.614",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "114.106 65.141 160 15.969 144 95.969 208 119.969 185.685 143.878",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LightningSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6k(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LightningSlash.displayName = "LightningSlash";

var renderPathFor$6l = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M130.49413,63.28047l11.648-11.648a44,44,0,1,1,62.22539,62.22539l-28.28427,28.28428a44,44,0,0,1-62.2254,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M125.50407,192.72133l-11.64621,11.6462a44,44,0,1,1-62.22539-62.22539l28.28427-28.28428a44,44,0,0,1,62.2254,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.34315,71.43146l19.799-19.799a44,44,0,1,1,62.22539,62.22539l-28.28427,28.28428a44,44,0,0,1-62.2254,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M133.65685,184.56854l-19.799,19.799a44,44,0,1,1-62.22539-62.22539l28.28427-28.28428a44,44,0,0,1,62.2254,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M210.0249,45.97559a52.00107,52.00107,0,0,0-73.54,0L116.686,65.77441a8.00053,8.00053,0,1,0,11.31445,11.31446L147.79932,57.29a35.99926,35.99926,0,1,1,50.91113,50.91016l-28.2832,28.28515a36.04088,36.04088,0,0,1-50.91211,0,8.00053,8.00053,0,0,0-11.31446,11.31445,52.0625,52.0625,0,0,0,73.54,0l28.28418-28.28515a52.00226,52.00226,0,0,0,0-73.53906Z"
      }), React__default.createElement("path", {
        d: "M127.99951,178.91113,108.20068,198.71A35.99926,35.99926,0,1,1,57.28955,147.7998l28.2832-28.28515a36.03821,36.03821,0,0,1,50.91211,0,8.00053,8.00053,0,1,0,11.31446-11.31445,52.0625,52.0625,0,0,0-73.54,0L45.9751,136.48535a52.00031,52.00031,0,0,0,73.54,73.53906L139.314,190.22559a8.00053,8.00053,0,0,0-11.31445-11.31446Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.34315,71.43146l19.799-19.799a44,44,0,1,1,62.22539,62.22539l-28.28427,28.28428a44,44,0,0,1-62.2254,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M133.65685,184.56854l-19.799,19.799a44,44,0,1,1-62.22539-62.22539l28.28427-28.28428a44,44,0,0,1,62.2254,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.34315,71.43146l19.799-19.799a44,44,0,1,1,62.22539,62.22539l-28.28427,28.28428a44,44,0,0,1-62.2254,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M133.65685,184.56854l-19.799,19.799a44,44,0,1,1-62.22539-62.22539l28.28427-28.28428a44,44,0,0,1,62.2254,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.34315,71.43146l19.799-19.799a44,44,0,1,1,62.22539,62.22539l-28.28427,28.28428a44,44,0,0,1-62.2254,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M133.65685,184.56854l-19.799,19.799a44,44,0,1,1-62.22539-62.22539l28.28427-28.28428a44,44,0,0,1,62.2254,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Link = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6l(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Link.displayName = "Link";

var renderPathFor$6m = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.34266,71.43146l19.799-19.799A44,44,0,0,1,204.367,113.85786l-19.799,19.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M133.65637,184.56854l-19.799,19.799A44,44,0,1,1,51.632,142.14214l19.799-19.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "86.05839",
        y1: "59.43146",
        x2: "86.05839",
        y2: "36.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "59.43097",
        y1: "86.05887",
        x2: "36.80355",
        y2: "86.05887",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "196.56805",
        y1: "169.94113",
        x2: "219.19547",
        y2: "169.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "169.94064",
        y1: "196.56854",
        x2: "169.94064",
        y2: "219.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.34266,71.43146l19.799-19.799A44,44,0,0,1,204.367,113.85786l-19.799,19.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M133.65637,184.56854l-19.799,19.799A44,44,0,1,1,51.632,142.14214l19.799-19.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "94.05839",
        y1: "71.43146",
        x2: "94.05839",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "71.43097",
        y1: "94.05887",
        x2: "48.80355",
        y2: "94.05887",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184.56805",
        y1: "161.94113",
        x2: "207.19547",
        y2: "161.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "161.94064",
        y1: "184.56854",
        x2: "161.94064",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M178.91064,128.001a7.99984,7.99984,0,1,0,11.31446,11.3125L210.023,119.51465a51.99928,51.99928,0,1,0-73.53711-73.53906L116.686,65.77441a7.99984,7.99984,0,0,0,11.3125,11.31446l19.80078-19.79981a35.99961,35.99961,0,1,1,50.91015,50.91211Z"
      }), React__default.createElement("path", {
        d: "M128.00049,178.91113l-19.80078,19.79981a35.99961,35.99961,0,1,1-50.91016-50.91211L77.08838,127.999a7.99983,7.99983,0,0,0-11.31445-11.3125L45.97607,136.48535a51.99928,51.99928,0,1,0,73.53711,73.53906L139.313,190.22559a7.99984,7.99984,0,0,0-11.3125-11.31446Z"
      }), React__default.createElement("path", {
        d: "M94.05811,79.43164a8.0004,8.0004,0,0,0,8-8V48.80371a8,8,0,1,0-16,0V71.43164A8.00039,8.00039,0,0,0,94.05811,79.43164Z"
      }), React__default.createElement("path", {
        d: "M48.80322,102.05859H71.43115a8,8,0,0,0,0-16H48.80322a8,8,0,1,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M207.1958,153.94141H184.56787a8,8,0,0,0,0,16H207.1958a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M161.94092,176.56836a8.00039,8.00039,0,0,0-8,8v22.62793a8,8,0,0,0,16,0V184.56836A8.00039,8.00039,0,0,0,161.94092,176.56836Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.34266,71.43146l19.799-19.799A44,44,0,0,1,204.367,113.85786l-19.799,19.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M133.65637,184.56854l-19.799,19.799A44,44,0,1,1,51.632,142.14214l19.799-19.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "94.05839",
        y1: "71.43146",
        x2: "94.05839",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "71.43097",
        y1: "94.05887",
        x2: "48.80355",
        y2: "94.05887",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "184.56805",
        y1: "161.94113",
        x2: "207.19547",
        y2: "161.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "161.94064",
        y1: "184.56854",
        x2: "161.94064",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.34266,71.43146l19.799-19.799A44,44,0,0,1,204.367,113.85786l-19.799,19.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M133.65637,184.56854l-19.799,19.799A44,44,0,1,1,51.632,142.14214l19.799-19.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "94.05839",
        y1: "71.43146",
        x2: "94.05839",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "71.43097",
        y1: "94.05887",
        x2: "48.80355",
        y2: "94.05887",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "184.56805",
        y1: "161.94113",
        x2: "207.19547",
        y2: "161.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "161.94064",
        y1: "184.56854",
        x2: "161.94064",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.34266,71.43146l19.799-19.799A44,44,0,0,1,204.367,113.85786l-19.799,19.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M133.65637,184.56854l-19.799,19.799A44,44,0,1,1,51.632,142.14214l19.799-19.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "94.05839",
        y1: "71.43146",
        x2: "94.05839",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "71.43097",
        y1: "94.05887",
        x2: "48.80355",
        y2: "94.05887",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184.56805",
        y1: "161.94113",
        x2: "207.19547",
        y2: "161.94113",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "161.94064",
        y1: "184.56854",
        x2: "161.94064",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LinkBreak = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6m(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LinkBreak.displayName = "LinkBreak";

var renderPathFor$6n = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "94.05365",
        y1: "161.93204",
        x2: "161.9359",
        y2: "94.04979",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M144.96326,178.9102,116.679,207.19447a48,48,0,0,1-67.88225-67.88225L77.081,111.028",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M178.90922,144.96424,207.19349,116.68a48,48,0,0,0-67.88225-67.88225L111.027,77.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "94.05267",
        y1: "161.93204",
        x2: "161.93492",
        y2: "94.04979",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M144.96229,178.9102,116.678,207.19447a48,48,0,0,1-67.88226-67.88225L77.08,111.028",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M178.90825,144.96424,207.19252,116.68a48,48,0,0,0-67.88225-67.88225L111.026,77.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M156.27783,88.39258,88.396,156.27441a8.00053,8.00053,0,0,0,11.31445,11.31446L167.59229,99.707a8.00053,8.00053,0,1,0-11.31446-11.31445Z"
      }), React__default.createElement("path", {
        d: "M139.30518,173.25293,111.021,201.53711a39.99918,39.99918,0,1,1-56.56739-56.56738l28.28418-28.28418a8.00053,8.00053,0,1,0-11.31445-11.31446L43.13916,133.65527a56.00023,56.00023,0,0,0,79.19629,79.19629l28.28418-28.28418a8.00052,8.00052,0,0,0-11.31445-11.31445Z"
      }), React__default.createElement("path", {
        d: "M212.8501,43.14062a56.002,56.002,0,0,0-79.19629,0L105.36963,71.4248a8.00053,8.00053,0,0,0,11.31445,11.31446l28.28418-28.28418a39.99918,39.99918,0,0,1,56.56738,56.56738l-28.28418,28.28418a8.00053,8.00053,0,0,0,11.31446,11.31445l28.28418-28.28418A56.06459,56.06459,0,0,0,212.8501,43.14062Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "94.05413",
        y1: "161.93204",
        x2: "161.93639",
        y2: "94.04979",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M144.96375,178.9102l-28.28427,28.28427a48,48,0,0,1-67.88225-67.88225L77.0815,111.028",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M178.90971,144.96424,207.194,116.68a48,48,0,0,0-67.88225-67.88225L111.02746,77.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "94.05462",
        y1: "161.93204",
        x2: "161.93687",
        y2: "94.04979",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M144.96424,178.9102,116.68,207.19447a48,48,0,0,1-67.88225-67.88225L77.082,111.028",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M178.9102,144.96424,207.19447,116.68a48,48,0,0,0-67.88225-67.88225L111.028,77.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "94.05511",
        y1: "161.93204",
        x2: "161.93736",
        y2: "94.04979",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M144.96473,178.9102l-28.28427,28.28427a48,48,0,0,1-67.88225-67.88225L77.08248,111.028",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M178.91069,144.96424,207.195,116.68a48,48,0,0,0-67.88225-67.88225L111.02844,77.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LinkSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6n(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LinkSimple.displayName = "LinkSimple";

var renderPathFor$6o = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M144.96473,178.9102l-28.28427,28.28427a48,48,0,0,1-67.88225-67.88225L77.08248,111.028",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M178.91069,144.96424,207.195,116.68a48,48,0,0,0-67.88225-67.88225L111.02844,77.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M144.96473,178.9102l-28.28427,28.28427a48,48,0,0,1-67.88225-67.88225L77.08248,111.028",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M178.91069,144.96424,207.195,116.68a48,48,0,0,0-67.88225-67.88225L111.02844,77.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M139.30713,173.25293,111.023,201.53711a39.99918,39.99918,0,0,1-56.56738-56.56738l28.28418-28.28418a8.00053,8.00053,0,0,0-11.31446-11.31446L43.14111,133.65527a56.00023,56.00023,0,0,0,79.19629,79.19629l28.28418-28.28418a8.00052,8.00052,0,1,0-11.31445-11.31445Z"
      }), React__default.createElement("path", {
        d: "M212.85205,43.14062a56.002,56.002,0,0,0-79.19629,0L105.37158,71.4248A8.00053,8.00053,0,1,0,116.686,82.73926l28.28417-28.28418a39.99918,39.99918,0,0,1,56.56739,56.56738l-28.28418,28.28418a8.00052,8.00052,0,0,0,11.31445,11.31445l28.28418-28.28418A56.06457,56.06457,0,0,0,212.85205,43.14062Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M144.96473,178.9102l-28.28427,28.28427a48,48,0,0,1-67.88225-67.88225L77.08248,111.028",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M178.91069,144.96424,207.195,116.68a48,48,0,0,0-67.88225-67.88225L111.02844,77.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M144.96473,178.9102l-28.28427,28.28427a48,48,0,0,1-67.88225-67.88225L77.08248,111.028",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M178.91069,144.96424,207.195,116.68a48,48,0,0,0-67.88225-67.88225L111.02844,77.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M144.96473,178.9102l-28.28427,28.28427a48,48,0,0,1-67.88225-67.88225L77.08248,111.028",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M178.91069,144.96424,207.195,116.68a48,48,0,0,0-67.88225-67.88225L111.02844,77.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LinkSimpleBreak = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6o(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LinkSimpleBreak.displayName = "LinkSimpleBreak";

var renderPathFor$6p = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "79.97949",
        y1: "127.99219",
        x2: "175.97949",
        y2: "127.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M103.97266,175.99609h-40a48,48,0,0,1,0-96h40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M151.97949,175.99609h40a48,48,0,0,0,0-96h-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "79.96582",
        y1: "127.99219",
        x2: "175.96582",
        y2: "127.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M103.959,175.99609h-40a48,48,0,0,1,0-96h40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M151.96582,175.99609h40a48,48,0,0,0,0-96h-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M71.97266,127.99219a8.00009,8.00009,0,0,0,8,8h96a8,8,0,0,0,0-16h-96A8.00008,8.00008,0,0,0,71.97266,127.99219Z"
      }), React__default.createElement("path", {
        d: "M103.96582,167.99609h-40a40,40,0,0,1,0-80h40a8,8,0,0,0,0-16h-40a56,56,0,0,0,0,112h40a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M191.97266,71.99609h-40a8,8,0,0,0,0,16h40a40,40,0,0,1,0,80h-40a8,8,0,0,0,0,16h40a56,56,0,0,0,0-112Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "79.98633",
        y1: "127.99219",
        x2: "175.98633",
        y2: "127.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M103.97949,175.99609h-40a48,48,0,0,1,0-96h40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M151.98633,175.99609h40a48,48,0,0,0,0-96h-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "79.99316",
        y1: "127.99219",
        x2: "175.99316",
        y2: "127.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M103.98633,175.99609h-40a48,48,0,0,1,0-96h40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M151.99316,175.99609h40a48,48,0,0,0,0-96h-40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "80",
        y1: "127.99219",
        x2: "176",
        y2: "127.99219",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M103.99316,175.99609h-40a48,48,0,0,1,0-96h40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,175.99609h40a48,48,0,0,0,0-96H152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LinkSimpleHorizontal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6p(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LinkSimpleHorizontal.displayName = "LinkSimpleHorizontal";

var renderPathFor$6q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M103.99316,175.99609h-40a48,48,0,0,1,0-96h40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152,175.99609h40a48,48,0,0,0,0-96H152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M103.99316,175.99609h-40a48,48,0,0,1,0-96h40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,175.99609h40a48,48,0,0,0,0-96H152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M103.99316,167.99609h-40a40,40,0,0,1,0-80h40a8,8,0,0,0,0-16h-40a56,56,0,0,0,0,112h40a8,8,0,1,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M192,71.99609H152a8,8,0,0,0,0,16h40a40,40,0,0,1,0,80H152a8,8,0,0,0,0,16h40a56,56,0,0,0,0-112Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M103.99316,175.99609h-40a48,48,0,0,1,0-96h40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M152,175.99609h40a48,48,0,0,0,0-96H152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M103.99316,175.99609h-40a48,48,0,0,1,0-96h40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M152,175.99609h40a48,48,0,0,0,0-96H152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M103.99316,175.99609h-40a48,48,0,0,1,0-96h40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,175.99609h40a48,48,0,0,0,0-96H152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LinkSimpleHorizontalBreak = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LinkSimpleHorizontalBreak.displayName = "LinkSimpleHorizontalBreak";

var renderPathFor$6r = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "124",
        y1: "120.00094",
        x2: "124",
        y2: "176.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "84",
        y1: "120.00094",
        x2: "84",
        y2: "176.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M124,148.00094a28,28,0,1,1,56,0v28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "112.00094",
        x2: "120",
        y2: "176.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112.00094",
        x2: "88",
        y2: "176.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M120,140.00094a28,28,0,1,1,56,0v36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,208,32ZM96,176.00094a8,8,0,0,1-16,0v-64a8,8,0,0,1,16,0Zm-8-84a12,12,0,1,1,12-12A12,12,0,0,1,88,92.00094Zm96,84a8,8,0,0,1-16,0v-36a20,20,0,1,0-40,0v36a8,8,0,0,1-16,0v-64a7.99729,7.99729,0,0,1,15.79492-1.77856A35.98123,35.98123,0,0,1,184,140.00094Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "112.00094",
        x2: "120",
        y2: "176.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112.00094",
        x2: "88",
        y2: "176.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M120,140.00094a28,28,0,1,1,56,0v36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "112.00094",
        x2: "120",
        y2: "176.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112.00094",
        x2: "88",
        y2: "176.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M120,140.00094a28,28,0,1,1,56,0v36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "112.00094",
        x2: "120",
        y2: "176.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "112.00094",
        x2: "88",
        y2: "176.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M120,140.00094a28,28,0,1,1,56,0v36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "80",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LinkedinLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6r(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LinkedinLogo.displayName = "LinkedinLogo";

var renderPathFor$6s = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "64",
        x2: "216",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "192",
        x2: "216",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "64",
        x2: "216",
        y2: "64",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "192",
        x2: "216",
        y2: "192",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M215.999,120.00037h-176a8,8,0,0,0,0,16h176a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M39.999,72.00037h176a8,8,0,0,0,0-16h-176a8,8,0,1,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M215.999,184.00037h-176a8,8,0,0,0,0,16h176a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "64",
        x2: "216",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "192",
        x2: "216",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "64",
        x2: "216",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "192",
        x2: "216",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "64",
        x2: "216",
        y2: "64",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "192",
        x2: "216",
        y2: "192",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var List = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6s(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
List.displayName = "List";

var renderPathFor$6t = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "88",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "68",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "88",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "68",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M88,76H216a8,8,0,0,0,0-16H88a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M216,120H88.00586a8,8,0,1,0,0,16H216a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M216,180H88.00586a8,8,0,1,0,0,16H216a8,8,0,0,0,0-16Z"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "68",
        r: "12"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "128",
        r: "12"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "188.00586",
        r: "12"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "88",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "68",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "88",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "68",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "88",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "128",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "68",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "44",
        cy: "188",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ListBullets = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6t(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ListBullets.displayName = "ListBullets";

var renderPathFor$6u = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "56",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "128",
        x2: "56",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "56",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "56",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "128",
        x2: "56",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "56",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M96,76H216a8,8,0,0,0,0-16H96a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M216,120H96.00586a8,8,0,1,0,0,16H216a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M216,180H96.00586a8,8,0,1,0,0,16H216a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M56,60H40a8,8,0,0,0,0,16H56a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M56,120H40.00586a8,8,0,1,0,0,16H56a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M56,180H40.00586a8,8,0,1,0,0,16H56a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "56",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "128",
        x2: "56",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "56",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "56",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "128",
        x2: "56",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "56",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "56",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "128",
        x2: "56",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "56",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ListDashes = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6u(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ListDashes.displayName = "ListDashes";

var renderPathFor$6v = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "108",
        y1: "128",
        x2: "215.99902",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "108",
        y1: "64",
        x2: "215.99902",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "107.99902",
        y1: "192",
        x2: "215.99902",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "40 60 56 52 56 107.994",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M41.10018,152.55059A14.00226,14.00226,0,1,1,65.609,165.82752L40,200H68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "215.99902",
        y2: "128",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "64",
        x2: "215.99902",
        y2: "64",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.99902",
        y1: "192",
        x2: "215.99902",
        y2: "192",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "40 60 56 52 56 107.994",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M41.10018,152.55059A14.00226,14.00226,0,1,1,65.609,165.82752L40,200H68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.999,128a8.00039,8.00039,0,0,1-8,8H104a8,8,0,0,1,0-16H215.999A8.00039,8.00039,0,0,1,223.999,128ZM104,72H215.999a8,8,0,0,0,0-16H104a8,8,0,0,0,0,16ZM215.999,184h-112a8,8,0,1,0,0,16h112a8,8,0,0,0,0-16ZM43.57764,67.15527,48,64.94434v43.0498a8,8,0,1,0,16,0V52a7.99928,7.99928,0,0,0-11.57764-7.15527l-16,8a7.99984,7.99984,0,1,0,7.15528,14.31054ZM72.23828,170.30566a22.00226,22.00226,0,1,0-38.50635-20.87109A8,8,0,1,0,48.46826,155.667a6.00233,6.00233,0,1,1,10.59717,5.55176l-25.46729,33.9834A8.00013,8.00013,0,0,0,40,208H68a8,8,0,0,0,0-16H55.99219l16.01855-21.375Q72.12867,170.46827,72.23828,170.30566Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "215.99902",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "64",
        x2: "215.99902",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "103.99902",
        y1: "192",
        x2: "215.99902",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "40 60 56 52 56 107.994",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M41.10018,152.55059A14.00226,14.00226,0,1,1,65.609,165.82752L40,200H68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "215.99902",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "64",
        x2: "215.99902",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "103.99902",
        y1: "192",
        x2: "215.99902",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "40 60 56 52 56 107.994",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M41.10018,152.55059A14.00226,14.00226,0,1,1,65.609,165.82752L40,200H68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "215.99902",
        y2: "128",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "64",
        x2: "215.99902",
        y2: "64",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.99902",
        y1: "192",
        x2: "215.99902",
        y2: "192",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "40 60 56 52 56 107.994",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M41.10018,152.55059A14.00226,14.00226,0,1,1,65.609,165.82752L40,200H68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ListNumbers = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6v(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ListNumbers.displayName = "ListNumbers";

var renderPathFor$6w = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "67.99414",
        x2: "216",
        y2: "67.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "127.99414",
        x2: "216",
        y2: "127.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "187.99414",
        x2: "144",
        y2: "187.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "188",
        x2: "232",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "164",
        x2: "208",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "144",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "188.00586",
        x2: "232",
        y2: "188.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "164.00586",
        x2: "208",
        y2: "212.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M40,76H216a8,8,0,0,0,0-16H40a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M216,120H40.00586a8,8,0,1,0,0,16H216a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M144,180H40.00586a8,8,0,1,0,0,16H144a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M232,180.00586H216v-16a8,8,0,1,0-16,0v16H184a8,8,0,0,0,0,16h16v16a8,8,0,0,0,16,0v-16h16a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "144",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "188.00586",
        x2: "232",
        y2: "188.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "164.00586",
        x2: "208",
        y2: "212.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "67.99414",
        x2: "216",
        y2: "67.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "127.99414",
        x2: "216",
        y2: "127.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "187.99414",
        x2: "144",
        y2: "187.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "188",
        x2: "232",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "164",
        x2: "208",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "67.99414",
        x2: "216",
        y2: "67.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "127.99414",
        x2: "216",
        y2: "127.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "187.99414",
        x2: "144",
        y2: "187.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "188",
        x2: "232",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "164",
        x2: "208",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ListPlus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6w(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ListPlus.displayName = "ListPlus";

var renderPathFor$6x = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M92,88V52a36,36,0,0,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "127.98242",
        cy: "152",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M92,88V52a36,36,0,0,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.9707",
        cy: "152",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,80H172V52a44,44,0,0,0-88,0V80H48A16.01833,16.01833,0,0,0,32,96V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V96A16.01833,16.01833,0,0,0,208,80Zm-80.00586,84a12,12,0,1,1,12-12A12,12,0,0,1,127.99414,164ZM156,80H100V52a28,28,0,0,1,56,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M92,88V52a36,36,0,0,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "127.98828",
        cy: "152",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M92,88V52a36,36,0,0,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "152",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M92,88V52a36,36,0,0,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "152",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Lock = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6x(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Lock.displayName = "Lock";

var renderPathFor$6y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "144",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "164",
        x2: "127.99414",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99414,88h-160a8,8,0,0,0-8,8V208a8,8,0,0,0,8,8h160a8,8,0,0,0,8-8V96A8,8,0,0,0,207.99414,88Zm-80,72a20,20,0,1,1,20-20A20.00006,20.00006,0,0,1,127.99414,160Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "140",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "160",
        x2: "127.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "140",
        r: "12"
      }), React__default.createElement("path", {
        d: "M207.99414,80h-36V52a44,44,0,1,0-88,0V80h-36a16.01833,16.01833,0,0,0-16,16V208a16.01833,16.01833,0,0,0,16,16h160a16.01833,16.01833,0,0,0,16-16V96A16.01833,16.01833,0,0,0,207.99414,80Zm-72,86.82935V184a8,8,0,1,1-16,0V166.82935a28,28,0,1,1,16,0Zm20-86.82935h-56V52a28,28,0,1,1,56,0Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "140",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "160",
        x2: "127.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "140",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "160",
        x2: "127.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "140",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "160",
        x2: "127.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LockKey = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LockKey.displayName = "LockKey";

var renderPathFor$6z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "144",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "164",
        x2: "127.99414",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36.00169,36.00169,0,0,1,71.78028-4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99414,88h-160a8,8,0,0,0-8,8V208a8,8,0,0,0,8,8h160a8,8,0,0,0,8-8V96A8,8,0,0,0,207.99414,88Zm-80,72a20,20,0,1,1,20-20A20.00006,20.00006,0,0,1,127.99414,160Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "140",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "160",
        x2: "127.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "140",
        r: "12"
      }), React__default.createElement("path", {
        d: "M207.99414,80h-108V52a28,28,0,1,1,56,0,8,8,0,0,0,16,0,44,44,0,1,0-88,0V80h-36a16.01833,16.01833,0,0,0-16,16V208a16.01833,16.01833,0,0,0,16,16h160a16.01833,16.01833,0,0,0,16-16V96A16.01833,16.01833,0,0,0,207.99414,80Zm-72,86.82935V184a8,8,0,1,1-16,0V166.82935a28,28,0,1,1,16,0Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "140",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "160",
        x2: "127.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "140",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "160",
        x2: "127.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "140",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99414",
        y1: "160",
        x2: "127.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LockKeyOpen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LockKeyOpen.displayName = "LockKeyOpen";

var renderPathFor$6A = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "39.99414",
        y1: "132",
        x2: "215.99414",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "172",
        x2: "215.99414",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "120",
        x2: "215.99414",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "152",
        x2: "215.99414",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "184",
        x2: "215.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.96484,80h-36V52a44,44,0,0,0-88,0V80h-36a16.01833,16.01833,0,0,0-16,16V208a16.01833,16.01833,0,0,0,16,16h160a16.01833,16.01833,0,0,0,16-16V96A16.01833,16.01833,0,0,0,207.96484,80Zm-108-28a28,28,0,0,1,56,0V80h-56Zm84,140h-112a8,8,0,1,1,0-16h112a8,8,0,0,1,0,16Zm0-32h-112a8,8,0,1,1,0-16h112a8,8,0,0,1,0,16Zm0-32h-112a8,8,0,1,1,0-16h112a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "39.99414",
        y1: "120",
        x2: "215.99414",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "152",
        x2: "215.99414",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "184",
        x2: "215.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "39.99414",
        y1: "120",
        x2: "215.99414",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "152",
        x2: "215.99414",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "184",
        x2: "215.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "39.99414",
        y1: "120",
        x2: "215.99414",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "152",
        x2: "215.99414",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "184",
        x2: "215.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LockLaminated = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6A(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LockLaminated.displayName = "LockLaminated";

var renderPathFor$6B = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40.0127",
        y1: "132",
        x2: "216.0127",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.0127",
        y1: "172",
        x2: "216.0127",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40.0127",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M92.0127,88V52A36.00169,36.00169,0,0,1,163.793,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "120",
        x2: "215.99414",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "152",
        x2: "215.99414",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "184",
        x2: "215.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99463,80h-108V52a28,28,0,0,1,56,0,8,8,0,0,0,16,0,44,44,0,0,0-88,0V80h-36a16.01833,16.01833,0,0,0-16,16V208a16.01833,16.01833,0,0,0,16,16h160a16.01833,16.01833,0,0,0,16-16V96A16.01833,16.01833,0,0,0,207.99463,80ZM183.99268,192H71.99463a8,8,0,0,1,0-16H183.99268a8,8,0,0,1,0,16Zm0-32H71.99463a8,8,0,0,1,0-16H183.99268a8,8,0,0,1,0,16Zm0-32H71.99463a8,8,0,0,1,0-16H183.99268a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "39.99414",
        y1: "120",
        x2: "215.99414",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "152",
        x2: "215.99414",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "184",
        x2: "215.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "39.99414",
        y1: "120",
        x2: "215.99414",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "152",
        x2: "215.99414",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "184",
        x2: "215.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "39.99414",
        y1: "120",
        x2: "215.99414",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "152",
        x2: "215.99414",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "39.99414",
        y1: "184",
        x2: "215.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LockLaminatedOpen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6B(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LockLaminatedOpen.displayName = "LockLaminatedOpen";

var renderPathFor$6C = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "127.98242",
        cy: "152",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M92,88V52a36.00169,36.00169,0,0,1,71.78028-4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M92,88V52a36,36,0,0,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.9707",
        cy: "152",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,80H100V52a28,28,0,0,1,56,0,8,8,0,0,0,16,0,44,44,0,0,0-88,0V80H48A16.01833,16.01833,0,0,0,32,96V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V96A16.01833,16.01833,0,0,0,208,80Zm-80.00586,84a12,12,0,1,1,12-12A12,12,0,0,1,127.99414,164Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M92,88V52a36,36,0,0,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "127.98828",
        cy: "152",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M92,88V52a36,36,0,0,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "152",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M92,88V52a36,36,0,0,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "152",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LockOpen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6C(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LockOpen.displayName = "LockOpen";

var renderPathFor$6D = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99463,80h-36V52a44,44,0,0,0-88,0V80h-36a16.01833,16.01833,0,0,0-16,16V208a16.01833,16.01833,0,0,0,16,16h160a16.01833,16.01833,0,0,0,16-16V96A16.01833,16.01833,0,0,0,207.99463,80Zm-108-28a28,28,0,0,1,56,0V80h-56Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LockSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6D(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LockSimple.displayName = "LockSimple";

var renderPathFor$6E = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M92.0127,88V52A36.00169,36.00169,0,0,1,163.793,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99463,80h-108V52a28,28,0,0,1,56,0,8,8,0,0,0,16,0,44,44,0,0,0-88,0V80h-36a16.01833,16.01833,0,0,0-16,16V208a16.01833,16.01833,0,0,0,16,16h160a16.01833,16.01833,0,0,0,16-16V96A16.01833,16.01833,0,0,0,207.99463,80Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "39.99414",
        y: "88",
        width: "176",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M91.99414,88V52a36,36,0,1,1,72,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var LockSimpleOpen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6E(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
LockSimpleOpen.displayName = "LockSimpleOpen";

var renderPathFor$6F = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "115.99707",
        cy: "116",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "175.39063",
        y1: "175.40039",
        x2: "223.99121",
        y2: "224.00098",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "115.99512",
        cy: "116",
        r: "84",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "115.99512",
        cy: "116",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "175.38868",
        y1: "175.40039",
        x2: "223.98926",
        y2: "224.00098",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M175.99609,116a60,60,0,1,1-60-60A60.06812,60.06812,0,0,1,175.99609,116Zm53.65137,113.65771a8.0006,8.0006,0,0,1-11.31445,0l-43.2229-43.2229a92.11513,92.11513,0,1,1,11.31445-11.31347l43.2229,43.2229A8,8,0,0,1,229.64746,229.65771ZM115.99609,192a76,76,0,1,0-76-76A76.08614,76.08614,0,0,0,115.99609,192Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "115.99805",
        cy: "116",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "175.39161",
        y1: "175.40039",
        x2: "223.99219",
        y2: "224.00098",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "115.99902",
        cy: "116",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "175.39258",
        y1: "175.40039",
        x2: "223.99316",
        y2: "224.00098",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "116",
        cy: "116",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "175.39356",
        y1: "175.40039",
        x2: "223.99414",
        y2: "224.00098",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MagnifyingGlass = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6F(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MagnifyingGlass.displayName = "MagnifyingGlass";

var renderPathFor$6G = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "83.99707",
        y1: "116",
        x2: "147.99707",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "115.99707",
        cy: "115.99707",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "175.39063",
        y1: "175.39747",
        x2: "223.99121",
        y2: "223.99805",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "115.99512",
        cy: "115.99707",
        r: "84",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "83.99512",
        y1: "116",
        x2: "147.99512",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "115.99512",
        cy: "115.99707",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "175.38868",
        y1: "175.39747",
        x2: "223.98926",
        y2: "223.99805",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M229.64746,218.34131l-43.2229-43.22284a92.11145,92.11145,0,1,0-11.31445,11.31341l43.2229,43.22291a8.00018,8.00018,0,0,0,11.31445-11.31348ZM147.99609,124h-64a8,8,0,1,1,0-16h64a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "83.99805",
        y1: "116",
        x2: "147.99805",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "115.99805",
        cy: "115.99707",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "175.39161",
        y1: "175.39747",
        x2: "223.99219",
        y2: "223.99805",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "83.99902",
        y1: "116",
        x2: "147.99902",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "115.99902",
        cy: "115.99707",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "175.39258",
        y1: "175.39747",
        x2: "223.99316",
        y2: "223.99805",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "84",
        y1: "116",
        x2: "148",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "116",
        cy: "115.99707",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "175.39356",
        y1: "175.39747",
        x2: "223.99414",
        y2: "223.99805",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MagnifyingGlassMinus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6G(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MagnifyingGlassMinus.displayName = "MagnifyingGlassMinus";

var renderPathFor$6H = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "83.99707",
        y1: "116",
        x2: "147.99707",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "115.99707",
        y1: "84",
        x2: "115.99707",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "115.99707",
        cy: "115.99609",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "175.39063",
        y1: "175.39649",
        x2: "223.99121",
        y2: "223.99707",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "115.99512",
        cy: "115.99609",
        r: "84",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "83.99512",
        y1: "116",
        x2: "147.99512",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "115.99512",
        y1: "84",
        x2: "115.99512",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "115.99512",
        cy: "115.99609",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "175.38868",
        y1: "175.39649",
        x2: "223.98926",
        y2: "223.99707",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M229.64746,218.34033l-43.2229-43.22284a92.11133,92.11133,0,1,0-11.31445,11.31342l43.2229,43.2229a8.00018,8.00018,0,1,0,11.31445-11.31348ZM147.99609,124h-24v24a8,8,0,0,1-16,0V124h-24a8,8,0,1,1,0-16h24V84a8,8,0,0,1,16,0v24h24a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "83.99805",
        y1: "116",
        x2: "147.99805",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "115.99805",
        y1: "84",
        x2: "115.99805",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "115.99805",
        cy: "115.99609",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "175.39161",
        y1: "175.39649",
        x2: "223.99219",
        y2: "223.99707",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "83.99902",
        y1: "116",
        x2: "147.99902",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "115.99902",
        y1: "84",
        x2: "115.99902",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "115.99902",
        cy: "115.99609",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "175.39258",
        y1: "175.39649",
        x2: "223.99316",
        y2: "223.99707",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "84",
        y1: "116",
        x2: "148",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "116",
        y1: "84",
        x2: "116",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "116",
        cy: "115.99609",
        r: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "175.39356",
        y1: "175.39649",
        x2: "223.99414",
        y2: "223.99707",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MagnifyingGlassPlus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6H(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MagnifyingGlassPlus.displayName = "MagnifyingGlassPlus";

var renderPathFor$6I = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "104",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M208,104c0,72-80,128-80,128S48,176,48,104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24a80.0002,80.0002,0,0,0-80,80c0,72,80,128,80,128s80-56,80-128A80.0002,80.0002,0,0,0,128,24Zm0,112a32,32,0,1,1,32-32A32.00034,32.00034,0,0,1,128,136Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "104",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,104c0,72-80,128-80,128S48,176,48,104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M127.99414,15.9971a88.1046,88.1046,0,0,0-88,88c0,75.29688,80,132.17188,83.40625,134.55469a8.023,8.023,0,0,0,9.1875,0c3.40625-2.38281,83.40625-59.25781,83.40625-134.55469A88.10459,88.10459,0,0,0,127.99414,15.9971ZM128,72a32,32,0,1,1-32,32A31.99909,31.99909,0,0,1,128,72Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "104",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M208,104c0,72-80,128-80,128S48,176,48,104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "104",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M208,104c0,72-80,128-80,128S48,176,48,104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "104",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,104c0,72-80,128-80,128S48,176,48,104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MapPin = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6I(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MapPin.displayName = "MapPin";

var renderPathFor$6J = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "56",
        y1: "232",
        x2: "200",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "104",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M208,104c0,72-80,128-80,128S48,176,48,104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24a80.0002,80.0002,0,0,0-80,80c0,72,80,128,80,128s80-56,80-128A80.0002,80.0002,0,0,0,128,24Zm0,112a32,32,0,1,1,32-32A32.00034,32.00034,0,0,1,128,136Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "232",
        x2: "200",
        y2: "232",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "104",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,104c0,72-80,128-80,128S48,176,48,104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M199.99975,224h-49.4602a266.47606,266.47606,0,0,0,23.49731-23.75049c27.45215-31.5708,41.96289-64.853,41.96289-96.24951a88,88,0,0,0-176,0c0,31.39648,14.51075,64.67871,41.96289,96.24951A266.476,266.476,0,0,0,105.46,224H55.99975a8,8,0,0,0,0,16h144a8,8,0,0,0,0-16ZM128,72a32,32,0,1,1-32,32A31.99971,31.99971,0,0,1,128,72Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "56",
        y1: "232",
        x2: "200",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "104",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M208,104c0,72-80,128-80,128S48,176,48,104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "56",
        y1: "232",
        x2: "200",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "104",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M208,104c0,72-80,128-80,128S48,176,48,104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "56",
        y1: "232",
        x2: "200",
        y2: "232",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "104",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,104c0,72-80,128-80,128S48,176,48,104a80,80,0,0,1,160,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MapPinLine = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6J(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MapPinLine.displayName = "MapPinLine";

var renderPathFor$6K = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 184 32 200 32 56 96 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "160 216 96 184 96 40 160 72 160 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "160 72 224 56 224 200 160 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "160 216 96 184 96 40 160 72 160 216",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "96 184 32 200 32 56 96 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "160 216 96 184 96 40 160 72 160 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 72 224 56 224 200 160 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M228.9226,49.69434a7.99952,7.99952,0,0,0-6.86328-1.45557L160.93066,63.521,99.57788,32.84448c-.01758-.00879-.03613-.01416-.054-.0227a8.0283,8.0283,0,0,0-.86059-.363c-.05152-.01831-.10425-.03125-.156-.04858q-.36695-.12121-.7456-.207c-.082-.01855-.16407-.03515-.24659-.051q-.35778-.06921-.72338-.105c-.06934-.00708-.13843-.01709-.208-.02222a7.93012,7.93012,0,0,0-.94019-.01684l-.02392.00219a7.97484,7.97484,0,0,0-.8833.09571c-.1001.01611-.19874.03857-.29834.05859-.12623.0249-.25245.04273-.37867.07422l-64,16A7.99985,7.99985,0,0,0,23.99975,56V200a8.00045,8.00045,0,0,0,9.94043,7.76123L95.06909,192.479l61.35254,30.67627c.03637.01807.0747.03.11133.04761q.32482.15673.66308.28442c.04175.01563.08277.0337.125.04883a7.95445,7.95445,0,0,0,.81494.24146c.04273.01025.08545.01782.12818.02734q.36034.0802.72925.12671c.05078.00659.10131.01392.15234.01929a7.29318,7.29318,0,0,0,1.89233-.02222c.11182-.01465.22144-.04248.33277-.06177.18994-.0332.37939-.05835.56933-.10571l64-16A8,8,0,0,0,231.99975,200V56A7.99871,7.99871,0,0,0,228.9226,49.69434ZM151.99975,203.05566l-48-24V52.94434l48,24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 184 32 200 32 56 96 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "160 216 96 184 96 40 160 72 160 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "160 72 224 56 224 200 160 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 184 32 200 32 56 96 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "160 216 96 184 96 40 160 72 160 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "160 72 224 56 224 200 160 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "96 184 32 200 32 56 96 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "160 216 96 184 96 40 160 72 160 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 72 224 56 224 200 160 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MapTrifold = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6K(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MapTrifold.displayName = "MapTrifold";

var renderPathFor$6L = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "24 40 232 40 128 144 24 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "144",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "216",
        x2: "168",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "60",
        y1: "76",
        x2: "196",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "56 72 200 72 128 144 56 72",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "24 40 232 40 128 144 24 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "144",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "216",
        x2: "168",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "72",
        x2: "200",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M237.65723,45.65674A8.0001,8.0001,0,0,0,232,32H24a8.0001,8.0001,0,0,0-5.65723,13.65674L120,147.314V208H88a8,8,0,0,0,0,16h80a8,8,0,0,0,0-16H136V147.314ZM212.68652,48l-16,16H59.31348l-16-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "24 40 232 40 128 144 24 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "144",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "216",
        x2: "168",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "72",
        x2: "200",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "24 40 232 40 128 144 24 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "144",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "216",
        x2: "168",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "72",
        x2: "200",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "24 40 232 40 128 144 24 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "144",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "216",
        x2: "168",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "72",
        x2: "200",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Martini = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6L(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Martini.displayName = "Martini";

var renderPathFor$6M = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "184",
        x2: "104",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "152",
        x2: "72",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "72",
        x2: "40",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "164.0664",
        x2: "152",
        y2: "164.0664",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "203.9336",
        x2: "152",
        y2: "203.9336",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "96",
        x2: "160",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "184",
        x2: "104",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "152",
        x2: "72",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "72",
        x2: "40",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "168.0664",
        x2: "152",
        y2: "168.0664",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "199.9336",
        x2: "152",
        y2: "199.9336",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "96",
        x2: "160",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M104,176H80V152a8,8,0,0,0-16,0v24H40a8,8,0,0,0,0,16H64v24a8,8,0,0,0,16,0V192h24a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M104,64H40a8,8,0,0,0,0,16h64a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M152,176.06641h64a8,8,0,0,0,0-16H152a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M216,191.93359H152a8,8,0,0,0,0,16h64a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M154.34326,101.65674a7.99945,7.99945,0,0,0,11.31348,0L184,83.31348l18.34326,18.34326a7.99984,7.99984,0,1,0,11.31348-11.31348L195.3136,72l18.34314-18.34326a7.99984,7.99984,0,0,0-11.31348-11.31348L184,60.68652,165.65674,42.34326a7.99984,7.99984,0,0,0-11.31348,11.31348L172.6864,72,154.34326,90.34326A7.99915,7.99915,0,0,0,154.34326,101.65674Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "184",
        x2: "104",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "152",
        x2: "72",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "72",
        x2: "40",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "168.0664",
        x2: "152",
        y2: "168.0664",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "199.9336",
        x2: "152",
        y2: "199.9336",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "96",
        x2: "160",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "184",
        x2: "104",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "152",
        x2: "72",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "72",
        x2: "40",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "168.0664",
        x2: "152",
        y2: "168.0664",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "199.9336",
        x2: "152",
        y2: "199.9336",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "96",
        x2: "160",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "184",
        x2: "104",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "152",
        x2: "72",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "72",
        x2: "40",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "168.0664",
        x2: "152",
        y2: "168.0664",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "199.9336",
        x2: "152",
        y2: "199.9336",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "96",
        x2: "160",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MathOperations = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6M(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MathOperations.displayName = "MathOperations";

var renderPathFor$6N = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "96",
        r: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "176 159.995 176 240 127.993 216 80 240 80 160.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "96",
        r: "48",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "96",
        r: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "96",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "176 159.995 176 240 127.993 216 80 240 80 160.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "96",
        r: "56"
      }), React__default.createElement("path", {
        d: "M127.99414,8A87.96624,87.96624,0,0,0,72,163.8374V240a7.99951,7.99951,0,0,0,11.57812,7.15527l44.415-22.21093,44.42969,22.21142A8,8,0,0,0,184,240V163.82764A87.96617,87.96617,0,0,0,127.99414,8Zm0,160a72,72,0,1,1,72-72A72.08124,72.08124,0,0,1,127.99414,168Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "96",
        r: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "96",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "176 159.995 176 240 127.993 216 80 240 80 160.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "96",
        r: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "96",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "176 159.995 176 240 127.993 216 80 240 80 160.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.99414",
        cy: "96",
        r: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "96",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "176 159.995 176 240 127.993 216 80 240 80 160.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Medal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6N(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Medal.displayName = "Medal";

var renderPathFor$6O = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "24.03516",
        y1: "48.00094",
        x2: "40.03516",
        y2: "48.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "120.03516",
        y1: "48.00094",
        x2: "136.03516",
        y2: "48.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "24.03516",
        y1: "128.00094",
        x2: "48.03516",
        y2: "128.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "112.03516",
        y1: "128.00094",
        x2: "136.03516",
        y2: "128.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176.03516",
        y1: "88.00094",
        x2: "240.03516",
        y2: "88.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176.03516",
        y1: "128.00094",
        x2: "240.03516",
        y2: "128.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "72.03516",
        y1: "168.00094",
        x2: "240.03516",
        y2: "168.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "72.03516",
        y1: "208.00094",
        x2: "240.03516",
        y2: "208.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "40.035 128.001 40.035 48.001 80.035 112.001 120.035 48.001 120.035 128.001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "24.01172",
        y1: "56.00094",
        x2: "40.01172",
        y2: "56.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120.01172",
        y1: "56.00094",
        x2: "136.01172",
        y2: "56.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "24.01172",
        y1: "136.00094",
        x2: "48.01172",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112.01172",
        y1: "136.00094",
        x2: "136.01172",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168.01172",
        y1: "104.00094",
        x2: "240.01172",
        y2: "104.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168.01172",
        y1: "136.00094",
        x2: "240.01172",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72.01172",
        y1: "168.00094",
        x2: "240.01172",
        y2: "168.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72.01172",
        y1: "200.00094",
        x2: "240.01172",
        y2: "200.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "40.012 136.001 40.012 56.001 80.012 120.001 120.012 56.001 120.012 136.001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M48.02344,128.00094V83.89547l25.21582,40.34571a8.00063,8.00063,0,0,0,13.56836,0l25.21582-40.34571v44.10547a8,8,0,0,0,0,16h24a8,8,0,0,0,0-16h-8v-64h8a8,8,0,0,0,0-16h-16c-.04,0-.07862.00537-.11817.00586-.15478.00244-.3081.01221-.46191.02344-.11768.0083-.23584.01611-.35205.0293-.12793.01513-.2544.03711-.38135.05859-.13769.02246-.27539.04443-.41064.07422-.103.02246-.20459.05176-.30664.07861-.15088.03955-.30176.07862-.44922.12647-.09424.03076-.186.06836-.2793.10254-.11816.04345-.23926.08105-.35449.12988-.02881.01172-.05518.02734-.0835.04-.104.04492-.20459.09814-.30713.14746-.125.06152-.25146.12061-.373.188s-.23877.14355-.35743.21728c-.09619.06006-.19384.11719-.28711.18116-.1289.08837-.25244.18554-.37695.28173-.07812.061-.1582.11914-.23437.18262-.11914.09961-.23243.20752-.3462.31494-.0581.05469-.12109.10449-.17724.16114-.01807.01757-.0332.03759-.05078.05566-.09766.09961-.18994.20557-.28321.31152-.05957.06787-.125.13086-.18261.20069-.02344.02832-.043.05957-.06592.08838-.07373.09228-.14307.189-.21289.28515-.09082.124-.18067.249-.26416.37842-.02149.0332-.04639.063-.06787.09668l-33.21582,53.146-33.21582-53.146c-.02149-.03369-.04639-.06348-.06787-.09668-.0835-.1294-.17334-.2544-.26416-.37842-.06983-.09619-.13916-.19287-.2129-.28515-.02294-.02881-.043-.06006-.06591-.08838-.05762-.06983-.12256-.13282-.18262-.20069-.09326-.10547-.18555-.21191-.2832-.312-.01758-.01758-.03321-.0376-.05078-.05517-.05616-.05616-.11866-.106-.17627-.16065-.11426-.10791-.228-.21582-.34766-.31592-.0752-.063-.1543-.12011-.23193-.18017-.125-.09717-.24952-.19483-.3794-.28369-.09277-.064-.19043-.1211-.28613-.18116-.11865-.07373-.23584-.14941-.35791-.21679-.12256-.06836-.25-.12793-.37647-.19-.10058-.04882-.20019-.10107-.30273-.1455-.02881-.0127-.05566-.02881-.08447-.04053-.1167-.04981-.23926-.08789-.35889-.13184-.09131-.0332-.18164-.06982-.27393-.10009-.14843-.04834-.30127-.08789-.45361-.12745-.10059-.02636-.20068-.05566-.30225-.07812-.1372-.02979-.27636-.05225-.416-.0752-.125-.0205-.249-.04248-.375-.05712-.11817-.01368-.23828-.02149-.35791-.02979-.15186-.01123-.30322-.02051-.45557-.02344-.04052-.00049-.08008-.00586-.1206-.00586h-16a8,8,0,0,0,0,16h8v64h-8a8,8,0,1,0,0,16h24a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M168.02344,112.00094h72a8,8,0,0,0,0-16h-72a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M240.02344,128.00094h-72a8,8,0,0,0,0,16h72a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M240.02344,160.00094h-168a8,8,0,0,0,0,16h168a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M240.02344,192.00094h-168a8,8,0,0,0,0,16h168a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "24.04688",
        y1: "56.00094",
        x2: "40.04688",
        y2: "56.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "120.04688",
        y1: "56.00094",
        x2: "136.04688",
        y2: "56.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "24.04688",
        y1: "136.00094",
        x2: "48.04688",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "112.04688",
        y1: "136.00094",
        x2: "136.04688",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "168.04688",
        y1: "104.00094",
        x2: "240.04688",
        y2: "104.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "168.04688",
        y1: "136.00094",
        x2: "240.04688",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72.04688",
        y1: "168.00094",
        x2: "240.04688",
        y2: "168.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72.04688",
        y1: "200.00094",
        x2: "240.04688",
        y2: "200.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "40.047 136.001 40.047 56.001 80.047 120.001 120.047 56.001 120.047 136.001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "24.05859",
        y1: "56.00094",
        x2: "40.05859",
        y2: "56.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "120.05859",
        y1: "56.00094",
        x2: "136.05859",
        y2: "56.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "24.05859",
        y1: "136.00094",
        x2: "48.05859",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "112.05859",
        y1: "136.00094",
        x2: "136.05859",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "168.05859",
        y1: "104.00094",
        x2: "240.05859",
        y2: "104.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "168.05859",
        y1: "136.00094",
        x2: "240.05859",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72.05859",
        y1: "168.00094",
        x2: "240.05859",
        y2: "168.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72.05859",
        y1: "200.00094",
        x2: "240.05859",
        y2: "200.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "40.059 136.001 40.059 56.001 80.059 120.001 120.059 56.001 120.059 136.001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "24.07031",
        y1: "56.00094",
        x2: "40.07031",
        y2: "56.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120.07031",
        y1: "56.00094",
        x2: "136.07031",
        y2: "56.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "24.07031",
        y1: "136.00094",
        x2: "48.07031",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112.07031",
        y1: "136.00094",
        x2: "136.07031",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168.07031",
        y1: "104.00094",
        x2: "240.07031",
        y2: "104.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168.07031",
        y1: "136.00094",
        x2: "240.07031",
        y2: "136.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72.07031",
        y1: "168.00094",
        x2: "240.07031",
        y2: "168.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72.07031",
        y1: "200.00094",
        x2: "240.07031",
        y2: "200.00094",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "40.07 136.001 40.07 56.001 80.07 120.001 120.07 56.001 120.07 136.001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MediumLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6O(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MediumLogo.displayName = "MediumLogo";

var renderPathFor$6P = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M143.99951,79.46017V203.05573a8,8,0,0,0,4.42229,7.15542L167.07945,219.54a8,8,0,0,0,11.33885-5.21513L191.99951,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M191.99951,160a40,40,0,0,0,0-80h-40S97.54779,80,45.14845,36.05237a7.99844,7.99844,0,0,0-13.14894,6.11524V197.83239a7.99844,7.99844,0,0,0,13.14894,6.11524C97.54779,160,151.99951,160,151.99951,160Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M151.99951,160h40a40,40,0,0,0,0-80h-40Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M151.99951,80V203.71853a8,8,0,0,0,3.5624,6.6564L166.554,217.703a8,8,0,0,0,12.19875-4.71612L191.99951,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M191.99951,160a40,40,0,0,0,0-80h-40S97.54779,80,45.14845,36.05237a7.99844,7.99844,0,0,0-13.14894,6.11524V197.83239a7.99844,7.99844,0,0,0,13.14894,6.11524C97.54779,160,151.99951,160,151.99951,160Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,120a48.055,48.055,0,0,0-48-48H152.0166c-.51855-.00195-52.38086-.68945-101.72656-42.07617A15.999,15.999,0,0,0,23.999,42.168V197.832a15.83932,15.83932,0,0,0,9.2295,14.49121,16.07273,16.07273,0,0,0,6.80664,1.52539,15.91249,15.91249,0,0,0,10.2539-3.77148C88.1665,178.30859,127.52344,170.521,144,168.61572v35.103a15.965,15.965,0,0,0,7.124,13.3125l10.99317,7.3291a16.00058,16.00058,0,0,0,24.39648-9.43262L198.354,167.56641A48.06327,48.06327,0,0,0,240,120Zm-69.00879,91.04688L160,203.71875V168h21.75391ZM192,152H160V88h32a32,32,0,0,1,0,64Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M151.99951,80V203.71853a8,8,0,0,0,3.5624,6.6564L166.554,217.703a8,8,0,0,0,12.19875-4.71612L191.99951,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M191.99951,160a40,40,0,0,0,0-80h-40S97.54779,80,45.14845,36.05237a7.99844,7.99844,0,0,0-13.14894,6.11524V197.83239a7.99844,7.99844,0,0,0,13.14894,6.11524C97.54779,160,151.99951,160,151.99951,160Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M151.99951,80V203.71853a8,8,0,0,0,3.5624,6.6564L166.554,217.703a8,8,0,0,0,12.19875-4.71612L191.99951,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M191.99951,160a40,40,0,0,0,0-80h-40S97.54779,80,45.14845,36.05237a7.99844,7.99844,0,0,0-13.14894,6.11524V197.83239a7.99844,7.99844,0,0,0,13.14894,6.11524C97.54779,160,151.99951,160,151.99951,160Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M152,80V203.71853a8,8,0,0,0,3.5624,6.6564l10.99213,7.32809a8,8,0,0,0,12.19874-4.71612L192,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M192,160a40,40,0,0,0,0-80H152S97.54828,80,45.14894,36.05237A7.99844,7.99844,0,0,0,32,42.16761V197.83239a7.99844,7.99844,0,0,0,13.14894,6.11524C97.54828,160,152,160,152,160Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Megaphone = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6P(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Megaphone.displayName = "Megaphone";

var renderPathFor$6Q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M127.99991,24H128a40,40,0,0,1,40,40v56a40,40,0,0,1-40,40h-.00008A39.99991,39.99991,0,0,1,88,120.00009V63.99991A39.99991,39.99991,0,0,1,127.99991,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M208,120a80,80,0,0,1-160,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "200",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M127.99991,24H128a40,40,0,0,1,40,40v64a40,40,0,0,1-40,40h-.00008A39.99991,39.99991,0,0,1,88,128.00009V63.99991A39.99991,39.99991,0,0,1,127.99991,24Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M127.99991,24H128a40,40,0,0,1,40,40v64a40,40,0,0,1-40,40h-.00008A39.99991,39.99991,0,0,1,88,128.00009V63.99991A39.99991,39.99991,0,0,1,127.99991,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "200",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M199.56055,136.00017a72.00715,72.00715,0,0,1-143.12111-.00011",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M127.99414,175.99609a48.05083,48.05083,0,0,0,48-47.99218V63.99609a48,48,0,1,0-96,0v64A48.05249,48.05249,0,0,0,127.99414,175.99609Z"
      }), React__default.createElement("path", {
        d: "M200.43164,128.05078a8.07828,8.07828,0,0,0-8.82812,7.07813,64.00856,64.00856,0,0,1-127.21875-.00782,8.09865,8.09865,0,0,0-8.82813-7.07031,8.01056,8.01056,0,0,0-7.07812,8.83594A79.60051,79.60051,0,0,0,119.99414,207.251v24.74511a8,8,0,1,0,16,0V207.252a79.577,79.577,0,0,0,71.51563-70.373A8.00321,8.00321,0,0,0,200.43164,128.05078Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M127.99991,24H128a40,40,0,0,1,40,40v64a40,40,0,0,1-40,40h-.00008A39.99991,39.99991,0,0,1,88,128.00009V63.99991A39.99991,39.99991,0,0,1,127.99991,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "200",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M199.56055,136.00017a72.00715,72.00715,0,0,1-143.12111-.00011",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M127.99991,24H128a40,40,0,0,1,40,40v64a40,40,0,0,1-40,40h-.00008A39.99991,39.99991,0,0,1,88,128.00009V63.99991A39.99991,39.99991,0,0,1,127.99991,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "200",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M199.56055,136.00017a72.00715,72.00715,0,0,1-143.12111-.00011",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M127.99991,24H128a40,40,0,0,1,40,40v64a40,40,0,0,1-40,40h-.00008A39.99991,39.99991,0,0,1,88,128.00009V63.99991A39.99991,39.99991,0,0,1,127.99991,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "200",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M199.56055,136.00017a72.00715,72.00715,0,0,1-143.12111-.00011",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Microphone = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6Q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Microphone.displayName = "Microphone";

var renderPathFor$6R = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "200",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M150.68227,152.95168A39.81525,39.81525,0,0,1,128.00009,160H128a40,40,0,0,1-40-40V84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M98.91341,36.54133A39.88791,39.88791,0,0,1,128,24h.00008A39.99991,39.99991,0,0,1,168,63.99991v48.53544",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M177.71207,182.68344A80.00376,80.00376,0,0,1,48,120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M208,120a79.77285,79.77285,0,0,1-5.85339,30.09425",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M127.99991,24H128a40,40,0,0,1,40,40v64a40,40,0,0,1-40,40h-.00008A39.99991,39.99991,0,0,1,88,128.00009V63.99991A39.99991,39.99991,0,0,1,127.99991,24Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M176.42693,181.28138A72.00558,72.00558,0,0,1,56.43944,136.00006",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M154.90249,157.60205A39.85421,39.85421,0,0,1,128.00009,168H128a40,40,0,0,1-40-40V84.00214",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "200",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M93.95906,42.98434A39.97457,39.97457,0,0,1,128,24h.00008A39.99991,39.99991,0,0,1,168,63.99991V124.4291",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M199.56055,136.00017a71.54827,71.54827,0,0,1-4.48193,18.2151",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M213.91992,210.61816l-160-176A8.0006,8.0006,0,1,0,42.08008,45.38184L80,87.09375V128a47.9902,47.9902,0,0,0,73.91211,40.39685l10.875,11.96252A63.99208,63.99208,0,0,1,64.39062,135.12109a7.9996,7.9996,0,0,0-15.90234,1.75782A79.83705,79.83705,0,0,0,120,207.59692V232a8,8,0,0,0,16,0V207.59082a79.72,79.72,0,0,0,39.62012-15.31506l26.46,29.10608a8.0006,8.0006,0,1,0,11.83984-10.76368Z"
      }), React__default.createElement("path", {
        d: "M162.08008,129.81055A8.0004,8.0004,0,0,0,176,124.42871V64A48.0045,48.0045,0,0,0,87.15527,38.77539a8.00113,8.00113,0,0,0,.88379,9.59082Z"
      }), React__default.createElement("path", {
        d: "M192.165,161.665a7.99262,7.99262,0,0,0,10.36426-4.53613,79.61568,79.61568,0,0,0,4.98242-20.25,7.9996,7.9996,0,0,0-15.90235-1.75782,63.67417,63.67417,0,0,1-3.98046,16.17969A7.99991,7.99991,0,0,0,192.165,161.665Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "200",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M154.90713,157.59783A39.85426,39.85426,0,0,1,128.00009,168H128a40,40,0,0,1-40-40V84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M176.43278,181.27606a72.00558,72.00558,0,0,1-119.99334-45.276",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M199.56055,136.00017a71.52052,71.52052,0,0,1-6.20937,22.26059",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M93.95908,42.98431A39.97458,39.97458,0,0,1,128,24h.00008A39.99991,39.99991,0,0,1,168,63.99991V124.4291",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "200",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M176.43278,181.27606a72.00558,72.00558,0,0,1-119.99334-45.276",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M154.90713,157.59783A39.85426,39.85426,0,0,1,128.00009,168H128a40,40,0,0,1-40-40V84.0087",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M93.95908,42.98431A39.97458,39.97458,0,0,1,128,24h.00008A39.99991,39.99991,0,0,1,168,63.99991V124.4291",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M199.56055,136.00017a71.54833,71.54833,0,0,1-4.482,18.21516",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176.42693,181.28138A72.00558,72.00558,0,0,1,56.43944,136.00006",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M154.90249,157.60205A39.85421,39.85421,0,0,1,128.00009,168H128a40,40,0,0,1-40-40V84.00214",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "200",
        x2: "128",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M93.95906,42.98434A39.97457,39.97457,0,0,1,128,24h.00008A39.99991,39.99991,0,0,1,168,63.99991V124.4291",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M199.56055,136.00017a71.54827,71.54827,0,0,1-4.48193,18.2151",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MicrophoneSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6R(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MicrophoneSlash.displayName = "MicrophoneSlash";

var renderPathFor$6S = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,136H40a8,8,0,0,1,0-16H216a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Minus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6S(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Minus.displayName = "Minus";

var renderPathFor$6T = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm40,112H88a8,8,0,0,1,0-16h80a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MinusCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6T(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MinusCircle.displayName = "MinusCircle";

var renderPathFor$6U = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "16",
        y: "64",
        width: "224",
        height: "128",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "172",
        y1: "64",
        x2: "240",
        y2: "124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "172",
        y1: "192",
        x2: "240",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "84",
        y1: "64",
        x2: "16",
        y2: "124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "84",
        y1: "192",
        x2: "16",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32"
      }), React__default.createElement("path", {
        d: "M232,64H176l64,56V72A7.99993,7.99993,0,0,0,232,64Z"
      }), React__default.createElement("path", {
        d: "M232,192a7.99993,7.99993,0,0,0,8-8V136l-64,56Z"
      }), React__default.createElement("path", {
        d: "M16,72v48L80,64H24A7.99993,7.99993,0,0,0,16,72Z"
      }), React__default.createElement("path", {
        d: "M16,184a7.99993,7.99993,0,0,0,8,8H80L16,136Z"
      })), React__default.createElement("rect", {
        x: "16",
        y: "64",
        width: "224",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "64",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "192",
        x2: "240",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "64",
        x2: "16",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "192",
        x2: "16",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232,56H24A16.01833,16.01833,0,0,0,8,72V184a16.01833,16.01833,0,0,0,16,16H232a16.01833,16.01833,0,0,0,16-16V72A16.01833,16.01833,0,0,0,232,56ZM74.95947,184,24,140.32056V115.67944L74.95947,72H181.04053l50.96338,43.68262.002,24.63281L181.04053,184ZM168,128a40,40,0,1,1-40-40A40.04584,40.04584,0,0,1,168,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "16",
        y: "64",
        width: "224",
        height: "128",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "64",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "192",
        x2: "240",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "64",
        x2: "16",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "192",
        x2: "16",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "16",
        y: "64",
        width: "224",
        height: "128",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "64",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "192",
        x2: "240",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "64",
        x2: "16",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "192",
        x2: "16",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "16",
        y: "64",
        width: "224",
        height: "128",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "64",
        x2: "240",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "192",
        x2: "240",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "64",
        x2: "16",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "192",
        x2: "16",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Money = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6U(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Money.displayName = "Money";

var renderPathFor$6V = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "228",
        x2: "96",
        y2: "228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("rect", {
        x: "24",
        y: "40.0002",
        width: "208",
        height: "160",
        rx: "24"
      }), React__default.createElement("path", {
        d: "M160,216.0002H96a8,8,0,0,0,0,16h64a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Monitor = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6V(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Monitor.displayName = "Monitor";

var renderPathFor$6W = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "228",
        x2: "96",
        y2: "228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "164 120 108 84 108 156 164 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,48H48A16.00016,16.00016,0,0,0,32,64V176a16.00016,16.00016,0,0,0,16,16H208a16.00016,16.00016,0,0,0,16-16V64A16.00016,16.00016,0,0,0,208,48ZM112,152V88l48,32Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "160 120 112 88 112 152 160 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,224.00024a8.00039,8.00039,0,0,1-8,8H96a8,8,0,1,1,0-16h64A8.0004,8.0004,0,0,1,168,224.00024Zm64-160v112a24.0275,24.0275,0,0,1-24,24H48a24.0275,24.0275,0,0,1-24-24v-112a24.0275,24.0275,0,0,1,24-24H208A24.0275,24.0275,0,0,1,232,64.00024ZM168,120a8.02148,8.02148,0,0,0-3.5625-6.65625l-48-32A7.99612,7.99612,0,0,0,104,88v64a7.99975,7.99975,0,0,0,12.4375,6.65625l48-32A8.02151,8.02151,0,0,0,168,120Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "160 120 112 88 112 152 160 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "160 120 112 88 112 152 160 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "144",
        rx: "16",
        transform: "translate(256 240) rotate(180)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "224",
        x2: "96",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "160 120 112 88 112 152 160 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MonitorPlay = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6W(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MonitorPlay.displayName = "MonitorPlay";

var renderPathFor$6X = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M229.36426,151.35791A104.00619,104.00619,0,1,1,104.64111,26.63574a7.99975,7.99975,0,0,1,9.58741,9.58545A88.0856,88.0856,0,0,0,219.77734,141.77051a8.00049,8.00049,0,0,1,9.58692,9.5874Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Moon = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6X(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Moon.displayName = "Moon";

var renderPathFor$6Y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "220",
        y1: "108",
        x2: "220",
        y2: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "244",
        y1: "84",
        x2: "196",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "164",
        y1: "20",
        x2: "164",
        y2: "52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "180",
        y1: "36",
        x2: "148",
        y2: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "112",
        x2: "216",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "88",
        x2: "192",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "24",
        x2: "168",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "40",
        x2: "152",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M248,88a8.00008,8.00008,0,0,1-8,8H224v16a8,8,0,0,1-16,0V96H192a8,8,0,0,1,0-16h16V64a8,8,0,0,1,16,0V80h16A8.00008,8.00008,0,0,1,248,88ZM152,48h8v8a8,8,0,0,0,16,0V48h8a8,8,0,0,0,0-16h-8V24a8,8,0,0,0-16,0v8h-8a8,8,0,0,0,0,16Zm67.77734,93.77051A88.08879,88.08879,0,0,1,114.22852,36.22119a7.99975,7.99975,0,0,0-9.58741-9.58545A104.00615,104.00615,0,1,0,229.36426,151.35791a8.00049,8.00049,0,0,0-9.58692-9.5874Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "112",
        x2: "216",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "88",
        x2: "192",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "24",
        x2: "168",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "40",
        x2: "152",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "112",
        x2: "216",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "88",
        x2: "192",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "24",
        x2: "168",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "40",
        x2: "152",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "216",
        y1: "112",
        x2: "216",
        y2: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "88",
        x2: "192",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "24",
        x2: "168",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "40",
        x2: "152",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M221.567,149.56784A96.0849,96.0849,0,0,1,106.43219,34.43294l-.00127-.00029A96.01213,96.01213,0,1,0,221.56729,149.56932Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MoonStars = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6Y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MoonStars.displayName = "MoonStars";

var renderPathFor$6Z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "52",
        y: "24",
        width: "152",
        height: "208",
        rx: "56",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "52",
        y1: "104",
        x2: "204",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "104",
        x2: "128.00007",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104l.00007-80H108A56,56,0,0,0,52,80v24Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "52",
        y: "24",
        width: "152",
        height: "208",
        rx: "56",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "52",
        y1: "104",
        x2: "204",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "104",
        x2: "128.00007",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M148,16H108A64.07239,64.07239,0,0,0,44,80v96a64.07239,64.07239,0,0,0,64,64h40a64.07239,64.07239,0,0,0,64-64V80A64.07239,64.07239,0,0,0,148,16Zm48,64V96H136V32h12A48.05468,48.05468,0,0,1,196,80ZM108,32h12V96H60V80A48.05468,48.05468,0,0,1,108,32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "52",
        y: "24",
        width: "152",
        height: "208",
        rx: "56",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "52",
        y1: "104",
        x2: "204",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "104",
        x2: "128.00007",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "52",
        y: "24",
        width: "152",
        height: "208",
        rx: "56",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "52",
        y1: "104",
        x2: "204",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "104",
        x2: "128.00007",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "52",
        y: "24",
        width: "152",
        height: "208",
        rx: "56",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "52",
        y1: "104",
        x2: "204",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "104",
        x2: "128.00007",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Mouse = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6Z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Mouse.displayName = "Mouse";

var renderPathFor$6_ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "128 184 128 40 208 64 208 112 128 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 184 128 40 208 64 208 112 128 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M210.29883,56.3374l-80-24A7.99991,7.99991,0,0,0,120,40V87.82031q-.0044.1831,0,.36573v60.07519A47.97353,47.97353,0,1,0,136,184V98.75195l69.70117,20.91065A7.99991,7.99991,0,0,0,216,112V64A7.99972,7.99972,0,0,0,210.29883,56.3374Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "128 184 128 40 208 64 208 112 128 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "128 184 128 40 208 64 208 112 128 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 184 128 40 208 64 208 112 128 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MusicNote = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6_(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MusicNote.displayName = "MusicNote";

var renderPathFor$6$ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "128 184 128 40 208 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 184 128 40 208 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M210.29883,56.3374l-80-24A7.99991,7.99991,0,0,0,120,40V148.26123A47.97353,47.97353,0,1,0,136,184V50.75244L205.70117,71.6626a8,8,0,1,0,4.59766-15.3252Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "128 184 128 40 208 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "128 184 128 40 208 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "184",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 184 128 40 208 64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MusicNoteSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$6$(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MusicNoteSimple.displayName = "MusicNoteSimple";

var renderPathFor$70 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "80",
        x2: "80",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "80 204 80 64 208 32 208 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "80",
        x2: "80",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "80 204 80 64 208 32 208 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M212.916,25.69144a7.896,7.896,0,0,0-6.85938-1.45313l-128,32a7.99686,7.99686,0,0,0-6.0625,7.75782v110.0957a35.98113,35.98113,0,1,0,16,29.9043V110.23831l112-28v59.85352a35.98113,35.98113,0,1,0,16,29.9043v-140A8.01525,8.01525,0,0,0,212.916,25.69144Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "80",
        x2: "80",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "80 204 80 64 208 32 208 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "80",
        x2: "80",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "80 204 80 64 208 32 208 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "80",
        x2: "80",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "80 204 80 64 208 32 208 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MusicNotes = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$70(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MusicNotes.displayName = "MusicNotes";

var renderPathFor$71 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "80 204 80 64 208 32 208 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "80 204 80 64 208 32 208 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M212.92285,25.69434a7.99949,7.99949,0,0,0-6.86328-1.45557l-128,32A7.99964,7.99964,0,0,0,72,64V174.0835A35.98908,35.98908,0,1,0,88,204V70.24609l112-28V142.0835A35.98908,35.98908,0,1,0,216,172V32A7.99874,7.99874,0,0,0,212.92285,25.69434Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "80 204 80 64 208 32 208 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "80 204 80 64 208 32 208 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "180",
        cy: "172",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "80 204 80 64 208 32 208 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var MusicNotesSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$71(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
MusicNotesSimple.displayName = "MusicNotesSimple";

var renderPathFor$72 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M37.39014,47.56448l58.605,169.30343a8,8,0,0,0,15.20612-.2642l23.5556-76.5557a8,8,0,0,1,5.29355-5.29355l76.5557-23.5556a8,8,0,0,0,.2642-15.20612L47.56692,37.3877A8,8,0,0,0,37.39014,47.56448Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M37.39014,47.56448l58.605,169.30343a8,8,0,0,0,15.20612-.2642l23.5556-76.5557a8,8,0,0,1,5.29355-5.29355l76.5557-23.5556a8,8,0,0,0,.2642-15.20612L47.56692,37.3877A8,8,0,0,0,37.39014,47.56448Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M37.39014,47.56448l58.605,169.30343a8,8,0,0,0,15.20612-.2642l23.5556-76.5557a8,8,0,0,1,5.29355-5.29355l76.5557-23.5556a8,8,0,0,0,.2642-15.20612L47.56692,37.3877A8,8,0,0,0,37.39014,47.56448Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.4873,88.43359,50.18457,29.82812A15.99955,15.99955,0,0,0,29.83105,50.18164l58.6045,169.30371A15.75666,15.75666,0,0,0,103.53516,230.251c.09863,0,.19922-.001.29785-.00293a15.76424,15.76424,0,0,0,15.01465-11.292l23.55566-76.55468L218.96,118.8457a16.00021,16.00021,0,0,0,.52734-30.41211Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M37.39014,47.56448l58.605,169.30343a8,8,0,0,0,15.20612-.2642l23.5556-76.5557a8,8,0,0,1,5.29355-5.29355l76.5557-23.5556a8,8,0,0,0,.2642-15.20612L47.56692,37.3877A8,8,0,0,0,37.39014,47.56448Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M37.39014,47.56448l58.605,169.30343a8,8,0,0,0,15.20612-.2642l23.5556-76.5557a8,8,0,0,1,5.29355-5.29355l76.5557-23.5556a8,8,0,0,0,.2642-15.20612L47.56692,37.3877A8,8,0,0,0,37.39014,47.56448Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M37.39014,47.56448l58.605,169.30343a8,8,0,0,0,15.20612-.2642l23.5556-76.5557a8,8,0,0,1,5.29355-5.29355l76.5557-23.5556a8,8,0,0,0,.2642-15.20612L47.56692,37.3877A8,8,0,0,0,37.39014,47.56448Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NavigationArrow = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$72(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NavigationArrow.displayName = "NavigationArrow";

var renderPathFor$73 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "92",
        y1: "92",
        x2: "196",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "92",
        y1: "128",
        x2: "196",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "92",
        y1: "164",
        x2: "196",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,208H216a20,20,0,0,0,20-20V56a8,8,0,0,0-8-8H60a8,8,0,0,0-8,8V188a20,20,0,0,1-40,0V80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,208a16,16,0,0,0,16-16V56a8,8,0,0,1,8-8H224a8,8,0,0,1,8,8V192a16,16,0,0,1-16,16Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "96",
        x2: "192",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "192",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "160",
        x2: "192",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,208a16,16,0,0,0,16-16V56a8,8,0,0,1,8-8H224a8,8,0,0,1,8,8V192a16,16,0,0,1-16,16Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,208a16,16,0,0,1-16-16V80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,40H56A16.01833,16.01833,0,0,0,40,56V192a8,8,0,0,1-16,0V80A8,8,0,0,0,8,80V192.10645A24.02715,24.02715,0,0,0,32,216H216a24.0275,24.0275,0,0,0,24-24V56A16.01833,16.01833,0,0,0,224,40ZM192,168H88a8,8,0,0,1,0-16H192a8,8,0,0,1,0,16Zm0-32H88a8,8,0,0,1,0-16H192a8,8,0,0,1,0,16Zm0-32H88a8,8,0,0,1,0-16H192a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "88",
        y1: "96",
        x2: "192",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "192",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "160",
        x2: "192",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,208a16,16,0,0,0,16-16V56a8,8,0,0,1,8-8H224a8,8,0,0,1,8,8V192a16,16,0,0,1-16,16Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,208a16,16,0,0,1-16-16V80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "88",
        y1: "96",
        x2: "192",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "192",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "160",
        x2: "192",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,208a16,16,0,0,0,16-16V56a8,8,0,0,1,8-8H224a8,8,0,0,1,8,8V192a16,16,0,0,1-16,16Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,208a16,16,0,0,1-16-16V80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "88",
        y1: "96",
        x2: "192",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "192",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "160",
        x2: "192",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,208a16,16,0,0,0,16-16V56a8,8,0,0,1,8-8H224a8,8,0,0,1,8,8V192a16,16,0,0,1-16,16Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,208a16,16,0,0,1-16-16V80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Newspaper = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$73(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Newspaper.displayName = "Newspaper";

var renderPathFor$74 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,216V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V216l-32-16-32,16-32-16L96,216,64,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "108",
        x2: "184",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "148",
        x2: "184",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "72",
        y: "96",
        width: "40",
        height: "64",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,48H40a8.00009,8.00009,0,0,0-8,8V216l32-16,32,16,32-16,32,16,32-16,32,16V56A8.00009,8.00009,0,0,0,216,48ZM112,160H64V96h48Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M32,216V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V216l-32-16-32,16-32-16L96,216,64,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "144",
        x2: "192",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "64",
        y: "96",
        width: "48",
        height: "64",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M72,104h32v48H72ZM232,56V216a7.99951,7.99951,0,0,1-11.57812,7.15527L192,208.94434l-28.42188,14.21093a8.00049,8.00049,0,0,1-7.15624,0L128,208.94434,99.57812,223.15527a7.99634,7.99634,0,0,1-7.15624,0L64,208.94434,35.57812,223.15527A7.99951,7.99951,0,0,1,24,216V56A16.01833,16.01833,0,0,1,40,40H216A16.01833,16.01833,0,0,1,232,56ZM120,96a8.00039,8.00039,0,0,0-8-8H64a8.00039,8.00039,0,0,0-8,8v64a8.00039,8.00039,0,0,0,8,8h48a8.00039,8.00039,0,0,0,8-8Zm80,48a8.00039,8.00039,0,0,0-8-8H144a8,8,0,0,0,0,16h48A8.00039,8.00039,0,0,0,200,144Zm0-32a8.00039,8.00039,0,0,0-8-8H144a8,8,0,0,0,0,16h48A8.00039,8.00039,0,0,0,200,112Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,216V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V216l-32-16-32,16-32-16L96,216,64,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "144",
        x2: "192",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "64",
        y: "96",
        width: "48",
        height: "64",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,216V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V216l-32-16-32,16-32-16L96,216,64,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "144",
        x2: "192",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "64",
        y: "96",
        width: "48",
        height: "64",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,216V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V216l-32-16-32,16-32-16L96,216,64,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "112",
        x2: "192",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "144",
        x2: "192",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "64",
        y: "96",
        width: "48",
        height: "64",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NewspaperClipping = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$74(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NewspaperClipping.displayName = "NewspaperClipping";

var renderPathFor$75 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "108",
        x2: "160",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "148",
        x2: "116",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M156.68629,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.68629a8,8,0,0,1-2.34315,5.65686l-51.3137,51.3137A8,8,0,0,1,156.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "215.277 155.992 156 155.992 156 215.272",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "216 159.992 160 159.992 160 216 216 159.992",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "96",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "160",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M156.68629,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.68629a8,8,0,0,1-2.34315,5.65686l-51.3137,51.3137A8,8,0,0,1,156.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "215.28 159.992 160 159.992 160 215.275",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01081,16.01081,0,0,0,32,48V208a16.01081,16.01081,0,0,0,16,16H156.6875A15.92313,15.92313,0,0,0,168,219.3125L219.3125,168A15.92313,15.92313,0,0,0,224,156.6875V48A16.01081,16.01081,0,0,0,208,32ZM96,88h64a8,8,0,0,1,0,16H96a8,8,0,0,1,0-16Zm32,80H96a8,8,0,0,1,0-16h32a8,8,0,0,1,0,16ZM96,136a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm64,68.6875V159.98438h44.70312Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "96",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "160",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M156.68629,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.68629a8,8,0,0,1-2.34315,5.65686l-51.3137,51.3137A8,8,0,0,1,156.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "215.277 159.992 160 159.992 160 215.272",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "96",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "160",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M156.68629,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.68629a8,8,0,0,1-2.34315,5.65686l-51.3137,51.3137A8,8,0,0,1,156.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "215.277 159.992 160 159.992 160 215.272",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "96",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "128",
        x2: "160",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "160",
        x2: "128",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M156.68629,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.68629a8,8,0,0,1-2.34315,5.65686l-51.3137,51.3137A8,8,0,0,1,156.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "215.276 159.992 160 159.992 160 215.272",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Note = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$75(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Note.displayName = "Note";

var renderPathFor$76 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M156.68629,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.68629a8,8,0,0,1-2.34315,5.65686l-51.3137,51.3137A8,8,0,0,1,156.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "215.284 155.992 156 155.992 156 215.275",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "216 159.992 160 159.992 160 216 216 159.992",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M156.68629,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.68629a8,8,0,0,1-2.34315,5.65686l-51.3137,51.3137A8,8,0,0,1,156.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "215.279 159.992 160 159.992 160 215.275",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16H156.68652A15.89354,15.89354,0,0,0,168,219.31348L219.31348,168A15.89557,15.89557,0,0,0,224,156.68652V48A16.01833,16.01833,0,0,0,208,32ZM160,204.68652V159.99219h44.69458Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M156.68629,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.68629a8,8,0,0,1-2.34315,5.65686l-51.3137,51.3137A8,8,0,0,1,156.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "215.279 159.992 160 159.992 160 215.278",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M156.68629,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.68629a8,8,0,0,1-2.34315,5.65686l-51.3137,51.3137A8,8,0,0,1,156.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "215.279 159.992 160 159.992 160 215.272",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M156.68629,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.68629a8,8,0,0,1-2.34315,5.65686l-51.3137,51.3137A8,8,0,0,1,156.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "215.281 159.992 160 159.992 160 215.272",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NoteBlank = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$76(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NoteBlank.displayName = "NoteBlank";

var renderPathFor$77 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "128 160 96 160 96 128 192 32 224 64 128 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "164",
        y1: "60",
        x2: "196",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M216,128.56836V208a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8h79.43163",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "128 160 96 160 96 128 168 56 200 88 128 160",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "128 160 96 160 96 128 192 32 224 64 128 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "56",
        x2: "200",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M216,120v88a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8h88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M229.65723,58.34326l-32-32a8.00034,8.00034,0,0,0-11.31446,0l-96,96A8.00035,8.00035,0,0,0,88,128v32a8.00008,8.00008,0,0,0,8,8h32a8.00076,8.00076,0,0,0,5.65723-2.34326l96-96A8,8,0,0,0,229.65723,58.34326Zm-29.657,18.343L179.314,56,192,43.31372,212.68652,64Z"
      }), React__default.createElement("path", {
        d: "M217.61133,104.33008l-72.63867,72.63769a23.84434,23.84434,0,0,1-16.97071,7.03028h-32a24.02687,24.02687,0,0,1-24-24v-32a23.84117,23.84117,0,0,1,7.0293-16.96973l72.6582-72.6582a7.88176,7.88176,0,0,0-7.67187-6.37207H48.002a16.01582,16.01582,0,0,0-16,16v160a16.01583,16.01583,0,0,0,16,16h160a16.01582,16.01582,0,0,0,16-16V112.00586A7.88084,7.88084,0,0,0,217.61133,104.33008Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "128 160 96 160 96 128 192 32 224 64 128 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "56",
        x2: "200",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M216,120v88a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8h88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "128 160 96 160 96 128 192 32 224 64 128 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "56",
        x2: "200",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M216,120v88a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8h88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "128 160 96 160 96 128 192 32 224 64 128 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "56",
        x2: "200",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M216,120v88a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8h88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NotePencil = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$77(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NotePencil.displayName = "NotePencil";

var renderPathFor$78 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "120",
        y1: "108",
        x2: "176",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "148",
        x2: "176",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "40",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H80Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "112",
        x2: "176",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "144",
        x2: "176",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "40",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,208,32ZM80,208H48V48H80Zm96-56H112a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm0-32H112a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "112",
        y1: "112",
        x2: "176",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "144",
        x2: "176",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "40",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "112",
        y1: "112",
        x2: "176",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "144",
        x2: "176",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "40",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "112",
        y1: "112",
        x2: "176",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "112",
        y1: "144",
        x2: "176",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "40",
        x2: "80",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Notebook = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$78(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Notebook.displayName = "Notebook";

var renderPathFor$79 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M150,102a22,22,0,1,1-6.44365-15.55635A21.93114,21.93114,0,0,1,150,102Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M154,150a26,26,0,1,1-7.61522-18.38478A25.91866,25.91866,0,0,1,154,150Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M150,102a22,22,0,1,1-6.44365-15.55635A21.93114,21.93114,0,0,1,150,102Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M154,150a26,26,0,1,1-7.61522-18.38478A25.91866,25.91866,0,0,1,154,150Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm24.03125,150.04688a33.99637,33.99637,0,1,1-48.0625-48.09375,30.89828,30.89828,0,0,1,3.10645-2.50782c-.0918-.08984-.20313-.15136-.29395-.24218a29.98907,29.98907,0,0,1,.01563-42.42188c11.29687-11.3125,31.09375-11.32812,42.42187.01563a29.98907,29.98907,0,0,1-.01562,42.42187c-.08594.08594-.19141.14355-.27833.22852a30.83759,30.83759,0,0,1,3.12208,2.52148,33.98762,33.98762,0,0,1-.01563,48.07813Z"
      }), React__default.createElement("path", {
        d: "M137.89063,111.90625a14,14,0,1,0-19.79688-.01562A14.318,14.318,0,0,0,137.89063,111.90625Z"
      }), React__default.createElement("path", {
        d: "M128,132a17.99808,17.99808,0,0,0-12.73437,30.71875,18.43509,18.43509,0,0,0,25.45312.01563A18,18,0,0,0,128,132Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M150,102a22,22,0,1,1-6.44365-15.55635A21.93114,21.93114,0,0,1,150,102Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M154,150a26,26,0,1,1-7.61522-18.38478A25.91866,25.91866,0,0,1,154,150Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M150,102a22,22,0,1,1-6.44365-15.55635A21.93114,21.93114,0,0,1,150,102Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M154,150a26,26,0,1,1-7.61522-18.38478A25.91866,25.91866,0,0,1,154,150Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M150,102a22,22,0,1,1-6.44365-15.55635A21.93114,21.93114,0,0,1,150,102Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M154,150a26,26,0,1,1-7.61522-18.38478A25.91866,25.91866,0,0,1,154,150Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberCircleEight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$79(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberCircleEight.displayName = "NumberCircleEight";

var renderPathFor$7a = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152,84H111.83477L104,132.20232a27.99935,27.99935,0,1,1,0,39.5969",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,84H111.83477L104,132.20232a27.99935,27.99935,0,1,1,0,39.5969",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24ZM123.88184,116.002A35.99912,35.99912,0,1,1,98.35449,177.4668a7.99985,7.99985,0,1,1,11.291-11.33594,20.20173,20.20173,0,0,0,28.47461-.001,19.91646,19.91646,0,0,0-.001-28.25976,20.20412,20.20412,0,0,0-28.47461.001,7.99971,7.99971,0,0,1-13.541-6.95214l7.835-48.20215A8.00076,8.00076,0,0,1,111.835,76H152a8,8,0,0,1,0,16H118.63965L114.542,117.21094A36.413,36.413,0,0,1,123.88184,116.002Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M152,84H111.83477L104,132.20232a27.99935,27.99935,0,1,1,0,39.5969",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M152,84H111.83477L104,132.20232a27.99935,27.99935,0,1,1,0,39.5969",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,84H111.83477L104,132.20232a27.99935,27.99935,0,1,1,0,39.5969",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberCircleFive = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7a(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberCircleFive.displayName = "NumberCircleFive";

var renderPathFor$7b = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "123.998 76 100 144 148 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "112",
        x2: "148",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "123.998 76 100 144 148 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "112",
        x2: "148",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm28,152a8,8,0,0,1-16,0V152H100a7.99995,7.99995,0,0,1-7.54395-10.66211l23.998-68A7.99987,7.99987,0,1,1,131.542,78.66211L111.30664,136H140V112a8,8,0,0,1,16,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "123.998 76 100 144 148 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "112",
        x2: "148",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "123.998 76 100 144 148 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "112",
        x2: "148",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "123.998 76 100 144 148 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "112",
        x2: "148",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberCircleFour = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7b(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberCircleFour.displayName = "NumberCircleFour";

var renderPathFor$7c = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152.24871",
        y1: "126.00466",
        x2: "120",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "112",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152.24871",
        y1: "126.00466",
        x2: "120",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "112",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M148,112a20,20,0,1,1-20-20A20.02229,20.02229,0,0,1,148,112Zm84,16A104,104,0,1,1,128,24,104.11791,104.11791,0,0,1,232,128Zm-68-16a36,36,0,1,0-36,36q.91626,0,1.82129-.04639l-16.68945,27.94385a8.00015,8.00015,0,1,0,13.73632,8.20508l32.249-53.99512c.09668-.16162.178-.32812.262-.49365A35.76587,35.76587,0,0,0,164,112Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152.24871",
        y1: "126.00466",
        x2: "120",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "112",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152.24871",
        y1: "126.00466",
        x2: "120",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "112",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152.24871",
        y1: "126.00466",
        x2: "120",
        y2: "180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "112",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberCircleNine = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7c(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberCircleNine.displayName = "NumberCircleNine";

var renderPathFor$7d = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "108 99.993 132 84 132 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "108 99.993 132 84 132 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm12,152a8,8,0,0,1-16,0V98.94434l-11.56348,7.70605a8.00008,8.00008,0,1,1-8.873-13.31445l24-15.99317A8.00039,8.00039,0,0,1,140,84Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "108 99.993 132 84 132 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "108 99.993 132 84 132 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "108 99.993 132 84 132 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberCircleOne = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7d(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberCircleOne.displayName = "NumberCircleOne";

var renderPathFor$7e = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "104 84 152 84 120 180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "104 84 152 84 120 180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm31.58984,62.53027-32,96a8.0005,8.0005,0,1,1-15.17968-5.06054L140.90039,92H104a8,8,0,0,1,0-16h48a8.00022,8.00022,0,0,1,7.58984,10.53027Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "104 84 152 84 120 180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "104 84 152 84 120 180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "104 84 152 84 120 180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberCircleSeven = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7e(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberCircleSeven.displayName = "NumberCircleSeven";

var renderPathFor$7f = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "103.75129",
        y1: "129.98956",
        x2: "136",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "144",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.75129",
        y1: "129.98956",
        x2: "136",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "144",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M148,144a20,20,0,1,1-20-20A20.02229,20.02229,0,0,1,148,144Zm84-16A104,104,0,1,1,128,24,104.11791,104.11791,0,0,1,232,128Zm-68,16a36.04061,36.04061,0,0,0-36-36q-.917,0-1.82324.04639l16.6914-27.94385a8.00015,8.00015,0,0,0-13.73632-8.20508l-32.249,53.98926c-.11157.18652-.20776.37793-.30224.56982A35.99384,35.99384,0,1,0,164,144Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "103.75129",
        y1: "129.98956",
        x2: "136",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "144",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "103.75129",
        y1: "129.98956",
        x2: "136",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "144",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "103.75129",
        y1: "129.98956",
        x2: "136",
        y2: "76",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "144",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberCircleSix = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7f(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberCircleSix.displayName = "NumberCircleSix";

var renderPathFor$7g = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M103.99683,83.99216h48L124.00317,124a28,28,0,1,1-19.799,47.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M103.99683,83.99216h48L124.00317,124a28,28,0,1,1-19.799,47.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm21.458,153.45605a35.99982,35.99982,0,0,1-50.91113,0,8.00052,8.00052,0,0,1,11.31445-11.31445A19.99959,19.99959,0,1,0,124.00293,132a8,8,0,0,1-6.55469-12.58691l19.1875-27.4209H103.99707a8,8,0,0,1,0-16h48a8,8,0,0,1,6.55469,12.58691L137.5332,118.61816A36.019,36.019,0,0,1,149.458,177.45605Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M103.99683,83.99216h48L124.00317,124a28,28,0,1,1-19.799,47.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M103.99683,83.99216h48L124.00317,124a28,28,0,1,1-19.799,47.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M103.99683,83.99216h48L124.00317,124a28,28,0,1,1-19.799,47.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberCircleThree = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7g(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberCircleThree.displayName = "NumberCircleThree";

var renderPathFor$7h = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M105.886,94.65812a24.00387,24.00387,0,1,1,42.01514,22.7605v0L104,176v-.00575h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M105.886,94.65812a24.00387,24.00387,0,1,1,42.01514,22.7605v0L104,176v-.00575h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm24,143.99414a8,8,0,0,1,0,16H104.31738c-.10644.00391-.21289.00684-.31836.00684a8.00343,8.00343,0,0,1-6.30175-12.93164L141.37012,112.794a16.00416,16.00416,0,1,0-28.11621-15.01954A8,8,0,1,1,98.51758,91.542a32.00411,32.00411,0,1,1,56.01269,30.35547c-.07324.1084-.14843.21484-.22754.31934l-34.30566,45.77734Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M105.886,94.65812a24.00387,24.00387,0,1,1,42.01514,22.7605v0L104,176v-.00575h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M105.886,94.65812a24.00387,24.00387,0,1,1,42.01514,22.7605v0L104,176v-.00575h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M105.886,94.65812a24.00387,24.00387,0,1,1,42.01514,22.7605v0L104,176v-.00575h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberCircleTwo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7h(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberCircleTwo.displayName = "NumberCircleTwo";

var renderPathFor$7i = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "32",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "32",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "24",
        ry: "40"
      }), React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm0,160c-27.63281,0-40-28.125-40-56s12.36719-56,40-56,40,28.125,40,56S155.63281,184,128,184Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "32",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "32",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "32",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberCircleZero = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7i(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberCircleZero.displayName = "NumberCircleZero";

var renderPathFor$7j = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M178.76923,71.66667a46.108,46.108,0,0,1-14.87,33.70542,53.13546,53.13546,0,0,1-71.79854,0,45.63467,45.63467,0,0,1,0-67.41085,53.13546,53.13546,0,0,1,71.79854,0A46.108,46.108,0,0,1,178.76923,71.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M188,175.66667a54.49122,54.49122,0,0,1-17.57359,39.83368,62.79644,62.79644,0,0,1-84.85282,0,53.93188,53.93188,0,0,1,0-79.66737,62.79644,62.79644,0,0,1,84.85282,0A54.49124,54.49124,0,0,1,188,175.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M178.76923,71.66667a46.108,46.108,0,0,1-14.87,33.70542,53.13546,53.13546,0,0,1-71.79854,0,45.63467,45.63467,0,0,1,0-67.41085,53.13546,53.13546,0,0,1,71.79854,0A46.108,46.108,0,0,1,178.76923,71.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M188,175.66667a54.49122,54.49122,0,0,1-17.57359,39.83368,62.79644,62.79644,0,0,1-84.85282,0,53.93188,53.93188,0,0,1,0-79.66737,62.79644,62.79644,0,0,1,84.85282,0A54.49124,54.49124,0,0,1,188,175.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M175.90234,130.00049a68.12024,68.12024,0,0,0-16.36377-11.356,58.78324,58.78324,0,0,0,9.83643-7.43994,53.63156,53.63156,0,0,0,0-79.0752,61.13213,61.13213,0,0,0-82.75,0,53.63156,53.63156,0,0,0,0,79.0752,58.76231,58.76231,0,0,0,9.83667,7.43994,68.1188,68.1188,0,0,0-16.364,11.35645,61.93012,61.93012,0,0,0,0,91.332,70.79516,70.79516,0,0,0,95.80468-.00049,61.93012,61.93012,0,0,0,0-91.332ZM97.57617,99.53955a37.63752,37.63752,0,0,1,0-55.74609,45.13922,45.13922,0,0,1,60.84766,0,37.63752,37.63752,0,0,1,0,55.74609,45.13783,45.13783,0,0,1-60.84766,0Zm67.375,110.12842a54.80089,54.80089,0,0,1-73.90234.00049,45.936,45.936,0,0,1,0-68.00293,54.80089,54.80089,0,0,1,73.90234-.00049,45.936,45.936,0,0,1,0,68.00293Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M178.76923,71.66667a46.108,46.108,0,0,1-14.87,33.70542,53.13546,53.13546,0,0,1-71.79854,0,45.63467,45.63467,0,0,1,0-67.41085,53.13546,53.13546,0,0,1,71.79854,0A46.108,46.108,0,0,1,178.76923,71.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M188,175.66667a54.49122,54.49122,0,0,1-17.57359,39.83368,62.79644,62.79644,0,0,1-84.85282,0,53.93188,53.93188,0,0,1,0-79.66737,62.79644,62.79644,0,0,1,84.85282,0A54.49124,54.49124,0,0,1,188,175.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M178.76923,71.66667a46.108,46.108,0,0,1-14.87,33.70542,53.13546,53.13546,0,0,1-71.79854,0,45.63467,45.63467,0,0,1,0-67.41085,53.13546,53.13546,0,0,1,71.79854,0A46.108,46.108,0,0,1,178.76923,71.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M188,175.66667a54.49122,54.49122,0,0,1-17.57359,39.83368,62.79644,62.79644,0,0,1-84.85282,0,53.93188,53.93188,0,0,1,0-79.66737,62.79644,62.79644,0,0,1,84.85282,0A54.49124,54.49124,0,0,1,188,175.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M178.76923,71.66667a46.108,46.108,0,0,1-14.87,33.70542,53.13546,53.13546,0,0,1-71.79854,0,45.63467,45.63467,0,0,1,0-67.41085,53.13546,53.13546,0,0,1,71.79854,0A46.108,46.108,0,0,1,178.76923,71.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M188,175.66667a54.49122,54.49122,0,0,1-17.57359,39.83368,62.79644,62.79644,0,0,1-84.85282,0,53.93188,53.93188,0,0,1,0-79.66737,62.79644,62.79644,0,0,1,84.85282,0A54.49124,54.49124,0,0,1,188,175.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberEight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7j(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberEight.displayName = "NumberEight";

var renderPathFor$7k = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,32H95.66955L80,128.40465a55.99871,55.99871,0,1,1,0,79.19378",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,32H95.66955L80,128.40465a55.99871,55.99871,0,1,1,0,79.19378",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M165.17383,122.73535a64.11724,64.11724,0,0,1-90.81836,90.53174,7.99968,7.99968,0,1,1,11.28906-11.3374,47.99883,47.99883,0,1,0,0-67.85645,7.99971,7.99971,0,0,1-13.541-6.95215L87.77344,30.7168A8.00076,8.00076,0,0,1,95.66992,24H176a8,8,0,0,1,0,16H102.47461l-11.501,70.75537a64.53171,64.53171,0,0,1,74.2002,11.98Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,32H95.66955L80,128.40465a55.99871,55.99871,0,1,1,0,79.19378",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,32H95.66955L80,128.40465a55.99871,55.99871,0,1,1,0,79.19378",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,32H95.66955L80,128.40465a55.99871,55.99871,0,1,1,0,79.19378",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberFive = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7k(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberFive.displayName = "NumberFive";

var renderPathFor$7l = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "123.997 24 76 160 172 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "172",
        y1: "95.98859",
        x2: "172",
        y2: "223.98844",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "123.997 24 76 160 172 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "172",
        y1: "96",
        x2: "172",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M180,96V224a8,8,0,0,1-16,0V168H76a8.00033,8.00033,0,0,1-7.54395-10.66211l47.99707-136a7.99988,7.99988,0,0,1,15.0879,5.32422L87.30664,152H164V96a8,8,0,0,1,16,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "123.997 24 76 160 172 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "172",
        y1: "96",
        x2: "172",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "123.997 24 76 160 172 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "172",
        y1: "96",
        x2: "172",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "123.997 24 76 160 172 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "172",
        y1: "96",
        x2: "172",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberFour = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7l(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberFour.displayName = "NumberFour";

var renderPathFor$7m = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176.48933",
        y1: "115.99533",
        x2: "111.75",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "88",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176.48933",
        y1: "115.99533",
        x2: "111.75",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "88",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24a64,64,0,1,0,19.38452,124.99121l-42.49585,70.896a7.99956,7.99956,0,1,0,13.72266,8.22558L182.68848,121.2124c.02881-.04736.05664-.095.08545-.14233l.57666-.96216c.10473-.17456.19409-.354.28393-.533A63.95216,63.95216,0,0,0,128,24Zm41.18115,88.62769-.22778.37988a48.6994,48.6994,0,1,1,.22778-.37988Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176.48933",
        y1: "115.99533",
        x2: "111.75",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "88",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176.48933",
        y1: "115.99533",
        x2: "111.75",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "88",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176.48933",
        y1: "115.99533",
        x2: "111.75",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "88",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberNine = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7m(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberNine.displayName = "NumberNine";

var renderPathFor$7n = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "84 63.986 132 32 132 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "84 63.986 132 32 132 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M131.99574,232a8.00252,8.00252,0,0,1-8.00427-8.00045V46.95129l-35.54531,23.691A8.00167,8.00167,0,1,1,79.56448,57.3298L127.55489,25.344A8.0046,8.0046,0,0,1,140,32.00038V223.99955A8.00252,8.00252,0,0,1,131.99574,232Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "84 63.986 132 32 132 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "84 63.986 132 32 132 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "84 63.986 132 32 132 224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberOne = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7n(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberOne.displayName = "NumberOne";

var renderPathFor$7o = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 40 176 40 112 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 40 176 40 112 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M112.001,240a8.00547,8.00547,0,0,1-7.59082-10.53164L164.90043,47.99985H80A7.99993,7.99993,0,1,1,80,32h96a8,8,0,0,1,7.58984,10.52969l-64,191.99819A8.00469,8.00469,0,0,1,112.001,240Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 40 176 40 112 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 40 176 40 112 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "80 40 176 40 112 232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSeven = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7o(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSeven.displayName = "NumberSeven";

var renderPathFor$7p = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "79.51067",
        y1: "140.00467",
        x2: "144",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "168",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "79.51067",
        y1: "140.00467",
        x2: "144",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "168",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,104a63.75508,63.75508,0,0,0-19.49121,3.04492l42.36035-70.9436a8.00043,8.00043,0,0,0-13.73828-8.20288L72.6416,135.90332c-.10449.17529-.19385.355-.28369.53442A63.97854,63.97854,0,1,0,128,104Zm0,112a47.97612,47.97612,0,0,1-41.15674-72.67017l.17749-.29736A47.99419,47.99419,0,1,1,128,216Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "79.51067",
        y1: "140.00467",
        x2: "144",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "168",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "79.51067",
        y1: "140.00467",
        x2: "144",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "168",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "79.51067",
        y1: "140.00467",
        x2: "144",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "168",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSix = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7p(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSix.displayName = "NumberSix";

var renderPathFor$7q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M150,102a22,22,0,1,1-6.44365-15.55635A21.93114,21.93114,0,0,1,150,102Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M154,150a26,26,0,1,1-7.61522-18.38478A25.91866,25.91866,0,0,1,154,150Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M150,102a22,22,0,1,1-6.44365-15.55635A21.93114,21.93114,0,0,1,150,102Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M154,150a26,26,0,1,1-7.61522-18.38478A25.91866,25.91866,0,0,1,154,150Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M137.89062,111.90625a14,14,0,1,0-19.79687-.01562A14.318,14.318,0,0,0,137.89062,111.90625Z"
      }), React__default.createElement("path", {
        d: "M128,132a17.99808,17.99808,0,0,0-12.73438,30.71875,18.43511,18.43511,0,0,0,25.45313.01563A18,18,0,0,0,128,132Z"
      }), React__default.createElement("path", {
        d: "M208,32H48A16.02085,16.02085,0,0,0,32,48V208a16.02085,16.02085,0,0,0,16,16H208a16.02085,16.02085,0,0,0,16-16V48A16.02085,16.02085,0,0,0,208,32ZM152.03125,174.04688a33.99637,33.99637,0,1,1-48.0625-48.09375,30.89715,30.89715,0,0,1,3.10645-2.50782c-.0918-.08984-.20313-.15136-.29395-.24218a29.98908,29.98908,0,0,1,.01562-42.42188c11.29688-11.3125,31.09375-11.32812,42.42188.01563a29.98906,29.98906,0,0,1-.01563,42.42187c-.08593.08594-.1914.14355-.27832.22852a30.83637,30.83637,0,0,1,3.12207,2.52148,33.98761,33.98761,0,0,1-.01562,48.07813Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M150,102a22,22,0,1,1-6.44365-15.55635A21.93114,21.93114,0,0,1,150,102Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M154,150a26,26,0,1,1-7.61522-18.38478A25.91866,25.91866,0,0,1,154,150Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M150,102a22,22,0,1,1-6.44365-15.55635A21.93114,21.93114,0,0,1,150,102Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M154,150a26,26,0,1,1-7.61522-18.38478A25.91866,25.91866,0,0,1,154,150Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M150,102a22,22,0,1,1-6.44365-15.55635A21.93114,21.93114,0,0,1,150,102Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M154,150a26,26,0,1,1-7.61522-18.38478A25.91866,25.91866,0,0,1,154,150Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSquareEight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSquareEight.displayName = "NumberSquareEight";

var renderPathFor$7r = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M152,80H111.83477L104,128.20232a27.99935,27.99935,0,1,1,0,39.5969",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M152,80H111.83477L104,128.20232a27.99935,27.99935,0,1,1,0,39.5969",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,208,32ZM123.88184,112.002A35.99912,35.99912,0,1,1,98.35449,173.4668a7.99985,7.99985,0,1,1,11.291-11.33594,20.20173,20.20173,0,0,0,28.47461-.001,19.91646,19.91646,0,0,0-.001-28.25976,20.20412,20.20412,0,0,0-28.47461.001,7.99971,7.99971,0,0,1-13.541-6.95214l7.835-48.20215A8.00076,8.00076,0,0,1,111.835,72H152a8,8,0,0,1,0,16H118.63965L114.542,113.21094A36.413,36.413,0,0,1,123.88184,112.002Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M152,80H111.83477L104,128.20232a27.99935,27.99935,0,1,1,0,39.5969",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M152,80H111.83477L104,128.20232a27.99935,27.99935,0,1,1,0,39.5969",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M152,80H111.83477L104,128.20232a27.99935,27.99935,0,1,1,0,39.5969",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSquareFive = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7r(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSquareFive.displayName = "NumberSquareFive";

var renderPathFor$7s = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "123.998 76 100 144 148 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "111.99435",
        x2: "148",
        y2: "175.99435",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "123.998 76 100 144 148 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "112",
        x2: "148",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,208,32ZM156,176a8,8,0,0,1-16,0V152H100a8.00052,8.00052,0,0,1-7.54395-10.6626l23.998-68A8,8,0,0,1,131.542,78.6626L111.30664,136H140V112a8,8,0,0,1,16,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "123.998 76 100 144 148 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "112",
        x2: "148",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "123.998 76 100 144 148 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "112",
        x2: "148",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "123.998 76 100 144 148 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "148",
        y1: "112",
        x2: "148",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSquareFour = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7s(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSquareFour.displayName = "NumberSquareFour";

var renderPathFor$7t = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152.24871",
        y1: "126.00466",
        x2: "120",
        y2: "180.00001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "112",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "152.24871",
        y1: "126.00466",
        x2: "120",
        y2: "180.00001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "112",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M148,112a20,20,0,1,1-20-20A20.02229,20.02229,0,0,1,148,112Zm76-64V208a16.01833,16.01833,0,0,1-16,16H48a16.01833,16.01833,0,0,1-16-16V48A16.01833,16.01833,0,0,1,48,32H208A16.01833,16.01833,0,0,1,224,48Zm-60,64a36,36,0,1,0-36,36q.91626,0,1.82129-.04614l-16.68945,27.9436a8.00015,8.00015,0,1,0,13.73632,8.20508l32.249-53.99512c.09668-.16162.178-.32812.262-.49341A35.76746,35.76746,0,0,0,164,112Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152.24871",
        y1: "126.00466",
        x2: "120",
        y2: "180.00001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "112",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152.24871",
        y1: "126.00466",
        x2: "120",
        y2: "180.00001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "112",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "152.24871",
        y1: "126.00466",
        x2: "120",
        y2: "180.00001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "112",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSquareNine = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7t(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSquareNine.displayName = "NumberSquareNine";

var renderPathFor$7u = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "108 99.993 132 84 132 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "108 99.993 132 84 132 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.02085,16.02085,0,0,0,32,48V208a16.02085,16.02085,0,0,0,16,16H208a16.02085,16.02085,0,0,0,16-16V48A16.02085,16.02085,0,0,0,208,32ZM139.99219,175.99219a8,8,0,0,1-16,0V98.95313l-11.54688,7.69531a7.99982,7.99982,0,1,1-8.875-13.3125l23.98438-15.99219A7.99941,7.99941,0,0,1,139.99219,84Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "108 99.993 132 84 132 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "108 99.993 132 84 132 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "108 99.993 132 84 132 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSquareOne = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7u(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSquareOne.displayName = "NumberSquareOne";

var renderPathFor$7v = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 84 152 84 120 180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "104 84 152 84 120 180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,208,32ZM159.58984,86.53027l-32,96a8.0005,8.0005,0,1,1-15.17968-5.06054L140.90039,92H104a8,8,0,0,1,0-16h48a8.00022,8.00022,0,0,1,7.58984,10.53027Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 84 152 84 120 180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 84 152 84 120 180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "104 84 152 84 120 180",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSquareSeven = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7v(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSquareSeven.displayName = "NumberSquareSeven";

var renderPathFor$7w = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "103.75534",
        y1: "134.00234",
        x2: "136",
        y2: "79.99421",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "148",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "103.75534",
        y1: "134.00234",
        x2: "136",
        y2: "79.99421",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "148",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M148,148a20,20,0,1,1-20-20A20.02229,20.02229,0,0,1,148,148ZM224,48V208a16.01833,16.01833,0,0,1-16,16H48a16.01833,16.01833,0,0,1-16-16V48A16.01833,16.01833,0,0,1,48,32H208A16.01833,16.01833,0,0,1,224,48ZM164,148a36.04061,36.04061,0,0,0-36-36q-.91517,0-1.81909.04614l16.68823-27.95141a8,8,0,0,0-13.73828-8.20118L96.88574,129.90137c-.06152.103-.11035.20984-.16675.31445A35.99282,35.99282,0,1,0,164,148Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "103.75534",
        y1: "134.00234",
        x2: "136",
        y2: "79.99421",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "148",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "103.75534",
        y1: "134.00234",
        x2: "136",
        y2: "79.99421",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "148",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "103.75534",
        y1: "134.00234",
        x2: "136",
        y2: "79.99421",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "148",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSquareSix = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7w(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSquareSix.displayName = "NumberSquareSix";

var renderPathFor$7x = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,84h47.99366l-27.99,40.00455a27.99773,27.99773,0,1,1-19.79638,47.79511",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M104,84h47.99366l-27.99,40.00455a27.99773,27.99773,0,1,1-19.79638,47.79511",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,208,32ZM149.457,177.45654a35.9963,35.9963,0,0,1-50.90723,0,8.00018,8.00018,0,0,1,11.31446-11.31347,19.99683,19.99683,0,1,0,14.13965-34.13868,7.99971,7.99971,0,0,1-6.55469-12.58642L136.63281,92H104a8,8,0,0,1,0-16h47.99414a7.99973,7.99973,0,0,1,6.55469,12.58643L137.5332,118.62305A36.01783,36.01783,0,0,1,149.457,177.45654Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,84h47.99366l-27.99,40.00455a27.99773,27.99773,0,1,1-19.79638,47.79511",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,84h47.99366l-27.99,40.00455a27.99773,27.99773,0,1,1-19.79638,47.79511",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M104,84h47.99366l-27.99,40.00455a27.99773,27.99773,0,1,1-19.79638,47.79511",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSquareThree = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7x(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSquareThree.displayName = "NumberSquareThree";

var renderPathFor$7y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M105.886,94.65812a24.00387,24.00387,0,1,1,42.01514,22.7605v0L104,176v-.00575h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M105.886,94.65812a24.00387,24.00387,0,1,1,42.01514,22.7605v0L104,176v-.00575h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,208,32ZM152,167.99414a8,8,0,0,1,0,16H104.31738c-.10644.0044-.21191.00635-.31836.00635a8.00251,8.00251,0,0,1-6.30078-12.93164L141.37012,112.793a16.0039,16.0039,0,1,0-28.11621-15.01856A8,8,0,1,1,98.51758,91.542a32.00411,32.00411,0,1,1,56.01269,30.35547c-.07324.10791-.14843.21436-.22754.31836l-34.30566,45.77832Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M105.886,94.65812a24.00387,24.00387,0,1,1,42.01514,22.7605v0L104,176v-.00575h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M105.886,94.65812a24.00387,24.00387,0,1,1,42.01514,22.7605v0L104,176v-.00575h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M105.886,94.65812a24.00387,24.00387,0,1,1,42.01514,22.7605v0L104,176v-.00575h48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSquareTwo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSquareTwo.displayName = "NumberSquareTwo";

var renderPathFor$7z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "32",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "32",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "24",
        ry: "40"
      }), React__default.createElement("path", {
        d: "M208,32H48A16.02085,16.02085,0,0,0,32,48V208a16.02085,16.02085,0,0,0,16,16H208a16.02085,16.02085,0,0,0,16-16V48A16.02085,16.02085,0,0,0,208,32ZM128,184c-27.63281,0-40-28.125-40-56s12.36719-56,40-56,40,28.125,40,56S155.63281,184,128,184Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "32",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "32",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "32",
        ry: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberSquareZero = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberSquareZero.displayName = "NumberSquareZero";

var renderPathFor$7A = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,32h95.98733l-55.97994,80.0091a55.99545,55.99545,0,1,1-39.59275,95.59021",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,32h95.98733l-55.97994,80.0091a55.99545,55.99545,0,1,1-39.59275,95.59021",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M184,168.00488a63.99178,63.99178,0,0,1-109.24219,45.251,8,8,0,0,1,11.31446-11.313,47.994,47.994,0,1,0,33.93554-81.93408,7.99947,7.99947,0,0,1-6.55469-12.58594L160.626,40H80a8,8,0,0,1,0-16h95.9873A7.99946,7.99946,0,0,1,182.542,36.58594l-48.28125,69.00683A64.055,64.055,0,0,1,184,168.00488Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,32h95.98733l-55.97994,80.0091a55.99545,55.99545,0,1,1-39.59275,95.59021",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,32h95.98733l-55.97994,80.0091a55.99545,55.99545,0,1,1-39.59275,95.59021",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,32h95.98733l-55.97994,80.0091a55.99545,55.99545,0,1,1-39.59275,95.59021",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberThree = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7A(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberThree.displayName = "NumberThree";

var renderPathFor$7B = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M83.77207,61.31625a48.00774,48.00774,0,1,1,84.03029,45.521v0L80,224v-.01149h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M83.77207,61.31625a48.00774,48.00774,0,1,1,84.03029,45.521v0L80,224v-.01149h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M184,223.98828a8.00008,8.00008,0,0,1-8,8H80.43555q-.21827.01245-.43653.01221a8.00346,8.00346,0,0,1-6.26757-12.9751l87.54687-116.82178a40.00778,40.00778,0,1,0-70.1377-37.771A8,8,0,1,1,76.4043,58.2002a56.00758,56.00758,0,1,1,98.02734,53.11523c-.07324.1084-.14844.21484-.22754.31934L96.001,215.98828H176A8.00039,8.00039,0,0,1,184,223.98828Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M83.77207,61.31625a48.00774,48.00774,0,1,1,84.03029,45.521v0L80,224v-.01149h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M83.77207,61.31625a48.00774,48.00774,0,1,1,84.03029,45.521v0L80,224v-.01149h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M83.77207,61.31625a48.00774,48.00774,0,1,1,84.03029,45.521v0L80,224v-.01149h96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberTwo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7B(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberTwo.displayName = "NumberTwo";

var renderPathFor$7C = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "72",
        ry: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "72",
        ry: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,240c-25.75977,0-46.99219-12.57129-61.40039-36.35474C54.60547,183.848,48,156.98334,48,128c0-28.98566,6.60547-55.8512,18.59961-75.64771C81.00781,28.57043,102.24023,16,128,16s46.99219,12.57043,61.40039,36.35229C201.39453,72.1488,208,99.01434,208,128c0,28.98334-6.60547,55.848-18.59961,75.64526C174.99219,227.42871,153.75977,240,128,240Zm0-208c-44.21094,0-64,48.2157-64,96s19.78906,96,64,96,64-48.2157,64-96S172.21094,32,128,32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "72",
        ry: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "72",
        ry: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("ellipse", {
        cx: "128",
        cy: "128",
        rx: "72",
        ry: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var NumberZero = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7C(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
NumberZero.displayName = "NumberZero";

var renderPathFor$7D = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.999,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87291,0l-84,47.47826a8,8,0,0,0-4.06355,6.9645v94.66456a8,8,0,0,0,4.06355,6.96451l84,47.47826a8,8,0,0,0,7.87291,0l84-47.47826A8,8,0,0,0,219.999,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "127.99902",
        cy: "128",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.93555,73.70325l-84-47.47815a7.99926,7.99926,0,0,0-7.87305,0l-84,47.47815A8.00029,8.00029,0,0,0,35.999,80.66772v94.66456a8.00065,8.00065,0,0,0,4.06348,6.9646l84,47.47814a7.99987,7.99987,0,0,0,7.87305,0l84-47.47814a8.00064,8.00064,0,0,0,4.06347-6.9646V80.66772A8.00028,8.00028,0,0,0,215.93555,73.70325ZM127.999,164a36,36,0,1,1,36-36A35.99991,35.99991,0,0,1,127.999,164Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M219.999,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87291,0l-84,47.47826a8,8,0,0,0-4.06355,6.9645v94.66456a8,8,0,0,0,4.06355,6.96451l84,47.47826a8,8,0,0,0,7.87291,0l84-47.47826A8,8,0,0,0,219.999,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.99902",
        cy: "128",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.87207,66.73877l-84-47.478a16.08529,16.08529,0,0,0-15.74609,0l-84,47.478a16.0253,16.0253,0,0,0-8.127,13.92871v94.665a16.0253,16.0253,0,0,0,8.127,13.92871l84,47.478a16.08113,16.08113,0,0,0,15.74609,0l84-47.478a16.02529,16.02529,0,0,0,8.12695-13.92871v-94.665A16.02529,16.02529,0,0,0,219.87207,66.73877ZM127.999,164a36,36,0,1,1,36-36A36.04074,36.04074,0,0,1,127.999,164Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.999,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87291,0l-84,47.47826a8,8,0,0,0-4.06355,6.9645v94.66456a8,8,0,0,0,4.06355,6.96451l84,47.47826a8,8,0,0,0,7.87291,0l84-47.47826A8,8,0,0,0,219.999,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "127.99902",
        cy: "128",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.999,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87291,0l-84,47.47826a8,8,0,0,0-4.06355,6.9645v94.66456a8,8,0,0,0,4.06355,6.96451l84,47.47826a8,8,0,0,0,7.87291,0l84-47.47826A8,8,0,0,0,219.999,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "127.99902",
        cy: "128",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M220,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826A8,8,0,0,0,36,80.66772v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,220,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Nut = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7D(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Nut.displayName = "Nut";

var renderPathFor$7E = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M227.3125,80.23438,175.76562,28.6875A16.11511,16.11511,0,0,0,164.45312,24H91.54687a16.11515,16.11515,0,0,0-11.3125,4.6875L28.6875,80.23438A16.11511,16.11511,0,0,0,24,91.54688v72.90625a16.11515,16.11515,0,0,0,4.6875,11.3125L80.23437,227.3125A16.11515,16.11515,0,0,0,91.54687,232h72.90625a16.11511,16.11511,0,0,0,11.3125-4.6875l51.54688-51.54687A16.11515,16.11515,0,0,0,232,164.45313V91.54688A16.11511,16.11511,0,0,0,227.3125,80.23438Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Octagon = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7E(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Octagon.displayName = "Octagon";

var renderPathFor$7F = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.94915",
        y1: "128",
        x2: "127.88745",
        y2: "230.81036",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M219.88745,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826a8,8,0,0,0-4.06354,6.9645v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,219.88745,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "218.792 76.627 128.949 128 36.99 76.616",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "177.022 148.511 177.022 100.511 84.243 48.669",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M127.88742,230.81054a7.99524,7.99524,0,0,1-3.93643-1.03549l-84-47.47826a8,8,0,0,1-4.06354-6.96451V80.66772a7.99474,7.99474,0,0,1,1.102-4.05194l.00063.00037L128.94915,128l-1.0617,102.81036Z"
      })), React__default.createElement("line", {
        x1: "128.94915",
        y1: "128",
        x2: "127.88745",
        y2: "230.81036",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M219.88745,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826a8,8,0,0,0-4.06354,6.9645v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,219.88745,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "218.792 76.627 128.949 128 36.99 76.616",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "177.022 148.511 177.022 100.511 84.243 48.669",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M225.82544,72.83154c-.0315-.0581-.05616-.11816-.08936-.17627-.02734-.04736-.05981-.08984-.08789-.13672a15.99349,15.99349,0,0,0-5.88769-5.78027l-84-47.47754a16.08155,16.08155,0,0,0-15.7461-.00049l-84.001,47.479a15.99051,15.99051,0,0,0-5.959,5.89844c-.01514.02636-.0332.0498-.04785.07617-.02588.04638-.04517.09472-.07007.1416a15.98426,15.98426,0,0,0-2.04907,7.8125V175.332a16.028,16.028,0,0,0,8.127,13.92969l84,47.47754a15.97414,15.97414,0,0,0,7.30957,2.0415c.15967.01123.31812.02735.48047.02881.02832.00049.05664.001.085.001.21729,0,.43067-.01563.64356-.03272a15.97171,15.97171,0,0,0,7.22754-2.03808l84.001-47.479a16.02639,16.02639,0,0,0,8.126-13.92871V80.668A15.98584,15.98584,0,0,0,225.82544,72.83154Zm-97.938-39.64209,75.81347,42.85108L176.9768,91.32129,100.572,48.62891Zm1.01562,85.6211L52.21631,75.96,84.26538,57.84521l76.5,42.7461Zm7.11524,99.40429.8833-85.54687,32.1206-18.36719v34.21a8,8,0,0,0,16,0V105.15186L211.88745,89.79v85.542Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.94915",
        y1: "128",
        x2: "127.88745",
        y2: "230.81036",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M219.88745,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826a8,8,0,0,0-4.06354,6.9645v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,219.88745,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "218.792 76.627 128.949 128 36.99 76.616",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "177.022 148.511 177.022 100.511 84.243 48.669",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.94915",
        y1: "128",
        x2: "127.88745",
        y2: "230.81036",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M219.88745,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826a8,8,0,0,0-4.06354,6.9645v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,219.88745,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "218.792 76.627 128.949 128 36.99 76.616",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "177.022 148.511 177.022 100.511 84.243 48.669",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.94915",
        y1: "128",
        x2: "127.88745",
        y2: "230.81036",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M219.88745,175.33228V80.66772a8,8,0,0,0-4.06354-6.9645l-84-47.47826a8,8,0,0,0-7.87292,0l-84,47.47826a8,8,0,0,0-4.06354,6.9645v94.66456a8,8,0,0,0,4.06354,6.96451l84,47.47826a8,8,0,0,0,7.87292,0l84-47.47826A8,8,0,0,0,219.88745,175.33228Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "218.792 76.627 128.949 128 36.99 76.616",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "177.022 148.511 177.022 100.511 84.243 48.669",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Package = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7F(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Package.displayName = "Package";

var renderPathFor$7G = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M72,32H208a8,8,0,0,1,8,8V144a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V64A32,32,0,0,1,72,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M112,152l-8,56a24,24,0,0,0,48,0l-8-56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "112",
        x2: "216",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "32",
        x2: "168",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,112v32a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V112Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M112,152l-8,56a24,24,0,0,0,48,0l-8-56Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M72,32H208a8,8,0,0,1,8,8V144a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V64A32,32,0,0,1,72,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M112,152l-8,56a24,24,0,0,0,48,0l-8-56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "112",
        x2: "216",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "32",
        x2: "168",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,24H72A40.04552,40.04552,0,0,0,32,64v80a16.01833,16.01833,0,0,0,16,16h54.776l-6.69543,46.86816A7.97979,7.97979,0,0,0,96,208a32,32,0,0,0,64,0,7.97979,7.97979,0,0,0-.08057-1.13184L153.224,160H208a16.01833,16.01833,0,0,0,16-16V40A16.01833,16.01833,0,0,0,208,24ZM72,40h88V72a8,8,0,0,0,16,0V40h32l.00635,64H48V64A24.0275,24.0275,0,0,1,72,40Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M72,32H208a8,8,0,0,1,8,8V144a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V64A32,32,0,0,1,72,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M112,152l-8,56a24,24,0,0,0,48,0l-8-56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "112",
        x2: "216",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "32",
        x2: "168",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M72,32H208a8,8,0,0,1,8,8V144a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V64A32,32,0,0,1,72,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M112,152l-8,56a24,24,0,0,0,48,0l-8-56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "112",
        x2: "216",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "32",
        x2: "168",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M72,32H208a8,8,0,0,1,8,8V144a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V64A32,32,0,0,1,72,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M112,152l-8,56a24,24,0,0,0,48,0l-8-56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "112",
        x2: "216",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "32",
        x2: "168",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PaintBrushBroad = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7G(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PaintBrushBroad.displayName = "PaintBrushBroad";

var renderPathFor$7H = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "42.46089",
        y: "60.11775",
        width: "147.07821",
        height: "135.7645",
        rx: "8",
        transform: "translate(-56.53405 119.51472) rotate(-45)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "116.00586",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M204,208c0-19.99414,20-40,20-40s20,20.00586,20,40a20,20,0,0,1-40,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "113.85786",
        y1: "101.86372",
        x2: "49.85786",
        y2: "37.86372",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,196c0-19.99414,20-40,20-40s20,20.00586,20,40a20,20,0,0,1-40,0Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "42.46089",
        y: "60.11775",
        width: "147.07821",
        height: "135.7645",
        rx: "8",
        transform: "translate(-56.53405 119.51472) rotate(-45)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "116.00586",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,196c0-19.99414,20-40,20-40s20,20.00586,20,40a20,20,0,0,1-40,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "113.85786",
        y1: "101.86372",
        x2: "49.85786",
        y2: "37.86372",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M233.65723,150.34375a7.99945,7.99945,0,0,0-11.31446,0C221.42969,151.25635,200,172.958,200,196a28,28,0,0,0,56,0C256,172.958,234.57031,151.25635,233.65723,150.34375Z"
      }), React__default.createElement("path", {
        d: "M55.51465,32.207A8.00018,8.00018,0,0,0,44.2002,43.52051L68.68286,68.00317,79.99658,56.689Z"
      }), React__default.createElement("path", {
        d: "M220.68652,124A15.89427,15.89427,0,0,0,216,112.68652L131.31348,27.999A16.02162,16.02162,0,0,0,108.68555,28l-28.689,28.689,43.87451,43.87452a16.06775,16.06775,0,1,1-11.31372,11.31421L68.68286,68.00317,16.001,120.68555A15.99888,15.99888,0,0,0,16,143.31348L100.68555,228l.001.001A16.02134,16.02134,0,0,0,123.31445,228L215.999,135.31445A15.895,15.895,0,0,0,220.68652,124Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "42.46089",
        y: "60.11775",
        width: "147.07821",
        height: "135.7645",
        rx: "8",
        transform: "translate(-56.53405 119.51472) rotate(-45)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "116.00586",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M208,196c0-19.99414,20-40,20-40s20,20.00586,20,40a20,20,0,0,1-40,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "113.85786",
        y1: "101.86372",
        x2: "49.85786",
        y2: "37.86372",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "42.46089",
        y: "60.11775",
        width: "147.07821",
        height: "135.7645",
        rx: "8",
        transform: "translate(-56.53405 119.51472) rotate(-45)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "116.00586",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M208,196c0-19.99414,20-40,20-40s20,20.00586,20,40a20,20,0,0,1-40,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "113.85786",
        y1: "101.86372",
        x2: "49.85786",
        y2: "37.86372",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "42.46089",
        y: "60.11775",
        width: "147.07821",
        height: "135.7645",
        rx: "8",
        transform: "translate(-56.53405 119.51472) rotate(-45)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "116.00586",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,196c0-19.99414,20-40,20-40s20,20.00586,20,40a20,20,0,0,1-40,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "113.85786",
        y1: "101.86372",
        x2: "49.85786",
        y2: "37.86372",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PaintBucket = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7H(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PaintBucket.displayName = "PaintBucket";

var renderPathFor$7I = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120.90154,36.46437,26.30921,205.37925A8,8,0,0,0,35.98,216.822l89.211-31.86106a8,8,0,0,1,5.38138,0l89.211,31.86106a8,8,0,0,0,9.67074-11.44277L134.86164,36.46437A8,8,0,0,0,120.90154,36.46437Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "127.88159",
        y1: "184",
        x2: "127.88159",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120.90154,36.46437,26.30921,205.37925A8,8,0,0,0,35.98,216.822l89.211-31.86106a8,8,0,0,1,5.38138,0l89.211,31.86106a8,8,0,0,0,9.67074-11.44277L134.86164,36.46437A8,8,0,0,0,120.90154,36.46437Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M120.90154,36.46437,26.30921,205.37925A8,8,0,0,0,35.98,216.822l89.211-31.86106a8,8,0,0,1,5.38138,0l89.211,31.86106a8,8,0,0,0,9.67074-11.44277L134.86164,36.46437A8,8,0,0,0,120.90154,36.46437Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.88159",
        y1: "184",
        x2: "127.88159",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M236.43432,201.4707l-94.59179-168.915a16.00119,16.00119,0,0,0-27.92188,0L19.32885,201.47021A16.00042,16.00042,0,0,0,38.67065,224.356l81.21094-29.00391V120a8,8,0,1,1,16,0v75.352L217.09253,224.356a16.171,16.171,0,0,0,5.44531.95117,16.02221,16.02221,0,0,0,13.89648-23.83643Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120.90154,36.46437,26.30921,205.37925A8,8,0,0,0,35.98,216.822l89.211-31.86106a8,8,0,0,1,5.38138,0l89.211,31.86106a8,8,0,0,0,9.67074-11.44277L134.86164,36.46437A8,8,0,0,0,120.90154,36.46437Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.88159",
        y1: "184",
        x2: "127.88159",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120.90154,36.46437,26.30921,205.37925A8,8,0,0,0,35.98,216.822l89.211-31.86106a8,8,0,0,1,5.38138,0l89.211,31.86106a8,8,0,0,0,9.67074-11.44277L134.86164,36.46437A8,8,0,0,0,120.90154,36.46437Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "127.88159",
        y1: "184",
        x2: "127.88159",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M120.90154,36.46437,26.30921,205.37925A8,8,0,0,0,35.98,216.822l89.211-31.86106a8,8,0,0,1,5.38138,0l89.211,31.86106a8,8,0,0,0,9.67074-11.44277L134.86164,36.46437A8,8,0,0,0,120.90154,36.46437Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.88159",
        y1: "184",
        x2: "127.88159",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PaperPlane = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7I(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PaperPlane.displayName = "PaperPlane";

var renderPathFor$7J = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.53563,121.02,50.62075,26.42762A8,8,0,0,0,39.178,36.09836l31.86106,89.211a8,8,0,0,1,0,5.38138L39.178,219.90164a8,8,0,0,0,11.44277,9.67074l168.91488-94.59233A8,8,0,0,0,219.53563,121.02Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "128",
        x2: "136",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.53563,121.02,50.62075,26.42762A8,8,0,0,0,39.178,36.09836l31.86106,89.211a8,8,0,0,1,0,5.38138L39.178,219.90164a8,8,0,0,0,11.44277,9.67074l168.91488-94.59233A8,8,0,0,0,219.53563,121.02Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M219.53563,121.02,50.62075,26.42762A8,8,0,0,0,39.178,36.09836l31.86106,89.211a8,8,0,0,1,0,5.38138L39.178,219.90164a8,8,0,0,0,11.44277,9.67074l168.91488-94.59233A8,8,0,0,0,219.53563,121.02Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "128",
        x2: "136",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.44434,114.03906,54.5293,19.44727A16.00042,16.00042,0,0,0,31.64355,38.78906L60.64746,120H136a8,8,0,0,1,0,16H60.64746L31.64355,217.21094a16.0398,16.0398,0,0,0,15.041,21.4082,16.039,16.039,0,0,0,7.8457-2.06641l168.91309-94.59179a16.00165,16.00165,0,0,0,.001-27.92188Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.53563,121.02,50.62075,26.42762A8,8,0,0,0,39.178,36.09836l31.86106,89.211a8,8,0,0,1,0,5.38138L39.178,219.90164a8,8,0,0,0,11.44277,9.67074l168.91488-94.59233A8,8,0,0,0,219.53563,121.02Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "128",
        x2: "136",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.53563,121.02,50.62075,26.42762A8,8,0,0,0,39.178,36.09836l31.86106,89.211a8,8,0,0,1,0,5.38138L39.178,219.90164a8,8,0,0,0,11.44277,9.67074l168.91488-94.59233A8,8,0,0,0,219.53563,121.02Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "128",
        x2: "136",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M219.53563,121.02,50.62075,26.42762A8,8,0,0,0,39.178,36.09836l31.86106,89.211a8,8,0,0,1,0,5.38138L39.178,219.90164a8,8,0,0,0,11.44277,9.67074l168.91488-94.59233A8,8,0,0,0,219.53563,121.02Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "128",
        x2: "136",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PaperPlaneRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7J(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PaperPlaneRight.displayName = "PaperPlaneRight";

var renderPathFor$7K = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M210.25072,35.878,23.923,88.432a8,8,0,0,0-1.253,14.9295l85.61084,40.5525a8.00008,8.00008,0,0,1,3.80521,3.80521L152.63852,233.33a8,8,0,0,0,14.9295-1.253L220.122,45.74928A8,8,0,0,0,210.25072,35.878Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "110.86292",
        y1: "145.13708",
        x2: "156.11775",
        y2: "99.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M210.25072,35.878,23.923,88.432a8,8,0,0,0-1.253,14.9295l85.61084,40.5525a8.00008,8.00008,0,0,1,3.80521,3.80521L152.63852,233.33a8,8,0,0,0,14.9295-1.253L220.122,45.74928A8,8,0,0,0,210.25072,35.878Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M210.25072,35.878,23.923,88.432a8,8,0,0,0-1.253,14.9295l85.61084,40.5525a8.00008,8.00008,0,0,1,3.80521,3.80521L152.63852,233.33a8,8,0,0,0,14.9295-1.253L220.122,45.74928A8,8,0,0,0,210.25072,35.878Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "110.86292",
        y1: "145.13708",
        x2: "156.11775",
        y2: "99.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.73633,32.26367a16.01051,16.01051,0,0,0-15.65723-4.085L21.751,80.73242a15.9995,15.9995,0,0,0-2.50586,29.8584l77.93359,36.916,53.28223-53.28223a8.00052,8.00052,0,0,1,11.31445,11.31445l-53.28223,53.28223,36.916,77.93359a15.85235,15.85235,0,0,0,14.41406,9.15235q.687,0,1.38379-.05762A15.86994,15.86994,0,0,0,175.26758,234.249L227.82129,47.9209A16.0173,16.0173,0,0,0,223.73633,32.26367Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M210.25072,35.878,23.923,88.432a8,8,0,0,0-1.253,14.9295l85.61084,40.5525a8.00008,8.00008,0,0,1,3.80521,3.80521L152.63852,233.33a8,8,0,0,0,14.9295-1.253L220.122,45.74928A8,8,0,0,0,210.25072,35.878Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "110.86292",
        y1: "145.13708",
        x2: "156.11775",
        y2: "99.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M210.25072,35.878,23.923,88.432a8,8,0,0,0-1.253,14.9295l85.61084,40.5525a8.00008,8.00008,0,0,1,3.80521,3.80521L152.63852,233.33a8,8,0,0,0,14.9295-1.253L220.122,45.74928A8,8,0,0,0,210.25072,35.878Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "110.86292",
        y1: "145.13708",
        x2: "156.11775",
        y2: "99.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M210.25072,35.878,23.923,88.432a8,8,0,0,0-1.253,14.9295l85.61084,40.5525a8.00008,8.00008,0,0,1,3.80521,3.80521L152.63852,233.33a8,8,0,0,0,14.9295-1.253L220.122,45.74928A8,8,0,0,0,210.25072,35.878Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "110.86292",
        y1: "145.13708",
        x2: "156.11775",
        y2: "99.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PaperPlaneTilt = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7K(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PaperPlaneTilt.displayName = "PaperPlaneTilt";

var renderPathFor$7L = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M95.99414,175.99512,191.799,83.799a28,28,0,0,0-39.598-39.598L54.05887,142.05887a48,48,0,0,0,67.88226,67.88226l82.053-81.946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M159.99414,79.99512,76.68629,164.68629a16,16,0,0,0,22.62742,22.62742L198.62156,86.62253A32,32,0,1,0,153.36672,41.3677L54.05887,142.05887a48,48,0,0,0,67.88226,67.88226l82.053-81.946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M209.65479,122.3418a8,8,0,0,1-.00733,11.31347l-82.05322,81.94629a56.00006,56.00006,0,0,1-79.1919-79.20019L147.6709,35.751A39.99954,39.99954,0,1,1,204.27832,92.2793l-99.269,100.65136A23.99954,23.99954,0,1,1,71.02979,159.0293L154.291,74.38477a8.0001,8.0001,0,0,1,11.40625,11.2207L82.38965,170.29688a8,8,0,1,0,11.2666,11.36035L192.92578,81.00488a23.99971,23.99971,0,1,0-33.90185-33.97949L59.75488,147.67578a40.00024,40.00024,0,1,0,56.5293,56.6084L198.34082,122.335A7.99885,7.99885,0,0,1,209.65479,122.3418Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M159.99414,79.99512,76.68629,164.68629a16,16,0,0,0,22.62742,22.62742L198.62156,86.62253A32,32,0,1,0,153.36672,41.3677L54.05887,142.05887a48,48,0,0,0,67.88226,67.88226l82.053-81.946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M159.99414,79.99512,76.68629,164.68629a16,16,0,0,0,22.62742,22.62742L198.62156,86.62253A32,32,0,1,0,153.36672,41.3677L54.05887,142.05887a48,48,0,0,0,67.88226,67.88226l82.053-81.946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M159.99414,79.99512,76.68629,164.68629a16,16,0,0,0,22.62742,22.62742L198.62156,86.62253A32,32,0,1,0,153.36672,41.3677L54.05887,142.05887a48,48,0,0,0,67.88226,67.88226l82.053-81.946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Paperclip = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7L(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Paperclip.displayName = "Paperclip";

var renderPathFor$7M = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M183.99414,120H48a28,28,0,0,0,0,56H187.99414a48,48,0,1,0,0-96h-112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M78,143.99968H190A15.99984,15.99984,0,0,0,190,112H46c-17.23852,0-31.2131,14.32689-31.2131,32S28.76146,176,46,176H191.99414a48,48,0,1,0,0-96h-112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M191.99414,184H46c-21.62207,0-39.21289-17.94434-39.21289-40S24.37793,104,46,104H190a24,24,0,0,1,0,48H78a8,8,0,0,1,0-16H190a8,8,0,0,0,0-16H46c-12.7998,0-23.21289,10.7666-23.21289,24S33.2002,168,46,168H191.99414a40,40,0,1,0,0-80h-112a8,8,0,0,1,0-16h112a56,56,0,1,1,0,112Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M78,143.99968H190A15.99984,15.99984,0,0,0,190,112H46c-17.23852,0-31.2131,14.32689-31.2131,32S28.76146,176,46,176H191.99414a48,48,0,1,0,0-96h-112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M78,143.99968H190A15.99984,15.99984,0,0,0,190,112H46c-17.23852,0-31.2131,14.32689-31.2131,32S28.76146,176,46,176H191.99414a48,48,0,1,0,0-96h-112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M78,143.99968H190A15.99984,15.99984,0,0,0,190,112H46c-17.23852,0-31.2131,14.32689-31.2131,32S28.76146,176,46,176H191.99414a48,48,0,1,0,0-96h-112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PaperclipHorizontal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7M(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PaperclipHorizontal.displayName = "PaperclipHorizontal";

var renderPathFor$7N = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "200",
        cy: "200",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M72,56h96a32,32,0,0,1,0,64H72a40,40,0,0,0,0,80H176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "200",
        cy: "200",
        r: "24",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "200",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M72,56h96a32,32,0,0,1,0,64H72a40,40,0,0,0,0,80H176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,168a32.05794,32.05794,0,0,0-30.9873,24H72a32,32,0,0,1,0-64h96a40,40,0,0,0,0-80H72a8,8,0,0,0,0,16h96a24,24,0,0,1,0,48H72a48,48,0,0,0,0,96h97.0127A32.0015,32.0015,0,1,0,200,168Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "200",
        cy: "200",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M72,56h96a32,32,0,0,1,0,64H72a40,40,0,0,0,0,80H176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "200",
        cy: "200",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M72,56h96a32,32,0,0,1,0,64H72a40,40,0,0,0,0,80H176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "200",
        cy: "200",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M72,56h96a32,32,0,0,1,0,64H72a40,40,0,0,0,0,80H176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Path = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7N(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Path.displayName = "Path";

var renderPathFor$7O = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "48",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,48V208a16.01833,16.01833,0,0,1-16,16H164a16.01833,16.01833,0,0,1-16-16V48a16.01833,16.01833,0,0,1,16-16h36A16.01833,16.01833,0,0,1,216,48ZM92,32H56A16.01833,16.01833,0,0,0,40,48V208a16.01833,16.01833,0,0,0,16,16H92a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,92,32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "156",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48",
        y: "40",
        width: "52",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Pause = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7O(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Pause.displayName = "Pause";

var renderPathFor$7P = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "96",
        x2: "104",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "96",
        x2: "152",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "96",
        x2: "104",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "96",
        x2: "152",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24ZM112,160a8,8,0,0,1-16,0V96a8,8,0,0,1,16,0Zm48,0a8,8,0,0,1-16,0V96a8,8,0,0,1,16,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "96",
        x2: "104",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "96",
        x2: "152",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "96",
        x2: "104",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "96",
        x2: "152",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "96",
        x2: "104",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "96",
        x2: "152",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PauseCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7P(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PauseCircle.displayName = "PauseCircle";

var renderPathFor$7Q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "206.6386",
        y2: "183.06334",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "49.3614",
        y2: "183.06334",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "206.6386",
        y2: "183.06334",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "49.3614",
        y2: "183.06334",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M213.6377,186.938a104,104,0,1,0-171.2754,0,8.09637,8.09637,0,0,0,.44532.71387c.12011.17163.25537.32543.38623.48461a103.91407,103.91407,0,0,0,169.61279-.001c.13086-.15894.26563-.31226.38574-.48364A8.09637,8.09637,0,0,0,213.6377,186.938ZM216,128a87.46128,87.46128,0,0,1-11.63916,43.70215L136,123.8352V40.36743A88.117,88.117,0,0,1,216,128ZM120,40.36743V123.8352L51.63916,171.70215A87.96692,87.96692,0,0,1,120,40.36743Zm-59.16162,144.426L120,143.36816v72.26441A87.90216,87.90216,0,0,1,60.83838,184.79346ZM136,215.63257V143.36816l59.16162,41.4253A87.90216,87.90216,0,0,1,136,215.63257Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "206.6386",
        y2: "183.06334",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "49.3614",
        y2: "183.06334",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "206.6386",
        y2: "183.06334",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "49.3614",
        y2: "183.06334",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "206.6386",
        y2: "183.06334",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "49.3614",
        y2: "183.06334",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Peace = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7Q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Peace.displayName = "Peace";

var renderPathFor$7R = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.88745",
        cy: "44",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M153.91044,134.715,188.657,161.74012a12,12,0,1,0,16.97056-16.97057l-39.598-50.91169A19.93738,19.93738,0,0,0,151.88746,88h-48a19.93739,19.93739,0,0,0-14.14213,5.85786l-39.598,50.91169A12,12,0,1,0,67.1179,161.74012L101.86446,134.715,74.13088,222.3089a12,12,0,0,0,21.75139,10.14284l32.0052-50.37108h0l32.0052,50.37108A12,12,0,0,0,181.644,222.3089Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.88745",
        cy: "44",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M153.91044,134.715,188.657,161.74012a12,12,0,1,0,16.97056-16.97057l-39.598-50.91169A19.93738,19.93738,0,0,0,151.88746,88h-48a19.93739,19.93739,0,0,0-14.14213,5.85786l-39.598,50.91169A12,12,0,1,0,67.1179,161.74012L101.86446,134.715,74.13088,222.3089a12,12,0,0,0,21.75139,10.14284l32.0052-50.37108h0l32.0052,50.37108A12,12,0,0,0,181.644,222.3089Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "127.88745",
        cy: "44",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M153.91044,134.715,188.657,161.74012a12,12,0,1,0,16.97056-16.97057l-39.598-50.91169A19.93738,19.93738,0,0,0,151.88746,88h-48a19.93739,19.93739,0,0,0-14.14213,5.85786l-39.598,50.91169A12,12,0,1,0,67.1179,161.74012L101.86446,134.715,74.13088,222.3089a12,12,0,0,0,21.75139,10.14284l32.0052-50.37108h0l32.0052,50.37108A12,12,0,0,0,181.644,222.3089Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "127.88745",
        cy: "44",
        r: "36"
      }), React__default.createElement("path", {
        d: "M211.67456,139.51367,172.34448,88.94629a7.93269,7.93269,0,0,0-.65723-.74512A27.81868,27.81868,0,0,0,151.88745,80h-48a27.81872,27.81872,0,0,0-19.79981,8.20117,7.93259,7.93259,0,0,0-.65722.74512L44.09936,139.51416A20.00055,20.00055,0,0,0,72.37378,167.7876l14.09961-10.96729-19.832,62.64014a20.00009,20.00009,0,0,0,36.23731,16.897l25.00879-39.35937,25.00879,39.35937a20.00007,20.00007,0,0,0,36.2373-16.897l-19.832-62.64014,14.09961,10.96729a20.00035,20.00035,0,0,0,28.27344-28.27393Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.88745",
        cy: "44",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M153.91044,134.715,188.657,161.74012a12,12,0,1,0,16.97056-16.97057l-39.598-50.91169A19.93738,19.93738,0,0,0,151.88746,88h-48a19.93739,19.93739,0,0,0-14.14213,5.85786l-39.598,50.91169A12,12,0,1,0,67.1179,161.74012L101.86446,134.715,74.13088,222.3089a12,12,0,0,0,21.75139,10.14284l32.0052-50.37108h0l32.0052,50.37108A12,12,0,0,0,181.644,222.3089Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.88745",
        cy: "44",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M153.91044,134.715,188.657,161.74012a12,12,0,1,0,16.97056-16.97057l-39.598-50.91169A19.93738,19.93738,0,0,0,151.88746,88h-48a19.93739,19.93739,0,0,0-14.14213,5.85786l-39.598,50.91169A12,12,0,1,0,67.1179,161.74012L101.86446,134.715,74.13088,222.3089a12,12,0,0,0,21.75139,10.14284l32.0052-50.37108h0l32.0052,50.37108A12,12,0,0,0,181.644,222.3089Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "127.88745",
        cy: "44",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M153.91044,134.715,188.657,161.74012a12,12,0,1,0,16.97056-16.97057l-39.598-50.91169A19.93738,19.93738,0,0,0,151.88746,88h-48a19.93739,19.93739,0,0,0-14.14213,5.85786l-39.598,50.91169A12,12,0,1,0,67.1179,161.74012L101.86446,134.715,74.13088,222.3089a12,12,0,0,0,21.75139,10.14284l32.0052-50.37108h0l32.0052,50.37108A12,12,0,0,0,181.644,222.3089Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Pedestrian = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7R(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Pedestrian.displayName = "Pedestrian";

var renderPathFor$7S = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.68629,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137l-120,120A8,8,0,0,1,92.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "164 200 204 160 192 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "43.99996",
        y1: "155.99997",
        x2: "99.99999",
        y2: "212.00001",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,120,136,64l26.34315-26.34315a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M92.68629,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137l-120,120A8,8,0,0,1,92.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 192 200 152 192 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.5088",
        y1: "160.5088",
        x2: "95.49114",
        y2: "215.49114",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M228.68652,88A15.89427,15.89427,0,0,0,224,76.68652L179.31348,31.999A16.02162,16.02162,0,0,0,156.68555,32l-120,120.00049a15.953,15.953,0,0,0-3.56836,5.4458,7.95719,7.95719,0,0,0-.27149.75976A16.00722,16.00722,0,0,0,32,163.31348V208a16.01833,16.01833,0,0,0,16,16H92.68652a16.00666,16.00666,0,0,0,5.15869-.86377c.23829-.07324.47388-.15674.70582-.25244A15.94661,15.94661,0,0,0,104,219.31348l83.666-83.666,3.4746,13.89844-36.79785,36.79736a8.00018,8.00018,0,0,0,11.31446,11.31348l40-40a8.00081,8.00081,0,0,0,2.10351-7.59717l-6.90136-27.60547L223.999,99.31445A15.895,15.895,0,0,0,228.68652,88ZM192,108.68555,147.314,64,168,43.31348,212.68555,88Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.68629,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137l-120,120A8,8,0,0,1,92.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "160 192 200 152 192 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.50833",
        y1: "160.50833",
        x2: "95.49164",
        y2: "215.49164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.68629,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137l-120,120A8,8,0,0,1,92.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "160 192 200 152 192 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.50826",
        y1: "160.50826",
        x2: "95.49177",
        y2: "215.49177",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.68629,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137l-120,120A8,8,0,0,1,92.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 192 200 152 192 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.50826",
        y1: "160.50826",
        x2: "95.49177",
        y2: "215.49177",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Pen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7S(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Pen.displayName = "Pen";

var renderPathFor$7T = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.00001",
        y1: "144",
        x2: "128.00001",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128.00001",
        cy: "120",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M213.54294,107.79559A111.59855,111.59855,0,0,1,184,32H72a111.59857,111.59857,0,0,1-29.54333,75.796L128,240Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M184,32H72a111.5987,111.5987,0,0,1-29.54346,75.7959L128,240l85.543-132.20459A111.59817,111.59817,0,0,1,184,32ZM128,144a24,24,0,1,1,24-24A23.99994,23.99994,0,0,1,128,144Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128.00001",
        y1: "144",
        x2: "128.00001",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128.00001",
        cy: "120",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M213.54294,107.79559A111.59855,111.59855,0,0,1,184,32H72a111.59857,111.59857,0,0,1-29.54333,75.796L128,240Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M219.43164,102.37988A103.69573,103.69573,0,0,1,192,32.0937,8.04,8.04,0,0,0,184,24H72a8.03995,8.03995,0,0,0-8,8.09369,103.69821,103.69821,0,0,1-27.4316,70.28717,8,8,0,0,0-.82813,9.76123l76.90148,118.84827A4,4,0,0,0,120,228.81736V150.9873a32,32,0,1,1,16,0v77.83a4,4,0,0,0,7.35829,2.173L220.25977,112.1416A8.00061,8.00061,0,0,0,219.43164,102.37988Z"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "16"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.00001",
        y1: "144",
        x2: "128.00001",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128.00001",
        cy: "120",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M213.54294,107.79559A111.59855,111.59855,0,0,1,184,32H72a111.59857,111.59857,0,0,1-29.54333,75.796L128,240Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.00001",
        y1: "144",
        x2: "128.00001",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128.00001",
        cy: "120",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M213.54294,107.79559A111.59855,111.59855,0,0,1,184,32H72a111.59857,111.59857,0,0,1-29.54333,75.796L128,240Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.00001",
        y1: "144",
        x2: "128.00001",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128.00001",
        cy: "120",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M213.54294,107.79559A111.59855,111.59855,0,0,1,184,32H72a111.59857,111.59857,0,0,1-29.54333,75.796L128,240Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PenNib = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7T(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PenNib.displayName = "PenNib";

var renderPathFor$7U = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.68629,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137l-120,120A8,8,0,0,1,92.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "44",
        y1: "156",
        x2: "100",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M136,64l56,56,26.34315-26.34315a8,8,0,0,0,0-11.3137l-44.6863-44.6863a8,8,0,0,0-11.3137,0Z"
      })), React__default.createElement("line", {
        x1: "95.48882",
        y1: "215.48882",
        x2: "40.5088",
        y2: "160.5088",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.68629,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137l-120,120A8,8,0,0,1,92.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,76.68652,179.314,32a15.99948,15.99948,0,0,0-22.62744,0L130.34473,58.3418l-.00147.00146-.00146.00147L36.687,151.99951A15.89429,15.89429,0,0,0,32,163.31348V208a16.01833,16.01833,0,0,0,16,16H92.68652A15.89438,15.89438,0,0,0,104,219.31348l120.00049-120A16.01823,16.01823,0,0,0,224,76.68652Zm-32,32L147.31372,64,168,43.31348,212.68652,88Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.68629,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137l-120,120A8,8,0,0,1,92.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "95.48882",
        y1: "215.48882",
        x2: "40.5088",
        y2: "160.5088",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.68629,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137l-120,120A8,8,0,0,1,92.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "95.48882",
        y1: "215.48882",
        x2: "40.5088",
        y2: "160.5088",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.68629,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137l-120,120A8,8,0,0,1,92.68629,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "95.48882",
        y1: "215.48882",
        x2: "40.5088",
        y2: "160.5088",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Pencil = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7U(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Pencil.displayName = "Pencil";

var renderPathFor$7V = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "176 211.161 176 176 128 72 80 176 80 211.164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "150.15385",
        y1: "132",
        x2: "105.84615",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M80,196a24,24,0,0,1,48,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,224V196a24,24,0,0,1,48,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M195.88226,60.11768A96.00006,96.00006,0,1,0,80,211.145V176L128,72l48,104v35.145A96.01933,96.01933,0,0,0,195.88226,60.11768Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M144,184a16,16,0,0,1,32,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,184a16,16,0,0,1,32,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M144,222.66446V184a16,16,0,0,0-32,0v38.66482",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "176 211.161 176 176 128 72 80 176 80 211.164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "150.15385",
        y1: "120",
        x2: "105.84615",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M201.53906,54.46094A103.99994,103.99994,0,1,0,54.46094,201.53906,103.99994,103.99994,0,1,0,201.53906,54.46094ZM110.96484,128h34.07032l14.7716,32.00488A23.89985,23.89985,0,0,0,144,166.13086a23.94341,23.94341,0,0,0-32,0,23.89985,23.89985,0,0,0-15.80676-6.126Zm79.26075,62.22461Q187.23,193.22022,184,195.8833V176a8.00423,8.00423,0,0,0-.73633-3.35254l-48-104a8,8,0,0,0-14.52734,0l-48,104A8.00423,8.00423,0,0,0,72,176v19.8833q-3.22228-2.66822-6.22559-5.65869a87.99958,87.99958,0,1,1,124.45118,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M144,184a16,16,0,0,1,32,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M80,184a16,16,0,0,1,32,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M144,222.66446V184a16,16,0,0,0-32,0v38.66482",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "176 211.161 176 176 128 72 80 176 80 211.164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "105.84615",
        y1: "120",
        x2: "150.15385",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M144,184a16,16,0,0,1,32,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M80,184a16,16,0,0,1,32,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M144,222.66446V184a16,16,0,0,0-32,0v38.66482",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "176 211.161 176 176 128 72 80 176 80 211.164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "105.84615",
        y1: "120",
        x2: "150.15385",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M144,184a16,16,0,0,1,32,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,184a16,16,0,0,1,32,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M144,222.66446V184a16,16,0,0,0-32,0v38.66482",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "176 211.161 176 176 128 72 80 176 80 211.164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "105.84615",
        y1: "120",
        x2: "150.15385",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PencilCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7V(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PencilCircle.displayName = "PencilCircle";

var renderPathFor$7W = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "44",
        y1: "156",
        x2: "103.99998",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "216",
        y1: "216",
        x2: "96",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,120,136,64l26.34315-26.34315a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M96,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "216 216 96 216 40.509 160.509",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,208H115.314l82.33838-82.33887.00489-.00439.00439-.00488L223.999,99.31445A15.99888,15.99888,0,0,0,224,76.68652L179.31348,31.999A16.02162,16.02162,0,0,0,156.68555,32l-120,120.00049a15.95392,15.95392,0,0,0-3.572,5.45654c-.08228.19971-.15162.40283-.21705.60742A15.9896,15.9896,0,0,0,32,163.31348V208a16.01833,16.01833,0,0,0,16,16H216a8,8,0,0,0,0-16ZM168,43.31348,212.68555,88,192,108.68555,147.314,64Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "216 216 96 216 40.509 160.509",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "216 216 96 216 40.509 160.509",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "216 216 96 216 40.509 160.509",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PencilLine = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7W(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PencilLine.displayName = "PencilLine";

var renderPathFor$7X = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M136,64l56,56,26.34315-26.34315a8,8,0,0,0,0-11.3137l-44.6863-44.6863a8,8,0,0,0-11.3137,0Z"
      })), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M96,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,76.68652,179.314,32a15.99948,15.99948,0,0,0-22.62744,0L130.34473,58.3418l-.00147.00146-.00146.00147L36.687,151.99951A15.89429,15.89429,0,0,0,32,163.31348V208a16.01833,16.01833,0,0,0,16,16H92.68652A15.89438,15.89438,0,0,0,104,219.31348l120.00049-120A16.01823,16.01823,0,0,0,224,76.68652Zm-32,32L147.31372,64,168,43.31348,212.68652,88Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,216H48a8,8,0,0,1-8-8V163.31371a8,8,0,0,1,2.34315-5.65686l120-120a8,8,0,0,1,11.3137,0l44.6863,44.6863a8,8,0,0,1,0,11.3137Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "64",
        x2: "192",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PencilSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7X(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PencilSimple.displayName = "PencilSimple";

var renderPathFor$7Y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "28",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "28",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M205.65674,50.34326a7.99915,7.99915,0,0,0-11.31348,0l-144,144a7.99984,7.99984,0,1,0,11.31348,11.31348l144-144A7.99915,7.99915,0,0,0,205.65674,50.34326Z"
      }), React__default.createElement("path", {
        d: "M76,108a32,32,0,1,0-22.62744-9.3728A31.78931,31.78931,0,0,0,76,108Z"
      }), React__default.createElement("path", {
        d: "M202.62744,157.37256a31.98536,31.98536,0,1,0,0,45.25488A32.03584,32.03584,0,0,0,202.62744,157.37256Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "76",
        r: "28",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "180",
        r: "28",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Percent = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7Y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Percent.displayName = "Percent";

var renderPathFor$7Z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.97168,158.42676l-46.83789-20.07324a15.95139,15.95139,0,0,0-15.17871,1.39453l-25.043,16.69336A76.54083,76.54083,0,0,1,99.707,121.3916l.00195-.00195,16.63477-25.418a15.96924,15.96924,0,0,0,1.32031-15.06641L97.57227,34.02734a16.02839,16.02839,0,0,0-16.65235-9.583A56.07029,56.07029,0,0,0,32,80c0,79.40234,64.59766,144,144,144a56.07032,56.07032,0,0,0,55.55566-48.9209A16.03476,16.03476,0,0,0,221.97168,158.42676Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Phone = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7Z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Phone.displayName = "Phone";

var renderPathFor$7_ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M159.41743,40A80.14832,80.14832,0,0,1,216,96.58261",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M149.229,78.02345a44.10448,44.10448,0,0,1,28.74753,28.74747",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M159.41743,40A80.14832,80.14832,0,0,1,216,96.58261",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M151.13313,70.91728a48.089,48.089,0,0,1,33.94958,33.9496",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M221.97168,158.42676l-46.83789-20.07324a15.95139,15.95139,0,0,0-15.17871,1.39453l-25.043,16.69336A76.54083,76.54083,0,0,1,99.707,121.3916l.00195-.00195,16.63477-25.418a15.96924,15.96924,0,0,0,1.32031-15.06641L97.57227,34.02734a16.02839,16.02839,0,0,0-16.65235-9.583A56.07029,56.07029,0,0,0,32,80c0,79.40234,64.59766,144,144,144a56.07032,56.07032,0,0,0,55.55566-48.9209A16.03476,16.03476,0,0,0,221.97168,158.42676Z"
      }), React__default.createElement("path", {
        d: "M157.35156,47.72852a72.12078,72.12078,0,0,1,50.91992,50.91992,7.99975,7.99975,0,0,0,15.457-4.13086,88.16381,88.16381,0,0,0-62.2461-62.2461,7.99975,7.99975,0,0,0-4.13086,15.457Z"
      }), React__default.createElement("path", {
        d: "M149.06738,78.64551a40.06626,40.06626,0,0,1,28.28711,28.28711,7.99975,7.99975,0,0,0,15.457-4.13086,56.10589,56.10589,0,0,0-39.61328-39.61328,7.99975,7.99975,0,0,0-4.13086,15.457Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M159.41743,40A80.14832,80.14832,0,0,1,216,96.58261",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M151.13313,70.91728a48.089,48.089,0,0,1,33.94958,33.9496",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M159.41743,40A80.14832,80.14832,0,0,1,216,96.58261",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M151.13313,70.91728a48.089,48.089,0,0,1,33.94958,33.9496",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M159.41743,40A80.14832,80.14832,0,0,1,216,96.58261",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M151.13313,70.91728a48.089,48.089,0,0,1,33.94958,33.9496",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PhoneCall = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7_(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PhoneCall.displayName = "PhoneCall";

var renderPathFor$7$ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M155.371,101.25063a84.3478,84.3478,0,0,0-55.10429.12547,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,161.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,136,136,0,0,1,192.333,0,48.00881,48.00881,0,0,1,4.02766,63.31573,7.97345,7.97345,0,0,1-9.2595,2.47378l-47.35377-18.94151a8,8,0,0,1-4.85991-5.79231L160.51024,107.151A7.9287,7.9287,0,0,0,155.371,101.25063Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "200",
        x2: "216",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M155.371,101.25063a84.3478,84.3478,0,0,0-55.10429.12547,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,161.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,136,136,0,0,1,192.333,0,48.00881,48.00881,0,0,1,4.02766,63.31573,7.97345,7.97345,0,0,1-9.2595,2.47378l-47.35377-18.94151a8,8,0,0,1-4.85991-5.79231L160.51024,107.151A7.9287,7.9287,0,0,0,155.371,101.25063Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M155.371,101.25063a84.3478,84.3478,0,0,0-55.10429.12547,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,161.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,136,136,0,0,1,192.333,0,48.00881,48.00881,0,0,1,4.02766,63.31573,7.97345,7.97345,0,0,1-9.2595,2.47378l-47.35377-18.94151a8,8,0,0,1-4.85991-5.79231L160.51024,107.151A7.9287,7.9287,0,0,0,155.371,101.25063Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "200",
        x2: "216",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M229.82422,90.17578c-56.14551-56.14355-147.501-56.14648-203.64844.001a56.07211,56.07211,0,0,0-4.69043,73.87695,16.03254,16.03254,0,0,0,18.55078,4.99707L87.35059,150.125a15.94917,15.94917,0,0,0,9.74609-11.71875l5.90527-29.51172a76.51611,76.51611,0,0,1,49.67676-.10937v.00195l6.21094,29.73828a15.963,15.963,0,0,0,9.7207,11.584l47.35254,18.9414a16.03618,16.03618,0,0,0,18.55273-4.99805A56.07343,56.07343,0,0,0,229.82422,90.17578Z"
      }), React__default.createElement("path", {
        d: "M216,192H40a8,8,0,0,0,0,16H216a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M155.371,101.25063a84.3478,84.3478,0,0,0-55.10429.12547,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,161.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,136,136,0,0,1,192.333,0,48.00881,48.00881,0,0,1,4.02766,63.31573,7.97345,7.97345,0,0,1-9.2595,2.47378l-47.35377-18.94151a8,8,0,0,1-4.85991-5.79231L160.51024,107.151A7.9287,7.9287,0,0,0,155.371,101.25063Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "200",
        x2: "216",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M155.371,101.25063a84.3478,84.3478,0,0,0-55.10429.12547,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,161.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,136,136,0,0,1,192.333,0,48.00881,48.00881,0,0,1,4.02766,63.31573,7.97345,7.97345,0,0,1-9.2595,2.47378l-47.35377-18.94151a8,8,0,0,1-4.85991-5.79231L160.51024,107.151A7.9287,7.9287,0,0,0,155.371,101.25063Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "200",
        x2: "216",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M155.371,101.25063a84.3478,84.3478,0,0,0-55.10429.12547,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,161.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,136,136,0,0,1,192.333,0,48.00881,48.00881,0,0,1,4.02766,63.31573,7.97345,7.97345,0,0,1-9.2595,2.47378l-47.35377-18.94151a8,8,0,0,1-4.85991-5.79231L160.51024,107.151A7.9287,7.9287,0,0,0,155.371,101.25063Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "200",
        x2: "216",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PhoneDisconnect = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$7$(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PhoneDisconnect.displayName = "PhoneDisconnect";

var renderPathFor$80 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "160 56 160 96 200 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 56 160 96 200 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M221.97168,158.42676l-46.83789-20.07324a15.94874,15.94874,0,0,0-15.17871,1.39453l-25.043,16.69336A76.54083,76.54083,0,0,1,99.707,121.3916l.00195-.00195,16.63477-25.418a15.96924,15.96924,0,0,0,1.32031-15.06641L97.57227,34.02734a16.036,16.036,0,0,0-16.65235-9.583A56.07029,56.07029,0,0,0,32,80c0,79.40234,64.59766,144,144,144a56.07032,56.07032,0,0,0,55.55566-48.9209A16.03476,16.03476,0,0,0,221.97168,158.42676Z"
      }), React__default.createElement("path", {
        d: "M152.08594,97.10889c.021.15283.03955.30566.06933.45752.02491.125.05957.24609.09034.36914.03271.13037.06152.26123.10058.39013.03662.12061.082.23682.124.355.04541.12891.08838.25782.14063.38477.04492.10742.09766.21094.147.31641.06153.13183.12061.26464.18994.39355.05176.09717.11133.189.167.2832.07666.13037.15087.26172.23584.38819.0664.09863.14062.1914.21093.28662.084.11474.16407.231.25537.3418.11622.14111.2417.27343.36719.40625.0542.0581.10205.11914.15869.17578.0542.0542.11377.10058.16895.15283.13525.12744.27.25537.41406.37353.10645.08789.21826.16455.32813.24561.10009.07422.19726.15185.30078.22119.12207.08154.248.15234.37353.22656.09912.05909.19629.12159.29834.17627.124.0669.25147.12305.37842.18262.11035.05176.21875.10693.332.15381.1211.05029.24463.09082.36768.13476.12353.04444.2456.0918.37207.13038.12158.03662.24512.06347.36816.09472.13037.03272.25879.06885.3916.09522.14063.02832.28321.04492.42481.06494.1167.0166.231.03857.34912.05029.26221.02588.52588.04.78955.04h40a8,8,0,0,0,0-16H179.31445l34.34278-34.34277a8.00053,8.00053,0,0,0-11.31446-11.31446L168,76.68555V56a8,8,0,0,0-16,0V95.99512c0,.26562.01367.53174.04.79687C152.05078,96.89941,152.07129,97.00293,152.08594,97.10889Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "160 56 160 96 200 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "160 56 160 96 200 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "160 56 160 96 200 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PhoneIncoming = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$80(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PhoneIncoming.displayName = "PhoneIncoming";

var renderPathFor$81 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M221.97168,158.42676l-46.83789-20.07324a15.95139,15.95139,0,0,0-15.17871,1.39453l-25.043,16.69336A76.54083,76.54083,0,0,1,99.707,121.3916l.00195-.00195,16.63477-25.418a15.96924,15.96924,0,0,0,1.32031-15.06641L97.57227,34.02734a16.02839,16.02839,0,0,0-16.65235-9.583A56.07029,56.07029,0,0,0,32,80c0,79.40234,64.59766,144,144,144a56.07032,56.07032,0,0,0,55.55566-48.9209A16.03476,16.03476,0,0,0,221.97168,158.42676Z"
      }), React__default.createElement("path", {
        d: "M160,104a7.97772,7.97772,0,0,0,5.65723-2.34277L200,67.31445V88a8,8,0,0,0,16,0V48.00488c0-.26562-.01367-.53174-.04-.79687-.01074-.10742-.03125-.21094-.0459-.3169-.021-.15283-.03955-.30566-.06933-.45752-.02491-.125-.05957-.24609-.09034-.36914-.03271-.13037-.06152-.26123-.10058-.39013-.03662-.12061-.082-.23682-.124-.355-.04541-.12891-.08838-.25782-.14063-.38477-.04492-.10742-.09766-.21094-.147-.31641-.06153-.13183-.12061-.26464-.18994-.39355-.05176-.09717-.11133-.189-.167-.2832-.07666-.13037-.15087-.26172-.23584-.38819-.0664-.09863-.14062-.1914-.21093-.28662-.084-.11474-.16407-.231-.25537-.3418-.11622-.14111-.2417-.27343-.36719-.40625-.0542-.0581-.10205-.11914-.15869-.17578-.05323-.05322-.11133-.09863-.166-.1499-.13623-.12891-.27246-.25781-.417-.377-.10449-.08545-.21436-.16065-.32178-.24024-.10254-.07617-.20166-.15527-.3081-.22656-.11817-.0791-.24073-.148-.36231-.22021-.10351-.06153-.2041-.12647-.31055-.1836-.11865-.063-.24023-.1167-.36084-.17334-.11669-.05517-.23144-.11328-.35107-.16308-.1123-.04639-.22754-.084-.3418-.125-.13281-.04834-.26367-.09864-.39941-.13965-.10938-.0332-.2207-.05713-.33106-.08545-.14257-.03613-.2832-.07568-.42822-.10449-.12158-.02393-.24414-.0376-.3667-.05567-.13574-.02051-.27-.04541-.4082-.05908-.20215-.01953-.40479-.02637-.60742-.03076C208.11768,40.00781,208.05957,40,208,40H168a8,8,0,0,0,0,16h20.68555L154.34277,90.34277A8,8,0,0,0,160,104Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PhoneOutgoing = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$81(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PhoneOutgoing.displayName = "PhoneOutgoing";

var renderPathFor$82 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M114.9947,113.69328a83.97034,83.97034,0,0,0-14.728,3.68282,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,177.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,135.45028,135.45028,0,0,1,51.9466-32.47622",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M131.18495,72.03707a135.5393,135.5393,0,0,1,92.98157,39.79641,48.00881,48.00881,0,0,1,4.02766,63.31573,7.8198,7.8198,0,0,1-1.76283,1.66165",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M155.371,117.25063a84.3478,84.3478,0,0,0-55.10429.12547,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,177.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,136,136,0,0,1,192.333,0,48.00881,48.00881,0,0,1,4.02766,63.31573,7.97345,7.97345,0,0,1-9.2595,2.47378l-47.35377-18.94151a8,8,0,0,1-4.85991-5.79231L160.51024,123.151A7.9287,7.9287,0,0,0,155.371,117.25063Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M114.9947,113.69328a83.97034,83.97034,0,0,0-14.728,3.68282,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,177.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,135.45028,135.45028,0,0,1,51.9466-32.47622",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M120.52563,72.20427a135.66,135.66,0,0,1,103.64089,39.62921,48.00881,48.00881,0,0,1,4.02766,63.31573,7.97345,7.97345,0,0,1-9.2595,2.47378l-4.04895-1.61958",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M120.8877,108.28271c-.01416-.01562-.02832-.03173-.043-.04736l-31.083-34.19092c-.01611-.01855-.03272-.03613-.04883-.0542l-35.793-39.37207A8.0006,8.0006,0,1,0,42.08008,45.38184L70.03857,76.13623a142.75371,142.75371,0,0,0-43.86279,30.04053,56.07211,56.07211,0,0,0-4.69043,73.87695,16.03254,16.03254,0,0,0,18.55078,4.99707L87.35059,166.125a15.94917,15.94917,0,0,0,9.74609-11.71875l5.90527-29.51172a76.1958,76.1958,0,0,1,9.07422-2.51709l90.00391,99.0044a8.0006,8.0006,0,1,0,11.83984-10.76368Z"
      }), React__default.createElement("path", {
        d: "M229.82422,106.17578a144.20418,144.20418,0,0,0-109.73633-41.96A8.00053,8.00053,0,0,0,114.60547,77.585l94.36035,103.79883a8.0075,8.0075,0,0,0,2.94824,2.04687l4.04883,1.62012a16.03429,16.03429,0,0,0,18.55273-4.99805A56.07343,56.07343,0,0,0,229.82422,106.17578Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M114.9947,113.69328a83.97034,83.97034,0,0,0-14.728,3.68282,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,177.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,135.45028,135.45028,0,0,1,51.9466-32.47622",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M120.52563,72.20427a135.66,135.66,0,0,1,103.64089,39.62921,48.00881,48.00881,0,0,1,4.02766,63.31573,7.97345,7.97345,0,0,1-9.2595,2.47378l-4.04895-1.61958",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M114.9947,113.69328a83.97034,83.97034,0,0,0-14.728,3.68282,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,177.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,135.45028,135.45028,0,0,1,51.9466-32.47622",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M120.52563,72.20427a135.66,135.66,0,0,1,103.64089,39.62921,48.00881,48.00881,0,0,1,4.02766,63.31573,7.97345,7.97345,0,0,1-9.2595,2.47378l-4.04895-1.61958",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M114.9947,113.69328a83.97034,83.97034,0,0,0-14.728,3.68282,7.92755,7.92755,0,0,0-5.1169,5.95455l-5.89824,29.5076a8,8,0,0,1-4.87369,5.85972L37.06532,177.623a7.97345,7.97345,0,0,1-9.2595-2.47378,48.00881,48.00881,0,0,1,4.02766-63.31573,135.45028,135.45028,0,0,1,51.9466-32.47622",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M120.52563,72.20427a135.66,135.66,0,0,1,103.64089,39.62921,48.00881,48.00881,0,0,1,4.02766,63.31573,7.97345,7.97345,0,0,1-9.2595,2.47378l-4.04895-1.61958",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PhoneSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$82(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PhoneSlash.displayName = "PhoneSlash";

var renderPathFor$83 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "48",
        x2: "208",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "48",
        x2: "208",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M221.97168,158.42676l-46.83789-20.07324a15.94874,15.94874,0,0,0-15.17871,1.39453l-25.043,16.69336A76.54083,76.54083,0,0,1,99.707,121.3916l.00195-.00195,16.63477-25.418a15.96924,15.96924,0,0,0,1.32031-15.06641L97.57227,34.02734a16.03093,16.03093,0,0,0-16.65235-9.583A56.07029,56.07029,0,0,0,32,80c0,79.40234,64.59766,144,144,144a56.07032,56.07032,0,0,0,55.55566-48.9209A16.03476,16.03476,0,0,0,221.97168,158.42676Z"
      }), React__default.createElement("path", {
        d: "M154.34277,101.65723a8.00181,8.00181,0,0,0,11.31446,0L184,83.31445l18.34277,18.34278a8.00053,8.00053,0,0,0,11.31446-11.31446L195.31445,72l18.34278-18.34277a8.00053,8.00053,0,0,0-11.31446-11.31446L184,60.68555,165.65723,42.34277a8.00053,8.00053,0,0,0-11.31446,11.31446L172.68555,72,154.34277,90.34277A8.00122,8.00122,0,0,0,154.34277,101.65723Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "48",
        x2: "208",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "48",
        x2: "208",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.47629,124.81528a84.34782,84.34782,0,0,0,39.05334,38.8759,7.92754,7.92754,0,0,0,7.8287-.59231L164.394,146.40453a8,8,0,0,1,7.58966-.69723l46.837,20.073A7.97345,7.97345,0,0,1,223.619,174.077,48.00882,48.00882,0,0,1,176,216,136,136,0,0,1,40,80,48.00882,48.00882,0,0,1,81.923,32.381a7.97345,7.97345,0,0,1,8.29668,4.79823L110.31019,84.0571a8,8,0,0,1-.65931,7.53226L93.01449,117.00909A7.9287,7.9287,0,0,0,92.47629,124.81528Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "48",
        x2: "208",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "48",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PhoneX = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$83(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PhoneX.displayName = "PhoneX";

var renderPathFor$84 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "68",
        y1: "32",
        x2: "134",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "68",
        y: "32",
        width: "66",
        height: "132",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M134,164v66a66,66,0,0,1-66-66",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M134,164h8a66,66,0,0,0,0-132h-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "68 32 68 164 134 164 68 32",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "68",
        y1: "32",
        x2: "134",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "68",
        y: "32",
        width: "66",
        height: "132",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M134,164v66a66,66,0,0,1-66-66",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M134,164h8a66,66,0,0,0,0-132h-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M134,164h8a66,66,0,0,0,0-132h-8Z",
        opacity: "0.2"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M142,24H68c-.06836,0-.13477.00855-.20264.01026-.16162.004-.32275.01056-.48486.02447-.11377.00971-.22607.02387-.33838.03833-.14307.0185-.28613.039-.42871.06543-.13232.02429-.26221.05359-.39209.08435-.11865.02826-.23682.05725-.35449.09113-.15088.04315-.29883.09216-.4458.14386-.09668.034-.19287.06769-.28907.10565-.16113.06366-.31787.134-.47363.20764-.05566.02625-.11279.046-.168.07361-.03027.0152-.05761.03412-.08789.04968-.14795.0766-.2915.15979-.43408.24512-.0918.05481-.18457.10828-.27393.16626-.11572.07574-.22607.15729-.33789.23871-.10644.07776-.21435.15423-.3164.23657-.084.06811-.16309.14117-.24463.21258-.11719.10267-.23438.20472-.34473.31336-.06543.06445-.12549.13342-.18847.20007-.11426.12036-.228.2403-.3335.36682-.064.07611-.12158.15693-.18213.23542-.09424.12188-.18945.24267-.27637.36926-.07129.10406-.13476.21338-.20166.321-.06591.10669-.13427.21155-.19482.321-.0752.13513-.14111.27551-.2085.41528-.04248.08838-.08838.17493-.12744.26471-.0664.15186-.123.30841-.18017.465-.03125.08538-.06543.16943-.09375.25586-.04834.14813-.08741.2998-.127.45159-.02685.10328-.05664.20563-.07959.31-.02832.13-.04931.26233-.07129.39453-.02246.134-.04541.2674-.06152.40259-.01221.10742-.01855.21619-.02637.32483-.01269.16376-.023.32745-.0249.49225C60.00488,31.93187,60,31.96537,60,32V164a74.08385,74.08385,0,0,0,74,74,8.00008,8.00008,0,0,0,8-8V172a74,74,0,0,0,0-148ZM126,130.11137,80.94434,40H126ZM76.55176,172H126v49.4502A58.12735,58.12735,0,0,1,76.55176,172ZM142,156V40a58,58,0,0,1,0,116Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "68",
        y1: "32",
        x2: "134",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "68",
        y: "32",
        width: "66",
        height: "132",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M134,164v66a66,66,0,0,1-66-66",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M134,164h8a66,66,0,0,0,0-132h-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "68",
        y1: "32",
        x2: "134",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "68",
        y: "32",
        width: "66",
        height: "132",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M134,164v66a66,66,0,0,1-66-66",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M134,164h8a66,66,0,0,0,0-132h-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("line", {
        x1: "68",
        y1: "32",
        x2: "134",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "68",
        y: "32",
        width: "66",
        height: "132",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M134,164v66a66,66,0,0,1-66-66",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M134,164h8a66,66,0,0,0,0-132h-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      })));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PhosphorLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$84(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PhosphorLogo.displayName = "PhosphorLogo";

var renderPathFor$85 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M228.14833,121.17381,84.1717,33.18517A8,8,0,0,0,72,40.01136V215.98864a8,8,0,0,0,12.1717,6.82619l143.97663-87.98864A8,8,0,0,0,228.14833,121.17381Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M228.14833,121.17381,84.1717,33.18517A8,8,0,0,0,72,40.01136V215.98864a8,8,0,0,0,12.1717,6.82619l143.97663-87.98864A8,8,0,0,0,228.14833,121.17381Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M228.14833,121.17381,84.1717,33.18517A8,8,0,0,0,72,40.01136V215.98864a8,8,0,0,0,12.1717,6.82619l143.97663-87.98864A8,8,0,0,0,228.14833,121.17381Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232.3125,114.34375,88.34375,26.35937A15.99781,15.99781,0,0,0,64,40.00781V215.99219a16.00521,16.00521,0,0,0,24.34375,13.64843L232.3125,141.65625a16.00727,16.00727,0,0,0,0-27.3125Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M228.14833,121.17381,84.1717,33.18517A8,8,0,0,0,72,40.01136V215.98864a8,8,0,0,0,12.1717,6.82619l143.97663-87.98864A8,8,0,0,0,228.14833,121.17381Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M228.14833,121.17381,84.1717,33.18517A8,8,0,0,0,72,40.01136V215.98864a8,8,0,0,0,12.1717,6.82619l143.97663-87.98864A8,8,0,0,0,228.14833,121.17381Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M228.14833,121.17381,84.1717,33.18517A8,8,0,0,0,72,40.01136V215.98864a8,8,0,0,0,12.1717,6.82619l143.97663-87.98864A8,8,0,0,0,228.14833,121.17381Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Play = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$85(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Play.displayName = "Play";

var renderPathFor$86 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "164 128 108 92 108 164 164 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32a96,96,0,1,0,96,96A95.99975,95.99975,0,0,0,128,32ZM112,160V96l48,32Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "160 128 112 96 112 160 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm36.4375,110.65625-48,32A7.99612,7.99612,0,0,1,104,160V96a7.99612,7.99612,0,0,1,12.4375-6.65625l48,32a7.99959,7.99959,0,0,1,0,13.3125Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "160 128 112 96 112 160 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "160 128 112 96 112 160 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "160 128 112 96 112 160 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PlayCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$86(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PlayCircle.displayName = "PlayCircle";

var renderPathFor$87 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,120H136V40a8,8,0,0,0-16,0v80H40a8,8,0,0,0,0,16h80v80a8,8,0,0,0,16,0V136h80a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "40",
        x2: "128",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Plus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$87(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Plus.displayName = "Plus";

var renderPathFor$88 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,23.99805a104,104,0,1,0,104,104A104.12041,104.12041,0,0,0,128,23.99805Zm40,112H136v32a8,8,0,1,1-16,0v-32H88a8,8,0,0,1,0-16h32v-32a8,8,0,0,1,16,0v32h32a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "128",
        x2: "168",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PlusCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$88(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PlusCircle.displayName = "PlusCircle";

var renderPathFor$89 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "72",
        x2: "112",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "32",
        x2: "72",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "184",
        x2: "224",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "72",
        x2: "112",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "32",
        x2: "72",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "184",
        x2: "224",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M205.65674,50.34326a8,8,0,0,0-11.31348,0l-144,144a7.99984,7.99984,0,1,0,11.31348,11.31348l144-144A7.99915,7.99915,0,0,0,205.65674,50.34326Z"
      }), React__default.createElement("path", {
        d: "M64,112a8,8,0,0,0,16,0V80h32a8,8,0,0,0,0-16H80V32a8,8,0,0,0-16,0V64H32a8,8,0,0,0,0,16H64Z"
      }), React__default.createElement("path", {
        d: "M224,176H144a8,8,0,0,0,0,16h80a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "72",
        x2: "112",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "32",
        x2: "72",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "184",
        x2: "224",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "72",
        x2: "112",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "32",
        x2: "72",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "184",
        x2: "224",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "72",
        x2: "112",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "32",
        x2: "72",
        y2: "112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "184",
        x2: "224",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PlusMinus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$89(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PlusMinus.displayName = "PlusMinus";

var renderPathFor$8a = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88.40202",
        y1: "88.40202",
        x2: "60.11775",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "128",
        x2: "32",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88.40202",
        y1: "167.59798",
        x2: "60.11775",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "184",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "167.59798",
        x2: "195.88225",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "128",
        x2: "224",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "88.40202",
        x2: "195.88225",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32a96,96,0,1,0,96,96A95.99991,95.99991,0,0,0,128,32Zm0,152a56,56,0,1,1,56-56A56.00012,56.00012,0,0,1,128,184Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.40202",
        y1: "88.40202",
        x2: "60.11775",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "128",
        x2: "32",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.40202",
        y1: "167.59798",
        x2: "60.11775",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "184",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "167.59798",
        x2: "195.88225",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "128",
        x2: "224",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "88.40202",
        x2: "195.88225",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M202.16064,200.833a103.80643,103.80643,0,0,0,0-145.666,7.39654,7.39654,0,0,0-1.32666-1.32666,103.80639,103.80639,0,0,0-145.668,0A7.39654,7.39654,0,0,0,53.83936,55.167a103.80643,103.80643,0,0,0,0,145.666,7.39012,7.39012,0,0,0,1.32714,1.3269,103.80581,103.80581,0,0,0,145.667,0,7.39012,7.39012,0,0,0,1.32714-1.3269ZM40.36768,136h24.1499a63.6708,63.6708,0,0,0,12.95605,31.21216l-17.06884,17.0686A87.60592,87.60592,0,0,1,40.36768,136ZM60.40479,71.71924l17.06884,17.0686A63.6708,63.6708,0,0,0,64.51758,120H40.36768A87.60592,87.60592,0,0,1,60.40479,71.71924ZM215.63232,120h-24.1499a63.6708,63.6708,0,0,0-12.95605-31.21216l17.06884-17.0686A87.60592,87.60592,0,0,1,215.63232,120ZM167.21191,77.47339A63.66789,63.66789,0,0,0,136,64.51782V40.36743a87.60765,87.60765,0,0,1,48.28076,20.03736ZM120,64.51782A63.66789,63.66789,0,0,0,88.78809,77.47339L71.71924,60.40479A87.60765,87.60765,0,0,1,120,40.36743ZM88.78809,178.52661A63.66789,63.66789,0,0,0,120,191.48218v24.15039a87.60765,87.60765,0,0,1-48.28076-20.03736ZM136,191.48218a63.66789,63.66789,0,0,0,31.21191-12.95557l17.06885,17.0686A87.60765,87.60765,0,0,1,136,215.63257Zm42.52637-24.27A63.6708,63.6708,0,0,0,191.48242,136h24.1499a87.60592,87.60592,0,0,1-20.03711,48.28076Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88.40202",
        y1: "88.40202",
        x2: "60.11775",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "128",
        x2: "32",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88.40202",
        y1: "167.59798",
        x2: "60.11775",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "184",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "167.59798",
        x2: "195.88225",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "128",
        x2: "224",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "88.40202",
        x2: "195.88225",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88.40202",
        y1: "88.40202",
        x2: "60.11775",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "128",
        x2: "32",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88.40202",
        y1: "167.59798",
        x2: "60.11775",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "184",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "167.59798",
        x2: "195.88225",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "128",
        x2: "224",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "88.40202",
        x2: "195.88225",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.40202",
        y1: "88.40202",
        x2: "60.11775",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "128",
        x2: "32",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.40202",
        y1: "167.59798",
        x2: "60.11775",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "184",
        x2: "128",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "167.59798",
        x2: "195.88225",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "128",
        x2: "224",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "167.59798",
        y1: "88.40202",
        x2: "195.88225",
        y2: "60.11775",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PokerChip = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8a(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PokerChip.displayName = "PokerChip";

var renderPathFor$8b = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99219",
        y1: "48.00288",
        x2: "127.99219",
        y2: "124.00288",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M176.00189,54.23268a88,88,0,1,1-96.00346-.00021",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99219",
        y1: "48.00288",
        x2: "127.99219",
        y2: "124.00288",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176.00189,54.23268a88,88,0,1,1-96.00346-.00021",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,23.99988a104,104,0,1,0,104,104A104.11786,104.11786,0,0,0,128,23.99988Zm-8.00781,32.00293a8,8,0,0,1,16,0v60a8,8,0,1,1-16,0ZM128,207.99988A79.98292,79.98292,0,0,1,83.53516,61.52136a8,8,0,1,1,8.91357,13.28711,63.99978,63.99978,0,1,0,71.08838-.00976,8,8,0,0,1,8.91016-13.28955A79.98322,79.98322,0,0,1,128,207.99988Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99219",
        y1: "48.00288",
        x2: "127.99219",
        y2: "124.00288",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M176.00189,54.23268a88,88,0,1,1-96.00346-.00021",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99219",
        y1: "48.00288",
        x2: "127.99219",
        y2: "124.00288",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M176.00189,54.23268a88,88,0,1,1-96.00346-.00021",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99219",
        y1: "48.00288",
        x2: "127.99219",
        y2: "124.00288",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176.00189,54.23268a88,88,0,1,1-96.00346-.00021",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Power = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8b(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Power.displayName = "Power";

var renderPathFor$8c = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "63.99414",
        y: "40",
        width: "128",
        height: "40",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "63.99414",
        y: "156",
        width: "128",
        height: "64",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M63.99414,176h-36V96c0-8.83656,7.7604-16,17.33333-16H210.66081c9.57293,0,17.33333,7.16344,17.33333,16v80h-36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "116",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M210.66083,80H45.32751c-9.57293,0-17.33337,7.16357-17.33337,16v80h36V152h128v24h36V96C227.99414,87.16357,220.23376,80,210.66083,80Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "63.99414",
        y: "40",
        width: "128",
        height: "40",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "63.99414",
        y: "152",
        width: "128",
        height: "68",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M63.99414,176h-36V96c0-8.83656,7.7604-16,17.33333-16H210.66081c9.57293,0,17.33333,7.16344,17.33333,16v80h-36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "116",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M210.66064,72h-10.6665V40a8.00008,8.00008,0,0,0-8-8h-128a8.00008,8.00008,0,0,0-8,8V72H45.32764c-13.96875,0-25.3335,10.7666-25.3335,24v80a8.00008,8.00008,0,0,0,8,8h28v36a8.00008,8.00008,0,0,0,8,8h128a8.00008,8.00008,0,0,0,8-8V184h28a8.00008,8.00008,0,0,0,8-8V96C235.99414,82.7666,224.62939,72,210.66064,72ZM71.99414,48h112V72h-112Zm112,164h-112V160h112Zm4-84a12,12,0,1,1,12-12A12,12,0,0,1,187.99414,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "63.994 80 63.994 40 191.994 40 191.994 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "63.99414",
        y: "152",
        width: "128",
        height: "68",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M63.99414,176h-36V96c0-8.83656,7.7604-16,17.33333-16H210.66081c9.57293,0,17.33333,7.16344,17.33333,16v80h-36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "116",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "63.994 80 63.994 40 191.994 40 191.994 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "63.99414",
        y: "152",
        width: "128",
        height: "68",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M63.99414,176h-36V96c0-8.83656,7.7604-16,17.33333-16H210.66081c9.57293,0,17.33333,7.16344,17.33333,16v80h-36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "116",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "63.994 80 63.994 40 191.994 40 191.994 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "63.99414",
        y: "152",
        width: "128",
        height: "68",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M63.99414,176h-36V96c0-8.83656,7.7604-16,17.33333-16H210.66081c9.57293,0,17.33333,7.16344,17.33333,16v80h-36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "116",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Printer = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8c(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Printer.displayName = "Printer";

var renderPathFor$8d = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "60.11824",
        y1: "60.11775",
        x2: "195.88274",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "60.11824",
        y1: "60.11775",
        x2: "195.88274",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,128.00012a71.6357,71.6357,0,0,1-15.78027,44.90527L83.09424,71.78039A71.94387,71.94387,0,0,1,200,128.00012Zm-144,0a71.94342,71.94342,0,0,0,116.90576,56.21924L71.78027,83.09436A71.63607,71.63607,0,0,0,56,128.00012Zm180,0a108,108,0,1,1-108-108A108.12249,108.12249,0,0,1,236,128.00012Zm-20,0a88,88,0,1,0-88,88A88.09957,88.09957,0,0,0,216,128.00012Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "60.11824",
        y1: "60.11775",
        x2: "195.88274",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "60.11824",
        y1: "60.11775",
        x2: "195.88274",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "60.11824",
        y1: "60.11775",
        x2: "195.88274",
        y2: "195.88225",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Prohibit = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8d(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Prohibit.displayName = "Prohibit";

var renderPathFor$8e = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128.00452",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "99.71622",
        y1: "99.72024",
        x2: "156.28476",
        y2: "156.28879",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128.00452",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128.00452",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "99.71622",
        y1: "99.72024",
        x2: "156.28476",
        y2: "156.28879",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128.00049,24.00452a104,104,0,1,0,104,104A104.12041,104.12041,0,0,0,128.00049,24.00452Zm22.62742,137.94112L94.05936,105.3771a8,8,0,0,1,11.31371-11.31371l56.56854,56.56854a8,8,0,1,1-11.3137,11.31371Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128.00452",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "99.71622",
        y1: "99.72024",
        x2: "156.28476",
        y2: "156.28879",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128.00452",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "99.71622",
        y1: "99.72024",
        x2: "156.28476",
        y2: "156.28879",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128.00452",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "99.71622",
        y1: "99.72024",
        x2: "156.28476",
        y2: "156.28879",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ProhibitInset = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8e(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ProhibitInset.displayName = "ProhibitInset";

var renderPathFor$8f = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M215.02036,182.3046a48.03614,48.03614,0,0,0-20.16513-30.0948,7.99547,7.99547,0,0,1-3.41652-5.8483L180.72054,39.20379A8,8,0,0,0,172.76026,32H83.23974a8,8,0,0,0-7.96028,7.20379L64.56129,146.3615a7.99547,7.99547,0,0,1-3.41652,5.8483,48.03614,48.03614,0,0,0-20.16513,30.0948A8.0279,8.0279,0,0,0,48.804,192H207.196A8.0279,8.0279,0,0,0,215.02036,182.3046Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.02036,182.3046a48.03614,48.03614,0,0,0-20.16513-30.0948,7.99547,7.99547,0,0,1-3.41652-5.8483L180.72054,39.20379A8,8,0,0,0,172.76026,32H83.23974a8,8,0,0,0-7.96028,7.20379L64.56129,146.3615a7.99547,7.99547,0,0,1-3.41652,5.8483,48.03614,48.03614,0,0,0-20.16513,30.0948A8.0279,8.0279,0,0,0,48.804,192H207.196A8.0279,8.0279,0,0,0,215.02036,182.3046Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M215.02036,182.3046a48.03614,48.03614,0,0,0-20.16513-30.0948,7.99547,7.99547,0,0,1-3.41652-5.8483L180.72054,39.20379A8,8,0,0,0,172.76026,32H83.23974a8,8,0,0,0-7.96028,7.20379L64.56129,146.3615a7.99547,7.99547,0,0,1-3.41652,5.8483,48.03614,48.03614,0,0,0-20.16513,30.0948A8.0279,8.0279,0,0,0,48.804,192H207.196A8.0279,8.0279,0,0,0,215.02036,182.3046Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M222.85742,180.69727h0a55.69528,55.69528,0,0,0-23.44433-35.063.31793.31793,0,0,1-.01416-.06885L188.68066,38.40771A15.94953,15.94953,0,0,0,172.76025,24H83.23975A15.94952,15.94952,0,0,0,67.31934,38.40771L56.60107,145.56543a.31793.31793,0,0,1-.01416.06885,55.69718,55.69718,0,0,0-23.44433,35.063A16.02766,16.02766,0,0,0,48.80371,200H120v40a8,8,0,0,0,16,0V200h71.19629a16.02766,16.02766,0,0,0,15.66113-19.30273Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M215.02036,182.3046a48.03614,48.03614,0,0,0-20.16513-30.0948,7.99547,7.99547,0,0,1-3.41652-5.8483L180.72054,39.20379A8,8,0,0,0,172.76026,32H83.23974a8,8,0,0,0-7.96028,7.20379L64.56129,146.3615a7.99547,7.99547,0,0,1-3.41652,5.8483,48.03614,48.03614,0,0,0-20.16513,30.0948A8.0279,8.0279,0,0,0,48.804,192H207.196A8.0279,8.0279,0,0,0,215.02036,182.3046Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M215.02036,182.3046a48.03614,48.03614,0,0,0-20.16513-30.0948,7.99547,7.99547,0,0,1-3.41652-5.8483L180.72054,39.20379A8,8,0,0,0,172.76026,32H83.23974a8,8,0,0,0-7.96028,7.20379L64.56129,146.3615a7.99547,7.99547,0,0,1-3.41652,5.8483,48.03614,48.03614,0,0,0-20.16513,30.0948A8.0279,8.0279,0,0,0,48.804,192H207.196A8.0279,8.0279,0,0,0,215.02036,182.3046Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M215.02036,182.3046a48.03614,48.03614,0,0,0-20.16513-30.0948,7.99547,7.99547,0,0,1-3.41652-5.8483L180.72054,39.20379A8,8,0,0,0,172.76026,32H83.23974a8,8,0,0,0-7.96028,7.20379L64.56129,146.3615a7.99547,7.99547,0,0,1-3.41652,5.8483,48.03614,48.03614,0,0,0-20.16513,30.0948A8.0279,8.0279,0,0,0,48.804,192H207.196A8.0279,8.0279,0,0,0,215.02036,182.3046Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PushPin = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8f(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PushPin.displayName = "PushPin";

var renderPathFor$8g = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M72.5038,66.95418,64.56129,146.3615a7.99543,7.99543,0,0,1-3.41653,5.8483,48.03616,48.03616,0,0,0-20.16512,30.0948A8.0279,8.0279,0,0,0,48.804,192H186.18182",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "33.5",
        y1: "24",
        x2: "222.5",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M190.53671,137.3435l-9.81617-98.13971A8,8,0,0,0,172.76026,32H94.81593",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.02036,182.3046a48.03614,48.03614,0,0,0-20.16513-30.0948,7.99547,7.99547,0,0,1-3.41652-5.8483L180.72054,39.20379A8,8,0,0,0,172.76026,32H83.23974a8,8,0,0,0-7.96028,7.20379L64.56129,146.3615a7.99547,7.99547,0,0,1-3.41652,5.8483,48.03614,48.03614,0,0,0-20.16513,30.0948A8.0279,8.0279,0,0,0,48.804,192H207.196A8.0279,8.0279,0,0,0,215.02036,182.3046Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M191.83532,150.32672,180.72054,39.20379A8,8,0,0,0,172.76026,32H83.974",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M72.5038,66.95418,64.56129,146.3615a7.99543,7.99543,0,0,1-3.41653,5.8483,48.03616,48.03616,0,0,0-20.16512,30.0948A8.0279,8.0279,0,0,0,48.804,192H186.18182",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "33.5",
        y1: "24",
        x2: "222.5",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M185.92285,155.71582a7.99995,7.99995,0,0,0,13.87256-6.18555L188.68066,38.40771A15.94952,15.94952,0,0,0,172.76025,24H83.97412a8.00035,8.00035,0,0,0-5.9126,13.38965Z"
      }), React__default.createElement("path", {
        d: "M228.4209,226.62012l-35.99317-39.61133a8.0598,8.0598,0,0,0-.67822-.74707L39.4209,18.62012A8,8,0,0,0,27.5791,29.37988L64.19189,69.67383l-7.59082,75.8916a.32987.32987,0,0,1-.01416.06934,55.69488,55.69488,0,0,0-23.44433,35.0625A16.02766,16.02766,0,0,0,48.80371,200H120v40a8,8,0,0,0,16,0V200h46.61377l33.96533,37.37988a8,8,0,0,0,11.8418-10.75976Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M191.83532,150.32672,180.72054,39.20379A8,8,0,0,0,172.76026,32H83.974",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M72.5038,66.95418,64.56129,146.3615a7.99543,7.99543,0,0,1-3.41653,5.8483,48.03616,48.03616,0,0,0-20.16512,30.0948A8.0279,8.0279,0,0,0,48.804,192H186.18182",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "33.5",
        y1: "24",
        x2: "222.5",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M191.83532,150.32672,180.72054,39.20379A8,8,0,0,0,172.76026,32H83.974",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M72.5038,66.95418,64.56129,146.3615a7.99543,7.99543,0,0,1-3.41653,5.8483,48.03616,48.03616,0,0,0-20.16512,30.0948A8.0279,8.0279,0,0,0,48.804,192H186.18182",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "33.5",
        y1: "24",
        x2: "222.5",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "192",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M191.83532,150.32672,180.72054,39.20379A8,8,0,0,0,172.76026,32H83.974",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M72.5038,66.95418,64.56129,146.3615a7.99543,7.99543,0,0,1-3.41653,5.8483,48.03616,48.03616,0,0,0-20.16512,30.0948A8.0279,8.0279,0,0,0,48.804,192H186.18182",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "33.5",
        y1: "24",
        x2: "222.5",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PushPinSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8g(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PushPinSlash.displayName = "PushPinSlash";

var renderPathFor$8h = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M63.99986,216a8,8,0,0,1-8-8.00009l.00053-42.69468a28,28,0,1,1,0-50.61044L55.99988,72.0001A8,8,0,0,1,64,64l46.69456.00053a27.99993,27.99993,0,1,1,50.61031,0L207.99939,64a8,8,0,0,1,8.00007,7.9999L216,114.69478a28,28,0,1,0,0,50.61044l-.00053,42.69487a8,8,0,0,1-8,7.9999Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M63.99986,216a8,8,0,0,1-8-8.00009l.00053-42.69468a28,28,0,1,1,0-50.61044L55.99988,72.0001A8,8,0,0,1,64,64l46.69456.00053a27.99993,27.99993,0,1,1,50.61031,0L207.99939,64a8,8,0,0,1,8.00007,7.9999L216,114.69478a28,28,0,1,0,0,50.61044l-.00053,42.69487a8,8,0,0,1-8,7.9999Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M63.99986,216a8,8,0,0,1-8-8.00009l.00053-42.69468a28,28,0,1,1,0-50.61044L55.99988,72.0001A8,8,0,0,1,64,64l46.69456.00053a27.99993,27.99993,0,1,1,50.61031,0L207.99939,64a8,8,0,0,1,8.00007,7.9999L216,114.69478a28,28,0,1,0,0,50.61044l-.00053,42.69487a8,8,0,0,1-8,7.9999Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M165.78027,224.001,207.99951,224a16.018,16.018,0,0,0,16-16L224,170.34863a7.99966,7.99966,0,0,0-11.05957-7.3916A23.25464,23.25464,0,0,1,204,164.72754c-13.2334,0-24-11.09277-24-24.72754s10.7666-24.72754,24-24.72754a23.25464,23.25464,0,0,1,8.94043,1.77051A7.99966,7.99966,0,0,0,224,109.65137L223.99951,72A16.01812,16.01812,0,0,0,207.999,56l-36.21728.001A36.60975,36.60975,0,0,0,171.99951,52a36,36,0,0,0-72,0,36.60975,36.60975,0,0,0,.21778,4.001L63.99951,56a16.018,16.018,0,0,0-16,16L48,104.21777A36.47481,36.47481,0,0,0,43.99951,104a36,36,0,0,0,0,72A36.47481,36.47481,0,0,0,48,175.78223L47.99951,208A16.01791,16.01791,0,0,0,63.999,224l42.22071.001h0"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M63.99986,216a8,8,0,0,1-8-8.00009l.00053-42.69468a28,28,0,1,1,0-50.61044L55.99988,72.0001A8,8,0,0,1,64,64l46.69456.00053a27.99993,27.99993,0,1,1,50.61031,0L207.99939,64a8,8,0,0,1,8.00007,7.9999L216,114.69478a28,28,0,1,0,0,50.61044l-.00053,42.69487a8,8,0,0,1-8,7.9999Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M63.99986,216a8,8,0,0,1-8-8.00009l.00053-42.69468a28,28,0,1,1,0-50.61044L55.99988,72.0001A8,8,0,0,1,64,64l46.69456.00053a27.99993,27.99993,0,1,1,50.61031,0L207.99939,64a8,8,0,0,1,8.00007,7.9999L216,114.69478a28,28,0,1,0,0,50.61044l-.00053,42.69487a8,8,0,0,1-8,7.9999Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M63.99986,216a8,8,0,0,1-8-8.00009l.00053-42.69468a28,28,0,1,1,0-50.61044L55.99988,72.0001A8,8,0,0,1,64,64l46.69456.00053a27.99993,27.99993,0,1,1,50.61031,0L207.99939,64a8,8,0,0,1,8.00007,7.9999L216,114.69478a28,28,0,1,0,0,50.61044l-.00053,42.69487a8,8,0,0,1-8,7.9999Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var PuzzlePiece = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8h(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
PuzzlePiece.displayName = "PuzzlePiece";

var renderPathFor$8i = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48.00244",
        y: "48",
        width: "60",
        height: "60",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48.00244",
        y: "148",
        width: "60",
        height: "60",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "148.00244",
        y: "48",
        width: "60",
        height: "60",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "148.00244",
        y1: "148",
        x2: "148.00244",
        y2: "172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "148.002 208 184.002 208 184.002 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "184.00244",
        y1: "164",
        x2: "208.00244",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48.00244",
        y: "48",
        width: "64",
        height: "64",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "48.00244",
        y: "144",
        width: "64",
        height: "64",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "144.00244",
        y: "48",
        width: "64",
        height: "64",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "48.00244",
        y: "48",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48.00244",
        y: "144",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "144.00244",
        y: "48",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "144.00244",
        y1: "144",
        x2: "144.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144.002 208 176.002 208 176.002 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176.00244",
        y1: "160",
        x2: "208.00244",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208.00244",
        y1: "192",
        x2: "208.00244",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("rect", {
        x: "40.00244",
        y: "40",
        width: "80",
        height: "80",
        rx: "16"
      }), React__default.createElement("rect", {
        x: "40.00244",
        y: "136",
        width: "80",
        height: "80",
        rx: "16"
      }), React__default.createElement("rect", {
        x: "136.00244",
        y: "40",
        width: "80",
        height: "80",
        rx: "16"
      }), React__default.createElement("path", {
        d: "M144.00244,184a8.00039,8.00039,0,0,0,8-8V144a8,8,0,0,0-16,0v32A8.00039,8.00039,0,0,0,144.00244,184Z"
      }), React__default.createElement("path", {
        d: "M208.00244,152h-24v-8a8,8,0,0,0-16,0v56h-24a8,8,0,1,0,0,16h32a8.00039,8.00039,0,0,0,8-8V168h24a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M208.00244,184a8.00039,8.00039,0,0,0-8,8v16a8,8,0,0,0,16,0V192A8.00039,8.00039,0,0,0,208.00244,184Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48.00244",
        y: "48",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48.00244",
        y: "144",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "144.00244",
        y: "48",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "144.00244",
        y1: "144",
        x2: "144.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "144.002 208 176.002 208 176.002 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176.00244",
        y1: "160",
        x2: "208.00244",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208.00244",
        y1: "192",
        x2: "208.00244",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48.00244",
        y: "48",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48.00244",
        y: "144",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "144.00244",
        y: "48",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "144.00244",
        y1: "144",
        x2: "144.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "144.002 208 176.002 208 176.002 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176.00244",
        y1: "160",
        x2: "208.00244",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208.00244",
        y1: "192",
        x2: "208.00244",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48.00244",
        y: "48",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48.00244",
        y: "144",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "144.00244",
        y: "48",
        width: "64",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "144.00244",
        y1: "144",
        x2: "144.00244",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "144.002 208 176.002 208 176.002 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176.00244",
        y1: "160",
        x2: "208.00244",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208.00244",
        y1: "192",
        x2: "208.00244",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var QrCode = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8i(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
QrCode.displayName = "QrCode";

var renderPathFor$8j = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00146",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128.00146,144v-8a32,32,0,1,0-32-32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128.00146",
        cy: "184",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00244",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128.00244",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128.00244,152v-8a32,32,0,1,0-32-32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128.00244",
        cy: "184",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128.00146,23.99963a104,104,0,1,0,104,104A104.11791,104.11791,0,0,0,128.00146,23.99963Zm12.001,160.00391a12.002,12.002,0,1,1,0-.00391Zm16.28418-43.71875a39.72506,39.72506,0,0,1-20.28516,10.91992v.79492a8,8,0,1,1-16,0v-8a8.0004,8.0004,0,0,1,8-8,23.99881,23.99881,0,1,0-24-24,8,8,0,0,1-16,0,40,40,0,1,1,68.28516,28.28516Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00098",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128.001,152v-8a32,32,0,1,0-32-32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128.00098",
        cy: "184",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128.00049",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128.00049,152v-8a32,32,0,1,0-32-32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128.00049",
        cy: "184",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,152v-8a32,32,0,1,0-32-32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "184",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Question = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8j(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Question.displayName = "Question";

var renderPathFor$8k = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232 96 232 72 120 72 72 200 24 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232 96 232 72 120 72 72 200 24 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M72,208a7.99963,7.99963,0,0,1-7.49072-5.19092l-48-128a8.00011,8.00011,0,0,1,14.98144-5.61816L72,177.21582l40.50928-108.0249A7.99963,7.99963,0,0,1,120,64H232a7.99977,7.99977,0,0,1,8,8V96a8,8,0,0,1-16,0V80H125.544L79.49072,202.80908A7.99963,7.99963,0,0,1,72,208Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232 96 232 72 120 72 72 200 24 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232 96 232 72 120 72 72 200 24 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232 96 232 72 120 72 72 200 24 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Radical = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8k(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Radical.displayName = "Radical";

var renderPathFor$8l = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M12,180v-8a116,116,0,0,1,232,0v8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152,180v-4a24,24,0,0,0-48,0v4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M200,180v-4a72,72,0,0,0-144,0v4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,184V168a48,48,0,0,0-96,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,184V168a80,80,0,0,0-160,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M240,184V168a112,112,0,0,0-224,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M184,168v16a8,8,0,0,1-16,0V168a40,40,0,0,0-80,0v16a8,8,0,0,1-16,0V168a56,56,0,0,1,112,0ZM128,80a88.09957,88.09957,0,0,0-88,88v16a8,8,0,0,0,16,0V168a72,72,0,0,1,144,0v16a8,8,0,0,0,16,0V168A88.09957,88.09957,0,0,0,128,80Zm0-32A120.13623,120.13623,0,0,0,8,168v16a8,8,0,0,0,16,0V168a104,104,0,0,1,208,0v16a8,8,0,0,0,16,0V168A120.13623,120.13623,0,0,0,128,48Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,184V168a48,48,0,0,0-96,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M208,184V168a80,80,0,0,0-160,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M240,184V168a112,112,0,0,0-224,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,184V168a48,48,0,0,0-96,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M208,184V168a80,80,0,0,0-160,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M240,184V168a112,112,0,0,0-224,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,184V168a48,48,0,0,0-96,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M208,184V168a80,80,0,0,0-160,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M240,184V168a112,112,0,0,0-224,0v16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Rainbow = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8l(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Rainbow.displayName = "Rainbow";

var renderPathFor$8m = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M156,200c-13.25483,0-24-11.14314-24-24.88889s10.74517-24.88889,24-24.88889a23.18816,23.18816,0,0,1,8.81117,1.73087l-.00141-.0003A40.00363,40.00363,0,1,1,204,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M92,176V160a19.96611,19.96611,0,0,1,7.739-15.80207",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M52,176V160a60.01385,60.01385,0,0,1,90.83207-51.48275",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M12,176V160A100.00166,100.00166,0,0,1,177.59331,84.51611",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M152,200c-13.25483,0-24-11.14314-24-24.88889s10.74517-24.88889,24-24.88889a23.18816,23.18816,0,0,1,8.81117,1.73087l-.00141-.0003A40.00363,40.00363,0,1,1,200,200Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M152,200c-13.25483,0-24-11.14314-24-24.88889s10.74517-24.88889,24-24.88889a23.18816,23.18816,0,0,1,8.81117,1.73087l-.00141-.0003A40.00363,40.00363,0,1,1,200,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M16,176V160A96.00006,96.00006,0,0,1,178.92582,91.17453",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M48,176V160a64.00543,64.00543,0,0,1,101.86674-51.60093",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,176V160a32.02814,32.02814,0,0,1,39.42145-31.135",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M248,160a48.054,48.054,0,0,1-48,48H152c-17.645,0-32-14.75391-32-32.88867s14.355-32.88867,32-32.88867a31.5421,31.5421,0,0,1,3.33545.17578A48.00491,48.00491,0,0,1,248,160ZM112,72a87.53238,87.53238,0,0,1,61.34814,24.91016,8.00027,8.00027,0,0,0,11.15528-11.47071A104.00011,104.00011,0,0,0,8,160v16a8,8,0,0,0,16,0V160A88.09957,88.09957,0,0,1,112,72Zm0,32a55.55123,55.55123,0,0,1,33.12842,10.84473A7.99959,7.99959,0,1,0,154.605,101.9541,72.00452,72.00452,0,0,0,40,160v16a8,8,0,0,0,16,0V160A56.06322,56.06322,0,0,1,112,104Zm15.20508,26.71289a7.99944,7.99944,0,0,0-5.936-9.63086A40.02529,40.02529,0,0,0,72,160v16a8,8,0,0,0,16,0V160a24.02909,24.02909,0,0,1,29.57373-23.35156A7.99553,7.99553,0,0,0,127.20508,130.71289Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M152,200c-13.25483,0-24-11.14314-24-24.88889s10.74517-24.88889,24-24.88889a23.18816,23.18816,0,0,1,8.81117,1.73087l-.00141-.0003A40.00363,40.00363,0,1,1,200,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M16,176V160A96.00006,96.00006,0,0,1,178.92582,91.17453",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M48,176V160a64.00543,64.00543,0,0,1,101.86674-51.60093",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M80,176V160a32.02814,32.02814,0,0,1,39.42145-31.135",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M152,200c-13.25483,0-24-11.14314-24-24.88889s10.74517-24.88889,24-24.88889a23.18816,23.18816,0,0,1,8.81117,1.73087l-.00141-.0003A40.00363,40.00363,0,1,1,200,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M16,176V160A96.00006,96.00006,0,0,1,178.92582,91.17453",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M48,176V160a64.00543,64.00543,0,0,1,101.86674-51.60093",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M80,176V160a32.02814,32.02814,0,0,1,39.42145-31.135",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M152,200c-13.25483,0-24-11.14314-24-24.88889s10.74517-24.88889,24-24.88889a23.18816,23.18816,0,0,1,8.81117,1.73087l-.00141-.0003A40.00363,40.00363,0,1,1,200,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M16,176V160A96.00006,96.00006,0,0,1,178.92582,91.17453",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M48,176V160a64.00543,64.00543,0,0,1,101.86674-51.60093",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,176V160a32.02814,32.02814,0,0,1,39.42145-31.135",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var RainbowCloud = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8m(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
RainbowCloud.displayName = "RainbowCloud";

var renderPathFor$8n = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "76",
        y1: "100",
        x2: "180",
        y2: "100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "140",
        x2: "180",
        y2: "140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,208V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V208l-32-16-32,16-32-16L96,208,64,192Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,208V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V208l-32-16-32,16-32-16L96,208,64,192Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "104",
        x2: "180",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "136",
        x2: "180",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,208V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V208l-32-16-32,16-32-16L96,208,64,192Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,40H40A16.01833,16.01833,0,0,0,24,56V208a8,8,0,0,0,11.57812,7.15527L64,200.94434l28.42188,14.21093a8.00257,8.00257,0,0,0,7.15624,0L128,200.94434l28.42188,14.21093a8.00049,8.00049,0,0,0,7.15624,0L192,200.94434l28.42188,14.21093A8,8,0,0,0,232,208V56A16.01833,16.01833,0,0,0,216,40ZM180,144H76a8,8,0,0,1,0-16H180a8,8,0,0,1,0,16Zm0-32H76a8,8,0,0,1,0-16H180a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "76",
        y1: "104",
        x2: "180",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "136",
        x2: "180",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,208V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V208l-32-16-32,16-32-16L96,208,64,192Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "76",
        y1: "104",
        x2: "180",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "136",
        x2: "180",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,208V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V208l-32-16-32,16-32-16L96,208,64,192Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "76",
        y1: "104",
        x2: "180",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "76",
        y1: "136",
        x2: "180",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,208V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V208l-32-16-32,16-32-16L96,208,64,192Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Receipt = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8n(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Receipt.displayName = "Receipt";

var renderPathFor$8o = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "64",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "64",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm0,192a88,88,0,1,1,88-88A88.09957,88.09957,0,0,1,128,216Z"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "72"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "64",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Record = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8o(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Record.displayName = "Record";

var renderPathFor$8p = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24.00781",
        y: "40",
        width: "208",
        height: "176",
        rx: "16"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "48.00005",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Rectangle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8p(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Rectangle.displayName = "Rectangle";

var renderPathFor$8q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "132.00002",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "132.00002",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "32.00002",
        r: "12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M161.026,172.00058a72.17425,72.17425,0,0,1-66.05159.0002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M59.408,89.87843C77.71654,78.7483,101.71994,72,128,72s50.28346,6.7483,68.592,17.87843l-.00129.00213a24.002,24.002,0,1,1,31.61564,34.788l.002-.00083A51.61606,51.61606,0,0,1,232,144c0,39.7645-46.56239,72-104,72S24,183.7645,24,144a51.61624,51.61624,0,0,1,3.79162-19.3323l.00206.00082a24.00228,24.00228,0,1,1,31.61564-34.788Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "128 72 136 24 176.138 30.175",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,104a24.00125,24.00125,0,0,0-43.40918-14.11938l.001-.0022C178.28369,78.74831,154.28027,72,128,72S77.7168,78.74831,59.4082,89.87844l.001.0022A24.00186,24.00186,0,1,0,27.794,124.66848l-.00245-.00073A51.62014,51.62014,0,0,0,24,144c0,39.76441,46.5625,72,104,72s104-32.23559,104-72a51.62014,51.62014,0,0,0-3.7915-19.33227l-.002.00073A23.98866,23.98866,0,0,0,240,104Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "132.00002",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "132.00002",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "32.00002",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M161.026,176.00058a72.17425,72.17425,0,0,1-66.05159.0002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 72 136 24 172.185 29.567",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M59.408,89.87843C77.71654,78.7483,101.71994,72,128,72s50.28346,6.7483,68.592,17.87843l-.00129.00213a24.002,24.002,0,1,1,31.61564,34.788l.002-.00083A51.61606,51.61606,0,0,1,232,144c0,39.7645-46.56239,72-104,72S24,183.7645,24,144a51.61624,51.61624,0,0,1,3.79162-19.3323l.00206.00082a24.00228,24.00228,0,1,1,31.61564-34.788Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M248,104a31.99228,31.99228,0,0,0-52.9375-24.19043c-16.75439-8.90112-36.76172-14.279-57.666-15.52539l5.19581-31.17578,21.83105,3.3584a24.00409,24.00409,0,1,0,2.43506-15.814l-29.64209-4.56006a7.996,7.996,0,0,0-9.10742,6.5918l-6.91309,41.478c-21.83887.94165-42.813,6.37891-60.2583,15.647a31.99266,31.99266,0,0,0-42.59229,47.74024A59.04669,59.04669,0,0,0,16,144c0,21.93457,12.042,42.35156,33.90723,57.48926C70.875,216.00588,98.60938,224,128,224s57.125-7.99414,78.09277-22.51074C227.958,186.35158,240,165.93459,240,144a59.01726,59.01726,0,0,0-2.3457-16.44922A32.17163,32.17163,0,0,0,248,104ZM72,132a16,16,0,1,1,16,16A16.01833,16.01833,0,0,1,72,132Zm92.69629,51.10938a80.122,80.122,0,0,1-73.39209,0,8,8,0,0,1,7.34033-14.2168,64.09433,64.09433,0,0,0,58.71094,0,8.00008,8.00008,0,0,1,7.34082,14.2168ZM168,148a16,16,0,1,1,16-16A16.01833,16.01833,0,0,1,168,148Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "132.00002",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "132.00002",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "132.00002",
        r: "8"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "132.00002",
        r: "8"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "32.00002",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M161.026,176.00058a72.17425,72.17425,0,0,1-66.05159.0002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "128 72 136 24 172.185 29.567",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M59.408,89.87843C77.71654,78.7483,101.71994,72,128,72s50.28346,6.7483,68.592,17.87843l-.00129.00213a24.002,24.002,0,1,1,31.61564,34.788l.002-.00083A51.61606,51.61606,0,0,1,232,144c0,39.7645-46.56239,72-104,72S24,183.7645,24,144a51.61624,51.61624,0,0,1,3.79162-19.3323l.00206.00082a24.00228,24.00228,0,1,1,31.61564-34.788Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "132.00002",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "132.00002",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "132.00002",
        r: "8"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "132.00002",
        r: "8"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "32.00002",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M161.026,176.00058a72.17425,72.17425,0,0,1-66.05159.0002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "128 72 136 24 172.185 29.567",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M59.408,89.87843C77.71654,78.7483,101.71994,72,128,72s50.28346,6.7483,68.592,17.87843l-.00129.00213a24.002,24.002,0,1,1,31.61564,34.788l.002-.00083A51.61606,51.61606,0,0,1,232,144c0,39.7645-46.56239,72-104,72S24,183.7645,24,144a51.61624,51.61624,0,0,1,3.79162-19.3323l.00206.00082a24.00228,24.00228,0,1,1,31.61564-34.788Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "132.00002",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "132.00002",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "32.00002",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M161.026,176.00058a72.17425,72.17425,0,0,1-66.05159.0002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 72 136 24 172.185 29.567",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M59.408,89.87843C77.71654,78.7483,101.71994,72,128,72s50.28346,6.7483,68.592,17.87843l-.00129.00213a24.002,24.002,0,1,1,31.61564,34.788l.002-.00083A51.61606,51.61606,0,0,1,232,144c0,39.7645-46.56239,72-104,72S24,183.7645,24,144a51.61624,51.61624,0,0,1,3.79162-19.3323l.00206.00082a24.00228,24.00228,0,1,1,31.61564-34.788Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var RedditLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
RedditLogo.displayName = "RedditLogo";

var renderPathFor$8r = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 88 224 64 200 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,128A64,64,0,0,1,96,64H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "56 168 32 192 56 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,128a64,64,0,0,1-64,64H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 88 224 64 200 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,128A64,64,0,0,1,96,64H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 168 32 192 56 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,128a64,64,0,0,1-64,64H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M32,136a8.00039,8.00039,0,0,0,8-8A56.06322,56.06322,0,0,1,96,72H204.68628L194.34277,82.34326a8.00018,8.00018,0,0,0,11.31446,11.31348l24-24c.0271-.02686.04956-.05713.07617-.08447.15649-.16065.30908-.32569.45166-.49952.08423-.10254.15771-.21045.23608-.31591.07715-.10352.15747-.20459.22949-.312.082-.12255.15333-.24951.22779-.375.05859-.09863.12036-.19433.17456-.29541.06811-.127.12573-.25732.18652-.38671.05029-.10743.10425-.2129.1499-.32325.052-.12549.094-.25341.13941-.38086.04248-.11914.08838-.23632.12524-.35791.03882-.12841.06763-.25927.09986-.38916.03076-.123.06567-.24511.09057-.3706.03-.15088.04859-.30371.06958-.45654.0149-.106.0354-.21.0459-.31739a8.02276,8.02276,0,0,0,0-1.584c-.0105-.10742-.031-.21143-.0459-.31739-.021-.15283-.03955-.30566-.06958-.45654-.0249-.12549-.05981-.24756-.09057-.3706-.03223-.12989-.061-.26075-.09986-.38916-.03686-.12159-.08276-.23877-.12524-.35791-.04541-.12745-.0874-.25537-.13941-.38086-.04565-.11035-.09961-.21582-.1499-.32325-.06079-.12939-.11841-.25976-.18652-.38671-.0542-.10108-.116-.19678-.17456-.29541-.07446-.12549-.14575-.25245-.22779-.375-.072-.10743-.15234-.2085-.22949-.312-.07837-.10546-.15185-.21337-.23608-.31591-.14527-.17725-.30054-.34522-.46021-.50928-.02368-.02393-.0437-.05078-.06762-.07471l-24-24a8.00018,8.00018,0,1,0-11.31446,11.31348L204.68628,56H96a72.08124,72.08124,0,0,0-72,72A8.00039,8.00039,0,0,0,32,136Z"
      }), React__default.createElement("path", {
        d: "M224,120a8.00039,8.00039,0,0,0-8,8,56.06322,56.06322,0,0,1-56,56H51.31372l10.34351-10.34326a8.00018,8.00018,0,0,0-11.31446-11.31348l-24,24c-.02392.02393-.04394.05078-.06762.07471-.15967.16406-.31494.332-.46021.50928-.08423.10254-.15771.21045-.23608.31591-.07715.10352-.15747.20459-.22949.312-.082.12255-.15333.24951-.22779.375-.05859.09863-.12036.19433-.17456.29541-.06811.12695-.12573.25732-.18652.38671-.05029.10743-.10425.2129-.1499.32325-.052.12549-.094.25341-.13941.38086-.04248.11914-.08838.23632-.12524.35791-.03882.12841-.06763.25927-.09986.38916-.03076.123-.06567.24511-.09057.3706-.03.15088-.04859.30371-.06958.45654-.0149.106-.0354.21-.0459.31739a8.02276,8.02276,0,0,0,0,1.584c.0105.10742.031.21143.0459.31739.021.15283.03955.30566.06958.45654.0249.12549.05981.24756.09057.3706.03223.12989.061.26075.09986.38916.03686.12159.08276.23877.12524.35791.04541.12745.0874.25537.13941.38086.04565.11035.09961.21582.1499.32325.06079.12939.11841.25976.18652.38671.0542.10108.116.19678.17456.29541.07446.12549.14575.25245.22779.375.072.10743.15234.2085.22949.312.07837.10546.15185.21337.23608.31591.14258.17383.29517.33887.45166.49952.02661.02734.04907.05761.07617.08447l24,24a8.00018,8.00018,0,1,0,11.31446-11.31348L51.31372,200H160a72.08124,72.08124,0,0,0,72-72A8.00039,8.00039,0,0,0,224,120Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 88 224 64 200 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,128A64,64,0,0,1,96,64H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "56 168 32 192 56 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,128a64,64,0,0,1-64,64H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 88 224 64 200 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,128A64,64,0,0,1,96,64H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "56 168 32 192 56 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,128a64,64,0,0,1-64,64H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 88 224 64 200 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,128A64,64,0,0,1,96,64H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 168 32 192 56 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,128a64,64,0,0,1-64,64H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Repeat = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8r(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Repeat.displayName = "Repeat";

var renderPathFor$8s = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 88 224 64 200 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,128A64,64,0,0,1,96,64H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "56 168 32 192 56 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,128a64,64,0,0,1-64,64H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "116 111.993 132 104 132 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 88 224 64 200 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,128A64,64,0,0,1,96,64H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 168 32 192 56 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,128a64,64,0,0,1-64,64H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "116 111.993 132 104 132 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M32,136a8.00039,8.00039,0,0,0,8-8A56.06322,56.06322,0,0,1,96,72H204.68628L194.34277,82.34326a8.00018,8.00018,0,0,0,11.31446,11.31348l24-24c.0271-.02686.04956-.05713.07617-.08447.15649-.16065.30908-.32569.45166-.49952.08423-.10254.15771-.21045.23608-.31591.07715-.10352.15747-.20459.22949-.312.082-.12255.15333-.24951.22779-.375.05859-.09863.12036-.19433.17456-.29541.06811-.127.12573-.25732.18652-.38671.05029-.10743.10425-.2129.1499-.32325.052-.12549.094-.25341.13941-.38086.04248-.11914.08838-.23632.12524-.35791.03882-.12841.06763-.25927.09986-.38916.03076-.123.06567-.24511.09057-.3706.03-.15088.04859-.30371.06958-.45654.0149-.106.0354-.21.0459-.31739a8.02276,8.02276,0,0,0,0-1.584c-.0105-.10742-.031-.21143-.0459-.31739-.021-.15283-.03955-.30566-.06958-.45654-.0249-.12549-.05981-.24756-.09057-.3706-.03223-.12989-.061-.26075-.09986-.38916-.03686-.12159-.08276-.23877-.12524-.35791-.04541-.12745-.0874-.25537-.13941-.38086-.04565-.11035-.09961-.21582-.1499-.32325-.06079-.12939-.11841-.25976-.18652-.38671-.0542-.10108-.116-.19678-.17456-.29541-.07446-.12549-.14575-.25245-.22779-.375-.072-.10743-.15234-.2085-.22949-.312-.07837-.10546-.15185-.21337-.23608-.31591-.14527-.17725-.30054-.34522-.46021-.50928-.02368-.02393-.0437-.05078-.06762-.07471l-24-24a8.00018,8.00018,0,1,0-11.31446,11.31348L204.68628,56H96a72.08124,72.08124,0,0,0-72,72A8.00039,8.00039,0,0,0,32,136Z"
      }), React__default.createElement("path", {
        d: "M224,120a8.00039,8.00039,0,0,0-8,8,56.06322,56.06322,0,0,1-56,56H51.31372l10.34351-10.34326a8.00018,8.00018,0,0,0-11.31446-11.31348l-24,24c-.02392.02393-.04394.05078-.06762.07471-.15967.16406-.31494.332-.46021.50928-.08423.10254-.15771.21045-.23608.31591-.07715.10352-.15747.20459-.22949.312-.082.12255-.15333.24951-.22779.375-.05859.09863-.12036.19433-.17456.29541-.06811.12695-.12573.25732-.18652.38671-.05029.10743-.10425.2129-.1499.32325-.052.12549-.094.25341-.13941.38086-.04248.11914-.08838.23632-.12524.35791-.03882.12841-.06763.25927-.09986.38916-.03076.123-.06567.24511-.09057.3706-.03.15088-.04859.30371-.06958.45654-.0149.106-.0354.21-.0459.31739a8.02276,8.02276,0,0,0,0,1.584c.0105.10742.031.21143.0459.31739.021.15283.03955.30566.06958.45654.0249.12549.05981.24756.09057.3706.03223.12989.061.26075.09986.38916.03686.12159.08276.23877.12524.35791.04541.12745.0874.25537.13941.38086.04565.11035.09961.21582.1499.32325.06079.12939.11841.25976.18652.38671.0542.10108.116.19678.17456.29541.07446.12549.14575.25245.22779.375.072.10743.15234.2085.22949.312.07837.10546.15185.21337.23608.31591.14258.17383.29517.33887.45166.49952.02661.02734.04907.05761.07617.08447l24,24a8.00018,8.00018,0,1,0,11.31446-11.31348L51.31372,200H160a72.08124,72.08124,0,0,0,72-72A8.00039,8.00039,0,0,0,224,120Z"
      }), React__default.createElement("path", {
        d: "M132,160a8.00039,8.00039,0,0,0,8-8V104a7.99986,7.99986,0,0,0-11.5752-7.15674l-16,7.99268a8.00006,8.00006,0,0,0,7.1504,14.31347l4.4248-2.21V152A8.00039,8.00039,0,0,0,132,160Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 88 224 64 200 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,128A64,64,0,0,1,96,64H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "56 168 32 192 56 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,128a64,64,0,0,1-64,64H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "116 111.993 132 104 132 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 88 224 64 200 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,128A64,64,0,0,1,96,64H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "56 168 32 192 56 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,128a64,64,0,0,1-64,64H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "116 111.993 132 104 132 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "200 88 224 64 200 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,128A64,64,0,0,1,96,64H224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "56 168 32 192 56 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,128a64,64,0,0,1-64,64H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "116 111.993 132 104 132 152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var RepeatOnce = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8s(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
RepeatOnce.displayName = "RepeatOnce";

var renderPathFor$8t = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "168 156 132 128 168 100 168 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "112 156 76 128 112 100 112 156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "168 156 132 128 168 100 168 156"
      }), React__default.createElement("polygon", {
        points: "112 156 76 128 112 100 112 156"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32a96,96,0,1,0,96,96A95.99991,95.99991,0,0,0,128,32ZM112,160,64,128l48-32Zm64,0-48-32,48-32Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "176 160 128 128 176 96 176 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "112 160 64 128 112 96 112 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M24,128A104,104,0,1,0,128,24,104.11791,104.11791,0,0,0,24,128Zm32,0a7.99943,7.99943,0,0,1,3.5625-6.65625l48-32A8.00016,8.00016,0,0,1,120,96v32a7.99943,7.99943,0,0,1,3.5625-6.65625l48-32A8.00016,8.00016,0,0,1,184,96v64a7.99975,7.99975,0,0,1-12.4375,6.65625l-48-32A7.99943,7.99943,0,0,1,120,128v32a7.99975,7.99975,0,0,1-12.4375,6.65625l-48-32A7.99943,7.99943,0,0,1,56,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "172 160 124 128 172 96 172 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "116 160 68 128 116 96 116 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "172 160 124 128 172 96 172 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "116 160 68 128 116 96 116 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "176 160 128 128 176 96 176 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "112 160 64 128 112 96 112 160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var RewindCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8t(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
RewindCircle.displayName = "RewindCircle";

var renderPathFor$8u = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "144",
        y1: "228",
        x2: "112",
        y2: "228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M122.97053,19.76275C103.97814,34.97686,40.45429,95.77187,96,192h64c54.39078-96.16-8.20388-156.9371-26.9971-172.20489A7.98387,7.98387,0,0,0,122.97053,19.76275Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M73.86661,111.36007,42.51644,148.98028a8,8,0,0,0-1.66373,6.85692l12.36292,55.63314a8,8,0,0,0,12.80706,4.51151L96,192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M181.53142,110.63771l31.95214,38.34257a8,8,0,0,1,1.66373,6.85692l-12.36292,55.63314a8,8,0,0,1-12.80706,4.51151L160,192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M73.87573,111.39355l-.009-.03369L42.51636,148.98047a7.99958,7.99958,0,0,0-1.66358,6.85693l12.3628,55.63281a8,8,0,0,0,12.80713,4.51172L96,192C78.36523,161.44922,72.74268,134.47656,73.87573,111.39355Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M181.52239,110.6714l.009-.03369,31.35034,37.6206a7.99958,7.99958,0,0,1,1.66358,6.85693l-12.3628,55.63282a8,8,0,0,1-12.80712,4.51172l-29.9773-23.98194C177.03289,160.72706,182.65544,133.75441,181.52239,110.6714Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "144",
        y1: "224",
        x2: "112",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M122.97053,19.76275C103.97814,34.97686,40.45429,95.77187,96,192h64c54.39078-96.16-8.20388-156.9371-26.9971-172.20489A7.98387,7.98387,0,0,0,122.97053,19.76275Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M73.86661,111.36007,42.51644,148.98028a8,8,0,0,0-1.66373,6.85692l12.36292,55.63314a8,8,0,0,0,12.80706,4.51151L96,192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M181.53142,110.63771l31.95214,38.34257a8,8,0,0,1,1.66373,6.85692l-12.36292,55.63314a8,8,0,0,1-12.80706,4.51151L160,192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M144,216H112a8,8,0,0,0,0,16h32a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M219.62891,143.85889l-30.23658-36.28418a124.52267,124.52267,0,0,0-7.98022-34.8833c-11.61719-30.21192-32.15625-49.999-43.36523-59.10547a16.07708,16.07708,0,0,0-20.07813-.0669C106.61328,22.61621,85.81055,42.38867,74.07617,72.605A122.76188,122.76188,0,0,0,65.979,108.32861L36.37109,143.85889A16.10066,16.10066,0,0,0,33.043,157.57275l12.36328,55.63282a15.98523,15.98523,0,0,0,25.61328,9.023L98.80566,200h58.38868l27.78515,22.22852a15.91184,15.91184,0,0,0,9.96485,3.51709,16.0905,16.0905,0,0,0,5.34668-.91944,15.90581,15.90581,0,0,0,10.30273-11.62012L222.957,157.57373A16.102,16.102,0,0,0,219.62891,143.85889Zm-158.60352,65.876-12.36328-55.6333,17.92651-21.5122q3.40906,28.0371,19.14038,57.38281ZM128,108a12,12,0,1,1,12-12A12,12,0,0,1,128,108Zm66.97461,101.73486-24.74976-19.7998q15.53064-29.55175,18.74341-57.87695l18.36963,22.04345Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "144",
        y1: "224",
        x2: "112",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M122.97053,19.76275C103.97814,34.97686,40.45429,95.77187,96,192h64c54.39078-96.16-8.20388-156.9371-26.9971-172.20489A7.98387,7.98387,0,0,0,122.97053,19.76275Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M73.86661,111.36007,42.51644,148.98028a8,8,0,0,0-1.66373,6.85692l12.36292,55.63314a8,8,0,0,0,12.80706,4.51151L96,192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M181.53142,110.63771l31.95214,38.34257a8,8,0,0,1,1.66373,6.85692l-12.36292,55.63314a8,8,0,0,1-12.80706,4.51151L160,192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "144",
        y1: "224",
        x2: "112",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M122.97053,19.76275C103.97814,34.97686,40.45429,95.77187,96,192h64c54.39078-96.16-8.20388-156.9371-26.9971-172.20489A7.98387,7.98387,0,0,0,122.97053,19.76275Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M73.86661,111.36007,42.51644,148.98028a8,8,0,0,0-1.66373,6.85692l12.36292,55.63314a8,8,0,0,0,12.80706,4.51151L96,192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M181.53142,110.63771l31.95214,38.34257a8,8,0,0,1,1.66373,6.85692l-12.36292,55.63314a8,8,0,0,1-12.80706,4.51151L160,192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "144",
        y1: "224",
        x2: "112",
        y2: "224",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M122.97053,19.76275C103.97814,34.97686,40.45429,95.77187,96,192h64c54.39078-96.16-8.20388-156.9371-26.9971-172.20489A7.98387,7.98387,0,0,0,122.97053,19.76275Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M73.86661,111.36007,42.51644,148.98028a8,8,0,0,0-1.66373,6.85692l12.36292,55.63314a8,8,0,0,0,12.80706,4.51151L96,192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M181.53142,110.63771l31.95214,38.34257a8,8,0,0,1,1.66373,6.85692l-12.36292,55.63314a8,8,0,0,1-12.80706,4.51151L160,192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Rocket = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8u(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Rocket.displayName = "Rocket";

var renderPathFor$8v = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M195.88225,105.37258,128,173.25483,82.74517,128l67.88225-67.88225c25.70415-25.70415,51.40829-25.45342,62.37042-23.81787a7.96343,7.96343,0,0,1,6.70228,6.70228C221.33567,53.96429,221.5864,79.66843,195.88225,105.37258Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M184.56854,116.68629v64.56854a8,8,0,0,1-2.34314,5.65686l-32.34176,32.34176a8,8,0,0,1-13.5015-4.08793L128,173.25483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M139.31371,71.43146H74.74517a8,8,0,0,0-5.65686,2.34314L36.74655,106.11636a8,8,0,0,0,4.08793,13.5015L82.74517,128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M90.56048,192.38144c-15.05815,26.12823-53.07015,26.12823-53.07015,26.12823s0-38.012,26.12827-53.07018",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M94.05887,184.56854c-11.3137,33.94113-56.56854,33.94113-56.56854,33.94113s0-45.25484,33.94113-56.56854Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M184.56854,116.68629v64.56854a8,8,0,0,1-2.34314,5.65686l-32.34176,32.34176a8,8,0,0,1-13.5015-4.08793L128,173.25483Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M139.31371,71.43146H74.74517a8,8,0,0,0-5.65686,2.34314L36.74655,106.11636a8,8,0,0,0,4.08793,13.5015L82.74517,128Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M94.05887,184.56854c-11.3137,33.94113-56.56854,33.94113-56.56854,33.94113s0-45.25484,33.94113-56.56854",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M195.88225,105.37258,128,173.25483,82.74517,128l67.88225-67.88225c25.70415-25.70415,51.40829-25.45342,62.37042-23.81787a7.96343,7.96343,0,0,1,6.70228,6.70228C221.33567,53.96429,221.5864,79.66843,195.88225,105.37258Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M184.56854,116.68629v64.56854a8,8,0,0,1-2.34314,5.65686l-32.34176,32.34176a8,8,0,0,1-13.5015-4.08793L128,173.25483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M139.31371,71.43146H74.74517a8,8,0,0,0-5.65686,2.34314L36.74655,106.11636a8,8,0,0,0,4.08793,13.5015L82.74517,128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M96.58887,176.979a8.00118,8.00118,0,0,0-10.12012,5.06006C79.916,201.69775,58.57422,207.78613,46.332,209.669c1.88281-12.24854,7.97168-33.58594,27.62988-40.13819a8.00027,8.00027,0,1,0-5.06054-15.1792c-16.36035,5.45362-28.37891,18.45069-34.75782,37.58692a92.73335,92.73335,0,0,0-4.65332,26.57129,8.00041,8.00041,0,0,0,8,8,92.73569,92.73569,0,0,0,26.57129-4.65332c19.13575-6.37842,32.13282-18.39747,37.58692-34.75782A8.001,8.001,0,0,0,96.58887,176.979Z"
      }), React__default.createElement("path", {
        d: "M227.6123,41.82031A15.879,15.879,0,0,0,214.17871,28.3877c-11.28613-1.68409-40.62109-2.51319-69.209,26.07324l-8.97046,8.9707H74.74512a15.90118,15.90118,0,0,0-11.31446,4.686L31.08887,100.46a16.00008,16.00008,0,0,0,8.17675,27.00244l39.53492,7.90723,41.82983,41.82959,7.90674,39.53516a15.99768,15.99768,0,0,0,27.00391,8.17578l32.34179-32.34229a15.8955,15.8955,0,0,0,4.68555-11.313V120l8.9707-8.9707C230.127,82.44141,229.29688,53.10645,227.6123,41.82031ZM74.74512,79.43164h45.25439l-39.884,39.88379-37.71216-7.542ZM176.56836,181.25488l-32.3418,32.3418-7.54223-37.71191,39.884-39.88428Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M94.05887,184.56854c-11.3137,33.94113-56.56854,33.94113-56.56854,33.94113s0-45.25484,33.94113-56.56854",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M195.88225,105.37258,128,173.25483,82.74517,128l67.88225-67.88225c25.70415-25.70415,51.40829-25.45342,62.37042-23.81787a7.96343,7.96343,0,0,1,6.70228,6.70228C221.33567,53.96429,221.5864,79.66843,195.88225,105.37258Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M184.56854,116.68629v64.56854a8,8,0,0,1-2.34314,5.65686l-32.34176,32.34176a8,8,0,0,1-13.5015-4.08793L128,173.25483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M139.31371,71.43146H74.74517a8,8,0,0,0-5.65686,2.34314L36.74655,106.11636a8,8,0,0,0,4.08793,13.5015L82.74517,128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M94.05887,184.56854c-11.3137,33.94113-56.56854,33.94113-56.56854,33.94113s0-45.25484,33.94113-56.56854",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M195.88225,105.37258,128,173.25483,82.74517,128l67.88225-67.88225c25.70415-25.70415,51.40829-25.45342,62.37042-23.81787a7.96343,7.96343,0,0,1,6.70228,6.70228C221.33567,53.96429,221.5864,79.66843,195.88225,105.37258Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M184.56854,116.68629v64.56854a8,8,0,0,1-2.34314,5.65686l-32.34176,32.34176a8,8,0,0,1-13.5015-4.08793L128,173.25483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M139.31371,71.43146H74.74517a8,8,0,0,0-5.65686,2.34314L36.74655,106.11636a8,8,0,0,0,4.08793,13.5015L82.74517,128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M94.05887,184.56854c-11.3137,33.94113-56.56854,33.94113-56.56854,33.94113s0-45.25484,33.94113-56.56854",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M195.88225,105.37258,128,173.25483,82.74517,128l67.88225-67.88225c25.70415-25.70415,51.40829-25.45342,62.37042-23.81787a7.96343,7.96343,0,0,1,6.70228,6.70228C221.33567,53.96429,221.5864,79.66843,195.88225,105.37258Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M184.56854,116.68629v64.56854a8,8,0,0,1-2.34314,5.65686l-32.34176,32.34176a8,8,0,0,1-13.5015-4.08793L128,173.25483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M139.31371,71.43146H74.74517a8,8,0,0,0-5.65686,2.34314L36.74655,106.11636a8,8,0,0,0,4.08793,13.5015L82.74517,128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var RocketLaunch = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8v(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
RocketLaunch.displayName = "RocketLaunch";

var renderPathFor$8w = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "148",
        width: "176",
        height: "60",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "60",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "64",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "64",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("rect", {
        x: "32",
        y: "136",
        width: "192",
        height: "80",
        rx: "16"
      }), React__default.createElement("rect", {
        x: "32",
        y: "40",
        width: "192",
        height: "80",
        rx: "16"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "144",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "40",
        y: "48",
        width: "176",
        height: "64",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Rows = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8w(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Rows.displayName = "Rows";

var renderPathFor$8x = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M47.99414,144a64,64,0,0,1,64,64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M47.99414,96a112,112,0,0,1,112,112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M47.99414,48a160,160,0,0,1,160,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "51.99414",
        cy: "204",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M47.99414,144a64,64,0,0,1,64,64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M47.99414,96a112,112,0,0,1,112,112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M47.99414,48a160,160,0,0,1,160,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "51.99414",
        cy: "204",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M98.90576,157.08752a71.531,71.531,0,0,1,21.08838,50.91211,8,8,0,0,1-16,0,56.00027,56.00027,0,0,0-56-56,8,8,0,1,1,0-16A71.53147,71.53147,0,0,1,98.90576,157.08752ZM47.99414,87.99963a8,8,0,1,0,0,16,104.00183,104.00183,0,0,1,104,104,8,8,0,0,0,16,0,120.00093,120.00093,0,0,0-120-120Zm118.794,1.20606A166.90561,166.90561,0,0,0,47.99414,39.99963a8,8,0,0,0,0,16,151.00491,151.00491,0,0,1,107.48047,44.52051,151.00328,151.00328,0,0,1,44.51953,107.47949,8,8,0,0,0,16,0A166.90191,166.90191,0,0,0,166.78809,89.20569ZM51.99414,191.99963a12,12,0,1,0,12,12A12.01344,12.01344,0,0,0,51.99414,191.99963Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M47.99414,144a64,64,0,0,1,64,64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M47.99414,96a112,112,0,0,1,112,112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M47.99414,48a160,160,0,0,1,160,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "51.99414",
        cy: "204",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M47.99414,144a64,64,0,0,1,64,64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M47.99414,96a112,112,0,0,1,112,112",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M47.99414,48a160,160,0,0,1,160,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "51.99414",
        cy: "204",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,144a64,64,0,0,1,64,64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M48,96A112,112,0,0,1,160,208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M48,48A160,160,0,0,1,208,208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "52",
        cy: "204",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Rss = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8x(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Rss.displayName = "Rss";

var renderPathFor$8y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56,48A152,152,0,0,1,208,200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M56,120a80,80,0,0,1,80,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "56",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M55.99414,48a152,152,0,0,1,152,152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M55.99414,120a80,80,0,0,1,80,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "55.99414",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99414,199.99963a8,8,0,0,1-16,0c0-79.40234-64.59814-144-144-144a8,8,0,0,1,0-16C144.21826,39.99963,215.99414,111.775,215.99414,199.99963Zm-160-88a8,8,0,1,0,0,16,72.08124,72.08124,0,0,1,72,72,8,8,0,0,0,16,0A88.09957,88.09957,0,0,0,55.99414,111.99963Zm0,76a12,12,0,1,0,12,12A12.01344,12.01344,0,0,0,55.99414,187.99963Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56,48A152,152,0,0,1,208,200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M56,120a80,80,0,0,1,80,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "56",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56,48A152,152,0,0,1,208,200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M56,120a80,80,0,0,1,80,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "56",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56,48A152,152,0,0,1,208,200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M56,120a80,80,0,0,1,80,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "56",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var RssSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
RssSimple.displayName = "RssSimple";

var renderPathFor$8z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "60",
        cy: "76",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "180",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "128",
        x2: "83.10669",
        y2: "164.19016",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "193.68421",
        x2: "83.10611",
        y2: "91.80944",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "62.31579",
        x2: "171.41815",
        y2: "103.76653",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "60",
        cy: "76",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "180",
        r: "28",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "76",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "180",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "128",
        x2: "83.10669",
        y2: "164.19016",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "62.31579",
        x2: "164.33455",
        y2: "108.6132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "193.68421",
        x2: "83.10611",
        y2: "91.80944",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M157.73193,113.13086a8.00047,8.00047,0,0,1,2.085-11.12012l67.66553-46.29785A8.00013,8.00013,0,0,1,236.51758,68.918l-67.66553,46.29785a7.99794,7.99794,0,0,1-11.12012-2.085Zm80.87061,85.07129a7.99794,7.99794,0,0,1-11.12012,2.085l-91.4826-62.59351L93.49408,166.77686a36.034,36.034,0,1,1-9.05035-13.19458l37.38867-25.582-37.3891-25.582a35.84637,35.84637,0,1,1,9.0506-13.19458L236.51758,187.082A8.00047,8.00047,0,0,1,238.60254,198.20215ZM80,180a20,20,0,1,0-5.85791,14.1416A19.86692,19.86692,0,0,0,80,180ZM74.14209,90.1416a20,20,0,1,0-28.28418,0A19.86692,19.86692,0,0,0,74.14209,90.1416Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "60",
        cy: "76",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "180",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "128",
        x2: "83.10669",
        y2: "164.19016",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "62.31579",
        x2: "164.33455",
        y2: "108.6132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "193.68421",
        x2: "83.10611",
        y2: "91.80944",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "60",
        cy: "76",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "180",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "128",
        x2: "83.10669",
        y2: "164.19016",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "62.31579",
        x2: "164.33455",
        y2: "108.6132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "193.68421",
        x2: "83.10611",
        y2: "91.80944",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "60",
        cy: "76",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "60",
        cy: "180",
        r: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "128",
        x2: "83.10669",
        y2: "164.19016",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "62.31579",
        x2: "164.33455",
        y2: "108.6132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "232",
        y1: "193.68421",
        x2: "83.10611",
        y2: "91.80944",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Scissors = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Scissors.displayName = "Scissors";

var renderPathFor$8A = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M36,68V60a8,8,0,0,1,8-8H212a8,8,0,0,1,8,8V196a8,8,0,0,1-8,8H172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M36,188a16,16,0,0,1,16,16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M36,148a56,56,0,0,1,56,56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M36,108a96,96,0,0,1,96,96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.00049,47.99561h-176a7.99988,7.99988,0,0,0-8,8V192a15.99986,15.99986,0,0,1,15.99927,15.99561H216.00049a8,8,0,0,0,8-8v-144A7.99989,7.99989,0,0,0,216.00049,47.99561Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M32,96V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,192a16,16,0,0,1,16,16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,160a48,48,0,0,1,48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,128a80,80,0,0,1,80,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M32,184a8,8,0,0,0,0,16,8.00917,8.00917,0,0,1,8,8,8,8,0,0,0,16,0A24.02718,24.02718,0,0,0,32,184Z"
      }), React__default.createElement("path", {
        d: "M32,152a8,8,0,0,0,0,16,40.04552,40.04552,0,0,1,40,40,8,8,0,0,0,16,0A56.06322,56.06322,0,0,0,32,152Z"
      }), React__default.createElement("path", {
        d: "M32,120a8,8,0,0,0,0,16,72.08124,72.08124,0,0,1,72,72,8,8,0,0,0,16,0A88.09957,88.09957,0,0,0,32,120Z"
      }), React__default.createElement("path", {
        d: "M216,40H40A16.01833,16.01833,0,0,0,24,56V96a8.00008,8.00008,0,0,0,8,8A104.11791,104.11791,0,0,1,136,208a8.00008,8.00008,0,0,0,8,8h72a16.01833,16.01833,0,0,0,16-16V56A16.01833,16.01833,0,0,0,216,40Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,96V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,192a16,16,0,0,1,16,16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,160a48,48,0,0,1,48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,128a80,80,0,0,1,80,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,96V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,192a16,16,0,0,1,16,16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,160a48,48,0,0,1,48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,128a80,80,0,0,1,80,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,96V56a8,8,0,0,1,8-8H216a8,8,0,0,1,8,8V200a8,8,0,0,1-8,8H144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,192a16,16,0,0,1,16,16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,160a48,48,0,0,1,48,48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,128a80,80,0,0,1,80,80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Screencast = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8A(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Screencast.displayName = "Screencast";

var renderPathFor$8B = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M192,216H40a8,8,0,0,1-8-8V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M75.0245,175.99967A96.04041,96.04041,0,0,1,168,104h56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M192,216H40a8,8,0,0,1-8-8V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M75.0245,175.99967A96.04041,96.04041,0,0,1,168,104h56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M192,208H40V88a8,8,0,0,0-16,0V208a16.01833,16.01833,0,0,0,16,16H192a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M230.18311,109.0752c.09106-.11084.17114-.22706.25537-.3418.07055-.09522.14477-.188.21093-.28662.085-.12647.15894-.25782.23584-.38819.05567-.09423.11524-.186.16724-.2832.06909-.12891.12817-.26172.1897-.39355.04931-.10547.10205-.209.147-.31641.05225-.127.095-.25586.14063-.38477.042-.11816.08764-.23437.12426-.355.03907-.1289.06787-.25976.10034-.39013.03052-.12305.06519-.24414.09009-.36914.03-.15186.04859-.30469.06983-.45752.01465-.106.03515-.20948.04565-.3169a8.02276,8.02276,0,0,0,0-1.584c-.0105-.10742-.031-.21094-.04565-.3169-.02124-.15283-.0398-.30566-.06983-.45752-.0249-.125-.05957-.24609-.09009-.36914-.03247-.13037-.06127-.26123-.10034-.39013-.03662-.12061-.08227-.23682-.12426-.355-.04566-.12891-.08838-.25782-.14063-.38477-.04492-.10742-.09766-.21094-.147-.31641-.06153-.13183-.12061-.26464-.1897-.39355-.052-.09717-.11157-.189-.16724-.2832-.0769-.13037-.15087-.26172-.23584-.38819-.06616-.09863-.14038-.1914-.21093-.28662-.08423-.11474-.16431-.231-.25537-.3418-.116-.14111-.242-.27343-.36719-.40625-.05445-.0581-.1023-.11914-.15869-.17578l-48-48a8.00053,8.00053,0,0,0-11.31446,11.31446L204.68628,96H168A103.9414,103.9414,0,0,0,67.27734,174.00586a7.99961,7.99961,0,1,0,15.49414,3.98828A87.94718,87.94718,0,0,1,168,112h36.68628l-34.34351,34.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l48-48c.05639-.05664.10424-.11768.15869-.17578C229.94116,109.34863,230.06714,109.21631,230.18311,109.0752Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M192,216H40a8,8,0,0,1-8-8V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M75.0245,175.99967A96.04041,96.04041,0,0,1,168,104h56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M192,216H40a8,8,0,0,1-8-8V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M75.0245,175.99967A96.04041,96.04041,0,0,1,168,104h56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "176 152 224 104 176 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M192,216H40a8,8,0,0,1-8-8V88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M75.0245,175.99967A96.04041,96.04041,0,0,1,168,104h56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Share = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8B(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Share.displayName = "Share";

var renderPathFor$8C = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "64",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "200",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "56",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "149.08436",
        y1: "73.30291",
        x2: "90.91323",
        y2: "110.69864",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "90.9132",
        y1: "145.30134",
        x2: "149.08428",
        y2: "182.69704",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "176",
        cy: "200",
        r: "32",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "56",
        r: "32",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "64",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "200",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "56",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "149.08436",
        y1: "73.30291",
        x2: "90.91323",
        y2: "110.69864",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "90.9132",
        y1: "145.30134",
        x2: "149.08428",
        y2: "182.69704",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,160a39.87518,39.87518,0,0,0-28.61768,12.09277L101.28467,142.4585a39.85174,39.85174,0,0,0,0-28.917l46.09765-29.63427a39.94957,39.94957,0,1,0-8.667-13.44947L92.61719,100.09229a40,40,0,1,0,0,55.81542l46.09814,29.63453A39.99342,39.99342,0,1,0,176,160Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "64",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "200",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "56",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "149.08436",
        y1: "73.30291",
        x2: "90.91323",
        y2: "110.69864",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "90.9132",
        y1: "145.30134",
        x2: "149.08428",
        y2: "182.69704",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "64",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "200",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "56",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "149.08436",
        y1: "73.30291",
        x2: "90.91323",
        y2: "110.69864",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "90.9132",
        y1: "145.30134",
        x2: "149.08428",
        y2: "182.69704",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "64",
        cy: "128",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "200",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "176",
        cy: "56",
        r: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "149.08436",
        y1: "73.30291",
        x2: "90.91323",
        y2: "110.69864",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "90.9132",
        y1: "145.30134",
        x2: "149.08428",
        y2: "182.69704",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ShareNetwork = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8C(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ShareNetwork.displayName = "ShareNetwork";

var renderPathFor$8D = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.00146,32h-160a16.02085,16.02085,0,0,0-16,16v58.66406c0,89.46094,75.82032,119.125,91.03125,124.16406a15.45824,15.45824,0,0,0,9.9375,0c15.20313-5.03906,91.03125-34.69531,91.03125-124.16406V48A16.02084,16.02084,0,0,0,208.00146,32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Shield = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8D(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Shield.displayName = "Shield";

var renderPathFor$8E = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "172 96 113.333 152 84 124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "172 96 113.333 152 84 124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.00146,32h-160a16.02085,16.02085,0,0,0-16,16v58.66406c0,89.46094,75.82032,119.125,91.03125,124.16406a15.45824,15.45824,0,0,0,9.9375,0c15.20313-5.03906,91.03125-34.69531,91.03125-124.16406V48A16.02084,16.02084,0,0,0,208.00146,32ZM177.5249,101.78906l-58.67187,56a8.00489,8.00489,0,0,1-11.04688,0l-29.32812-28A8.00135,8.00135,0,1,1,89.5249,118.21094l23.80469,22.72656L166.478,90.21094a8.00135,8.00135,0,1,1,11.04687,11.57812Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "172 96 113.333 152 84 124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "172 96 113.333 152 84 124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "172 96 113.333 152 84 124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ShieldCheck = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8E(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ShieldCheck.displayName = "ShieldCheck";

var renderPathFor$8F = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "202.402 164.082 128 112 53.597 164.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M202.40575,164.0837C180.989,204.285,140.7647,219.81955,130.4562,223.23725a7.54755,7.54755,0,0,1-4.9124,0c-10.30857-3.41773-50.53339-18.95246-71.95-59.15443l.00313-.001L128,112l74.40193,52.08167Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "202.402 164.082 128 112 53.597 164.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99951,32.00012h-160a16.01818,16.01818,0,0,0-16,16v58.66651c0,89.45312,75.82617,119.12451,91.02637,124.16406a15.48361,15.48361,0,0,0,9.94726.00049c15.2002-5.04,91.02637-34.71143,91.02637-124.16455V48.00012A16.01817,16.01817,0,0,0,207.99951,32.00012Zm-160,16h160v58.66651c0,17.68237-3.39453,32.69653-8.79639,45.4104L132.5874,105.44617a8.00131,8.00131,0,0,0-9.17578,0L56.79541,152.077c-5.40137-12.71387-8.7959-27.728-8.7959-45.4104Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "202.402 164.082 128 112 53.597 164.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "202.402 164.082 128 112 53.597 164.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "202.402 164.082 128 112 53.597 164.082",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ShieldChevron = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8F(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ShieldChevron.displayName = "ShieldChevron";

var renderPathFor$8G = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "33.45455",
        y1: "24",
        x2: "222.54545",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M183.89179,189.48093c-20.898,21.71963-45.66537,31.18017-53.43559,33.75632a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667V48a8,8,0,0,1,8-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M102.05883,40H208a8,8,0,0,1,8,8v58.66667c0,18.84182-3.58637,34.858-9.3111,48.42156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "33.45455",
        y1: "24",
        x2: "222.54545",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M91.24631,40H208a8,8,0,0,1,8,8v58.66667c0,22.61089-5.16469,41.15262-12.99168,56.26977",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M183.89179,189.48093c-20.898,21.71963-45.66537,31.18017-53.43559,33.75632a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667V48a8,8,0,0,1,8-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M228.46533,226.61816l-38.64551-42.51025-.00781-.00928L108.60547,94.772l-69.231-76.15381A8.0006,8.0006,0,0,0,27.53467,29.38184L35.457,38.09668A15.90942,15.90942,0,0,0,31.99951,48v58.667c0,89.45117,75.82617,119.124,91.02637,124.16406a15.49078,15.49078,0,0,0,9.94824,0,148.267,148.267,0,0,0,50.55762-29.852l33.09375,36.40284a8.0006,8.0006,0,1,0,11.83984-10.76368Z"
      }), React__default.createElement("path", {
        d: "M197.08838,168.31836a8.001,8.001,0,0,0,13.02441-1.70313c9.21485-17.79785,13.88672-37.96679,13.88672-59.94824V48a16.01833,16.01833,0,0,0-16-16H91.24658a8.00036,8.00036,0,0,0-5.91992,13.38184Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "33.45455",
        y1: "24",
        x2: "222.54545",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M91.24631,40H208a8,8,0,0,1,8,8v58.66667c0,22.61089-5.16469,41.15262-12.99168,56.26977",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M183.89179,189.48093c-20.898,21.71963-45.66537,31.18017-53.43559,33.75632a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667V48a8,8,0,0,1,8-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "33.45455",
        y1: "24",
        x2: "222.54545",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M91.24631,40H208a8,8,0,0,1,8,8v58.66667c0,22.61089-5.16469,41.15262-12.99168,56.26977",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M183.89179,189.48093c-20.898,21.71963-45.66537,31.18017-53.43559,33.75632a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667V48a8,8,0,0,1,8-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "33.5",
        y1: "24",
        x2: "222.5",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M91.24631,40H208a8,8,0,0,1,8,8v58.66667c0,22.61089-5.16469,41.15262-12.99168,56.26977",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M183.89179,189.48093c-20.898,21.71963-45.66537,31.18017-53.43559,33.75632a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667V48a8,8,0,0,1,8-8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ShieldSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8G(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ShieldSlash.displayName = "ShieldSlash";

var renderPathFor$8H = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M39.99951,106.66667V48a8,8,0,0,1,8-8h160a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.30553,218.51683,39.99951,190.682,39.99951,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "127.99951",
        y1: "84",
        x2: "127.99951",
        y2: "124",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M39.99951,106.66667V48a8,8,0,0,1,8-8h160a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.30553,218.51683,39.99951,190.682,39.99951,106.66667Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M39.99951,106.66667V48a8,8,0,0,1,8-8h160a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.30553,218.51683,39.99951,190.682,39.99951,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99951",
        y1: "88",
        x2: "127.99951",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99951,32h-160a16.01833,16.01833,0,0,0-16,16v58.667c0,89.45313,75.82617,119.124,91.02637,124.16406a15.48781,15.48781,0,0,0,9.94726,0c15.2002-5.04,91.02637-34.71093,91.02637-124.16406V48A16.01833,16.01833,0,0,0,207.99951,32Zm-88,56a8,8,0,1,1,16,0v40a8,8,0,0,1-16,0Zm8,88a12,12,0,1,1,12-12A12,12,0,0,1,127.99951,176Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M39.99951,106.66667V48a8,8,0,0,1,8-8h160a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.30553,218.51683,39.99951,190.682,39.99951,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.99951",
        y1: "88",
        x2: "127.99951",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M39.99951,106.66667V48a8,8,0,0,1,8-8h160a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.30553,218.51683,39.99951,190.682,39.99951,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "127.99951",
        y1: "88",
        x2: "127.99951",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,106.66667V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8v58.66667c0,84.01533-71.306,111.85016-85.5438,116.57058a7.54755,7.54755,0,0,1-4.9124,0C111.306,218.51683,40,190.682,40,106.66667Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "88",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "164",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ShieldWarning = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8H(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ShieldWarning.displayName = "ShieldWarning";

var renderPathFor$8I = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,88a40,40,0,0,1-80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,88a40,40,0,0,1-80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,40H40A16.01833,16.01833,0,0,0,24,56V200a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V56A16.01833,16.01833,0,0,0,216,40Zm-88,96A48.054,48.054,0,0,1,80,88a8,8,0,0,1,16,0,32,32,0,0,0,64,0,8,8,0,0,1,16,0A48.054,48.054,0,0,1,128,136Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,88a40,40,0,0,1-80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,88a40,40,0,0,1-80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,88a40,40,0,0,1-80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ShoppingBag = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8I(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ShoppingBag.displayName = "ShoppingBag";

var renderPathFor$8J = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "88",
        x2: "224",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M168,124a40,40,0,0,1-80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,80H224V56a8,8,0,0,0-8-8H40a8,8,0,0,0-8,8Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "80",
        x2: "224",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,112a40,40,0,0,1-80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,40H40A16.01833,16.01833,0,0,0,24,56V200a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V56A16.01833,16.01833,0,0,0,216,40ZM128,160a48.054,48.054,0,0,1-48-48,8,8,0,0,1,16,0,32,32,0,0,0,64,0,8,8,0,0,1,16,0A48.054,48.054,0,0,1,128,160ZM40,72V56H216l.001,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "80",
        x2: "224",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M168,112a40,40,0,0,1-80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "80",
        x2: "224",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M168,112a40,40,0,0,1-80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "80",
        x2: "224",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,112a40,40,0,0,1-80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ShoppingBagOpen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8J(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ShoppingBagOpen.displayName = "ShoppingBagOpen";

var renderPathFor$8K = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,180H68.49479a8,8,0,0,1-7.871-6.56892L33.92162,26.56892A8,8,0,0,0,26.05066,20H12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "200",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "200",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M40,60H214.4143a8,8,0,0,1,7.871,9.43108L209.45455,140H54.54545",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,64H214.4143a8,8,0,0,1,7.871,9.43108l-13.09091,72A8,8,0,0,1,201.32339,152H56Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M192,184H68.49479a8,8,0,0,1-7.871-6.56892L33.92162,30.56892A8,8,0,0,0,26.05066,24H8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "204",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "204",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M40,64H214.4143a8,8,0,0,1,7.871,9.43108l-13.09091,72A8,8,0,0,1,201.32339,152H56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M217.06543,146.8623l13.09082-72.00048A16.00086,16.00086,0,0,0,214.41406,56H46.67676L41.793,29.13818A15.9918,15.9918,0,0,0,26.05078,16H8A8,8,0,0,0,8,32H26.05078L52.75293,178.86182a16.0028,16.0028,0,0,0,1.187,3.76489A27.99341,27.99341,0,1,0,97.293,192H166.707A27.99678,27.99678,0,1,0,192,176H68.49512l-2.90918-16h135.7373A15.99184,15.99184,0,0,0,217.06543,146.8623Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,184H68.49479a8,8,0,0,1-7.871-6.56892L33.92162,30.56892A8,8,0,0,0,26.05066,24H8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "204",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "204",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M40,64H214.4143a8,8,0,0,1,7.871,9.43108l-13.09091,72A8,8,0,0,1,201.32339,152H56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,184H68.49479a8,8,0,0,1-7.871-6.56892L33.92162,30.56892A8,8,0,0,0,26.05066,24H8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "204",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "204",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M40,64H214.4143a8,8,0,0,1,7.871,9.43108l-13.09091,72A8,8,0,0,1,201.32339,152H56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M192,184H68.49479a8,8,0,0,1-7.871-6.56892L33.92162,30.56892A8,8,0,0,0,26.05066,24H8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "204",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "204",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M40,64H214.4143a8,8,0,0,1,7.871,9.43108l-13.09091,72A8,8,0,0,1,201.32339,152H56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ShoppingCart = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8K(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ShoppingCart.displayName = "ShoppingCart";

var renderPathFor$8L = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "72",
        cy: "220",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "220",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M40,64H214.41528a8,8,0,0,1,7.8711,9.43029l-16.71771,92A8,8,0,0,1,197.69756,172H66.38913a8,8,0,0,1-7.87021-6.56482L33.92441,30.56482A8,8,0,0,0,26.0542,24H12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,64H214.41528a8,8,0,0,1,7.8711,9.43029l-17.44457,96A8,8,0,0,1,196.97071,176H67.11856a8,8,0,0,1-7.87022-6.56481Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M40,64H214.41528a8,8,0,0,1,7.8711,9.43029l-17.44457,96A8,8,0,0,1,196.97071,176H67.11856a8,8,0,0,1-7.87022-6.56481L33.92441,30.56482A8,8,0,0,0,26.0542,24H8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "216",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "216",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "72",
        cy: "216",
        r: "16"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "216",
        r: "16"
      }), React__default.createElement("path", {
        d: "M226.69922,61.74805A15.95974,15.95974,0,0,0,214.415,56H46.69531L41.79492,29.12988A15.995,15.995,0,0,0,26.05371,16H8A8,8,0,0,0,8,32H26.05469L32.044,64.84717a8.04283,8.04283,0,0,0,.21679,1.18554L51.37793,170.87012A15.994,15.994,0,0,0,67.11816,184H196.9707a15.99217,15.99217,0,0,0,15.74219-13.13965l17.44434-95.99951A15.957,15.957,0,0,0,226.69922,61.74805Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,64H214.41528a8,8,0,0,1,7.8711,9.43029l-17.44457,96A8,8,0,0,1,196.97071,176H67.11856a8,8,0,0,1-7.87022-6.56481L33.92441,30.56482A8,8,0,0,0,26.0542,24H8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "216",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "216",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "216",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "216",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "216",
        r: "8"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "216",
        r: "8"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,64H214.41528a8,8,0,0,1,7.8711,9.43029l-17.44457,96A8,8,0,0,1,196.97071,176H67.11856a8,8,0,0,1-7.87022-6.56481L33.92441,30.56482A8,8,0,0,0,26.0542,24H8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "216",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "216",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "216",
        r: "8"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "216",
        r: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,64H214.41528a8,8,0,0,1,7.8711,9.43029l-17.44457,96A8,8,0,0,1,196.97071,176H67.11856a8,8,0,0,1-7.87022-6.56481L33.92441,30.56482A8,8,0,0,0,26.0542,24H8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "72",
        cy: "216",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "192",
        cy: "216",
        r: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ShoppingCartSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8L(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ShoppingCartSimple.displayName = "ShoppingCartSimple";

var renderPathFor$8M = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,72H55.06445a64,64,0,0,1,52.079,26.80076l41.7132,58.39848A64,64,0,0,0,200.93555,184H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "208 48 232 72 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "208 160 232 184 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152.76794,93.858A64.00219,64.00219,0,0,1,200.93555,72H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,184H55.06445a64.00212,64.00212,0,0,0,48.16769-21.85814",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,72H55.06445a64,64,0,0,1,52.079,26.80076l41.7132,58.39848A64,64,0,0,0,200.93555,184H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 48 232 72 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 160 232 184 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M147.66275,100.47214l1.19385-1.67138A64,64,0,0,1,200.93555,72H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,184H55.06445a64,64,0,0,0,52.079-26.80076l1.19384-1.67138",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M239.91406,182.89087c-.021-.15259-.03955-.30566-.06933-.457-.02491-.12525-.05957-.24634-.09034-.36939-.03271-.13037-.06152-.26123-.10058-.39013-.03662-.12061-.082-.23706-.124-.35523-.04542-.12866-.08838-.25781-.14063-.38428-.04492-.10791-.09766-.21118-.147-.31665-.06153-.13183-.12061-.26464-.18994-.39379-.05176-.09693-.11133-.18873-.167-.283-.07666-.13037-.15088-.26172-.23584-.38819-.0664-.09887-.14062-.19116-.21093-.28686-.084-.1145-.16407-.23072-.25537-.34156-.11622-.14111-.2417-.27368-.36719-.40649-.0542-.05762-.10205-.11914-.15869-.17554l-24-24a8.00053,8.00053,0,0,0-11.31446,11.31446L212.686,176H200.93555a56.11029,56.11029,0,0,1-45.56934-23.4502L113.65332,94.15137A72.14126,72.14126,0,0,0,55.06445,64H32a8,8,0,0,0,0,16H55.06445a56.11029,56.11029,0,0,1,45.56934,23.4502l41.71289,58.39843A72.14125,72.14125,0,0,0,200.93555,192H212.686l-10.34327,10.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l24-24c.05664-.0564.10449-.11792.15869-.17554.12549-.13281.251-.26538.36719-.40649.0913-.11084.17138-.22706.25537-.34156.07031-.0957.14453-.188.21093-.28686.085-.12647.15918-.25782.23584-.38819.05567-.09423.11524-.186.167-.283.06933-.12915.12841-.262.18994-.39379.04931-.10547.10205-.20874.147-.31665.05225-.12647.09521-.25562.14063-.38428.042-.11817.0874-.23462.124-.35523.03906-.1289.06787-.25976.10058-.39013.03077-.12305.06543-.24414.09034-.36939.02978-.15137.04834-.30444.06933-.457.01465-.106.03516-.21.0459-.31714a8.02276,8.02276,0,0,0,0-1.584C239.94922,183.10083,239.92871,182.99683,239.91406,182.89087Z"
      }), React__default.createElement("path", {
        d: "M143.01367,106.98145a7.99621,7.99621,0,0,0,11.15918-1.86036l1.19336-1.67089A56.11029,56.11029,0,0,1,200.93555,80H212.686L202.34277,90.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l24-24c.05664-.0564.10449-.11792.15869-.17554.12549-.13281.251-.26538.36719-.40649.0913-.11084.17138-.22706.25537-.34156.07031-.0957.14453-.188.21093-.28686.085-.12647.15918-.25782.23584-.38819.05567-.09423.11524-.186.167-.283.06933-.12915.12841-.262.18994-.39379.04931-.10547.10205-.20874.147-.31665.05225-.12647.09521-.25562.14063-.38428.042-.11817.0874-.23462.124-.35523.03906-.1289.06787-.25976.10058-.39013.03077-.12305.06543-.24414.09034-.36939.02978-.15137.04834-.30444.06933-.457.01465-.106.03516-.21.0459-.31714a8.02276,8.02276,0,0,0,0-1.584c-.01074-.10718-.03125-.21118-.0459-.31714-.021-.15259-.03955-.30566-.06933-.457-.02491-.12525-.05957-.24634-.09034-.36939-.03271-.13037-.06152-.26123-.10058-.39013-.03662-.12061-.082-.23706-.124-.35523-.04542-.12866-.08838-.25781-.14063-.38428-.04492-.10791-.09766-.21118-.147-.31665-.06153-.13183-.12061-.26464-.18994-.39379-.05176-.09693-.11133-.18873-.167-.283-.07666-.13037-.15088-.26172-.23584-.38819-.0664-.09887-.14062-.19116-.21093-.28686-.084-.1145-.16407-.23072-.25537-.34156-.11622-.14111-.2417-.27368-.36719-.40649-.0542-.05762-.10205-.11914-.15869-.17554l-24-24a8.00053,8.00053,0,0,0-11.31446,11.31446L212.686,64H200.93555a72.14125,72.14125,0,0,0-58.58887,30.15137l-1.19336,1.6709A7.9986,7.9986,0,0,0,143.01367,106.98145Z"
      }), React__default.createElement("path", {
        d: "M112.98633,149.01855a7.99642,7.99642,0,0,0-11.15918,1.86036l-1.19336,1.67089A56.11029,56.11029,0,0,1,55.06445,176H32a8,8,0,0,0,0,16H55.06445a72.14126,72.14126,0,0,0,58.58887-30.15137l1.19336-1.6709A7.9986,7.9986,0,0,0,112.98633,149.01855Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,72H55.06445a64,64,0,0,1,52.079,26.80076l41.7132,58.39848A64,64,0,0,0,200.93555,184H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "208 48 232 72 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "208 160 232 184 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M147.66275,100.47214l1.19385-1.67138A64,64,0,0,1,200.93555,72H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,184H55.06445a64,64,0,0,0,52.079-26.80076l1.19384-1.67138",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,72H55.06445a64,64,0,0,1,52.079,26.80076l41.7132,58.39848A64,64,0,0,0,200.93555,184H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "208 48 232 72 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "208 160 232 184 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M147.66275,100.47214l1.19385-1.67138A64,64,0,0,1,200.93555,72H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,184H55.06445a64,64,0,0,0,52.079-26.80076l1.19384-1.67138",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,72H55.06445a64,64,0,0,1,52.079,26.80076l41.7132,58.39848A64,64,0,0,0,200.93555,184H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 48 232 72 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 160 232 184 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M147.66275,100.47214l1.19385-1.67138A64,64,0,0,1,200.93555,72H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,184H55.06445a64,64,0,0,0,52.079-26.80076l1.19384-1.67138",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Shuffle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8M(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Shuffle.displayName = "Shuffle";

var renderPathFor$8N = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,72H83.88306a8,8,0,0,1,6.50986,3.35009l75.21416,105.29982A8,8,0,0,0,172.11694,184H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "208 48 232 72 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "208 160 232 184 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M32,184H83.88306a8,8,0,0,0,6.50986-3.35009l13.02884-18.24038",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152.57823,93.59048l13.02885-18.24039A8,8,0,0,1,172.11694,72H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,72H83.88306a8,8,0,0,1,6.50986,3.35009l75.21416,105.29982A8,8,0,0,0,172.11694,184H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 48 232 72 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 160 232 184 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M147.66242,100.47261l17.94466-25.12252A8,8,0,0,1,172.11694,72H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,184H83.88306a8,8,0,0,0,6.50986-3.35009l17.94466-25.12252",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M239.91406,182.89087c-.021-.15259-.03955-.30566-.06933-.457-.02491-.12525-.05957-.24634-.09034-.36939-.03271-.13037-.06152-.26123-.10058-.39013-.03662-.12073-.082-.23706-.124-.35523-.04542-.12866-.08838-.25781-.14063-.38428-.04492-.10791-.09766-.21118-.147-.31665-.06153-.13195-.12061-.26464-.18994-.39379-.05176-.09693-.11133-.18873-.167-.28309-.07666-.13024-.15088-.26147-.23584-.38806-.0664-.09887-.14062-.19116-.21093-.28686-.084-.11438-.16407-.23084-.25537-.34156-.11622-.14111-.2417-.27368-.36719-.40649-.0542-.05762-.10205-.11914-.15869-.17554l-24-24a8.00053,8.00053,0,0,0-11.31446,11.31446l10.34375,10.343-40.56933.00074L96.90234,70.7002A16.03,16.03,0,0,0,83.88281,64H32a8,8,0,0,0,0,16l51.88281-.001L159.09766,185.2998A16.03,16.03,0,0,0,172.11719,192H212.686l-10.34327,10.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l24-24c.05664-.0564.10449-.11792.15869-.17554.12549-.13281.251-.26538.36719-.40649.0913-.11072.17138-.22718.25537-.34156.07031-.0957.14453-.188.21093-.28686.085-.12659.15918-.25782.23584-.38806.05567-.09436.11524-.18616.167-.28309.06933-.12915.12841-.26184.18994-.39379.04931-.10547.10205-.20874.147-.31665.05225-.12647.09521-.25562.14063-.38428.042-.11817.0874-.2345.124-.35523.03906-.1289.06787-.25976.10058-.39013.03077-.12305.06543-.24414.09034-.36939.02978-.15137.04834-.30444.06933-.457.01465-.106.03516-.21.0459-.31714a8.02276,8.02276,0,0,0,0-1.584C239.94922,183.10083,239.92871,182.99683,239.91406,182.89087Z"
      }), React__default.createElement("path", {
        d: "M143.01172,106.98242a7.99822,7.99822,0,0,0,11.16015-1.85937L172.11719,80H212.686L202.34277,90.34277a8.00053,8.00053,0,0,0,11.31446,11.31446l24-24c.05664-.0564.10449-.11792.15869-.17554.12549-.13281.251-.26538.36719-.40649.0913-.11072.17138-.22718.25537-.34156.07031-.0957.14453-.188.21093-.28686.085-.12659.15918-.25782.23584-.38806.05567-.09436.11524-.18616.167-.28309.06933-.12915.12841-.26184.18994-.39379.04931-.10547.10205-.20874.147-.31665.05225-.12647.09521-.25562.14063-.38428.042-.11817.0874-.2345.124-.35523.03906-.1289.06787-.25976.10058-.39013.03077-.12305.06543-.24414.09034-.36939.02978-.15137.04834-.30444.06933-.457.01465-.106.03516-.21.0459-.31714a8.02276,8.02276,0,0,0,0-1.584c-.01074-.10718-.03125-.21118-.0459-.31714-.021-.15259-.03955-.30566-.06933-.457-.02491-.12525-.05957-.24634-.09034-.36939-.03271-.13037-.06152-.26123-.10058-.39013-.03662-.12073-.082-.23706-.124-.35523-.04542-.12866-.08838-.25781-.14063-.38428-.04492-.10791-.09766-.21118-.147-.31665-.06153-.132-.12061-.26464-.18994-.39379-.05176-.09693-.11133-.18873-.167-.28309-.07666-.13024-.15088-.26147-.23584-.38806-.0664-.09887-.14062-.19116-.21093-.28686-.084-.11438-.16407-.23084-.25537-.34156-.11622-.14111-.2417-.27368-.36719-.40649-.0542-.05762-.10205-.11914-.15869-.17554l-24-24a8.00053,8.00053,0,0,0-11.31446,11.31446L212.686,64H172.11719a16.03166,16.03166,0,0,0-13.01953,6.69922L141.15234,95.82227A8.00057,8.00057,0,0,0,143.01172,106.98242Z"
      }), React__default.createElement("path", {
        d: "M112.98828,149.01758a7.99913,7.99913,0,0,0-11.16016,1.85937L83.88281,176H32a8,8,0,0,0,0,16H83.88281a16.03166,16.03166,0,0,0,13.01953-6.69922l17.94532-25.12305A8.00057,8.00057,0,0,0,112.98828,149.01758Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,72H83.88306a8,8,0,0,1,6.50986,3.35009l75.21416,105.29982A8,8,0,0,0,172.11694,184H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "208 48 232 72 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "208 160 232 184 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M147.66242,100.47261l17.94466-25.12252A8,8,0,0,1,172.11694,72H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M32,184H83.88306a8,8,0,0,0,6.50986-3.35009l17.94466-25.12252",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,72H83.88306a8,8,0,0,1,6.50986,3.35009l75.21416,105.29982A8,8,0,0,0,172.11694,184H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "208 48 232 72 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "208 160 232 184 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M147.66242,100.47261l17.94466-25.12252A8,8,0,0,1,172.11694,72H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M32,184H83.88306a8,8,0,0,0,6.50986-3.35009l17.94466-25.12252",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32,72H83.88306a8,8,0,0,1,6.50986,3.35009l75.21416,105.29982A8,8,0,0,0,172.11694,184H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 48 232 72 208 96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 160 232 184 208 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M147.66242,100.47261l17.94466-25.12252A8,8,0,0,1,172.11694,72H232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M32,184H83.88306a8,8,0,0,0,6.50986-3.35009l17.94466-25.12252",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ShuffleAngular = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8N(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ShuffleAngular.displayName = "ShuffleAngular";

var renderPathFor$8O = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "48",
        x2: "208",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "156.28419",
        y1: "99.71581",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "99.7158",
        y2: "156.2842",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "48",
        x2: "208",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "150.62718",
        y1: "105.37282",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "105.37282",
        y2: "150.62718",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M214.42358,212.75391c.07618-.10254.15577-.20264.22681-.3086.08252-.123.15405-.25049.22876-.37646.05811-.09815.11987-.19385.17383-.29444.06811-.12695.12573-.25732.18652-.38671.05029-.10743.10425-.2129.1499-.32325.052-.125.094-.25293.13916-.38037.04273-.11914.08863-.23681.12549-.35888.03882-.12793.06763-.25782.09961-.38721.031-.124.06592-.2461.09082-.37207.03-.15088.04834-.30371.06958-.45606.0149-.106.0354-.21045.0459-.31787.02637-.26513.04028-.53125.04-.79687V168a8,8,0,0,0-16,0v20.686L53.65723,42.34326A8.00018,8.00018,0,1,0,42.34277,53.65674L188.686,200H168a8,8,0,0,0,0,16h40c.26367,0,.5271-.01416.78955-.04.11694-.01123.23023-.0332.34546-.0498.14331-.02051.28687-.03711.429-.06543.13086-.02588.25782-.062.38624-.09424.125-.03125.25024-.0586.37377-.09619.12549-.03809.24634-.085.3689-.12891.12378-.04394.24829-.085.37012-.13525.11426-.04737.22388-.10352.33545-.15576.125-.05909.25122-.11475.374-.18018.105-.05664.20508-.12061.30713-.18164.12231-.07276.24561-.14209.36475-.22168.10986-.07324.21289-.15576.31884-.23438.10328-.07666.209-.14892.30933-.231.17358-.14258.33862-.29541.49951-.45166.02759-.02686.05786-.04981.08521-.07715.03051-.03028.05615-.064.08593-.09522.15284-.15771.30225-.31836.44165-.48828C214.27,212.96973,214.34448,212.86035,214.42358,212.75391Z"
      }), React__default.createElement("path", {
        d: "M150.627,113.37305a7.97784,7.97784,0,0,0,5.65723-2.34326L200,67.314V88a8,8,0,0,0,16,0V48.00488c.00024-.26562-.01367-.53174-.04-.79687-.0105-.10742-.031-.21192-.0459-.31787-.02124-.15235-.03955-.30518-.06958-.45606-.0249-.126-.05981-.248-.09082-.37207-.032-.12939-.06079-.25928-.09961-.38721-.03686-.12207-.083-.23974-.12549-.35937-.04516-.127-.0874-.25488-.13916-.37988-.04565-.11035-.09985-.21582-.15014-.32373-.06055-.1294-.11817-.25928-.186-.38623-.05444-.10108-.1167-.19776-.17529-.29639-.07422-.12549-.14551-.252-.2273-.374-.07153-.10694-.15161-.20752-.22827-.31055-.07885-.106-.15283-.21484-.23755-.31787-.1394-.16992-.28881-.33057-.44165-.48828-.02978-.03125-.05542-.06494-.08593-.09522-.0293-.0293-.06153-.05371-.09131-.08252-.15869-.15429-.32105-.30469-.49219-.44531-.106-.08691-.21777-.16357-.32715-.24463-.1001-.07373-.19678-.15137-.30029-.2207-.12476-.0835-.25415-.15625-.38233-.23194-.09619-.05712-.18994-.11767-.28881-.17089-.12769-.06836-.25879-.12647-.38941-.1875-.10669-.04981-.21118-.10352-.32031-.14893-.126-.05225-.25439-.09424-.38208-.13965-.1189-.04248-.23608-.08838-.35742-.125-.12622-.03857-.2544-.0664-.38208-.09814-.126-.03174-.25049-.06739-.37866-.09278-.14356-.02832-.28858-.04541-.43311-.06591-.114-.01612-.22632-.03809-.3418-.04932-.26245-.02588-.52563-.04-.78882-.04H168a8,8,0,0,0,0,16h20.68579L144.96973,99.71582a8.00025,8.00025,0,0,0,5.65722,13.65723Z"
      }), React__default.createElement("path", {
        d: "M99.71582,144.97021l-57.373,57.373a8.00018,8.00018,0,0,0,11.31446,11.31348l57.373-57.37256a8.00035,8.00035,0,0,0-11.31445-11.314Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "48",
        x2: "208",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "150.62718",
        y1: "105.37282",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "105.37282",
        y2: "150.62718",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "48",
        x2: "208",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "150.62718",
        y1: "105.37282",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "105.37282",
        y2: "150.62718",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "168 48 208 48 208 88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "208 168 208 208 168 208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "48",
        x2: "208",
        y2: "208",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "150.62718",
        y1: "105.37282",
        x2: "208",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "208",
        x2: "105.37282",
        y2: "150.62718",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ShuffleSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8O(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ShuffleSimple.displayName = "ShuffleSimple";

var renderPathFor$8P = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "94 170 136 128 94 86",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "23.97056",
        y1: "128",
        x2: "135.97056",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M120,40h72a8,8,0,0,1,8,8V208a8,8,0,0,1-8,8H120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "94 170 136 128 94 86",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "23.97056",
        y1: "128",
        x2: "135.97056",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M120,40h72a8,8,0,0,1,8,8V208a8,8,0,0,1-8,8H120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M141.65674,122.34277l-42-42A8.00018,8.00018,0,0,0,88.34326,91.65723L116.686,120H23.9707a8,8,0,1,0,0,16H116.686L88.34326,164.34277a8.00018,8.00018,0,0,0,11.31348,11.31446l42-42A8.00034,8.00034,0,0,0,141.65674,122.34277Z"
      }), React__default.createElement("path", {
        d: "M192,32H120a8,8,0,0,0,0,16h72V208H120a8,8,0,0,0,0,16h72a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,192,32Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "94 170 136 128 94 86",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "23.97056",
        y1: "128",
        x2: "135.97056",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M120,40h72a8,8,0,0,1,8,8V208a8,8,0,0,1-8,8H120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "94 170 136 128 94 86",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "23.97056",
        y1: "128",
        x2: "135.97056",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M120,40h72a8,8,0,0,1,8,8V208a8,8,0,0,1-8,8H120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "94 170 136 128 94 86",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "23.97056",
        y1: "128",
        x2: "135.97056",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M120,40h72a8,8,0,0,1,8,8V208a8,8,0,0,1-8,8H120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SignIn = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8P(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SignIn.displayName = "SignIn";

var renderPathFor$8Q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "174.029 86 216.029 128 174.029 170",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M120,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8h72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "174.029 86 216.029 128 174.029 170",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M120,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8h72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M221.68652,122.34277l-42-42a8.00018,8.00018,0,0,0-11.31347,11.31446L196.71582,120H104a8,8,0,0,0,0,16h92.71582l-28.34277,28.34277a8.00018,8.00018,0,0,0,11.31347,11.31446l42-42A8.0012,8.0012,0,0,0,221.68652,122.34277Z"
      }), React__default.createElement("path", {
        d: "M120,208H48V48h72a8,8,0,0,0,0-16H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16h72a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "174.029 86 216.029 128 174.029 170",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M120,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8h72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "174.029 86 216.029 128 174.029 170",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M120,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8h72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "174.029 86 216.029 128 174.029 170",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M120,216H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8h72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SignOut = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8Q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SignOut.displayName = "SignOut";

var renderPathFor$8R = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "72 40 184 40 240 104 128 224 16 104 72 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "177.091 104 128 224 78.909 104 128 40 177.091 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "104",
        x2: "240",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "184 40 128 40 78.909 104 128 224 240 104 184 40",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "72 40 184 40 240 104 128 224 16 104 72 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "177.091 104 128 224 78.909 104 128 40 177.091 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "104",
        x2: "240",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M246.48828,108.6676c.07129-.09924.14307-.19824.21-.30084.07324-.11182.14014-.22607.207-.34064.06006-.10333.1211-.20593.17676-.31213.062-.11768.11719-.23749.17236-.35748.05127-.11.10352-.21894.14942-.33155.0498-.12121.09131-.24438.13476-.36737.04053-.11541.084-.22925.11914-.347.041-.13526.07178-.2724.10547-.40924.02637-.1084.05762-.21479.07959-.32483q.074-.3673.1128-.73932c.00634-.06189.00634-.12543.01172-.18774.01562-.19642.02832-.39289.02978-.58985,0-.02008.00293-.03949.00293-.05963,0-.0733-.00879-.14429-.01074-.2171-.00488-.16461-.01074-.329-.02539-.49317-.00977-.11059-.02442-.21936-.03907-.32867-.01806-.14069-.03808-.28082-.064-.42059-.022-.11872-.04736-.23578-.07471-.35254-.02978-.12781-.062-.25482-.09814-.38141q-.05054-.17909-.10938-.35437c-.041-.12146-.08545-.24152-.13232-.36139-.04492-.11554-.09131-.23023-.1416-.34308-.05225-.11774-.10987-.23334-.168-.349-.05567-.1098-.11133-.21918-.17139-.326-.063-.11181-.13183-.22107-.20068-.33044-.0669-.10584-.1333-.21155-.20459-.31391-.07178-.1029-.14942-.20275-.22656-.303-.07911-.10236-.15772-.20478-.24121-.30317-.02491-.02948-.04639-.061-.07178-.09027l-56-64A8.001,8.001,0,0,0,184,32H72a8.001,8.001,0,0,0-6.02051,2.73193l-56,64c-.02539.02924-.04687.06079-.07178.09034-.08349.09832-.1621.20074-.24121.3031-.07714.10022-.15478.20007-.22656.303-.07129.10236-.13769.20807-.20459.31391-.06885.10937-.13769.21863-.20068.33044-.06006.10681-.11572.21619-.17139.326-.0581.11566-.11572.23126-.168.349-.05029.11285-.09668.22754-.1416.34308-.04687.11987-.09131.23993-.13232.36139q-.05861.1755-.10938.35437c-.03613.12659-.06836.2536-.09814.38141-.02735.11676-.05274.23382-.07471.35254-.02588.13977-.0459.2799-.064.42059-.01465.10931-.0293.21808-.03907.32867-.01465.16419-.02051.32856-.02539.49317C8.00879,103.85571,8,103.9267,8,104c0,.02014.00293.03955.00293.05963.00146.197.01416.39343.02978.58985.00538.06231.00538.12585.01172.18774q.03882.3717.1128.73932c.022.11.05322.21643.07959.32483.03369.13684.06445.274.10547.40924.03515.11773.07861.23157.11914.347.04345.123.085.24616.13476.36737.0459.11261.09815.22156.14942.33155.05517.12.11035.2398.17236.35748.05566.1062.1167.2088.17676.31213.06689.11457.13379.22882.207.34064.06689.1026.13867.2016.21.30084.07617.10541.15234.21033.23389.31275.07959.09961.16308.19525.24707.29089.0542.06177.10253.12683.15869.18726l112,120c.11377.12164.2373.23126.35742.34491.05615.05316.1084.10949.1665.16095a8.01052,8.01052,0,0,0,.81006.63409c.06348.04364.13037.08154.19531.12329a7.97782,7.97782,0,0,0,.7295.416c.081.041.16113.08313.24414.1214a8.00691,8.00691,0,0,0,.96045.37481c.04736.015.09716.02417.145.03821a7.98871,7.98871,0,0,0,.89062.20343c.09424.01617.18848.03143.28369.04419a7.12355,7.12355,0,0,0,2.13184,0c.09521-.01276.18945-.028.28369-.04419a7.98871,7.98871,0,0,0,.89062-.20343c.04786-.014.09766-.02325.145-.03821a8.00691,8.00691,0,0,0,.96045-.37481c.083-.03827.16309-.08039.24414-.1214a7.97782,7.97782,0,0,0,.7295-.416c.06494-.04175.13183-.07965.19531-.12329a8.01052,8.01052,0,0,0,.81006-.63409c.0581-.05146.11035-.10779.1665-.16095.12012-.11365.24365-.22327.35742-.34491l112-120c.05616-.06037.10449-.12531.15821-.18695.08447-.09577.168-.19147.24755-.2912C246.33594,108.87793,246.41211,108.773,246.48828,108.6676ZM73.53857,112l30.53418,74.63892L34.40967,112Zm108.92286,0h39.1289l-69.66308,74.63892Zm39.9082-16H181.03711L144.21875,48h36.15137ZM75.62988,48h36.15137L74.96289,96H33.63037Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "72 40 184 40 240 104 128 224 16 104 72 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "177.091 104 128 224 78.909 104 128 40 177.091 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "104",
        x2: "240",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "72 40 184 40 240 104 128 224 16 104 72 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "177.091 104 128 224 78.909 104 128 40 177.091 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "104",
        x2: "240",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "72 40 184 40 240 104 128 224 16 104 72 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "177.091 104 128 224 78.909 104 128 40 177.091 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "104",
        x2: "240",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SketchLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8R(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SketchLogo.displayName = "SketchLogo";

var renderPathFor$8S = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M67.17024,121.17374,187.8284,47.4382A8,8,0,0,1,200,54.26445v147.4711a8,8,0,0,1-12.1716,6.82625L67.17024,134.82625A8,8,0,0,1,67.17024,121.17374Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "40",
        x2: "56",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M67.17024,121.17374,187.8284,47.4382A8,8,0,0,1,200,54.26445v147.4711a8,8,0,0,1-12.1716,6.82625L67.17024,134.82625A8,8,0,0,1,67.17024,121.17374Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M67.17024,121.17374,187.8284,47.4382A8,8,0,0,1,200,54.26445v147.4711a8,8,0,0,1-12.1716,6.82625L67.17024,134.82625A8,8,0,0,1,67.17024,121.17374Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "40",
        x2: "56",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M56,32a8.00008,8.00008,0,0,1,8,8v73.73535l119.65723-73.124A16.0002,16.0002,0,0,1,208,54.26465v147.4707a16.004,16.004,0,0,1-24.34375,13.65283L64,142.26416V216a8,8,0,0,1-16,0V40A8.00008,8.00008,0,0,1,56,32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M67.17024,121.17374,187.8284,47.4382A8,8,0,0,1,200,54.26445v147.4711a8,8,0,0,1-12.1716,6.82625L67.17024,134.82625A8,8,0,0,1,67.17024,121.17374Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "40",
        x2: "56",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M67.17024,121.17374,187.8284,47.4382A8,8,0,0,1,200,54.26445v147.4711a8,8,0,0,1-12.1716,6.82625L67.17024,134.82625A8,8,0,0,1,67.17024,121.17374Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "40",
        x2: "56",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M67.17024,121.17374,187.8284,47.4382A8,8,0,0,1,200,54.26445v147.4711a8,8,0,0,1-12.1716,6.82625L67.17024,134.82625A8,8,0,0,1,67.17024,121.17374Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "40",
        x2: "56",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SkipBack = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8S(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SkipBack.displayName = "SkipBack";

var renderPathFor$8T = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "92",
        x2: "96",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "104 128 160 92 160 164 104 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32a96,96,0,1,0,96,96A95.99991,95.99991,0,0,0,128,32Zm28,128-48-32,48-32Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "108 128 156 96 156 160 108 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "96",
        x2: "100",
        y2: "160",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm36,136a7.99975,7.99975,0,0,1-12.4375,6.65625L108,137.61426V160a8,8,0,0,1-16,0V96a8,8,0,0,1,16,0v22.38574l43.5625-29.042A7.99612,7.99612,0,0,1,164,96Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "108 128 156 96 156 160 108 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "96",
        x2: "100",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "108 128 156 96 156 160 108 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "96",
        x2: "100",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "108 128 156 96 156 160 108 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "96",
        x2: "100",
        y2: "160",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SkipBackCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8T(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SkipBackCircle.displayName = "SkipBackCircle";

var renderPathFor$8U = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188.82976,121.17374,68.1716,47.4382A8,8,0,0,0,56,54.26445v147.4711a8,8,0,0,0,12.1716,6.82625l120.65816-73.73555A8,8,0,0,0,188.82976,121.17374Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188.82976,121.17374,68.1716,47.4382A8,8,0,0,0,56,54.26445v147.4711a8,8,0,0,0,12.1716,6.82625l120.65816-73.73555A8,8,0,0,0,188.82976,121.17374Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M188.82976,121.17374,68.1716,47.4382A8,8,0,0,0,56,54.26445v147.4711a8,8,0,0,0,12.1716,6.82625l120.65816-73.73555A8,8,0,0,0,188.82976,121.17374Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,40V216a8,8,0,0,1-16,0V142.26416l-119.65625,73.124A16.00029,16.00029,0,0,1,48,201.73535V54.26465A16.0002,16.0002,0,0,1,72.34277,40.61133L192,113.73535V40a8,8,0,0,1,16,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188.82976,121.17374,68.1716,47.4382A8,8,0,0,0,56,54.26445v147.4711a8,8,0,0,0,12.1716,6.82625l120.65816-73.73555A8,8,0,0,0,188.82976,121.17374Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188.82976,121.17374,68.1716,47.4382A8,8,0,0,0,56,54.26445v147.4711a8,8,0,0,0,12.1716,6.82625l120.65816-73.73555A8,8,0,0,0,188.82976,121.17374Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188.82976,121.17374,68.1716,47.4382A8,8,0,0,0,56,54.26445v147.4711a8,8,0,0,0,12.1716,6.82625l120.65816-73.73555A8,8,0,0,0,188.82976,121.17374Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SkipForward = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8U(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SkipForward.displayName = "SkipForward";

var renderPathFor$8V = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "92",
        x2: "160",
        y2: "164",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "152 128 96 92 96 164 152 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32a96,96,0,1,0,96,96A95.99991,95.99991,0,0,0,128,32ZM100,160V96l48,32Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "148 128 100 96 100 160 148 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "96",
        x2: "156",
        y2: "160",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm36,136a8,8,0,0,1-16,0V137.61426l-43.5625,29.042A7.99612,7.99612,0,0,1,92,160V96a7.99612,7.99612,0,0,1,12.4375-6.65625L148,118.38574V96a8,8,0,0,1,16,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "96",
        x2: "156",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "148 128 100 96 100 160 148 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "96",
        x2: "156",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "148 128 100 96 100 160 148 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "148 128 100 96 100 160 148 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "96",
        x2: "156",
        y2: "160",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SkipForwardCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8V(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SkipForwardCircle.displayName = "SkipForwardCircle";

var renderPathFor$8W = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,56.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V80a24,24,0,0,1,24-24Z",
        transform: "translate(184.00005 24.00003) rotate(90)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,80H104a24,24,0,0,1-24-24V56a24,24,0,0,1,24-24h0a24,24,0,0,1,24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152,32.00007h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V56A24,24,0,0,1,152,32.00007Z",
        transform: "translate(304 160.00011) rotate(180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M176,128V104a24,24,0,0,1,24-24h0a24,24,0,0,1,24,24v0a24,24,0,0,1-24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M176,104.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V128a24,24,0,0,1,24-24Z",
        transform: "translate(23.99995 328.00003) rotate(-90)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M128,176h24a24,24,0,0,1,24,24v0a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M104,128h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V152A24,24,0,0,1,104,128Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M80,128v24a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24v0a24,24,0,0,1,24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,104.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V128a24,24,0,0,1,24-24Z",
        transform: "translate(23.99995 328.00003) rotate(-90)",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,176h24a24,24,0,0,1,24,24v0a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M80,56.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V80a24,24,0,0,1,24-24Z",
        transform: "translate(184.00005 24.00003) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,80H104a24,24,0,0,1-24-24V56a24,24,0,0,1,24-24h0a24,24,0,0,1,24,24Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M80,56.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V80a24,24,0,0,1,24-24Z",
        transform: "translate(184.00005 24.00003) rotate(90)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,80H104a24,24,0,0,1-24-24V56a24,24,0,0,1,24-24h0a24,24,0,0,1,24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,32.00007h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V56A24,24,0,0,1,152,32.00007Z",
        transform: "translate(304 160.00011) rotate(180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,128V104a24,24,0,0,1,24-24h0a24,24,0,0,1,24,24v0a24,24,0,0,1-24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,104.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V128a24,24,0,0,1,24-24Z",
        transform: "translate(23.99995 328.00003) rotate(-90)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,176h24a24,24,0,0,1,24,24v0a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M104,128h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V152A24,24,0,0,1,104,128Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,128v24a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24v0a24,24,0,0,1,24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.13184,128A31.97762,31.97762,0,0,0,184,76.30522V56a31.97939,31.97939,0,0,0-56-21.132A31.97768,31.97768,0,0,0,76.30518,72H56a31.97928,31.97928,0,0,0-21.13184,56A31.97763,31.97763,0,0,0,72,179.69487V200a31.97939,31.97939,0,0,0,56,21.132A31.97768,31.97768,0,0,0,179.69482,184H200a31.97928,31.97928,0,0,0,21.13184-56ZM88,56a16,16,0,0,1,32,0V72H104A16.01833,16.01833,0,0,1,88,56ZM40,104A16.01833,16.01833,0,0,1,56,88h48a16.01833,16.01833,0,0,1,16,16v16H56A16.01833,16.01833,0,0,1,40,104Zm128,96a16,16,0,0,1-32,0V184h16A16.01833,16.01833,0,0,1,168,200Zm32-32H152a16.01833,16.01833,0,0,1-16-16V136h64a16,16,0,0,1,0,32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,56.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V80a24,24,0,0,1,24-24Z",
        transform: "translate(184.00005 24.00003) rotate(90)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,80H104a24,24,0,0,1-24-24V56a24,24,0,0,1,24-24h0a24,24,0,0,1,24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M152,32.00007h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V56a24,24,0,0,1,24-24Z",
        transform: "translate(304 160.00011) rotate(180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M176,128V104a24,24,0,0,1,24-24h0a24,24,0,0,1,24,24v0a24,24,0,0,1-24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M176,104.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V128A24,24,0,0,1,176,104.00005Z",
        transform: "translate(23.99995 328.00003) rotate(-90)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M128,176h24a24,24,0,0,1,24,24v0a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M104,128h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V152A24,24,0,0,1,104,128Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M80,128v24a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24v0a24,24,0,0,1,24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,56.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V80a24,24,0,0,1,24-24Z",
        transform: "translate(184.00005 24.00003) rotate(90)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,80H104a24,24,0,0,1-24-24V56a24,24,0,0,1,24-24h0a24,24,0,0,1,24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M152,32.00007h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V56A24,24,0,0,1,152,32.00007Z",
        transform: "translate(304 160.00011) rotate(180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M176,128V104a24,24,0,0,1,24-24h0a24,24,0,0,1,24,24v0a24,24,0,0,1-24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M176,104.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V128a24,24,0,0,1,24-24Z",
        transform: "translate(23.99995 328.00003) rotate(-90)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M128,176h24a24,24,0,0,1,24,24v0a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M104,128h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V152a24,24,0,0,1,24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M80,128v24a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24v0a24,24,0,0,1,24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,56.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V80a24,24,0,0,1,24-24Z",
        transform: "translate(184.00005 24.00003) rotate(90)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,80H104a24,24,0,0,1-24-24V56a24,24,0,0,1,24-24h0a24,24,0,0,1,24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,32.00007h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V56a24,24,0,0,1,24-24Z",
        transform: "translate(304 160.00011) rotate(180)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,128V104a24,24,0,0,1,24-24h0a24,24,0,0,1,24,24v0a24,24,0,0,1-24,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,104.00005h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V128a24,24,0,0,1,24-24Z",
        transform: "translate(23.99995 328.00003) rotate(-90)",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M128,176h24a24,24,0,0,1,24,24v0a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M104,128h24a0,0,0,0,1,0,0v72a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24V152a24,24,0,0,1,24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,128v24a24,24,0,0,1-24,24h0a24,24,0,0,1-24-24v0a24,24,0,0,1,24-24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SlackLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8W(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SlackLogo.displayName = "SlackLogo";

var renderPathFor$8X = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99805",
        y1: "108",
        x2: "127.99817",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "127.99817",
        y1: "40",
        x2: "127.99805",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "127.99805",
        cy: "88",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "199.99805",
        y1: "188",
        x2: "199.99888",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "199.99888",
        y1: "40",
        x2: "199.99805",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "199.99805",
        cy: "168",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "55.99805",
        y1: "156",
        x2: "55.99746",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "55.99746",
        y1: "40",
        x2: "55.99805",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "55.99805",
        cy: "136",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "55.99609",
        cy: "136",
        r: "20",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "127.99609",
        y1: "108",
        x2: "127.99622",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99622",
        y1: "40",
        x2: "127.99609",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.99609",
        cy: "88",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "199.99609",
        y1: "188",
        x2: "199.99693",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "199.99693",
        y1: "40",
        x2: "199.99609",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "199.99609",
        cy: "168",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "55.99609",
        y1: "156",
        x2: "55.99551",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "55.99551",
        y1: "40",
        x2: "55.99609",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "55.99609",
        cy: "136",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M135.99707,65.376V39.99988a8,8,0,0,0-16,0V65.376a23.995,23.995,0,0,0,0,45.2478v105.3761a8,8,0,0,0,16,0V110.62378a23.995,23.995,0,0,0,0-45.2478Z"
      }), React__default.createElement("path", {
        d: "M223.99707,167.99988a24.03744,24.03744,0,0,0-16-22.6239l.001-105.3761a8,8,0,1,0-16,0l-.001,105.3761a23.995,23.995,0,0,0,0,45.2478l.001,25.3761a8,8,0,0,0,16,0l-.001-25.37622A24.03728,24.03728,0,0,0,223.99707,167.99988Z"
      }), React__default.createElement("path", {
        d: "M63.99707,113.376l-.00049-73.3761a8,8,0,0,0-16,0l.00049,73.3761a23.995,23.995,0,0,0,0,45.2478l-.00049,57.3761a8,8,0,1,0,16,0l.00049-57.3761a23.995,23.995,0,0,0,0-45.2478Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99902",
        y1: "108",
        x2: "127.99915",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.99915",
        y1: "40",
        x2: "127.99902",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "127.99902",
        cy: "88",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "199.99902",
        y1: "188",
        x2: "199.99986",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "199.99986",
        y1: "40",
        x2: "199.99902",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "199.99902",
        cy: "168",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "55.99902",
        y1: "156",
        x2: "55.99844",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "55.99844",
        y1: "40",
        x2: "55.99902",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "55.99902",
        cy: "136",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "108",
        x2: "128.00012",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128.00012",
        y1: "40",
        x2: "128",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "88",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "188",
        x2: "200.00083",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200.00083",
        y1: "40",
        x2: "200",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "168",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "156",
        x2: "55.99941",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "55.99941",
        y1: "40",
        x2: "56",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "56",
        cy: "136",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128.00098",
        y1: "108",
        x2: "128.0011",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128.0011",
        y1: "40",
        x2: "128.00098",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128.00098",
        cy: "88",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200.00098",
        y1: "188",
        x2: "200.00181",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200.00181",
        y1: "40",
        x2: "200.00098",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "200.00098",
        cy: "168",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56.00098",
        y1: "156",
        x2: "56.00039",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56.00039",
        y1: "40",
        x2: "56.00098",
        y2: "116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "56.00098",
        cy: "136",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Sliders = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8X(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Sliders.displayName = "Sliders";

var renderPathFor$8Y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "147.99951",
        y1: "171.99353",
        x2: "39.99951",
        y2: "171.99365",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "215.99951",
        y1: "171.99365",
        x2: "187.99951",
        y2: "171.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "167.99951",
        cy: "171.99353",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "83.99951",
        y1: "83.99353",
        x2: "39.99951",
        y2: "83.99294",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "215.99951",
        y1: "83.99294",
        x2: "123.99951",
        y2: "83.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "103.99951",
        cy: "83.99353",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "103.99951",
        cy: "83.99353",
        r: "20",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "147.99951",
        y1: "171.99353",
        x2: "39.99951",
        y2: "171.99365",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "215.99951",
        y1: "171.99365",
        x2: "187.99951",
        y2: "171.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "167.99951",
        cy: "171.99353",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "83.99951",
        y1: "83.99353",
        x2: "39.99951",
        y2: "83.99294",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "215.99951",
        y1: "83.99294",
        x2: "123.99951",
        y2: "83.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "103.99951",
        cy: "83.99353",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M215.99951,163.99353H194.8291a27.99567,27.99567,0,0,0-53.65918,0H39.99951a8,8,0,0,0,0,16H141.16992a27.99567,27.99567,0,0,0,53.65918,0h21.17041a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M39.999,91.99255l37.1709.001a27.99567,27.99567,0,0,0,53.65918,0l85.17041-.001a8,8,0,0,0,0-16l-85.17041.001a27.99567,27.99567,0,0,0-53.65918,0L40,75.99255h-.00049a8,8,0,0,0-.00049,16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "147.99951",
        y1: "171.99353",
        x2: "39.99951",
        y2: "171.99365",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "215.99951",
        y1: "171.99365",
        x2: "187.99951",
        y2: "171.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "167.99951",
        cy: "171.99353",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "83.99951",
        y1: "83.99353",
        x2: "39.99951",
        y2: "83.99294",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "215.99951",
        y1: "83.99294",
        x2: "123.99951",
        y2: "83.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "103.99951",
        cy: "83.99353",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "147.99951",
        y1: "171.99353",
        x2: "39.99951",
        y2: "171.99365",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "215.99951",
        y1: "171.99365",
        x2: "187.99951",
        y2: "171.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "167.99951",
        cy: "171.99353",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "83.99951",
        y1: "83.99353",
        x2: "39.99951",
        y2: "83.99294",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "215.99951",
        y1: "83.99294",
        x2: "123.99951",
        y2: "83.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "103.99951",
        cy: "83.99353",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "147.99951",
        y1: "171.99353",
        x2: "39.99951",
        y2: "171.99365",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "215.99951",
        y1: "171.99365",
        x2: "187.99951",
        y2: "171.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "167.99951",
        cy: "171.99353",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "83.99951",
        y1: "83.99353",
        x2: "39.99951",
        y2: "83.99294",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "215.99951",
        y1: "83.99294",
        x2: "123.99951",
        y2: "83.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "103.99951",
        cy: "83.99353",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SlidersHorizontal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8Y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SlidersHorizontal.displayName = "SlidersHorizontal";

var renderPathFor$8Z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M169.57812,151.99627a48.02731,48.02731,0,0,1-83.15624.00073",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M169.57812,151.99627a48.02731,48.02731,0,0,1-83.15624.00073",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm36,72a12,12,0,1,1-12,12A12.0006,12.0006,0,0,1,164,96ZM92,96a12,12,0,1,1-12,12A12.0006,12.0006,0,0,1,92,96Zm84.5,60.00781a56.20543,56.20543,0,0,1-26.6875,23.58594A56.0807,56.0807,0,0,1,79.5,156.00781a7.99843,7.99843,0,1,1,13.84375-8.01562,40.274,40.274,0,0,0,19.09375,16.86719,40.44532,40.44532,0,0,0,31.14062,0,40.0058,40.0058,0,0,0,12.70313-8.57813,40.82317,40.82317,0,0,0,6.375-8.28906A7.99843,7.99843,0,1,1,176.5,156.00781Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M169.57812,151.99627a48.02731,48.02731,0,0,1-83.15624.00073",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M169.57812,151.99627a48.02731,48.02731,0,0,1-83.15624.00073",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M169.57812,151.99627a48.02731,48.02731,0,0,1-83.15624.00073",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Smiley = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8Z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Smiley.displayName = "Smiley";

var renderPathFor$8_ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24ZM92,120a12,12,0,1,1,12-12A12.0006,12.0006,0,0,1,92,120Zm72,0a12,12,0,1,1,12-12A12.0006,12.0006,0,0,1,164,120Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SmileyBlank = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8_(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SmileyBlank.displayName = "SmileyBlank";

var renderPathFor$8$ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "160",
        x2: "168",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "160",
        x2: "168",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24ZM92,96a12,12,0,1,1-12,12A12.0006,12.0006,0,0,1,92,96Zm76,72H88a8,8,0,0,1,0-16h80a8,8,0,0,1,0,16Zm-4-48a12,12,0,1,1,12-12A12.0006,12.0006,0,0,1,164,120Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "160",
        x2: "168",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "160",
        x2: "168",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "160",
        x2: "168",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SmileyMeh = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$8$(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SmileyMeh.displayName = "SmileyMeh";

var renderPathFor$90 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "85.791 164.762 96 152 112 172 128 152 144 172 160 152 170.21 164.762",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "80 172 96 152 112 172 128 152 144 172 160 152 176 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm36,72a12,12,0,1,1-12,12A12,12,0,0,1,164,96ZM92,96a12,12,0,1,1-12,12A12,12,0,0,1,92,96Zm88.99756,82.24707a8.00032,8.00032,0,0,1-11.24463-1.24951L160,164.80615l-9.75293,12.19141a8.00025,8.00025,0,0,1-12.49414,0L128,164.80615l-9.75293,12.19141a8.00025,8.00025,0,0,1-12.49414,0L96,164.80615l-9.75293,12.19141a8.00009,8.00009,0,0,1-12.49414-9.99512l16-20a8.00025,8.00025,0,0,1,12.49414,0L112,159.19385l9.75293-12.19141a8.00025,8.00025,0,0,1,12.49414,0L144,159.19385l9.75293-12.19141a8.00025,8.00025,0,0,1,12.49414,0l16,20A8.00036,8.00036,0,0,1,180.99756,178.24707Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "80 172 96 152 112 172 128 152 144 172 160 152 176 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "80 172 96 152 112 172 128 152 144 172 160 152 176 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "80 172 96 152 112 172 128 152 144 172 160 152 176 172",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SmileyNervous = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$90(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SmileyNervous.displayName = "SmileyNervous";

var renderPathFor$91 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M165.27454,169.75452a48.01426,48.01426,0,0,0-74.5496.00064",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M169.57833,175.99927a48.0273,48.0273,0,0,0-83.15623-.00074",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm36,72a12,12,0,1,1-12,12A12.0006,12.0006,0,0,1,164,96ZM92,96a12,12,0,1,1-12,12A12.0006,12.0006,0,0,1,92,96Zm81.58594,86.92188a7.9139,7.9139,0,0,1-4,1.07812,7.99834,7.99834,0,0,1-6.92969-3.99219,40.42846,40.42846,0,0,0-6.375-8.29687,39.8432,39.8432,0,0,0-12.71094-8.57031,40.30551,40.30551,0,0,0-31.14062,0,40.11288,40.11288,0,0,0-19.07813,16.86718A8.00181,8.00181,0,0,1,79.5,171.99219a56.02208,56.02208,0,0,1,97,0A7.98921,7.98921,0,0,1,173.58594,182.92188Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M169.57833,175.99927a48.0273,48.0273,0,0,0-83.15623-.00074",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M169.57833,175.99927a48.0273,48.0273,0,0,0-83.15623-.00074",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M169.57833,175.99927a48.0273,48.0273,0,0,0-83.15623-.00074",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SmileySad = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$91(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SmileySad.displayName = "SmileySad";

var renderPathFor$92 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M169.57812,151.99627a48.02731,48.02731,0,0,1-83.15624.00073",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M156.21732,219.78606a95.898,95.898,0,1,1,63.57-63.573Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M156.21732,219.78606a95.898,95.898,0,1,1,63.57-63.573Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M169.57812,151.99627a48.02731,48.02731,0,0,1-83.15624.00073",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M156.21732,219.78606a95.898,95.898,0,1,1,63.57-63.573Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24a104,104,0,1,0,30.56543,203.43359,7.99683,7.99683,0,0,0,3.30859-1.99072l63.57032-63.57324a7.99548,7.99548,0,0,0,1.99072-3.30859A104.07559,104.07559,0,0,0,128,24Zm36,72a12,12,0,1,1-12,12A12,12,0,0,1,164,96ZM92,96a12,12,0,1,1-12,12A12,12,0,0,1,92,96Zm84.50293,60.00244a56.19607,56.19607,0,0,1-26.70264,23.58936,56.05693,56.05693,0,0,1-70.30322-23.58863,8.00011,8.00011,0,0,1,13.84961-8.0122,40.19352,40.19352,0,0,0,19.08594,16.86548,39.95953,39.95953,0,0,0,43.85156-8.57618,40.18715,40.18715,0,0,0,6.36914-8.28979,8.00005,8.00005,0,1,1,13.84961,8.012Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M169.57812,151.99627a48.02731,48.02731,0,0,1-83.15624.00073",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M156.21732,219.78606a95.898,95.898,0,1,1,63.57-63.573Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M169.57812,151.99627a48.02731,48.02731,0,0,1-83.15624.00073",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M156.21732,219.78606a95.898,95.898,0,1,1,63.57-63.573Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M169.57812,151.99627a48.02731,48.02731,0,0,1-83.15624.00073",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M156.21732,219.78606a95.898,95.898,0,1,1,63.57-63.573Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "92",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "164",
        cy: "108",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SmileySticker = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$92(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SmileySticker.displayName = "SmileySticker";

var renderPathFor$93 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "180",
        y1: "96",
        x2: "148",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "180",
        y1: "128",
        x2: "148",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "108",
        y1: "96",
        x2: "76",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "108",
        y1: "128",
        x2: "76",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "96",
        x2: "152",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "128",
        x2: "152",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "96",
        x2: "72",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "72",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm-18.34375,98.34375a7.99915,7.99915,0,1,1-11.3125,11.3125L88,123.3125,77.65625,133.65625a7.99915,7.99915,0,0,1-11.3125-11.3125L76.6875,112,66.34375,101.65625a7.99915,7.99915,0,0,1,11.3125-11.3125L88,100.6875,98.34375,90.34375a7.99915,7.99915,0,0,1,11.3125,11.3125L99.3125,112ZM128,192a12,12,0,1,1,12-12A12.0006,12.0006,0,0,1,128,192Zm61.65625-69.65625a7.99915,7.99915,0,1,1-11.3125,11.3125L168,123.3125l-10.34375,10.34375a7.99915,7.99915,0,0,1-11.3125-11.3125L156.6875,112l-10.34375-10.34375a7.99915,7.99915,0,0,1,11.3125-11.3125L168,100.6875l10.34375-10.34375a7.99915,7.99915,0,0,1,11.3125,11.3125L179.3125,112Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "96",
        x2: "152",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "128",
        x2: "152",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "96",
        x2: "72",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "72",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "96",
        x2: "152",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "128",
        x2: "152",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "96",
        x2: "72",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "72",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "96",
        x2: "152",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "128",
        x2: "152",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "96",
        x2: "72",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "128",
        x2: "72",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SmileyXEyes = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$93(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SmileyXEyes.displayName = "SmileyXEyes";

var renderPathFor$94 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "64",
        x2: "128",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "104 40 128 64 152 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "104 216 128 192 152 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "72.57437",
        y1: "96",
        x2: "183.42563",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "39.79 104.785 72.574 96 63.79 63.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "192.21 192.785 183.426 160 216.21 151.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "72.57437",
        y1: "160",
        x2: "183.42563",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "63.79 192.785 72.574 160 39.79 151.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "216.21 104.785 183.426 96 192.21 63.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "64",
        x2: "128",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "104 40 128 64 152 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "104 216 128 192 152 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72.57437",
        y1: "96",
        x2: "183.42563",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "39.79 104.785 72.574 96 63.79 63.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192.21 192.785 183.426 160 216.21 151.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72.57437",
        y1: "160",
        x2: "183.42563",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "63.79 192.785 72.574 160 39.79 151.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "216.21 104.785 183.426 96 192.21 63.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M223.938,149.14551a7.99991,7.99991,0,0,1-5.65723,9.79785l-25.05713,6.71387,6.71436,25.05664a8.00007,8.00007,0,1,1-15.45508,4.14062l-7.927-29.58374L136,141.856V188.686l21.65674,21.65673a8.00018,8.00018,0,0,1-11.31348,11.31446L128,203.31348l-18.34326,18.34375a8.00018,8.00018,0,0,1-11.31348-11.31446L120,188.686V141.856L79.44409,165.27075l-7.927,29.58374A8.00007,8.00007,0,1,1,56.062,190.71387l6.71436-25.05664-25.05713-6.71387a8.00007,8.00007,0,1,1,4.14062-15.45508L71.44458,151.415,112.00073,128,71.44458,104.585l-29.58472,7.92676a8.00007,8.00007,0,1,1-4.14062-15.45508l25.05713-6.71387L56.062,65.28613a8.00007,8.00007,0,1,1,15.45508-4.14062l7.927,29.58374L120,114.144V67.314L98.34326,45.65723a8.00018,8.00018,0,0,1,11.31348-11.31446L128,52.68652l18.34326-18.34375a8.00018,8.00018,0,1,1,11.31348,11.31446L136,67.314V114.144l40.55591-23.41479,7.927-29.58374A8.00007,8.00007,0,1,1,199.938,65.28613l-6.71436,25.05664,25.05713,6.71387a8.00007,8.00007,0,1,1-4.14062,15.45508L184.55542,104.585,143.99927,128l40.55615,23.415,29.58472-7.92676A8.00062,8.00062,0,0,1,223.938,149.14551Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "64",
        x2: "128",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "104 40 128 64 152 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "104 216 128 192 152 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72.57437",
        y1: "96",
        x2: "183.42563",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "39.79 104.785 72.574 96 63.79 63.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "192.21 192.785 183.426 160 216.21 151.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "72.57437",
        y1: "160",
        x2: "183.42563",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "63.79 192.785 72.574 160 39.79 151.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "216.21 104.785 183.426 96 192.21 63.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "64",
        x2: "128",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "104 40 128 64 152 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "104 216 128 192 152 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72.57437",
        y1: "96",
        x2: "183.42563",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "39.79 104.785 72.574 96 63.79 63.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "192.21 192.785 183.426 160 216.21 151.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "72.57437",
        y1: "160",
        x2: "183.42563",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "63.79 192.785 72.574 160 39.79 151.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "216.21 104.785 183.426 96 192.21 63.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "64",
        x2: "128",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "104 40 128 64 152 40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "104 216 128 192 152 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72.57437",
        y1: "96",
        x2: "183.42563",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "39.79 104.785 72.574 96 63.79 63.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "192.21 192.785 183.426 160 216.21 151.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "72.57437",
        y1: "160",
        x2: "183.42563",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "63.79 192.785 72.574 160 39.79 151.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "216.21 104.785 183.426 96 192.21 63.215",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Snowflake = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$94(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Snowflake.displayName = "Snowflake";

var renderPathFor$95 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "144 167.994 184 207.994 223.999 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "111.99347",
        x2: "184",
        y2: "207.99347",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "127.99353",
        x2: "119.99902",
        y2: "127.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "63.99353",
        x2: "183.99902",
        y2: "63.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "191.99353",
        x2: "104",
        y2: "191.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "144 167.994 184 207.994 223.999 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "111.99347",
        x2: "184",
        y2: "207.99347",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "127.99353",
        x2: "119.99902",
        y2: "127.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "63.99353",
        x2: "183.99902",
        y2: "63.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "191.99353",
        x2: "104",
        y2: "191.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M229.65625,162.34412a8,8,0,0,0-11.31348-.001L192,188.682V111.99353a8,8,0,0,0-16,0v76.686L149.65723,162.3363a8.00036,8.00036,0,0,0-11.314,11.31446l40,40c.02588.02588.05469.04785.08106.07324.16211.15771.32861.31152.50341.45508.09864.08056.20166.15137.30274.22656.1084.08057.21387.16455.32617.23975.11719.07812.23926.14648.35938.21826.10351.06152.20507.12695.312.18408.12109.06494.2456.11963.36865.17773.11377.05372.2251.11036.3418.1587.11865.04882.24023.08886.36035.13183.126.04492.25.09326.3789.13233.11963.03662.2417.063.36329.09326.13183.0332.26171.07031.396.09668.14014.02783.28125.04443.42236.06445.11719.01709.23243.03906.35108.05078.26269.02588.52588.04.78955.04s.52686-.01416.78906-.04c.12012-.01172.23682-.03418.35547-.05127.13965-.02.2793-.03613.418-.06347.13574-.02686.26758-.06446.40137-.09815.11914-.03027.23925-.05615.35791-.0918.13037-.04.25683-.08886.38427-.13476.11866-.04248.2378-.08154.3545-.12988.11914-.04932.2334-.10743.35009-.16211.12012-.05713.2417-.11035.35987-.17334.11084-.05957.21679-.12744.32422-.1919.11621-.06933.23339-.13476.34668-.21045.11816-.0791.22949-.16748.34326-.25244.09521-.07129.19336-.13769.28613-.21387q.29-.238.55615-.50244c.00928-.00927.02-.01709.0293-.02685l39.999-39.99317A7.99958,7.99958,0,0,0,229.65625,162.34412Z"
      }), React__default.createElement("path", {
        d: "M119.999,119.99353H48a8,8,0,0,0,0,16h71.999a8,8,0,1,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M48,71.99353H183.999a8,8,0,0,0,0-16H48a8,8,0,1,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M104,183.99353H48a8,8,0,0,0,0,16h56a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "144 167.994 184 207.994 223.999 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "111.99347",
        x2: "184",
        y2: "207.99347",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "127.99353",
        x2: "119.99902",
        y2: "127.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "63.99353",
        x2: "183.99902",
        y2: "63.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "191.99353",
        x2: "104",
        y2: "191.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "144 167.994 184 207.994 223.999 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "111.99347",
        x2: "184",
        y2: "207.99347",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "127.99353",
        x2: "119.99902",
        y2: "127.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "63.99353",
        x2: "183.99902",
        y2: "63.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "191.99353",
        x2: "104",
        y2: "191.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "144 167.994 184 207.994 223.999 168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "111.99347",
        x2: "184",
        y2: "207.99347",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "127.99353",
        x2: "119.99902",
        y2: "127.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "63.99353",
        x2: "183.99902",
        y2: "63.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "191.99353",
        x2: "104",
        y2: "191.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SortAscending = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$95(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SortAscending.displayName = "SortAscending";

var renderPathFor$96 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "144 87.994 184 47.994 223.999 87.987",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "143.99359",
        x2: "184",
        y2: "47.99359",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "127.99353",
        x2: "119.99902",
        y2: "127.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "63.99353",
        x2: "103.99902",
        y2: "63.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "191.99353",
        x2: "183.99902",
        y2: "191.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "144 87.994 184 47.994 223.999 87.987",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "143.99359",
        x2: "184",
        y2: "47.99359",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "127.99353",
        x2: "119.99902",
        y2: "127.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "63.99353",
        x2: "103.99902",
        y2: "63.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "191.99353",
        x2: "183.99902",
        y2: "191.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M229.65527,82.32947l-39.999-39.99317c-.00879-.00927-.019-.0166-.02832-.02587-.17822-.17627-.36426-.345-.55811-.50391-.08935-.07349-.18359-.13721-.27539-.20606-.11718-.08813-.23193-.17871-.354-.26025-.10889-.07275-.22168-.13574-.3335-.20264-.11279-.06762-.22314-.13818-.33935-.20019-.11133-.05982-.22608-.10986-.33985-.16406-.123-.05835-.24462-.11963-.37109-.17188-.10742-.04468-.21777-.08032-.32715-.11987-.13672-.04981-.27246-.10181-.4126-.14429-.106-.032-.21386-.05517-.3208-.08252-.1455-.03735-.28955-.07764-.43847-.10693-.11866-.02344-.23877-.03662-.35889-.05469-.13818-.021-.2749-.04639-.415-.06006-.20019-.01953-.40088-.02588-.60156-.03027-.061-.00147-.12061-.00928-.18213-.00928-.05811,0-.11426.00733-.17188.00879-.20458.00415-.40869.01074-.61279.03076-.13672.01343-.26953.03833-.40429.05835-.12354.01856-.24756.03247-.37012.05664-.14453.02857-.28516.06763-.42676.104-.11084.02832-.22314.05249-.333.08569-.13525.041-.2666.09155-.39892.1394-.11426.04126-.229.07862-.3418.12525-.12109.05-.23682.10864-.35449.16455-.11914.05615-.23926.10913-.35645.17163-.10986.05884-.21387.12573-.32031.18921-.11816.07031-.23731.137-.352.21387-.11377.07641-.22119.16137-.33106.2434-.09961.07422-.20117.14331-.29785.22266-.17578.14429-.34277.2981-.50537.45679-.02588.0249-.0542.04614-.07959.07177l-40,40a8.00036,8.00036,0,0,0,11.314,11.31446L176,67.3075v76.686a8,8,0,0,0,16,0V67.3053l26.34277,26.33862a7.99983,7.99983,0,1,0,11.3125-11.31445Z"
      }), React__default.createElement("path", {
        d: "M48,135.99353h71.999a8,8,0,1,0,0-16H48a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M48,71.99353h55.999a8,8,0,0,0,0-16H48a8,8,0,1,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M183.999,183.99353H48a8,8,0,0,0,0,16H183.999a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "144 87.994 184 47.994 223.999 87.987",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "143.99359",
        x2: "184",
        y2: "47.99359",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "127.99353",
        x2: "119.99902",
        y2: "127.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "63.99353",
        x2: "103.99902",
        y2: "63.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "191.99353",
        x2: "183.99902",
        y2: "191.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "144 87.994 184 47.994 223.999 87.987",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "143.99359",
        x2: "184",
        y2: "47.99359",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "127.99353",
        x2: "119.99902",
        y2: "127.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "63.99353",
        x2: "103.99902",
        y2: "63.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "191.99353",
        x2: "183.99902",
        y2: "191.99353",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "144 87.994 184 47.994 223.999 87.987",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "184",
        y1: "143.99359",
        x2: "184",
        y2: "47.99359",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "127.99353",
        x2: "119.99902",
        y2: "127.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "63.99353",
        x2: "103.99902",
        y2: "63.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "191.99353",
        x2: "183.99902",
        y2: "191.99353",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SortDescending = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$96(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SortDescending.displayName = "SortDescending";

var renderPathFor$97 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M160,232H96l8.66461-46.21023A52.01694,52.01694,0,0,1,28,140C28,88,128,24,128,24S228,88,228,140a52.01693,52.01693,0,0,1-76.66484,45.78964Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24S228,88,228,140a52.00142,52.00142,0,0,1-85.37486,39.87791L160,232H96l17.37486-52.12209A52.00142,52.00142,0,0,1,28,140C28,88,128,24,128,24Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M128,24S228,88,228,140a52.00142,52.00142,0,0,1-85.37486,39.87791L160,232H96l17.37486-52.12209A52.00142,52.00142,0,0,1,28,140C28,88,128,24,128,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M232,140a55.99915,55.99915,0,0,1-81.90137,49.64941l11.94092,35.82129A7.99929,7.99929,0,0,1,154.4502,236H101.5498a7.99966,7.99966,0,0,1-7.58935-10.53027l11.94092-35.82032A55.99915,55.99915,0,0,1,24,140C24,86.42676,121.68555,23.292,125.84375,20.63086a3.9978,3.9978,0,0,1,4.3125,0C134.31445,23.292,232,86.42676,232,140Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24S228,88,228,140a52.00142,52.00142,0,0,1-85.37486,39.87791L160,232H96l17.37486-52.12209A52.00142,52.00142,0,0,1,28,140C28,88,128,24,128,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24S228,88,228,140a52.00142,52.00142,0,0,1-85.37486,39.87791L160,232H96l17.37486-52.12209A52.00142,52.00142,0,0,1,28,140C28,88,128,24,128,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24S228,88,228,140a52.00142,52.00142,0,0,1-85.37486,39.87791L160,232H96l17.37486-52.12209A52.00142,52.00142,0,0,1,28,140C28,88,128,24,128,24Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Spade = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$97(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Spade.displayName = "Spade";

var renderPathFor$98 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.89989,77.08831a72,72,0,0,1,0,101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "79.98242",
        y1: "88",
        x2: "79.98242",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M190.61551,105.37258a32,32,0,0,1,0,45.25484",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M218.91161,77.08831a72,72,0,0,1,0,101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "79.9707",
        y1: "88",
        x2: "79.9707",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.62723,105.37258a32,32,0,0,1,0,45.25484",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M224.56836,71.43935a8.00053,8.00053,0,0,0-11.31445,11.31446,63.99788,63.99788,0,0,1,0,90.50976A8.00053,8.00053,0,0,0,224.56836,184.578a80.00148,80.00148,0,0,0,0-113.13868Z"
      }), React__default.createElement("path", {
        d: "M155.51465,24.82217a7.99448,7.99448,0,0,0-8.42578.87207l-69.834,54.31445H32a16.01833,16.01833,0,0,0-16,16v64a16.01833,16.01833,0,0,0,16,16H77.25488l69.834,54.31445A7.99958,7.99958,0,0,0,160,224.00869v-192A7.9997,7.9997,0,0,0,155.51465,24.82217ZM32,96.00869H71.9707v64H32Z"
      }), React__default.createElement("path", {
        d: "M184.96973,99.72549a7.99913,7.99913,0,0,0,.001,11.31347,23.99832,23.99832,0,0,1,0,33.93946,7.99983,7.99983,0,1,0,11.3125,11.31445,39.99719,39.99719,0,0,0,0-56.56836A7.99825,7.99825,0,0,0,184.96973,99.72549Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.894,77.08831a72,72,0,0,1,0,101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "79.98828",
        y1: "88",
        x2: "79.98828",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M190.60965,105.37258a32,32,0,0,1,0,45.25484",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.88817,77.08831a72,72,0,0,1,0,101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "88",
        x2: "79.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M190.60379,105.37258a32,32,0,0,1,0,45.25484",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.88231,77.08831a72,72,0,0,1,0,101.82338",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "80",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.59793,105.37258a32,32,0,0,1,0,45.25484",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SpeakerHigh = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$98(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SpeakerHigh.displayName = "SpeakerHigh";

var renderPathFor$99 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "79.98242",
        y1: "88",
        x2: "79.98242",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M190.61551,105.37258a32,32,0,0,1,0,45.25484",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "79.9707",
        y1: "88",
        x2: "79.9707",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.62723,105.37258a32,32,0,0,1,0,45.25484",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M155.51465,24.81927a7.99655,7.99655,0,0,0-8.42578.87207l-69.834,54.31445H32a16.01833,16.01833,0,0,0-16,16v64a16.01833,16.01833,0,0,0,16,16H77.25488l69.834,54.31446A7.99958,7.99958,0,0,0,160,224.00579v-192A7.9997,7.9997,0,0,0,155.51465,24.81927ZM32,96.00579H71.9707v64H32Z"
      }), React__default.createElement("path", {
        d: "M196.2832,99.72161a7.99984,7.99984,0,0,0-11.3125,11.31446,23.99831,23.99831,0,0,1,0,33.93945A7.99983,7.99983,0,1,0,196.2832,156.29a39.99719,39.99719,0,0,0,0-56.56836Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "79.98828",
        y1: "88",
        x2: "79.98828",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M190.60965,105.37258a32,32,0,0,1,0,45.25484",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "88",
        x2: "79.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M190.60379,105.37258a32,32,0,0,1,0,45.25484",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "80",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.59793,105.37258a32,32,0,0,1,0,45.25484",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SpeakerLow = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$99(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SpeakerLow.displayName = "SpeakerLow";

var renderPathFor$9a = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "79.98242",
        y1: "88",
        x2: "79.98242",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "79.9707",
        y1: "88",
        x2: "79.9707",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M155.51465,24.81637a7.99655,7.99655,0,0,0-8.42578.87207L77.25488,80.0029H32a16.01833,16.01833,0,0,0-16,16v64a16.01833,16.01833,0,0,0,16,16H77.25488l69.834,54.31445A7.99958,7.99958,0,0,0,160,224.0029v-192A7.99972,7.99972,0,0,0,155.51465,24.81637ZM32,96.0029H71.9707v64H32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "79.98828",
        y1: "88",
        x2: "79.98828",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "88",
        x2: "79.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "80",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SpeakerNone = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9a(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SpeakerNone.displayName = "SpeakerNone";

var renderPathFor$9b = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "191.98828",
        y1: "104",
        x2: "191.98828",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "227.98828",
        y1: "88",
        x2: "227.98828",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "192",
        y1: "104",
        x2: "192",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "88",
        x2: "224",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M155.50977,24.80957a7.993,7.993,0,0,0-8.42188.875L77.24414,79.99707h-45.25a16.01583,16.01583,0,0,0-16,16v64a16.01583,16.01583,0,0,0,16,16h45.25l69.84375,54.3125a7.99451,7.99451,0,0,0,12.90625-6.3125v-192A7.99374,7.99374,0,0,0,155.50977,24.80957Z"
      }), React__default.createElement("path", {
        d: "M191.99414,96a8.00039,8.00039,0,0,0-8,8v48a8,8,0,0,0,16,0V104A8.00039,8.00039,0,0,0,191.99414,96Z"
      }), React__default.createElement("path", {
        d: "M223.99414,80a8.00039,8.00039,0,0,0-8,8v80a8,8,0,0,0,16,0V88A8.00039,8.00039,0,0,0,223.99414,80Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "191.98242",
        y1: "104",
        x2: "191.98242",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "223.98242",
        y1: "88",
        x2: "223.98242",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "191.97656",
        y1: "104",
        x2: "191.97656",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "223.97656",
        y1: "88",
        x2: "223.97656",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "191.9707",
        y1: "104",
        x2: "191.9707",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "223.9707",
        y1: "88",
        x2: "223.9707",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SpeakerSimpleHigh = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9b(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SpeakerSimpleHigh.displayName = "SpeakerSimpleHigh";

var renderPathFor$9c = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "191.98828",
        y1: "104",
        x2: "191.98828",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "192",
        y1: "104",
        x2: "192",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M155.50977,24.80957a7.993,7.993,0,0,0-8.42188.875L77.24414,79.99707h-45.25a16.01583,16.01583,0,0,0-16,16v64a16.01583,16.01583,0,0,0,16,16h45.25l69.84375,54.3125a7.99451,7.99451,0,0,0,12.90625-6.3125v-192A7.99374,7.99374,0,0,0,155.50977,24.80957Z"
      }), React__default.createElement("path", {
        d: "M191.99414,96a8.00039,8.00039,0,0,0-8,8v48a8,8,0,0,0,16,0V104A8.00039,8.00039,0,0,0,191.99414,96Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "191.98242",
        y1: "104",
        x2: "191.98242",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "191.97656",
        y1: "104",
        x2: "191.97656",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "191.9707",
        y1: "104",
        x2: "191.9707",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SpeakerSimpleLow = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9c(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SpeakerSimpleLow.displayName = "SpeakerSimpleLow";

var renderPathFor$9d = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M155.50977,24.8096a7.993,7.993,0,0,0-8.42188.875L77.24414,79.9971h-45.25a16.01583,16.01583,0,0,0-16,16v64a16.01582,16.01582,0,0,0,16,16h45.25l69.84375,54.3125a7.99451,7.99451,0,0,0,12.90625-6.3125v-192A7.99375,7.99375,0,0,0,155.50977,24.8096Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SpeakerSimpleNone = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9d(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SpeakerSimpleNone.displayName = "SpeakerSimpleNone";

var renderPathFor$9e = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "227.97656",
        y1: "88",
        x2: "227.97656",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152,154.4V224L80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H91.63636",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "118.484 58.068 152 32 152 94.935",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "191.97656",
        y1: "104",
        x2: "191.97656",
        y2: "138.9095",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "191.97656",
        y1: "104",
        x2: "191.97656",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "223.97656",
        y1: "88",
        x2: "223.97656",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "112.15 62.994 152 32 152 106.829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,154.4V224L80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H91.63636",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M191.97656,160a8.00039,8.00039,0,0,0,8-8V104a8,8,0,0,0-16,0v48A8.00039,8.00039,0,0,0,191.97656,160Z"
      }), React__default.createElement("path", {
        d: "M223.97656,80a8.00039,8.00039,0,0,0-8,8v80a8,8,0,1,0,16,0V88A8.00039,8.00039,0,0,0,223.97656,80Z"
      }), React__default.createElement("path", {
        d: "M53.91992,34.61813A8.0006,8.0006,0,1,0,42.08008,45.3818L73.55127,80H32A16.01833,16.01833,0,0,0,16,96v64a16.01833,16.01833,0,0,0,16,16H77.25488l69.834,54.31445A7.99958,7.99958,0,0,0,160,224V175.09372l42.08008,46.28808a8.0006,8.0006,0,1,0,11.83984-10.76367Z"
      }), React__default.createElement("path", {
        d: "M146.08008,112.2109A8.0004,8.0004,0,0,0,160,106.82907V32a7.99958,7.99958,0,0,0-12.91113-6.31446L107.23926,56.67965a7.99966,7.99966,0,0,0-1.00879,11.69629Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "191.97656",
        y1: "104",
        x2: "191.97656",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "223.97656",
        y1: "88",
        x2: "223.97656",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "112.15 62.994 152 32 152 106.829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M152,154.4V224L80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H91.63636",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "191.97656",
        y1: "104",
        x2: "191.97656",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "223.97656",
        y1: "88",
        x2: "223.97656",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "112.15 62.994 152 32 152 106.829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M152,154.4V224L80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H91.63636",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "191.97656",
        y1: "104",
        x2: "191.97656",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "223.97656",
        y1: "88",
        x2: "223.97656",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "112.15 62.994 152 32 152 106.829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,154.4V224L80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H91.63636",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SpeakerSimpleSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9e(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SpeakerSimpleSlash.displayName = "SpeakerSimpleSlash";

var renderPathFor$9f = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "104",
        x2: "191.99997",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "152",
        x2: "191.99997",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "104",
        x2: "191.99997",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "152",
        x2: "191.99997",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M155.50977,24.80957a7.993,7.993,0,0,0-8.42188.875L77.24414,79.99707h-45.25a16.01583,16.01583,0,0,0-16,16v64a16.01583,16.01583,0,0,0,16,16h45.25l69.84375,54.3125a7.99451,7.99451,0,0,0,12.90625-6.3125v-192A7.99374,7.99374,0,0,0,155.50977,24.80957Z"
      }), React__default.createElement("path", {
        d: "M227.30664,127.99707l18.34375-18.34375a7.99915,7.99915,0,0,0-11.3125-11.3125l-18.34375,18.34375L197.65039,98.34082a7.99915,7.99915,0,0,0-11.3125,11.3125l18.34375,18.34375-18.34375,18.34375a7.99915,7.99915,0,1,0,11.3125,11.3125l18.34375-18.34375,18.34375,18.34375a7.99915,7.99915,0,0,0,11.3125-11.3125Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "104",
        x2: "191.99997",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "152",
        x2: "191.99997",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "104",
        x2: "191.99997",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "152",
        x2: "191.99997",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "104",
        x2: "191.99997",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "152",
        x2: "191.99997",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SpeakerSimpleX = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9f(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SpeakerSimpleX.displayName = "SpeakerSimpleX";

var renderPathFor$9g = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "79.99414",
        y1: "88.01159",
        x2: "79.99414",
        y2: "168.01159",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M152,154.4v69.61162l-72-56H32a8,8,0,0,1-8-8v-64a8,8,0,0,1,8-8H80L86.82274,82.705",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "118.49 58.075 152 32.012 152 94.935",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M190.60379,105.38417a32.01923,32.01923,0,0,1,5.51036,37.88051",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M218.88817,77.0999a72.00424,72.00424,0,0,1,4.72754,96.61262",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M218.88817,77.0999a72,72,0,0,1,0,101.82337",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "88.01159",
        x2: "79.99414",
        y2: "168.01159",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.60379,105.38417a32,32,0,0,1,0,45.25483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,154.4v69.61162l-72-56H32a8,8,0,0,1-8-8v-64a8,8,0,0,1,8-8H80L86.82274,82.705",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "112.156 63.001 152 32.012 152 106.829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M53.91992,34.61813A8.0006,8.0006,0,1,0,42.08008,45.3818L73.55371,80.0029H32a16.01833,16.01833,0,0,0-16,16v64a16.01833,16.01833,0,0,0,16,16H77.25488l69.834,54.31445-.00537-.01123.00439.00342a7.99451,7.99451,0,0,0,12.90625-6.3125V175.08737l42.08594,46.29443a8.0006,8.0006,0,1,0,11.83984-10.76367ZM71.9707,160.0029H32v-64H71.9707Z"
      }), React__default.createElement("path", {
        d: "M146.08008,112.2109A8.0004,8.0004,0,0,0,160,106.82907V32.01169a7.99958,7.99958,0,0,0-12.91113-6.31446L107.24512,56.68649a7.99966,7.99966,0,0,0-1.00879,11.69629Z"
      }), React__default.createElement("path", {
        d: "M224.544,71.44235a7.99983,7.99983,0,1,0-11.3125,11.31445,63.99908,63.99908,0,0,1,0,90.50879A7.99983,7.99983,0,1,0,224.544,184.58a79.99795,79.99795,0,0,0,0-113.13769Z"
      }), React__default.createElement("path", {
        d: "M191.97656,128.01169a23.83779,23.83779,0,0,1-7.02929,16.96972,7.99984,7.99984,0,1,0,11.3125,11.31446,39.99957,39.99957,0,0,0,.001-56.56934A8.00052,8.00052,0,0,0,184.94629,111.041,23.84269,23.84269,0,0,1,191.97656,128.01169Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.88817,77.0999a72,72,0,0,1,0,101.82337",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "88.01159",
        x2: "79.99414",
        y2: "168.01159",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M190.60379,105.38417a32,32,0,0,1,0,45.25483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M152,154.4v69.61162l-72-56H32a8,8,0,0,1-8-8v-64a8,8,0,0,1,8-8H80L86.82274,82.705",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "112.156 63.001 152 32.012 152 106.829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.88817,77.0999a72,72,0,0,1,0,101.82337",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "88.01159",
        x2: "79.99414",
        y2: "168.01159",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M190.60379,105.38417a32,32,0,0,1,0,45.25483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M152,154.4v69.61162l-72-56H32a8,8,0,0,1-8-8v-64a8,8,0,0,1,8-8H80L86.82274,82.705",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "112.156 63.001 152 32.012 152 106.829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M218.88817,77.0999a72,72,0,0,1,0,101.82337",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "88.01159",
        x2: "79.99414",
        y2: "168.01159",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M190.60379,105.38417a32,32,0,0,1,0,45.25483",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152,154.4v69.61162l-72-56H32a8,8,0,0,1-8-8v-64a8,8,0,0,1,8-8H80L86.82274,82.705",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "112.156 63.001 152 32.012 152 106.829",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SpeakerSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9g(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SpeakerSlash.displayName = "SpeakerSlash";

var renderPathFor$9h = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "104",
        x2: "191.99997",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "152",
        x2: "191.99997",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "79.98242",
        y1: "88",
        x2: "79.98242",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "104",
        x2: "191.99997",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "152",
        x2: "191.99997",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "79.9707",
        y1: "88",
        x2: "79.9707",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M155.51465,24.81348a7.99448,7.99448,0,0,0-8.42578.87207L77.25488,80H32A16.01833,16.01833,0,0,0,16,96v64a16.01833,16.01833,0,0,0,16,16H77.25488l69.834,54.31445A7.99958,7.99958,0,0,0,160,224V32A7.9997,7.9997,0,0,0,155.51465,24.81348ZM32,96H71.9707v64H32Z"
      }), React__default.createElement("path", {
        d: "M227.31445,128l18.34278-18.34277a8.00053,8.00053,0,0,0-11.31446-11.31446L216,116.68555,197.65723,98.34277a8.00053,8.00053,0,0,0-11.31446,11.31446L204.68555,128l-18.34278,18.34277a8.00053,8.00053,0,0,0,11.31446,11.31446L216,139.31445l18.34277,18.34278a8.00053,8.00053,0,0,0,11.31446-11.31446Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "104",
        x2: "191.99997",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "152",
        x2: "191.99997",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "79.98828",
        y1: "88",
        x2: "79.98828",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "104",
        x2: "191.99997",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "152",
        x2: "191.99997",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "79.99414",
        y1: "88",
        x2: "79.99414",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M80,168H32a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H80l72-56V224Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "104",
        x2: "191.99997",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "239.99997",
        y1: "152",
        x2: "191.99997",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "80",
        y1: "88",
        x2: "80",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SpeakerX = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9h(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SpeakerX.displayName = "SpeakerX";

var renderPathFor$9i = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32",
        y: "32",
        width: "192",
        height: "192",
        rx: "16"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Square = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9i(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Square.displayName = "Square";

var renderPathFor$9j = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "44",
        width: "168",
        height: "168",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "44",
        x2: "128",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "139.99414",
        y1: "44",
        x2: "212",
        y2: "116.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "88.00584",
        x2: "212",
        y2: "172.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "144.00584",
        x2: "195.99414",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,44h76a8,8,0,0,1,8,8V204a8,8,0,0,1-8,8H128Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "44",
        y: "44",
        width: "168",
        height: "168",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "44",
        x2: "128",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M204,36H52A16.01833,16.01833,0,0,0,36,52V204a16.01833,16.01833,0,0,0,16,16H204a16.01833,16.01833,0,0,0,16-16V52A16.01833,16.01833,0,0,0,204,36ZM52,52h76V204H52Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "44",
        width: "168",
        height: "168",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "44",
        x2: "128",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "139.99414",
        y1: "44",
        x2: "212",
        y2: "116.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "88.00584",
        x2: "212",
        y2: "172.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "144.00584",
        x2: "195.99414",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "44",
        width: "168",
        height: "168",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "44",
        x2: "128",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "139.99414",
        y1: "44",
        x2: "212",
        y2: "116.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "88.00584",
        x2: "212",
        y2: "172.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "144.00584",
        x2: "195.99414",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "44",
        width: "168",
        height: "168",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "44",
        x2: "128",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "139.99414",
        y1: "44",
        x2: "212",
        y2: "116.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "88.00584",
        x2: "212",
        y2: "172.00586",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "127.99998",
        y1: "144.00584",
        x2: "195.99414",
        y2: "212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SquareHalf = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9j(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SquareHalf.displayName = "SquareHalf";

var renderPathFor$9k = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48",
        y: "48",
        width: "60",
        height: "60",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "148",
        y: "48",
        width: "60",
        height: "60",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48",
        y: "148",
        width: "60",
        height: "60",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "148",
        y: "148",
        width: "60",
        height: "60",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48",
        y: "48",
        width: "64",
        height: "64",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "144",
        y: "48",
        width: "64",
        height: "64",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "48",
        y: "144",
        width: "64",
        height: "64",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "144",
        y: "144",
        width: "64",
        height: "64",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "144",
        y: "144",
        width: "64",
        height: "64",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48",
        y: "48",
        width: "64",
        height: "64",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "144",
        y: "48",
        width: "64",
        height: "64",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48",
        y: "144",
        width: "64",
        height: "64",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "80",
        height: "80",
        rx: "8"
      }), React__default.createElement("rect", {
        x: "136",
        y: "40",
        width: "80",
        height: "80",
        rx: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "136",
        width: "80",
        height: "80",
        rx: "8"
      }), React__default.createElement("rect", {
        x: "136",
        y: "136",
        width: "80",
        height: "80",
        rx: "8"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48",
        y: "48",
        width: "64",
        height: "64",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "144",
        y: "48",
        width: "64",
        height: "64",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48",
        y: "144",
        width: "64",
        height: "64",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "144",
        y: "144",
        width: "64",
        height: "64",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48",
        y: "48",
        width: "64",
        height: "64",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "144",
        y: "48",
        width: "64",
        height: "64",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48",
        y: "144",
        width: "64",
        height: "64",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "144",
        y: "144",
        width: "64",
        height: "64",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "48",
        y: "48",
        width: "64",
        height: "64",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "144",
        y: "48",
        width: "64",
        height: "64",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "48",
        y: "144",
        width: "64",
        height: "64",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("rect", {
        x: "144",
        y: "144",
        width: "64",
        height: "64",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SquaresFour = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9k(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SquaresFour.displayName = "SquaresFour";

var renderPathFor$9l = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "32 176 128 232 224 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "32 128 128 184 224 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "32 80 128 136 224 80 128 24 32 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "32 80 128 136 224 80 128 24 32 80",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "32 176 128 232 224 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "32 128 128 184 224 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "32 80 128 136 224 80 128 24 32 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M219.96875,169.08984,128,222.73828,36.03125,169.08984a8.00008,8.00008,0,0,0-8.0625,13.82032l96,56a8.00059,8.00059,0,0,0,8.0625,0l96-56a8.00008,8.00008,0,0,0-8.0625-13.82032Z"
      }), React__default.createElement("path", {
        d: "M219.96875,121.08984,128,174.73828,36.03125,121.08984a8.00008,8.00008,0,0,0-8.0625,13.82032l96,56a8.00059,8.00059,0,0,0,8.0625,0l96-56a8.00008,8.00008,0,0,0-8.0625-13.82032Z"
      }), React__default.createElement("path", {
        d: "M27.96875,86.91016l96,56a8.00059,8.00059,0,0,0,8.0625,0l96-56a8.00016,8.00016,0,0,0,0-13.82032l-96-56a8.00059,8.00059,0,0,0-8.0625,0l-96,56a8.00016,8.00016,0,0,0,0,13.82032Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "32 176 128 232 224 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "32 128 128 184 224 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "32 80 128 136 224 80 128 24 32 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "32 176 128 232 224 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "32 128 128 184 224 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "32 80 128 136 224 80 128 24 32 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "32 176 128 232 224 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "32 128 128 184 224 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "32 80 128 136 224 80 128 24 32 80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Stack = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9l(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Stack.displayName = "Stack";

var renderPathFor$9m = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "16 100 128 164 240 100 128 36 16 100",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "16 148 128 212 240 148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "16 104 128 168 240 104 128 40 16 104",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "16 104 128 168 240 104 128 40 16 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "16 144 128 208 240 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M12.03125,110.94629l112,64a8.00091,8.00091,0,0,0,7.9375,0l112-64a8.00024,8.00024,0,0,0,0-13.89258l-112-64a8.00411,8.00411,0,0,0-7.9375,0l-112,64a8.00024,8.00024,0,0,0,0,13.89258Z"
      }), React__default.createElement("path", {
        d: "M236.03125,137.05371,128,198.78613,19.96875,137.05371a8.00012,8.00012,0,0,0-7.9375,13.89258l112,64a8.00091,8.00091,0,0,0,7.9375,0l112-64a8.00012,8.00012,0,0,0-7.9375-13.89258Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "16 104 128 168 240 104 128 40 16 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "16 144 128 208 240 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "16 104 128 168 240 104 128 40 16 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "16 144 128 208 240 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "16 104 128 168 240 104 128 40 16 104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "16 144 128 208 240 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var StackSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9m(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
StackSimple.displayName = "StackSimple";

var renderPathFor$9n = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.41106,190.73266l50.43543,31.95385c6.44693,4.08451,14.45124-1.99032,12.53819-9.51579l-14.57192-57.32241a8.75742,8.75742,0,0,1,2.83756-8.87589l45.2273-37.64345c5.94268-4.9462,2.87542-14.80876-4.75965-15.30428l-59.06388-3.83326a8.41836,8.41836,0,0,1-7.24792-5.3506l-22.02834-55.473a8.31887,8.31887,0,0,0-15.55566,0L98.19383,84.84083a8.41836,8.41836,0,0,1-7.24792,5.3506L31.882,94.02469c-7.63507.49552-10.70233,10.35808-4.75965,15.30428l45.2273,37.64345a8.75742,8.75742,0,0,1,2.83756,8.87589L61.6734,209.00846c-2.29566,9.03056,7.30952,16.32036,15.04583,11.41895l46.86971-29.69475A8.21431,8.21431,0,0,1,132.41106,190.73266Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.41106,190.73266l50.43543,31.95385c6.44693,4.08451,14.45124-1.99032,12.53819-9.51579l-14.57192-57.32241a8.75742,8.75742,0,0,1,2.83756-8.87589l45.2273-37.64345c5.94268-4.9462,2.87542-14.80876-4.75965-15.30428l-59.06388-3.83326a8.41836,8.41836,0,0,1-7.24792-5.3506l-22.02834-55.473a8.31887,8.31887,0,0,0-15.55566,0L98.19383,84.84083a8.41836,8.41836,0,0,1-7.24792,5.3506L31.882,94.02469c-7.63507.49552-10.70233,10.35808-4.75965,15.30428l45.2273,37.64345a8.75742,8.75742,0,0,1,2.83756,8.87589L61.6734,209.00846c-2.29566,9.03056,7.30952,16.32036,15.04583,11.41895l46.86971-29.69475A8.21431,8.21431,0,0,1,132.41106,190.73266Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M132.41106,190.73266l50.43543,31.95385c6.44693,4.08451,14.45124-1.99032,12.53819-9.51579l-14.57192-57.32241a8.75742,8.75742,0,0,1,2.83756-8.87589l45.2273-37.64345c5.94268-4.9462,2.87542-14.80876-4.75965-15.30428l-59.06388-3.83326a8.41836,8.41836,0,0,1-7.24792-5.3506l-22.02834-55.473a8.31887,8.31887,0,0,0-15.55566,0L98.19383,84.84083a8.41836,8.41836,0,0,1-7.24792,5.3506L31.882,94.02469c-7.63507.49552-10.70233,10.35808-4.75965,15.30428l45.2273,37.64345a8.75742,8.75742,0,0,1,2.83756,8.87589L61.6734,209.00846c-2.29566,9.03056,7.30952,16.32036,15.04583,11.41895l46.86971-29.69475A8.21431,8.21431,0,0,1,132.41106,190.73266Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M239.166,97.41117A16.37036,16.37036,0,0,0,224.63477,86.044l-59.39063-4.15625L143.21289,26.41117A16.33117,16.33117,0,0,0,127.99414,15.9971h-.01562A16.324,16.324,0,0,0,112.791,26.41117L90.43164,82.208,31.36914,86.044A16.37036,16.37036,0,0,0,16.83789,97.41117a16.68222,16.68222,0,0,0,5.15625,18.0625l45.4375,38.40625L53.916,207.044a18.37492,18.37492,0,0,0,7.01562,19.51562,17.83088,17.83088,0,0,0,20.0625.625l46.875-29.69531c.0625-.04687.125-.07812.26563,0l50.4375,31.95313a16.14026,16.14026,0,0,0,18.20312-.5625,16.64744,16.64744,0,0,0,6.35938-17.67969L188.77539,153.1221l45.23438-37.64843A16.68222,16.68222,0,0,0,239.166,97.41117Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.41106,190.73266l50.43543,31.95385c6.44693,4.08451,14.45124-1.99032,12.53819-9.51579l-14.57192-57.32241a8.75742,8.75742,0,0,1,2.83756-8.87589l45.2273-37.64345c5.94268-4.9462,2.87542-14.80876-4.75965-15.30428l-59.06388-3.83326a8.41836,8.41836,0,0,1-7.24792-5.3506l-22.02834-55.473a8.31887,8.31887,0,0,0-15.55566,0L98.19383,84.84083a8.41836,8.41836,0,0,1-7.24792,5.3506L31.882,94.02469c-7.63507.49552-10.70233,10.35808-4.75965,15.30428l45.2273,37.64345a8.75742,8.75742,0,0,1,2.83756,8.87589L61.6734,209.00846c-2.29566,9.03056,7.30952,16.32036,15.04583,11.41895l46.86971-29.69475A8.21431,8.21431,0,0,1,132.41106,190.73266Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.41106,190.73266l50.43543,31.95385c6.44693,4.08451,14.45124-1.99032,12.53819-9.51579l-14.57192-57.32241a8.75742,8.75742,0,0,1,2.83756-8.87589l45.2273-37.64345c5.94268-4.9462,2.87542-14.80876-4.75965-15.30428l-59.06388-3.83326a8.41836,8.41836,0,0,1-7.24792-5.3506l-22.02834-55.473a8.31887,8.31887,0,0,0-15.55566,0L98.19383,84.84083a8.41836,8.41836,0,0,1-7.24792,5.3506L31.882,94.02469c-7.63507.49552-10.70233,10.35808-4.75965,15.30428l45.2273,37.64345a8.75742,8.75742,0,0,1,2.83756,8.87589L61.6734,209.00846c-2.29566,9.03056,7.30952,16.32036,15.04583,11.41895l46.86971-29.69475A8.21431,8.21431,0,0,1,132.41106,190.73266Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M132.41106,190.73266l50.43543,31.95385c6.44693,4.08451,14.45124-1.99032,12.53819-9.51579l-14.57192-57.32241a8.75742,8.75742,0,0,1,2.83756-8.87589l45.2273-37.64345c5.94268-4.9462,2.87542-14.80876-4.75965-15.30428l-59.06388-3.83326a8.41836,8.41836,0,0,1-7.24792-5.3506l-22.02834-55.473a8.31887,8.31887,0,0,0-15.55566,0L98.19383,84.84083a8.41836,8.41836,0,0,1-7.24792,5.3506L31.882,94.02469c-7.63507.49552-10.70233,10.35808-4.75965,15.30428l45.2273,37.64345a8.75742,8.75742,0,0,1,2.83756,8.87589L61.6734,209.00846c-2.29566,9.03056,7.30952,16.32036,15.04583,11.41895l46.86971-29.69475A8.21431,8.21431,0,0,1,132.41106,190.73266Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Star = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9n(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Star.displayName = "Star";

var renderPathFor$9o = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,216H88a48,48,0,0,1-48-48V88A48,48,0,0,1,88,40h80a48,48,0,0,1,48,48v48C208,160,160,208,136,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M136,216V184a48,48,0,0,1,48-48h32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,216V184a48,48,0,0,1,48-48h32C208,160,160,208,136,216Z",
        opacity: "0.2"
      }), React__default.createElement("g", null, React__default.createElement("path", {
        d: "M136,216H88a48,48,0,0,1-48-48V88A48,48,0,0,1,88,40h80a48,48,0,0,1,48,48v48C208,160,160,208,136,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M136,216V184a48,48,0,0,1,48-48h32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      })));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,32H88A56.0629,56.0629,0,0,0,32,88v80a56.0629,56.0629,0,0,0,56,56h48a8.0151,8.0151,0,0,0,2.53027-.41016c26.23243-8.74511,76.31446-58.82714,85.05957-85.05957A8.0151,8.0151,0,0,0,224,136V88A56.0629,56.0629,0,0,0,168,32ZM136,207.42236V176a40.04584,40.04584,0,0,1,40-40h31.42236C198.15991,157.55176,157.55176,198.16016,136,207.42236Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,216H88a48,48,0,0,1-48-48V88A48,48,0,0,1,88,40h80a48,48,0,0,1,48,48v48C208,160,160,208,136,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M136,216V184a48,48,0,0,1,48-48h32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,216H88a48,48,0,0,1-48-48V88A48,48,0,0,1,88,40h80a48,48,0,0,1,48,48v48C208,160,160,208,136,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M136,216V184a48,48,0,0,1,48-48h32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M136,216H88a48,48,0,0,1-48-48V88A48,48,0,0,1,88,40h80a48,48,0,0,1,48,48v48C208,160,160,208,136,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M136,216V184a48,48,0,0,1,48-48h32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Sticker = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9o(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Sticker.displayName = "Sticker";

var renderPathFor$9p = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "52",
        y: "52",
        width: "152",
        height: "152",
        rx: "6.90909",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "52",
        y: "52",
        width: "152",
        height: "152",
        rx: "6.90909",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "52",
        y: "52",
        width: "152",
        height: "152",
        rx: "6.90909",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "44",
        width: "168",
        height: "168",
        rx: "14.90918"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "52",
        y: "52",
        width: "152",
        height: "152",
        rx: "6.90909",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "52",
        y: "52",
        width: "152",
        height: "152",
        rx: "6.90909",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "52",
        y: "52",
        width: "152",
        height: "152",
        rx: "6.90909",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Stop = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9p(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Stop.displayName = "Stop";

var renderPathFor$9q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "104",
        y: "104",
        width: "48",
        height: "48",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32a96,96,0,1,0,96,96A95.99991,95.99991,0,0,0,128,32Zm24,120H104V104h48Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "104",
        y: "104",
        width: "48",
        height: "48",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm32,128a8.00008,8.00008,0,0,1-8,8H104a8.00008,8.00008,0,0,1-8-8V104a8.00008,8.00008,0,0,1,8-8h48a8.00008,8.00008,0,0,1,8,8Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "104",
        y: "104",
        width: "48",
        height: "48",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "104",
        y: "104",
        width: "48",
        height: "48",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "104",
        y: "104",
        width: "48",
        height: "48",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var StopCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
StopCircle.displayName = "StopCircle";

var renderPathFor$9r = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,139.58816V208a8,8,0,0,0,8,8H200a8,8,0,0,0,8-8V139.58972",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M54.03441,40H201.96559a8,8,0,0,1,7.69219,5.80223L224,96H32L46.34222,45.80223A8,8,0,0,1,54.03441,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M96,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M160,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,96v16a32,32,0,0,1-64,0V96",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M224,96v16a32,32,0,0,1-64,0V96",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M48,139.58816V208a8,8,0,0,0,8,8H200a8,8,0,0,0,8-8V139.58972",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M54.03441,40H201.96559a8,8,0,0,1,7.69219,5.80223L224,96H32L46.34222,45.80223A8,8,0,0,1,54.03441,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M96,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M160,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M231.98975,95.79919c-.00293-.11914-.00953-.23779-.01807-.35705-.0127-.1836-.03149-.36475-.0564-.5448-.0144-.10315-.02881-.20581-.04712-.30872-.03784-.21142-.08545-.41894-.13964-.62426-.01416-.05372-.02076-.10853-.03614-.16211L217.35059,43.604A16.06985,16.06985,0,0,0,201.96582,32H54.03418A16.06971,16.06971,0,0,0,38.64941,43.60449L24.30762,93.80225c-.01538.05358-.022.10839-.03614.16211-.05419.20532-.1018.41284-.13964.62426-.01831.10291-.03272.20557-.04712.30872-.02491.18-.0437.3612-.0564.5448-.00854.11926-.01514.23791-.01807.35705C24.00854,95.86658,24,95.93213,24,96v16a39.96242,39.96242,0,0,0,16,31.978V208a16.01833,16.01833,0,0,0,16,16H200a16.01833,16.01833,0,0,0,16-16V143.978A39.96242,39.96242,0,0,0,232,112V96C232,95.93213,231.99146,95.86658,231.98975,95.79919ZM40,104H88v8a23.98436,23.98436,0,0,1-35.12427,21.256,7.98438,7.98438,0,0,0-1.813-1.05774A23.99623,23.99623,0,0,1,40,112Zm112,8a24,24,0,0,1-48,0v-8h48Zm52.93213,20.20166a7.97469,7.97469,0,0,0-1.80176,1.05115A23.98441,23.98441,0,0,1,168,112v-8h48v8A23.99664,23.99664,0,0,1,204.93213,132.20166Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,139.58816V208a8,8,0,0,0,8,8H200a8,8,0,0,0,8-8V139.58972",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M54.03441,40H201.96559a8,8,0,0,1,7.69219,5.80223L224,96H32L46.34222,45.80223A8,8,0,0,1,54.03441,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M96,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M160,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,139.58816V208a8,8,0,0,0,8,8H200a8,8,0,0,0,8-8V139.58972",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M54.03441,40H201.96559a8,8,0,0,1,7.69219,5.80223L224,96H32L46.34222,45.80223A8,8,0,0,1,54.03441,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M96,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M160,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M48,139.58816V208a8,8,0,0,0,8,8H200a8,8,0,0,0,8-8V139.58972",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M54.03441,40H201.96559a8,8,0,0,1,7.69219,5.80223L224,96H32L46.34222,45.80223A8,8,0,0,1,54.03441,40Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M96,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M160,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,96v16a32,32,0,0,1-64,0V96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Storefront = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9r(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Storefront.displayName = "Storefront";

var renderPathFor$9s = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "68.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,212V48a16,16,0,0,0-16-16H104A16,16,0,0,0,88,48V212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,72V216l-47.99219,0a8,8,0,0,1-8-8v-128a8,8,0,0,1,8-8Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M168.00781,72V216l47.99219,0a8,8,0,0,0,8-8v-128a8,8,0,0,0-8-8Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,216V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.00781,64H176V56a24.0275,24.0275,0,0,0-24-24H104A24.0275,24.0275,0,0,0,80,56v8H40.00781a16.01833,16.01833,0,0,0-16,16V208a16.01833,16.01833,0,0,0,16,16h176a16.01833,16.01833,0,0,0,16-16V80A16.01833,16.01833,0,0,0,216.00781,64ZM96,80h64V208H96Zm0-24a8.00917,8.00917,0,0,1,8-8h48a8.00917,8.00917,0,0,1,8,8v8H96Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,216V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,216V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,216V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56V216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Suitcase = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9s(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Suitcase.displayName = "Suitcase";

var renderPathFor$9t = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "68.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,100V48a16,16,0,0,0-16-16H104A16,16,0,0,0,88,48v52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,104V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56v48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216.00781,64H176V56a24.0275,24.0275,0,0,0-24-24H104A24.0275,24.0275,0,0,0,80,56v8H40.00781a16.01833,16.01833,0,0,0-16,16V208a16.01833,16.01833,0,0,0,16,16h176a16.01833,16.01833,0,0,0,16-16V80A16.01833,16.01833,0,0,0,216.00781,64ZM96,104a8,8,0,0,1-16,0V88a8,8,0,0,1,16,0Zm0-48a8.00917,8.00917,0,0,1,8-8h48a8.00917,8.00917,0,0,1,8,8v8H96Zm80,48a8,8,0,0,1-16,0V88a8,8,0,0,1,16,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,104V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56v48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,104V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56v48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.00781",
        y: "72.00005",
        width: "192",
        height: "144",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M168,104V56a16,16,0,0,0-16-16H104A16,16,0,0,0,88,56v48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SuitcaseSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9t(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SuitcaseSimple.displayName = "SuitcaseSimple";

var renderPathFor$9u = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "28",
        x2: "128",
        y2: "12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "198.71068",
        y1: "57.28932",
        x2: "210.02439",
        y2: "45.97561",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "228",
        y1: "128",
        x2: "244",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "198.71068",
        y1: "198.71068",
        x2: "210.02439",
        y2: "210.02439",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "228",
        x2: "128",
        y2: "244",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "57.28932",
        y1: "198.71068",
        x2: "45.97561",
        y2: "210.02439",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "28",
        y1: "128",
        x2: "12",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "57.28932",
        y1: "57.28932",
        x2: "45.97561",
        y2: "45.97561",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "62.94618",
        x2: "48.80404",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "16",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "193.05382",
        x2: "48.80404",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "193.05382",
        x2: "207.19596",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "240",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "62.94618",
        x2: "207.19596",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "68"
      }), React__default.createElement("path", {
        d: "M128,44a8.00008,8.00008,0,0,0,8-8V16a8,8,0,0,0-16,0V36A8.00008,8.00008,0,0,0,128,44Z"
      }), React__default.createElement("path", {
        d: "M57.28955,68.603A7.99984,7.99984,0,1,0,68.603,57.28955L54.46094,43.14746A7.99984,7.99984,0,1,0,43.14746,54.46094Z"
      }), React__default.createElement("path", {
        d: "M44,128a8.00008,8.00008,0,0,0-8-8H16a8,8,0,0,0,0,16H36A8.00008,8.00008,0,0,0,44,128Z"
      }), React__default.createElement("path", {
        d: "M57.28955,187.397,43.14746,201.53906a7.99984,7.99984,0,1,0,11.31348,11.31348L68.603,198.71045A7.99984,7.99984,0,1,0,57.28955,187.397Z"
      }), React__default.createElement("path", {
        d: "M128,212a8.00008,8.00008,0,0,0-8,8v20a8,8,0,0,0,16,0V220A8.00008,8.00008,0,0,0,128,212Z"
      }), React__default.createElement("path", {
        d: "M198.71045,187.397A7.99984,7.99984,0,1,0,187.397,198.71045l14.14209,14.14209a7.99984,7.99984,0,1,0,11.31348-11.31348Z"
      }), React__default.createElement("path", {
        d: "M240,120H220a8,8,0,0,0,0,16h20a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M193.05371,70.94629a7.97507,7.97507,0,0,0,5.65674-2.34326l14.14209-14.14209a7.99984,7.99984,0,1,0-11.31348-11.31348L187.397,57.28955a7.99976,7.99976,0,0,0,5.65674,13.65674Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "62.94618",
        x2: "48.80404",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "16",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "193.05382",
        x2: "48.80404",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "193.05382",
        x2: "207.19596",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "240",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "62.94618",
        x2: "207.19596",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "62.94618",
        x2: "48.80404",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "16",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "193.05382",
        x2: "48.80404",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "193.05382",
        x2: "207.19596",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "240",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "62.94618",
        x2: "207.19596",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "62.94618",
        x2: "48.80404",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "16",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "193.05382",
        x2: "48.80404",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "193.05382",
        x2: "207.19596",
        y2: "207.19596",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "240",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "62.94618",
        x2: "207.19596",
        y2: "48.80404",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Sun = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9u(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Sun.displayName = "Sun";

var renderPathFor$9v = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "28",
        x2: "128",
        y2: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "198.71068",
        y1: "57.28932",
        x2: "204.36753",
        y2: "51.63247",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "228",
        y1: "128",
        x2: "236",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "198.71068",
        y1: "198.71068",
        x2: "204.36753",
        y2: "204.36753",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "228",
        x2: "128",
        y2: "236",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "57.28932",
        y1: "198.71068",
        x2: "51.63247",
        y2: "204.36753",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "28",
        y1: "128",
        x2: "20",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "57.28932",
        y1: "57.28932",
        x2: "51.63247",
        y2: "51.63247",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "62.94618",
        x2: "57.28932",
        y2: "57.28932",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "28",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "193.05382",
        x2: "57.28932",
        y2: "198.71068",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "193.05382",
        x2: "198.71068",
        y2: "198.71068",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "228",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "62.94618",
        x2: "198.71068",
        y2: "57.28932",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "68"
      }), React__default.createElement("path", {
        d: "M128,44a7.99993,7.99993,0,0,0,8-8V28a8,8,0,0,0-16,0v8A7.99993,7.99993,0,0,0,128,44Z"
      }), React__default.createElement("path", {
        d: "M57.28906,68.603A8,8,0,1,0,68.603,57.28955l-5.65674-5.657A7.99983,7.99983,0,1,0,51.63281,62.946Z"
      }), React__default.createElement("path", {
        d: "M36,120H28a8,8,0,0,0,0,16h8a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M57.28955,187.397l-5.65674,5.65674a7.99984,7.99984,0,1,0,11.31348,11.31348l5.65674-5.65674A7.99984,7.99984,0,0,0,57.28955,187.397Z"
      }), React__default.createElement("path", {
        d: "M128,212a7.99977,7.99977,0,0,0-8,8v8a8,8,0,0,0,16,0v-8A7.99977,7.99977,0,0,0,128,212Z"
      }), React__default.createElement("path", {
        d: "M198.71045,187.397A7.99984,7.99984,0,0,0,187.397,198.71045l5.65674,5.65674a7.99984,7.99984,0,0,0,11.31348-11.31348Z"
      }), React__default.createElement("path", {
        d: "M228,120h-8a8,8,0,0,0,0,16h8a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M193.05371,70.94629a7.977,7.977,0,0,0,5.65723-2.34326l5.65625-5.657a7.99983,7.99983,0,1,0-11.31348-11.31347l-5.65674,5.657a7.99988,7.99988,0,0,0,5.65674,13.65674Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "62.94618",
        x2: "57.28932",
        y2: "57.28932",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "28",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "193.05382",
        x2: "57.28932",
        y2: "198.71068",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "193.05382",
        x2: "198.71068",
        y2: "198.71068",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "228",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "62.94618",
        x2: "198.71068",
        y2: "57.28932",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "62.94618",
        x2: "57.28932",
        y2: "57.28932",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "28",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "193.05382",
        x2: "57.28932",
        y2: "198.71068",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "193.05382",
        x2: "198.71068",
        y2: "198.71068",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "228",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "62.94618",
        x2: "198.71068",
        y2: "57.28932",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "36",
        x2: "128",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "62.94618",
        x2: "57.28932",
        y2: "57.28932",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "128",
        x2: "28",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "62.94618",
        y1: "193.05382",
        x2: "57.28932",
        y2: "198.71068",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "220",
        x2: "128",
        y2: "228",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "193.05382",
        x2: "198.71068",
        y2: "198.71068",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "220",
        y1: "128",
        x2: "228",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "193.05382",
        y1: "62.94618",
        x2: "198.71068",
        y2: "57.28932",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SunDim = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9v(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SunDim.displayName = "SunDim";

var renderPathFor$9w = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "92.79312",
        y1: "59.00308",
        x2: "85.13946",
        y2: "40.52549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "43.00308",
        y1: "108.79312",
        x2: "24.52549",
        y2: "101.13946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "212.99692",
        y1: "108.79312",
        x2: "231.47451",
        y2: "101.13946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "163.20688",
        y1: "59.00308",
        x2: "170.86054",
        y2: "40.52549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "160",
        x2: "16",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "200",
        x2: "48",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M77.3915,160.00018a52,52,0,1,1,101.217.00018",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M70.157,160.00035a60,60,0,1,1,115.686-.00008Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "92.79312",
        y1: "59.00308",
        x2: "85.13946",
        y2: "40.52549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "43.00308",
        y1: "108.79312",
        x2: "24.52549",
        y2: "101.13946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "212.99692",
        y1: "108.79312",
        x2: "231.47451",
        y2: "101.13946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "163.20688",
        y1: "59.00308",
        x2: "170.86054",
        y2: "40.52549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "160",
        x2: "16",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "200",
        x2: "48",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M70.157,160.00035a60,60,0,1,1,115.686-.00008",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M77.74854,43.58691a8.00009,8.00009,0,0,1,14.78222-6.123l7.65332,18.47754a8.00009,8.00009,0,1,1-14.78222,6.123ZM21.46387,108.53027l18.47754,7.65332a7.99964,7.99964,0,1,0,6.123-14.78125L27.58691,93.749a7.99964,7.99964,0,1,0-6.123,14.78125ZM213,116.79492a7.97082,7.97082,0,0,0,3.05859-.61133l18.47754-7.65332a7.99964,7.99964,0,1,0-6.123-14.78125l-18.47754,7.65332A8.001,8.001,0,0,0,213,116.79492ZM160.14551,66.39355a7.99266,7.99266,0,0,0,10.45263-4.3291l7.65332-18.47754a8.00009,8.00009,0,0,0-14.78222-6.123l-7.65332,18.47754A7.99929,7.99929,0,0,0,160.14551,66.39355ZM240,152H195.52319a68,68,0,1,0-135.04638,0H16a8,8,0,0,0,0,16H185.81812l.02905.00195L185.87085,168H240a8,8,0,0,0,0-16Zm-32,40H48a8,8,0,0,0,0,16H208a8,8,0,0,0,0-16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "92.79312",
        y1: "59.00308",
        x2: "85.13946",
        y2: "40.52549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "43.00308",
        y1: "108.79312",
        x2: "24.52549",
        y2: "101.13946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "212.99692",
        y1: "108.79312",
        x2: "231.47451",
        y2: "101.13946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "163.20688",
        y1: "59.00308",
        x2: "170.86054",
        y2: "40.52549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "160",
        x2: "16",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "200",
        x2: "48",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M70.157,160.00035a60,60,0,1,1,115.686-.00008",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "92.79312",
        y1: "59.00308",
        x2: "85.13946",
        y2: "40.52549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "43.00308",
        y1: "108.79312",
        x2: "24.52549",
        y2: "101.13946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "212.99692",
        y1: "108.79312",
        x2: "231.47451",
        y2: "101.13946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "163.20688",
        y1: "59.00308",
        x2: "170.86054",
        y2: "40.52549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "160",
        x2: "16",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "200",
        x2: "48",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M70.157,160.00035a60,60,0,1,1,115.686-.00008",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "92.79312",
        y1: "59.00308",
        x2: "85.13946",
        y2: "40.52549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "43.00308",
        y1: "108.79312",
        x2: "24.52549",
        y2: "101.13946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "212.99692",
        y1: "108.79312",
        x2: "231.47451",
        y2: "101.13946",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "163.20688",
        y1: "59.00308",
        x2: "170.86054",
        y2: "40.52549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "240",
        y1: "160",
        x2: "16",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "208",
        y1: "200",
        x2: "48",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M70.157,160.00035a60,60,0,1,1,115.686-.00008",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var SunHorizon = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9w(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
SunHorizon.displayName = "SunHorizon";

var renderPathFor$9x = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M36.67036,173.04838,60.85763,35.87558a8,8,0,0,1,9.26764-6.48928l55.14924,9.7243a8,8,0,0,1,6.48927,9.26765L107.453,186.25133a36.00022,36.00022,0,0,1-41.01188,29.317C46.4984,212.4439,33.16509,192.92775,36.67036,173.04838Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M118.28071,124.84457,191.244,98.2881a8,8,0,0,1,10.2537,4.78138l19.15313,52.62278a8,8,0,0,1-4.78138,10.25371l-131.557,47.88282",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M219.99977,162.53273v45.467a8,8,0,0,1-8,8h-140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "72",
        y1: "180",
        x2: "74.08378",
        y2: "168.18231",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M36.67036,173.04838,60.85763,35.87558a8,8,0,0,1,9.26764-6.48928l55.14924,9.7243a8,8,0,0,1,6.48927,9.26765L107.453,186.25133a36.00022,36.00022,0,0,1-41.01188,29.317C46.4984,212.4439,33.16509,192.92775,36.67036,173.04838Z"
      })), React__default.createElement("circle", {
        cx: "72",
        cy: "179.99977",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M36.67036,173.04838,60.85763,35.87558a8,8,0,0,1,9.26764-6.48928l55.14924,9.7243a8,8,0,0,1,6.48927,9.26765L107.453,186.25133a36.00022,36.00022,0,0,1-41.01188,29.317C46.4984,212.4439,33.16509,192.92775,36.67036,173.04838Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M118.28071,124.84457,191.244,98.2881a8,8,0,0,1,10.2537,4.78138l19.15313,52.62278a8,8,0,0,1-4.78138,10.25371l-131.557,47.88282",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M219.99977,162.53273v45.467a8,8,0,0,1-8,8h-140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M228.16846,152.95605,209.01514,100.334a16.0165,16.0165,0,0,0-20.50733-9.56347l-59.94262,21.81738,11.0769-62.82031a16.00057,16.00057,0,0,0-12.97852-18.53613L71.51514,21.50879A15.99894,15.99894,0,0,0,52.979,34.48633L28.792,171.65918a45.288,45.288,0,0,0,7.74365,33.9834A43.299,43.299,0,0,0,71.937,223.99707h.00342c.02014,0,.03955.00293.05957.00293H212a16.01833,16.01833,0,0,0,16-16V164.27759A15.91483,15.91483,0,0,0,228.16846,152.95605ZM72,192a12,12,0,1,1,12-12A12.01343,12.01343,0,0,1,72,192Zm140,16H123.71875L212,175.86841Zm-98.54736-13.29053a43.46748,43.46748,0,0,0,1.8789-7.06885l10.02552-56.85791L193.98,105.80566l19.15332,52.623Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "72",
        cy: "179.99977",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M36.67036,173.04838,60.85763,35.87558a8,8,0,0,1,9.26764-6.48928l55.14924,9.7243a8,8,0,0,1,6.48927,9.26765L107.453,186.25133a36.00022,36.00022,0,0,1-41.01188,29.317C46.4984,212.4439,33.16509,192.92775,36.67036,173.04838Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M118.28071,124.84457,191.244,98.2881a8,8,0,0,1,10.2537,4.78138l19.15313,52.62278a8,8,0,0,1-4.78138,10.25371l-131.557,47.88282",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M219.99977,162.53273v45.467a8,8,0,0,1-8,8h-140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "72",
        cy: "179.99977",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M36.67036,173.04838,60.85763,35.87558a8,8,0,0,1,9.26764-6.48928l55.14924,9.7243a8,8,0,0,1,6.48927,9.26765L107.453,186.25133a36.00022,36.00022,0,0,1-41.01188,29.317C46.4984,212.4439,33.16509,192.92775,36.67036,173.04838Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M118.28071,124.84457,191.244,98.2881a8,8,0,0,1,10.2537,4.78138l19.15313,52.62278a8,8,0,0,1-4.78138,10.25371l-131.557,47.88282",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M219.99977,162.53273v45.467a8,8,0,0,1-8,8h-140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "72",
        cy: "179.99977",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M36.67036,173.04838,60.85763,35.87558a8,8,0,0,1,9.26764-6.48928l55.14924,9.7243a8,8,0,0,1,6.48927,9.26765L107.453,186.25133a36.00022,36.00022,0,0,1-41.01188,29.317C46.4984,212.4439,33.16509,192.92775,36.67036,173.04838Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M118.28071,124.84457,191.244,98.2881a8,8,0,0,1,10.2537,4.78138l19.15313,52.62278a8,8,0,0,1-4.78138,10.25371l-131.557,47.88282",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M219.99977,162.53273v45.467a8,8,0,0,1-8,8h-140",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Swatches = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9x(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Swatches.displayName = "Swatches";

var renderPathFor$9y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "72.201 128.201 152.201 40.201 216 40 215.799 103.799 127.799 183.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M82.14214,205.45584,60.201,227.397a8,8,0,0,1-11.31371,0L28.603,207.11268a8,8,0,0,1,0-11.31371l21.94113-21.94112a8,8,0,0,0,0-11.31371L33.65685,145.65685a8,8,0,0,1,0-11.3137l16.6863-16.6863a8,8,0,0,1,11.3137,0l76.6863,76.6863a8,8,0,0,1,0,11.3137l-16.6863,16.6863a8,8,0,0,1-11.3137,0L93.45584,205.45584A8,8,0,0,0,82.14214,205.45584Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M82.14214,197.45584,52.201,227.397a8,8,0,0,1-11.31371,0L28.603,215.11268a8,8,0,0,1,0-11.31371l29.94113-29.94112a8,8,0,0,0,0-11.31371L37.65685,141.65685a8,8,0,0,1,0-11.3137l12.6863-12.6863a8,8,0,0,1,11.3137,0l76.6863,76.6863a8,8,0,0,1,0,11.3137l-12.6863,12.6863a8,8,0,0,1-11.3137,0L93.45584,197.45584A8,8,0,0,0,82.14214,197.45584Z",
        opacity: "0.2"
      }), React__default.createElement("polyline", {
        points: "76.201 132.201 152.201 40.201 216 40 215.799 103.799 123.799 179.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M82.14214,197.45584,52.201,227.397a8,8,0,0,1-11.31371,0L28.603,215.11268a8,8,0,0,1,0-11.31371l29.94113-29.94112a8,8,0,0,0,0-11.31371L37.65685,141.65685a8,8,0,0,1,0-11.3137l12.6863-12.6863a8,8,0,0,1,11.3137,0l76.6863,76.6863a8,8,0,0,1,0,11.3137l-12.6863,12.6863a8,8,0,0,1-11.3137,0L93.45584,197.45584A8,8,0,0,0,82.14214,197.45584Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M221.65723,34.34326A8.00246,8.00246,0,0,0,216,32h-.02539l-63.79883.20117A8.00073,8.00073,0,0,0,146.0332,35.106L75.637,120.32275,67.31348,111.999A16.02162,16.02162,0,0,0,44.68555,112L32.001,124.68555A15.99888,15.99888,0,0,0,32,147.31348l20.88672,20.88769L22.94531,198.14258a16.01777,16.01777,0,0,0,.001,22.62695l12.28418,12.28418a16.00007,16.00007,0,0,0,22.62793,0L87.79883,203.1123,108.68652,224.001A16.02251,16.02251,0,0,0,131.31445,224L143.999,211.31445A15.99888,15.99888,0,0,0,144,188.68652l-8.32324-8.32324,85.21679-70.39648a8.00125,8.00125,0,0,0,2.90528-6.14258L224,40.02539A8.001,8.001,0,0,0,221.65723,34.34326Zm-13.84668,65.67822-83.49829,68.97706L111.314,156l54.34327-54.34277a8.00053,8.00053,0,0,0-11.31446-11.31446L100,144.686,87.00195,131.6875,155.97852,48.189l51.99609-.16357Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "76.201 132.201 152.201 40.201 216 40 215.799 103.799 123.799 179.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M82.14214,197.45584,52.201,227.397a8,8,0,0,1-11.31371,0L28.603,215.11268a8,8,0,0,1,0-11.31371l29.94113-29.94112a8,8,0,0,0,0-11.31371L37.65685,141.65685a8,8,0,0,1,0-11.3137l12.6863-12.6863a8,8,0,0,1,11.3137,0l76.6863,76.6863a8,8,0,0,1,0,11.3137l-12.6863,12.6863a8,8,0,0,1-11.3137,0L93.45584,197.45584A8,8,0,0,0,82.14214,197.45584Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "76.201 132.201 152.201 40.201 216 40 215.799 103.799 123.799 179.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M82.14214,197.45584,52.201,227.397a8,8,0,0,1-11.31371,0L28.603,215.11268a8,8,0,0,1,0-11.31371l29.94113-29.94112a8,8,0,0,0,0-11.31371L37.65685,141.65685a8,8,0,0,1,0-11.3137l12.6863-12.6863a8,8,0,0,1,11.3137,0l76.6863,76.6863a8,8,0,0,1,0,11.3137l-12.6863,12.6863a8,8,0,0,1-11.3137,0L93.45584,197.45584A8,8,0,0,0,82.14214,197.45584Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "76.201 132.201 152.201 40.201 216 40 215.799 103.799 123.799 179.799",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "100",
        y1: "156",
        x2: "160",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M82.14214,197.45584,52.201,227.397a8,8,0,0,1-11.31371,0L28.603,215.11268a8,8,0,0,1,0-11.31371l29.94113-29.94112a8,8,0,0,0,0-11.31371L37.65685,141.65685a8,8,0,0,1,0-11.3137l12.6863-12.6863a8,8,0,0,1,11.3137,0l76.6863,76.6863a8,8,0,0,1,0,11.3137l-12.6863,12.6863a8,8,0,0,1-11.3137,0L93.45584,197.45584A8,8,0,0,0,82.14214,197.45584Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Sword = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Sword.displayName = "Sword";

var renderPathFor$9z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32.0002,56H223.9998a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40.0002a8,8,0,0,1-8-8V56A0,0,0,0,1,32.0002,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "104",
        x2: "224",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "152",
        x2: "224",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88.00008",
        y1: "104",
        x2: "88.00008",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "32.0002",
        y: "104",
        width: "55.99988",
        height: "96",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M32.0002,56H223.9998a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40.0002a8,8,0,0,1-8-8V56A0,0,0,0,1,32.0002,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "104",
        x2: "224",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "152",
        x2: "224",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.00008",
        y1: "104",
        x2: "88.00008",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224.00586,48h-192a7.99977,7.99977,0,0,0-8,8V192a16.01833,16.01833,0,0,0,16,16h176a16.01833,16.01833,0,0,0,16-16V56A7.99977,7.99977,0,0,0,224.00586,48Zm-184,64h40v32h-40Zm56,0H216.01l.00244,32H96.00586Zm-56,48h40v32h-40Zm176,32h-120V160H216.01367l.00244,31.99951Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32.0002,56H223.9998a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40.0002a8,8,0,0,1-8-8V56A0,0,0,0,1,32.0002,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "104",
        x2: "224",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "152",
        x2: "224",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88.00008",
        y1: "104",
        x2: "88.00008",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32.0002,56H223.9998a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40.0002a8,8,0,0,1-8-8V56A0,0,0,0,1,32.0002,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "104",
        x2: "224",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "152",
        x2: "224",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88.00008",
        y1: "104",
        x2: "88.00008",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M32.0002,56H223.9998a0,0,0,0,1,0,0V192a8,8,0,0,1-8,8H40.0002a8,8,0,0,1-8-8V56A0,0,0,0,1,32.0002,56Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "104",
        x2: "224",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "32",
        y1: "152",
        x2: "224",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.00008",
        y1: "104",
        x2: "88.00008",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Table = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Table.displayName = "Table";

var renderPathFor$9A = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.66459,25.8792,42.0101,42.0101,25.8792,122.66459a8,8,0,0,0,2.1878,7.22578L132.51977,234.34315a8,8,0,0,0,11.31371,0l90.50967-90.50967a8,8,0,0,0,0-11.31371L129.89037,28.067A8,8,0,0,0,122.66459,25.8792Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.66459,25.8792,42.0101,42.0101,25.8792,122.66459a8,8,0,0,0,2.1878,7.22578L132.51977,234.34315a8,8,0,0,0,11.31371,0l90.50967-90.50967a8,8,0,0,0,0-11.31371L129.89037,28.067A8,8,0,0,0,122.66459,25.8792Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M122.66459,25.8792,42.0101,42.0101,25.8792,122.66459a8,8,0,0,0,2.1878,7.22578L132.51977,234.34315a8,8,0,0,0,11.31371,0l90.50967-90.50967a8,8,0,0,0,0-11.31371L129.89037,28.067A8,8,0,0,0,122.66459,25.8792Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,126.8623,135.54785,22.41016a15.95972,15.95972,0,0,0-14.45215-4.376L40.44043,34.165A8.00261,8.00261,0,0,0,34.165,40.44043L18.03418,121.0957a15.97009,15.97009,0,0,0,4.376,14.45215L126.86133,239.999a16.00006,16.00006,0,0,0,22.6289.001L239.999,149.49121A16.00007,16.00007,0,0,0,240,126.8623ZM83.99414,96a12,12,0,1,1,12-12A12,12,0,0,1,83.99414,96Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.66459,25.8792,42.0101,42.0101,25.8792,122.66459a8,8,0,0,0,2.1878,7.22578L132.51977,234.34315a8,8,0,0,0,11.31371,0l90.50967-90.50967a8,8,0,0,0,0-11.31371L129.89037,28.067A8,8,0,0,0,122.66459,25.8792Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.66459,25.8792,42.0101,42.0101,25.8792,122.66459a8,8,0,0,0,2.1878,7.22578L132.51977,234.34315a8,8,0,0,0,11.31371,0l90.50967-90.50967a8,8,0,0,0,0-11.31371L129.89037,28.067A8,8,0,0,0,122.66459,25.8792Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M122.66459,25.8792,42.0101,42.0101,25.8792,122.66459a8,8,0,0,0,2.1878,7.22578L132.51977,234.34315a8,8,0,0,0,11.31371,0l90.50967-90.50967a8,8,0,0,0,0-11.31371L129.89037,28.067A8,8,0,0,0,122.66459,25.8792Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "84",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Tag = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9A(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Tag.displayName = "Tag";

var renderPathFor$9B = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M194.37493,196.43765,240,128,194.37493,59.56244a8,8,0,0,0-6.6564-3.56239H40a8,8,0,0,0-8,8V192a8,8,0,0,0,8,8H187.71853A8,8,0,0,0,194.37493,196.43765Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M194.37493,196.43765,240,128,194.37493,59.56244a8,8,0,0,0-6.6564-3.56239H40a8,8,0,0,0-8,8V192a8,8,0,0,0,8,8H187.71853A8,8,0,0,0,194.37493,196.43765Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M194.37493,196.43765,240,128,194.37493,59.56244a8,8,0,0,0-6.6564-3.56239H40a8,8,0,0,0-8,8V192a8,8,0,0,0,8,8H187.71853A8,8,0,0,0,194.37493,196.43765Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M246.65625,123.56213l-45.624-68.43652a15.9687,15.9687,0,0,0-13.31348-7.126H40a16.01833,16.01833,0,0,0-16,16v128a16.01833,16.01833,0,0,0,16,16H187.71875a15.96649,15.96649,0,0,0,13.31348-7.125l-.001.001,45.625-68.43848A7.99771,7.99771,0,0,0,246.65625,123.56213Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M194.37493,196.43765,240,128,194.37493,59.56244a8,8,0,0,0-6.6564-3.56239H40a8,8,0,0,0-8,8V192a8,8,0,0,0,8,8H187.71853A8,8,0,0,0,194.37493,196.43765Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M194.37493,196.43765,240,128,194.37493,59.56244a8,8,0,0,0-6.6564-3.56239H40a8,8,0,0,0-8,8V192a8,8,0,0,0,8,8H187.71853A8,8,0,0,0,194.37493,196.43765Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M194.37493,196.43765,240,128,194.37493,59.56244a8,8,0,0,0-6.6564-3.56239H40a8,8,0,0,0-8,8V192a8,8,0,0,0,8,8H187.71853A8,8,0,0,0,194.37493,196.43765Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TagSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9B(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TagSimple.displayName = "TagSimple";

var renderPathFor$9C = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "224",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M161.94113,94.05887A47.98662,47.98662,0,1,0,175.05255,137.516",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M195.88225,60.11775A95.92854,95.92854,0,1,0,218.012,94.55869",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "48",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "224",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M195.88225,60.11775a95.90539,95.90539,0,1,0,18.76606,26.49271",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M161.94113,94.05887a47.99886,47.99886,0,1,0,13.98107,31.20092",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M211.2002,79.3916a8.00051,8.00051,0,0,0-3.77051,10.667,88.0876,88.0876,0,1,1-23.13037-29.67187l-22.769,22.76855a55.99686,55.99686,0,0,0-73.1333,84.438l.0044.00488.00537.00489a56.00035,56.00035,0,0,0,95.50244-42.79737,8.0002,8.0002,0,1,0-15.97461.90821,40.01415,40.01415,0,0,1-61.99805,35.66357l23.94922-23.94922,37.71289-37.7124.00489-.00537,62.05371-62.05371a8.00036,8.00036,0,0,0-11.31446-11.314L195.667,49.01855a104.00214,104.00214,0,0,0-141.206,152.52051A104.01636,104.01636,0,0,0,221.86719,83.16211,7.99983,7.99983,0,0,0,211.2002,79.3916Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "224",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M195.88225,60.11775a95.90539,95.90539,0,1,0,18.76606,26.49271",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M161.94113,94.05887a47.99886,47.99886,0,1,0,13.98107,31.20092",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "224",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M195.88225,60.11775a95.90539,95.90539,0,1,0,18.76606,26.49271",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M161.94113,94.05887a47.99886,47.99886,0,1,0,13.98107,31.20092",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "224",
        y2: "32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M195.88225,60.11775a95.90539,95.90539,0,1,0,18.76606,26.49271",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M161.94113,94.05887a47.99886,47.99886,0,1,0,13.98107,31.20092",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Target = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9C(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Target.displayName = "Target";

var renderPathFor$9D = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,134.87236l89.91726,79.12718a8,8,0,0,0,13.08288-4.21869L228.61385,45.64829a8,8,0,0,0-10.72308-9.233L33.33393,108.91975a8,8,0,0,0,1.35629,15.29065Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "134.87236",
        x2: "224.11223",
        y2: "36.56908",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M132.90708,174.39059l-31.25023,31.25023A8,8,0,0,1,88,199.984v-65.1116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", {
        opacity: "0.2"
      }, React__default.createElement("path", {
        d: "M88,134.87236,224.11223,36.56908l.00168-.00367a7.87244,7.87244,0,0,0-6.22314-.15014L33.33393,108.91975a8,8,0,0,0,1.35629,15.29065Z"
      })), React__default.createElement("path", {
        d: "M132.90708,174.39059l-31.25023,31.25023A8,8,0,0,1,88,199.984v-65.1116Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M88,134.87236l89.91726,79.12718a8,8,0,0,0,13.08288-4.21869L228.61385,45.64829a8,8,0,0,0-10.72308-9.233L33.33393,108.91975a8,8,0,0,0,1.35629,15.29065Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "134.87236",
        x2: "224.11223",
        y2: "36.56908",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M132.90708,174.39059l-31.25023,31.25023A8,8,0,0,1,88,199.984v-65.1116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M231.25586,31.73635a15.9634,15.9634,0,0,0-16.29-2.76758L30.40869,101.47365a15.99988,15.99988,0,0,0,2.7124,30.58106L80,141.43069V199.9844a15.99415,15.99415,0,0,0,27.31348,11.31347L133.25684,185.355l39.376,34.65088a15.86863,15.86863,0,0,0,10.51709,4.00293,16.15674,16.15674,0,0,0,4.96338-.78711,15.86491,15.86491,0,0,0,10.68457-11.65332L236.41162,47.43557A15.96073,15.96073,0,0,0,231.25586,31.73635ZM183.20215,207.99416,100.81006,135.4883l118.64453-85.687Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,134.87236l89.91726,79.12718a8,8,0,0,0,13.08288-4.21869L228.61385,45.64829a8,8,0,0,0-10.72308-9.233L33.33393,108.91975a8,8,0,0,0,1.35629,15.29065Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "134.87236",
        x2: "224.11223",
        y2: "36.56908",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M132.90708,174.39059l-31.25023,31.25023A8,8,0,0,1,88,199.984v-65.1116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,134.87236l89.91726,79.12718a8,8,0,0,0,13.08288-4.21869L228.61385,45.64829a8,8,0,0,0-10.72308-9.233L33.33393,108.91975a8,8,0,0,0,1.35629,15.29065Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "134.87236",
        x2: "224.11223",
        y2: "36.56908",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M132.90708,174.39059l-31.25023,31.25023A8,8,0,0,1,88,199.984v-65.1116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M88,134.87236l89.91726,79.12718a8,8,0,0,0,13.08288-4.21869L228.61385,45.64829a8,8,0,0,0-10.72308-9.233L33.33393,108.91975a8,8,0,0,0,1.35629,15.29065Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "134.87236",
        x2: "224.11223",
        y2: "36.56908",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M132.90708,174.39059l-31.25023,31.25023A8,8,0,0,1,88,199.984v-65.1116",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TelegramLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9D(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TelegramLogo.displayName = "TelegramLogo";

var renderPathFor$9E = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "40 64 112 128 40 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "119.99414",
        y1: "192",
        x2: "215.99414",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "40 64 112 128 40 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "119.99414",
        y1: "192",
        x2: "215.99414",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M120,128a8.00063,8.00063,0,0,0-2.68506-5.97949l-72-64a8.00018,8.00018,0,0,0-10.62988,11.959L99.9585,128,34.68506,186.02051a8.00018,8.00018,0,0,0,10.62988,11.959l72-64A8.00063,8.00063,0,0,0,120,128Z"
      }), React__default.createElement("path", {
        d: "M215.99414,184h-96a8,8,0,0,0,0,16h96a8,8,0,1,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "40 64 112 128 40 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "119.99414",
        y1: "192",
        x2: "215.99414",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "40 64 112 128 40 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "119.99414",
        y1: "192",
        x2: "215.99414",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "40 64 112 128 40 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "119.99414",
        y1: "192",
        x2: "215.99414",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Terminal = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9E(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Terminal.displayName = "Terminal";

var renderPathFor$9F = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "108",
        x2: "192",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.00307",
        y1: "148",
        x2: "215.99693",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "64.00307",
        y1: "188",
        x2: "191.99693",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "108",
        x2: "192",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00307",
        y1: "148",
        x2: "215.99693",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "64.00307",
        y1: "188",
        x2: "191.99693",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M40,76H216a8,8,0,0,0,0-16H40a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M64,100a8,8,0,0,0,0,16H192a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M215.99707,140H40.00293a8,8,0,1,0,0,16H215.99707a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M191.99707,180H64.00293a8,8,0,0,0,0,16H191.99707a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "108",
        x2: "192",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.00307",
        y1: "148",
        x2: "215.99693",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "64.00307",
        y1: "188",
        x2: "191.99693",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "108",
        x2: "192",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.00307",
        y1: "148",
        x2: "215.99693",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "64.00307",
        y1: "188",
        x2: "191.99693",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "64",
        y1: "108",
        x2: "192",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00307",
        y1: "148",
        x2: "215.99693",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "64.00307",
        y1: "188",
        x2: "191.99693",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TextAlignCenter = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9F(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TextAlignCenter.displayName = "TextAlignCenter";

var renderPathFor$9G = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "108",
        x2: "216",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "108",
        x2: "216",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M40,76H216a8,8,0,0,0,0-16H40a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M216,100H40a8,8,0,0,0,0,16H216a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M216,140H40.00586a8,8,0,1,0,0,16H216a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M216,180H40.00586a8,8,0,1,0,0,16H216a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "108",
        x2: "216",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "108",
        x2: "216",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "108",
        x2: "216",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TextAlignJustify = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9G(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TextAlignJustify.displayName = "TextAlignJustify";

var renderPathFor$9H = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "108",
        x2: "168",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "168",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "108",
        x2: "168",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "168",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M40.02344,76h176a8,8,0,0,0,0-16h-176a8,8,0,1,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M40.02344,116h128a8,8,0,0,0,0-16h-128a8,8,0,1,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M216.02344,140H40.0293a8,8,0,0,0,0,16H216.02344a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M168.02344,180H40.0293a8,8,0,0,0,0,16H168.02344a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "108",
        x2: "168",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "168",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "108",
        x2: "168",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "168",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40",
        y1: "108",
        x2: "168",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "188",
        x2: "168",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TextAlignLeft = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9H(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TextAlignLeft.displayName = "TextAlignLeft";

var renderPathFor$9I = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "108",
        x2: "216",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "108",
        x2: "216",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M40,76H216a8,8,0,0,0,0-16H40a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M216,100H88a8,8,0,0,0,0,16H216a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M216,140H40.00586a8,8,0,1,0,0,16H216a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M216,180H88.00586a8,8,0,1,0,0,16H216a8,8,0,0,0,0-16Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "108",
        x2: "216",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "108",
        x2: "216",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "68",
        x2: "216",
        y2: "68",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "108",
        x2: "216",
        y2: "108",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "40.00614",
        y1: "148",
        x2: "216",
        y2: "148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88.00614",
        y1: "188",
        x2: "216",
        y2: "188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TextAlignRight = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9I(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TextAlignRight.displayName = "TextAlignRight";

var renderPathFor$9J = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M64,120h88a40,40,0,0,1,0,80l-88.00586-.00488v-152L140,48a36,36,0,0,1,0,72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M64,120h88a40,40,0,0,1,0,80l-88.00586-.00488v-152L140,48a36,36,0,0,1,0,72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M170.4834,115.70117A43.98012,43.98012,0,0,0,140.00049,40l-76.00586-.00488h-.00049a7.99955,7.99955,0,0,0-8,8v152a8,8,0,0,0,7.99951,8L152,208a48.00015,48.00015,0,0,0,18.4834-92.29883ZM71.99414,55.99561,140,56a28,28,0,0,1,0,56H71.99414ZM152.00049,192l-80.00635-.00439V128H152a32,32,0,0,1,.00049,64Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M64,120h88a40,40,0,0,1,0,80l-88.00586-.00488v-152L140,48a36,36,0,0,1,0,72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M64,120h88a40,40,0,0,1,0,80l-88.00586-.00488v-152L140,48a36,36,0,0,1,0,72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M64,120h88a40,40,0,0,1,0,80l-88.00586-.00488v-152L140,48a36,36,0,0,1,0,72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TextBolder = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9J(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TextBolder.displayName = "TextBolder";

var renderPathFor$9K = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "151.99414",
        y1: "59.99512",
        x2: "103.99414",
        y2: "195.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "195.99512",
        x2: "143.99414",
        y2: "195.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "111.99414",
        y1: "59.99512",
        x2: "191.99414",
        y2: "59.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "151.99414",
        y1: "55.99512",
        x2: "103.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "199.99512",
        x2: "143.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "111.99414",
        y1: "55.99512",
        x2: "191.99414",
        y2: "55.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M199.99414,55.99512a8.00008,8.00008,0,0,1-8,8H157.76l-42.6665,128h28.90063a8,8,0,0,1,0,16H104.02307l-.028.002-.02735-.002H63.99414a8,8,0,0,1,0-16H98.22827l42.66651-128H111.99414a8,8,0,0,1,0-16h80A8.00008,8.00008,0,0,1,199.99414,55.99512Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "151.99414",
        y1: "55.99512",
        x2: "103.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "199.99512",
        x2: "143.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "111.99414",
        y1: "55.99512",
        x2: "191.99414",
        y2: "55.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "151.99414",
        y1: "55.99512",
        x2: "103.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "199.99512",
        x2: "143.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "111.99414",
        y1: "55.99512",
        x2: "191.99414",
        y2: "55.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "151.99414",
        y1: "55.99512",
        x2: "103.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "63.99414",
        y1: "199.99512",
        x2: "143.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "111.99414",
        y1: "55.99512",
        x2: "191.99414",
        y2: "55.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TextItalic = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9K(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TextItalic.displayName = "TextItalic";

var renderPathFor$9L = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M171.73144,79.99989C169.29943,62.00014,150.648,48,128,48c-24.30053,0-44,16.11775-44,36a32.40178,32.40178,0,0,0,2.00532,12.00253",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M153.03855,127.9992C171.72987,135.814,184,146.83949,184,164c0,28-25.072,44-56,44-25.63327,0-47.244-13.53195-53.892-32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M171.73144,79.99989C169.29943,62.00014,150.648,48,128,48c-24.30053,0-44,16.11775-44,36a32.40178,32.40178,0,0,0,2.00532,12.00253",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M153.03855,127.9992C171.72987,135.814,184,146.83949,184,164c0,28-25.072,44-56,44-25.63327,0-47.244-13.53195-53.892-32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,128a7.99977,7.99977,0,0,1-8,8H180.28784C188.071,143.907,192,153.26367,192,164c0,30.6167-26.31787,52-64,52-28.25928,0-53.51562-15.33447-61.41943-37.29053a8.00013,8.00013,0,0,1,15.05468-5.41894C87.2959,189.0166,106.36182,200,128,200c23.89209,0,48-11.13135,48-36,0-7.45044-2.60071-18.385-24.61145-28H40a8,8,0,0,1,0-16H152.95728c.03759-.00049.075,0,.11267,0H216A7.99977,7.99977,0,0,1,224,128ZM86.00781,104.00439a8.00453,8.00453,0,0,0,7.43946-10.9375A24.60019,24.60019,0,0,1,92,84c0-15.43945,16.14941-28,36-28,18.17725,0,33.90381,11.0127,35.80371,25.07129a7.99979,7.99979,0,0,0,15.85547-2.14258C176.66064,56.73584,154.45215,40,128,40,99.32715,40,76,59.73828,76,84a40.124,40.124,0,0,0,2.56348,14.938A8.00176,8.00176,0,0,0,86.00781,104.00439Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M171.73144,79.99989C169.29943,62.00014,150.648,48,128,48c-24.30053,0-44,16.11775-44,36a32.40178,32.40178,0,0,0,2.00532,12.00253",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M153.03855,127.9992C171.72987,135.814,184,146.83949,184,164c0,28-25.072,44-56,44-25.63327,0-47.244-13.53195-53.892-32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M171.73144,79.99989C169.29943,62.00014,150.648,48,128,48c-24.30053,0-44,16.11775-44,36a32.40178,32.40178,0,0,0,2.00532,12.00253",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M153.03855,127.9992C171.72987,135.814,184,146.83949,184,164c0,28-25.072,44-56,44-25.63327,0-47.244-13.53195-53.892-32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "128",
        x2: "216",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M171.73144,79.99989C169.29943,62.00014,150.648,48,128,48c-24.30053,0-44,16.11775-44,36a32.40178,32.40178,0,0,0,2.00532,12.00253",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M153.03855,127.9992C171.72987,135.814,184,146.83949,184,164c0,28-25.072,44-56,44-25.63327,0-47.244-13.53195-53.892-32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TextStrikethrough = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9L(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TextStrikethrough.displayName = "TextStrikethrough";

var renderPathFor$9M = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99414",
        y1: "55.99512",
        x2: "127.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "47.994 87.995 47.994 55.995 207.994 55.995 207.994 87.995",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "95.99414",
        y1: "199.99512",
        x2: "159.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99414",
        y1: "55.99512",
        x2: "127.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "47.994 87.995 47.994 55.995 207.994 55.995 207.994 87.995",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "95.99414",
        y1: "199.99512",
        x2: "159.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M207.99414,47.99512h-160a8.00008,8.00008,0,0,0-8,8v32a8,8,0,0,0,16,0v-24h64v128h-24a8,8,0,0,0,0,16h64a8,8,0,0,0,0-16h-24v-128h64v24a8,8,0,1,0,16,0v-32A8.00008,8.00008,0,0,0,207.99414,47.99512Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99414",
        y1: "55.99512",
        x2: "127.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "47.994 87.995 47.994 55.995 207.994 55.995 207.994 87.995",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "95.99414",
        y1: "199.99512",
        x2: "159.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99414",
        y1: "55.99512",
        x2: "127.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "47.994 87.995 47.994 55.995 207.994 55.995 207.994 87.995",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "95.99414",
        y1: "199.99512",
        x2: "159.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "127.99414",
        y1: "55.99512",
        x2: "127.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "47.994 87.995 47.994 55.995 207.994 55.995 207.994 87.995",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "95.99414",
        y1: "199.99512",
        x2: "159.99414",
        y2: "199.99512",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TextT = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9M(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TextT.displayName = "TextT";

var renderPathFor$9N = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216",
        x2: "216",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M64,56v60a64,64,0,0,0,128,0V56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216",
        x2: "216",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M64,56v64a64,64,0,0,0,128,0V56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M224,216a7.99977,7.99977,0,0,1-8,8H40a8,8,0,0,1,0-16H216A7.99977,7.99977,0,0,1,224,216Zm-96-24a72.0814,72.0814,0,0,0,72-72V56a8,8,0,0,0-16,0v64a56,56,0,0,1-112,0V56a8,8,0,0,0-16,0v64A72.0814,72.0814,0,0,0,128,192Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216",
        x2: "216",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M64,56v64a64,64,0,0,0,128,0V56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216",
        x2: "216",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M64,56v64a64,64,0,0,0,128,0V56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "40",
        y1: "216",
        x2: "216",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M64,56v64a64,64,0,0,0,128,0V56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TextUnderline = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9N(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TextUnderline.displayName = "TextUnderline";

var renderPathFor$9O = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "216",
        cy: "80",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "108",
        cy: "188",
        r: "12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "108",
        y1: "168",
        x2: "108",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M68,154.77579V56a40,40,0,0,1,80,0v98.77485l.0017-.0014a52,52,0,1,1-80.00385.00054Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "212",
        cy: "80",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152.00787,147.01562,152,147.02539V48a32,32,0,0,0-64,0v99.02539l-.00787-.00977a52,52,0,1,0,64.01574,0ZM120,208a20,20,0,1,1,20-20A19.9999,19.9999,0,0,1,120,208Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M212,52a28,28,0,1,0,28,28A28.03146,28.03146,0,0,0,212,52Zm0,40a12,12,0,1,1,12-12A12.01343,12.01343,0,0,1,212,92Zm-52,51.27441V48a40,40,0,0,0-80,0v95.27441a60,60,0,1,0,80,0ZM120,24a24.02718,24.02718,0,0,1,24,24V80H96V48A24.02718,24.02718,0,0,1,120,24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "212",
        cy: "80",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "212",
        cy: "80",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "212",
        cy: "80",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Thermometer = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9O(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Thermometer.displayName = "Thermometer";

var renderPathFor$9P = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "108",
        cy: "188",
        r: "12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "108",
        y1: "176",
        x2: "108",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "212",
        y1: "48",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "181.56619",
        y1: "70.11146",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "193.19087",
        y1: "105.88854",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "230.80913",
        y1: "105.88854",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "242.43381",
        y1: "70.11146",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M68,154.77579V56a40,40,0,0,1,80,0v98.77485l.0017-.0014a52,52,0,1,1-80.00385.00054Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "212",
        y1: "48",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "181.56619",
        y1: "70.11146",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "193.19087",
        y1: "105.88854",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "230.80913",
        y1: "105.88854",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "242.43381",
        y1: "70.11146",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152.00787,147.01562,152,147.02539V48a32,32,0,0,0-64,0v99.02539l-.00787-.00977a52,52,0,1,0,64.01574,0ZM120,208a20,20,0,1,1,20-20A19.9999,19.9999,0,0,1,120,208Z",
        opacity: "0.2"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M244.90576,77.71973l-19.96167,6.48632,12.33716,16.98047a8,8,0,1,1-12.94434,9.4043L212,93.61035l-12.33691,16.98047a7.99995,7.99995,0,0,1-12.94434-9.4043l12.33716-16.98047-19.96167-6.48632a8,8,0,1,1,4.94433-15.2168L204,68.98877V48a8,8,0,0,1,16,0V68.98877l19.96143-6.48584a8,8,0,1,1,4.94433,15.2168ZM180,188A60,60,0,1,1,80,143.27441V48a40,40,0,0,1,80,0v95.27441A59.61666,59.61666,0,0,1,180,188ZM96,48v56h48V48a24,24,0,0,0-48,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "212",
        y1: "48",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "181.56619",
        y1: "70.11146",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "193.19087",
        y1: "105.88854",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "230.80913",
        y1: "105.88854",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "242.43381",
        y1: "70.11146",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "212",
        y1: "48",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "181.56619",
        y1: "70.11146",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "193.19087",
        y1: "105.88854",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "230.80913",
        y1: "105.88854",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "242.43381",
        y1: "70.11146",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "212",
        y1: "48",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "181.56619",
        y1: "70.11146",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "193.19087",
        y1: "105.88854",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "230.80913",
        y1: "105.88854",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "242.43381",
        y1: "70.11146",
        x2: "212",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ThermometerCold = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9P(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ThermometerCold.displayName = "ThermometerCold";

var renderPathFor$9Q = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "108",
        cy: "188",
        r: "12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "108",
        y1: "176",
        x2: "108",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M240.28427,80A20,20,0,0,1,212,80a20,20,0,0,0-28.28427,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M240.28427,120A20,20,0,0,1,212,120a20,20,0,0,0-28.28427,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M68,154.77579V56a40,40,0,0,1,80,0v98.77485l.0017-.0014a52,52,0,1,1-80.00385.00054Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M240.28427,80A20,20,0,0,1,212,80a20,20,0,0,0-28.28427,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M240.28427,120A20,20,0,0,1,212,120a20,20,0,0,0-28.28427,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152.00787,147.01562,152,147.02539V48a32,32,0,0,0-64,0v99.02539l-.00787-.00977a52,52,0,1,0,64.01574,0ZM120,208a20,20,0,1,1,20-20A19.9999,19.9999,0,0,1,120,208Z",
        opacity: "0.2"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M160,143.27441V48a40,40,0,0,0-80,0v95.27441a60,60,0,1,0,80,0ZM120,24a24.02718,24.02718,0,0,1,24,24v8H96V48A24.02718,24.02718,0,0,1,120,24Zm58.05908,61.65723a8.00034,8.00034,0,0,1,0-11.31446,27.99923,27.99923,0,0,1,39.59766,0,12.01214,12.01214,0,0,0,16.9707,0,8.00018,8.00018,0,0,1,11.31348,11.31446,27.99923,27.99923,0,0,1-39.59766,0,12.01214,12.01214,0,0,0-16.9707,0A8.00182,8.00182,0,0,1,178.05908,85.65723Zm67.88184,28.68554a8.00034,8.00034,0,0,1,0,11.31446,27.99923,27.99923,0,0,1-39.59766,0,12.01214,12.01214,0,0,0-16.9707,0,8.00018,8.00018,0,0,1-11.31348-11.31446,27.99923,27.99923,0,0,1,39.59766,0,12.01214,12.01214,0,0,0,16.9707,0A8.00182,8.00182,0,0,1,245.94092,114.34277Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M240.28427,80A20,20,0,0,1,212,80a20,20,0,0,0-28.28427,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M240.28427,120A20,20,0,0,1,212,120a20,20,0,0,0-28.28427,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M240.28427,80A20,20,0,0,1,212,80a20,20,0,0,0-28.28427,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M240.28427,120A20,20,0,0,1,212,120a20,20,0,0,0-28.28427,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "120",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "168",
        x2: "120",
        y2: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M240.28427,80A20,20,0,0,1,212,80a20,20,0,0,0-28.28427,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M240.28427,120A20,20,0,0,1,212,120a20,20,0,0,0-28.28427,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ThermometerHot = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9Q(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ThermometerHot.displayName = "ThermometerHot";

var renderPathFor$9R = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "92",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,154.77579V56a40,40,0,0,1,80,0v98.77485l.0017-.0014a52,52,0,1,1-80.00385.00054Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M160.00787,147.01562,160,147.02539V48a32,32,0,0,0-64,0v99.02539l-.00787-.00977a52,52,0,1,0,64.01574,0ZM128,208a20,20,0,1,1,20-20A19.9999,19.9999,0,0,1,128,208Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M96,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M168,143.27441V48a40,40,0,0,0-80,0v95.27441a60,60,0,1,0,80,0ZM128,24a24.02718,24.02718,0,0,1,24,24V80H104V48A24.02718,24.02718,0,0,1,128,24Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,147.02548V48a32,32,0,0,1,64,0v99.02548l.00787-.01006a52,52,0,1,1-64.01574,0Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "188",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "168",
        x2: "128",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ThermometerSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9R(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ThermometerSimple.displayName = "ThermometerSimple";

var renderPathFor$9S = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M31.99414,48h48a0,0,0,0,1,0,0V152a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M79.99414,152l40,80a32,32,0,0,0,32-32V176h61.87549a16,16,0,0,0,15.87644-17.98456l-12-96A16,16,0,0,0,201.86963,48H79.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M31.99414,48h48a0,0,0,0,1,0,0V152a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M31.99414,48h48a0,0,0,0,1,0,0V152a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M79.99414,152l40,80a32,32,0,0,0,32-32V176h61.87549a16,16,0,0,0,15.87644-17.98456l-12-96A16,16,0,0,0,201.86963,48H79.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M237.68457,157.02344l-12-96.00049A24.03944,24.03944,0,0,0,201.86914,40H31.99414a16.01833,16.01833,0,0,0-16,16v88a16.01833,16.01833,0,0,0,16,16H75.0498l37.78907,75.57764A7.99869,7.99869,0,0,0,119.99414,240a40.04552,40.04552,0,0,0,40-40V184h53.875a24.00051,24.00051,0,0,0,23.81543-26.97656ZM71.99414,144h-40V56h40Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M31.99414,48h48a0,0,0,0,1,0,0V152a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V56A8,8,0,0,1,31.99414,48Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M79.99414,152l40,80a32,32,0,0,0,32-32V176h61.87549a16,16,0,0,0,15.87644-17.98456l-12-96A16,16,0,0,0,201.86963,48H79.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M31.99414,48h48a0,0,0,0,1,0,0V152a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V56A8,8,0,0,1,31.99414,48Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M79.99414,152l40,80a32,32,0,0,0,32-32V176h61.87549a16,16,0,0,0,15.87644-17.98456l-12-96A16,16,0,0,0,201.86963,48H79.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M31.99414,48h48a0,0,0,0,1,0,0V152a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M79.99414,152l40,80a32,32,0,0,0,32-32V176h61.87549a16,16,0,0,0,15.87644-17.98456l-12-96A16,16,0,0,0,201.86963,48H79.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ThumbsDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9S(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ThumbsDown.displayName = "ThumbsDown";

var renderPathFor$9T = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M31.99414,104h48a0,0,0,0,1,0,0V208a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V112A8,8,0,0,1,31.99414,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M79.99414,104l40-80a32,32,0,0,1,32,32V80h61.87549a16,16,0,0,1,15.87644,17.98456l-12,96A16,16,0,0,1,201.86963,208H79.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M31.99414,104h48a0,0,0,0,1,0,0V208a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V112A8,8,0,0,1,31.99414,104Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M31.99414,104h48a0,0,0,0,1,0,0V208a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V112A8,8,0,0,1,31.99414,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M79.99414,104l40-80a32,32,0,0,1,32,32V80h61.87549a16,16,0,0,1,15.87644,17.98456l-12,96A16,16,0,0,1,201.86963,208H79.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M231.86133,80.11621A24.01156,24.01156,0,0,0,213.86914,72h-53.875V56a40.04552,40.04552,0,0,0-40-40,7.99869,7.99869,0,0,0-7.15527,4.42236L75.0498,96H31.99414a16.01833,16.01833,0,0,0-16,16v88a16.01833,16.01833,0,0,0,16,16h169.875a24.03945,24.03945,0,0,0,23.81543-21.02344l12-96A24.01444,24.01444,0,0,0,231.86133,80.11621ZM31.99414,112h40v88h-40Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M31.99414,104h48a0,0,0,0,1,0,0V208a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V112A8,8,0,0,1,31.99414,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M79.99414,104l40-80a32,32,0,0,1,32,32V80h61.87549a16,16,0,0,1,15.87644,17.98456l-12,96A16,16,0,0,1,201.86963,208H79.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M31.99414,104h48a0,0,0,0,1,0,0V208a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V112A8,8,0,0,1,31.99414,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M79.99414,104l40-80a32,32,0,0,1,32,32V80h61.87549a16,16,0,0,1,15.87644,17.98456l-12,96A16,16,0,0,1,201.86963,208H79.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M31.99414,104h48a0,0,0,0,1,0,0V208a0,0,0,0,1,0,0h-48a8,8,0,0,1-8-8V112A8,8,0,0,1,31.99414,104Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M79.99414,104l40-80a32,32,0,0,1,32,32V80h61.87549a16,16,0,0,1,15.87644,17.98456l-12,96A16,16,0,0,1,201.86963,208H79.99414",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var ThumbsUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9T(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
ThumbsUp.displayName = "ThumbsUp";

var renderPathFor$9U = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "56",
        x2: "96",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M24,167.19024a7.98836,7.98836,0,0,1,6.39917-7.83019,32.00785,32.00785,0,0,0,0-62.7201A7.98836,7.98836,0,0,1,24,88.80976V64a8,8,0,0,1,8-8H224a8,8,0,0,1,8,8V88.80976A7.98836,7.98836,0,0,1,225.60083,96.64a32.00785,32.00785,0,0,0,0,62.7201A7.98836,7.98836,0,0,1,232,167.19024V192a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M96,56H224a8,8,0,0,1,8,8V88.80976A7.98836,7.98836,0,0,1,225.60083,96.64a32.00785,32.00785,0,0,0,0,62.7201A7.98836,7.98836,0,0,1,232,167.19024V192a8,8,0,0,1-8,8H96Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "56",
        x2: "96",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M24,167.19024a7.98836,7.98836,0,0,1,6.39917-7.83019,32.00785,32.00785,0,0,0,0-62.7201A7.98836,7.98836,0,0,1,24,88.80976V64a8,8,0,0,1,8-8H224a8,8,0,0,1,8,8V88.80976A7.98836,7.98836,0,0,1,225.60083,96.64a32.00785,32.00785,0,0,0,0,62.7201A7.98836,7.98836,0,0,1,232,167.19024V192a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M227.19141,104.48A16.04032,16.04032,0,0,0,240,88.80957V64a16.01833,16.01833,0,0,0-16-16H32A16.01833,16.01833,0,0,0,16,64V88.80957A16.04032,16.04032,0,0,0,28.80859,104.48a24.00818,24.00818,0,0,1,0,47.04A16.04032,16.04032,0,0,0,16,167.19043V192a16.01833,16.01833,0,0,0,16,16H224a16.01833,16.01833,0,0,0,16-16V167.19043A16.04032,16.04032,0,0,0,227.19141,151.52a24.00818,24.00818,0,0,1,0-47.04ZM32,167.19824a40.00306,40.00306,0,0,0,0-78.38867V64H88V192H32Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "56",
        x2: "96",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M24,167.19024a7.98836,7.98836,0,0,1,6.39917-7.83019,32.00785,32.00785,0,0,0,0-62.7201A7.98836,7.98836,0,0,1,24,88.80976V64a8,8,0,0,1,8-8H224a8,8,0,0,1,8,8V88.80976A7.98836,7.98836,0,0,1,225.60083,96.64a32.00785,32.00785,0,0,0,0,62.7201A7.98836,7.98836,0,0,1,232,167.19024V192a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "56",
        x2: "96",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M24,167.19024a7.98836,7.98836,0,0,1,6.39917-7.83019,32.00785,32.00785,0,0,0,0-62.7201A7.98836,7.98836,0,0,1,24,88.80976V64a8,8,0,0,1,8-8H224a8,8,0,0,1,8,8V88.80976A7.98836,7.98836,0,0,1,225.60083,96.64a32.00785,32.00785,0,0,0,0,62.7201A7.98836,7.98836,0,0,1,232,167.19024V192a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "96",
        y1: "56",
        x2: "96",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M24,167.19024a7.98836,7.98836,0,0,1,6.39917-7.83019,32.00785,32.00785,0,0,0,0-62.7201A7.98836,7.98836,0,0,1,24,88.80976V64a8,8,0,0,1,8-8H224a8,8,0,0,1,8,8V88.80976A7.98836,7.98836,0,0,1,225.60083,96.64a32.00785,32.00785,0,0,0,0,62.7201A7.98836,7.98836,0,0,1,232,167.19024V192a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Ticket = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9U(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Ticket.displayName = "Ticket";

var renderPathFor$9V = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "140",
        r: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "140",
        x2: "161.94113",
        y2: "106.05887",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "12",
        x2: "152",
        y2: "12",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "167.59798",
        y2: "88.40202",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "8",
        x2: "152",
        y2: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M104,16h48a8,8,0,0,0,0-16H104a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M128,32a96,96,0,1,0,96,96A96.10874,96.10874,0,0,0,128,32Zm45.25488,62.05859-39.59765,39.59815a8.00018,8.00018,0,0,1-11.31446-11.31348l39.59815-39.59814a8,8,0,1,1,11.314,11.31347Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "167.59798",
        y2: "88.40202",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "8",
        x2: "152",
        y2: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "167.59798",
        y2: "88.40202",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "8",
        x2: "152",
        y2: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "88",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "167.59798",
        y2: "88.40202",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "8",
        x2: "152",
        y2: "8",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Timer = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9V(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Timer.displayName = "Timer";

var renderPathFor$9W = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.83966,216H47.16034a8,8,0,0,1-7.95107-7.11655l-14.22222-128A8,8,0,0,1,32.93812,72H223.06188a8,8,0,0,1,7.95107,8.88345l-14.22222,128A8,8,0,0,1,208.83966,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,72a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.83966,216H47.16034a8,8,0,0,1-7.95107-7.11655l-14.22222-128A8,8,0,0,1,32.93812,72H223.06188a8,8,0,0,1,7.95107,8.88345l-14.22222,128A8,8,0,0,1,208.83966,216Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M208.83966,216H47.16034a8,8,0,0,1-7.95107-7.11655l-14.22222-128A8,8,0,0,1,32.93812,72H223.06188a8,8,0,0,1,7.95107,8.88345l-14.22222,128A8,8,0,0,1,208.83966,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,72a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M234.9834,69.3291A16.01892,16.01892,0,0,0,223.06152,64H175.3208a47.99073,47.99073,0,0,0-94.6416,0H32.93848A16.00031,16.00031,0,0,0,17.03613,81.7666L31.25781,209.76709A15.98372,15.98372,0,0,0,47.16016,224H208.83984a15.98375,15.98375,0,0,0,15.90235-14.2334l14.22168-128A16.01871,16.01871,0,0,0,234.9834,69.3291ZM128,40a32.05773,32.05773,0,0,1,30.9873,24H97.0127A32.05773,32.05773,0,0,1,128,40Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.83966,216H47.16034a8,8,0,0,1-7.95107-7.11655l-14.22222-128A8,8,0,0,1,32.93812,72H223.06188a8,8,0,0,1,7.95107,8.88345l-14.22222,128A8,8,0,0,1,208.83966,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,72a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.83966,216H47.16034a8,8,0,0,1-7.95107-7.11655l-14.22222-128A8,8,0,0,1,32.93812,72H223.06188a8,8,0,0,1,7.95107,8.88345l-14.22222,128A8,8,0,0,1,208.83966,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,72a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.83966,216H47.16034a8,8,0,0,1-7.95107-7.11655l-14.22222-128A8,8,0,0,1,32.93812,72H223.06188a8,8,0,0,1,7.95107,8.88345l-14.22222,128A8,8,0,0,1,208.83966,216Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,72a40,40,0,0,1,80,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Tote = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9W(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Tote.displayName = "Tote";

var renderPathFor$9X = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "44",
        y1: "128",
        x2: "212",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "44",
        y1: "72",
        x2: "212",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "44",
        y: "32",
        width: "168",
        height: "176",
        rx: "24",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "44",
        y: "72",
        width: "168",
        height: "56",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "44",
        y1: "128",
        x2: "212",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "44",
        y1: "72",
        x2: "212",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "32",
        width: "168",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M188,24H68A32.03667,32.03667,0,0,0,36,56V184a32.03667,32.03667,0,0,0,32,32H79.99976L65.59961,235.2002a8.00019,8.00019,0,0,0,12.80078,9.5996L100.00024,216h55.99952l21.59985,28.7998a8.00019,8.00019,0,0,0,12.80078-9.5996L176.00024,216H188a32.03667,32.03667,0,0,0,32-32V56A32.03667,32.03667,0,0,0,188,24ZM84,184a12,12,0,1,1,12-12A12,12,0,0,1,84,184Zm36-64H52V80h68Zm52,64a12,12,0,1,1,12-12A12,12,0,0,1,172,184Zm32-64H136V80h68Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "44",
        y1: "128",
        x2: "212",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "44",
        y1: "72",
        x2: "212",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "44",
        y: "32",
        width: "168",
        height: "176",
        rx: "24",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "44",
        y1: "128",
        x2: "212",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "44",
        y1: "72",
        x2: "212",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "44",
        y: "32",
        width: "168",
        height: "176",
        rx: "24",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "44",
        y1: "128",
        x2: "212",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "44",
        y1: "72",
        x2: "212",
        y2: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "32",
        width: "168",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "72",
        x2: "128",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Train = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9X(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Train.displayName = "Train";

var renderPathFor$9Y = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M70.11037,32H185.88963a8,8,0,0,1,7.71811,5.89506L216,120l-22.39226,82.10494A8,8,0,0,1,185.88963,208H70.11037a8,8,0,0,1-7.71811-5.89506L40,120,62.39226,37.89506A8,8,0,0,1,70.11037,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "208",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "40 120 128 136 216 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "88",
        x2: "160",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M40,120l88,16,88-16-22.39226,82.10494A8,8,0,0,1,185.88963,208H70.11037a8,8,0,0,1-7.71811-5.89506Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M70.11037,32H185.88963a8,8,0,0,1,7.71811,5.89506L216,120l-22.39226,82.10494A8,8,0,0,1,185.88963,208H70.11037a8,8,0,0,1-7.71811-5.89506L40,120,62.39226,37.89506A8,8,0,0,1,70.11037,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "208",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "40 120 128 136 216 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "88",
        x2: "160",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M160,80H96a8,8,0,0,0,0,16h64a8,8,0,0,0,0-16Z"
      }), React__default.createElement("path", {
        d: "M223.99023,119.85681q-.00732-.37884-.05078-.76166c-.011-.09741-.02295-.194-.03759-.291-.012-.07855-.01661-.15656-.03077-.23529-.03271-.18048-.08007-.35437-.124-.52967-.01221-.04766-.01636-.09668-.0293-.14416l-.033-.12073-.00122-.00421L201.3252,35.79A16.03362,16.03362,0,0,0,185.88965,24H70.11035A16.03362,16.03362,0,0,0,54.6748,35.79L32.31665,117.76892l-.002.00733-.03247.11877c-.0127.047-.01685.09546-.02881.14264-.04444.17578-.09155.35022-.12451.53119-.01416.07873-.0188.15674-.03077.23529-.01464.097-.02661.1936-.03759.291q-.044.38316-.05078.76166c-.00123.06708-.00611.13373-.00562.20081a7.94859,7.94859,0,0,0,.06567.98889c.00269.0202.00757.0401.0105.06036a7.95052,7.95052,0,0,0,.18115.89508c.00879.03406.01148.06909.02076.103L54.6748,204.209A16.03394,16.03394,0,0,0,70.11035,216h9.88941L65.59961,235.2002a8.00019,8.00019,0,0,0,12.80078,9.5996L100.00024,216h55.99952l21.59985,28.7998a8.00019,8.00019,0,0,0,12.80078-9.5996L176.00024,216h9.88941a16.03394,16.03394,0,0,0,15.43555-11.791l22.39257-82.104c.00928-.03394.012-.069.02076-.103a7.95052,7.95052,0,0,0,.18115-.89508c.00293-.02026.00781-.04016.0105-.06036a7.94859,7.94859,0,0,0,.06567-.98889C223.99634,119.99054,223.99146,119.92389,223.99023,119.85681ZM136,192a8,8,0,0,1-16,0V152a8,8,0,0,1,16,0Zm-8-64.13135L50.0127,113.68927,70.10645,40h115.7832l20.09717,73.68933Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M70.11037,32H185.88963a8,8,0,0,1,7.71811,5.89506L216,120l-22.39226,82.10494A8,8,0,0,1,185.88963,208H70.11037a8,8,0,0,1-7.71811-5.89506L40,120,62.39226,37.89506A8,8,0,0,1,70.11037,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "208",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "40 120 128 136 216 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "88",
        x2: "160",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M70.11037,32H185.88963a8,8,0,0,1,7.71811,5.89506L216,120l-22.39226,82.10494A8,8,0,0,1,185.88963,208H70.11037a8,8,0,0,1-7.71811-5.89506L40,120,62.39226,37.89506A8,8,0,0,1,70.11037,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "208",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "40 120 128 136 216 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "88",
        x2: "160",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M70.11037,32H185.88963a8,8,0,0,1,7.71811,5.89506L216,120l-22.39226,82.10494A8,8,0,0,1,185.88963,208H70.11037a8,8,0,0,1-7.71811-5.89506L40,120,62.39226,37.89506A8,8,0,0,1,70.11037,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "208",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "40 120 128 136 216 120",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "88",
        x2: "160",
        y2: "88",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TrainRegional = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9Y(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TrainRegional.displayName = "TrainRegional";

var renderPathFor$9Z = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "44",
        y1: "128",
        x2: "212",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "44",
        y: "32",
        width: "168",
        height: "176",
        rx: "24",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "88",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "168",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M212,56a24,24,0,0,0-24-24H68A24,24,0,0,0,44,56v72H212Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "44",
        y1: "128",
        x2: "212",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "32",
        width: "168",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M188,24H68A32.03667,32.03667,0,0,0,36,56V184a32.03667,32.03667,0,0,0,32,32H79.99976L65.59961,235.2002a8.00019,8.00019,0,0,0,12.80078,9.5996L100.00024,216h55.99952l21.59985,28.7998a8.00019,8.00019,0,0,0,12.80078-9.5996L176.00024,216H188a32.03667,32.03667,0,0,0,32-32V56A32.03667,32.03667,0,0,0,188,24Zm0,176H68a16.01833,16.01833,0,0,1-16-16V136H204v48A16.01833,16.01833,0,0,1,188,200Z"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "172",
        r: "12"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "172",
        r: "12"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "44",
        y1: "128",
        x2: "212",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "44",
        y: "32",
        width: "168",
        height: "176",
        rx: "24",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "44",
        y1: "128",
        x2: "212",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "44",
        y: "32",
        width: "168",
        height: "176",
        rx: "24",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "44",
        y1: "128",
        x2: "212",
        y2: "128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "96",
        y1: "208",
        x2: "72",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "208",
        x2: "184",
        y2: "240",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "44",
        y: "32",
        width: "168",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("circle", {
        cx: "84",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "172",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TrainSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9Z(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TrainSimple.displayName = "TrainSimple";

var renderPathFor$9_ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "231.982 216 175.982 104 119.982 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "135.98242",
        y1: "184",
        x2: "215.98242",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "87.98242",
        y1: "32",
        x2: "87.98242",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "23.98242",
        y1: "56",
        x2: "151.98242",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M119.98242,56a96,96,0,0,1-96,96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M64.69682,96.00062a96.01575,96.01575,0,0,0,87.27974,55.96606",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "231.971 216 175.971 104 119.971 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "135.9707",
        y1: "184",
        x2: "215.9707",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "87.9707",
        y1: "32",
        x2: "87.9707",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "23.9707",
        y1: "56",
        x2: "151.9707",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M119.9707,56a96,96,0,0,1-96,96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M61.43952,88.00088a96.03987,96.03987,0,0,0,90.52532,63.9658",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M239.13184,212.42188l-56-112a8.0001,8.0001,0,0,0-14.31055,0L147.12378,143.817a88.01219,88.01219,0,0,1-47.15234-16.89991A103.63932,103.63932,0,0,0,127.67187,64h24.30469a8,8,0,0,0,0-16h-56V32a8,8,0,0,0-16,0V48h-56a8,8,0,0,0,0,16h87.63257a87.71326,87.71326,0,0,1-23.64038,52.34106A87.6285,87.6285,0,0,1,68.98682,85.332a7.99985,7.99985,0,1,0-15.083,5.33789A103.55961,103.55961,0,0,0,75.9856,126.93945,87.52745,87.52745,0,0,1,23.97656,144a8,8,0,0,0,0,16,103.48476,103.48476,0,0,0,64.01331-22.09045A104.14165,104.14165,0,0,0,139.43115,159.202l-26.60986,53.21985a8.00006,8.00006,0,0,0,14.31055,7.15625L140.9209,192h70.11133l13.78906,27.57813a8.00006,8.00006,0,0,0,14.31055-7.15625ZM148.9209,176l27.05566-54.11133L203.03223,176Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "231.988 216 175.988 104 119.988 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "135.98828",
        y1: "184",
        x2: "215.98828",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "87.98828",
        y1: "32",
        x2: "87.98828",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "23.98828",
        y1: "56",
        x2: "151.98828",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M119.98828,56a96,96,0,0,1-96,96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M61.4571,88.00088a96.03987,96.03987,0,0,0,90.52532,63.9658",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "231.994 216 175.994 104 119.994 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "135.99414",
        y1: "184",
        x2: "215.99414",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "87.99414",
        y1: "32",
        x2: "87.99414",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "23.99414",
        y1: "56",
        x2: "151.99414",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M119.99414,56a96,96,0,0,1-96,96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M61.463,88.00088a96.03987,96.03987,0,0,0,90.52532,63.9658",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232 216 176 104 120 216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "136",
        y1: "184",
        x2: "216",
        y2: "184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "32",
        x2: "88",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "24",
        y1: "56",
        x2: "152",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M120,56a96,96,0,0,1-96,96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M61.46882,88.00088a96.03987,96.03987,0,0,0,90.52532,63.9658",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Translate = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9_(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Translate.displayName = "Translate";

var renderPathFor$9$ = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "215.99609",
        y1: "60",
        x2: "39.99609",
        y2: "60.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "104",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "152",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M199.99609,60.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M168,60V36a16,16,0,0,0-16-16H104A16,16,0,0,0,88,36V60",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M199.99609,56.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-152Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "215.99609",
        y1: "56",
        x2: "39.99609",
        y2: "56.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "104",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "152",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M199.99609,56.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,56V40a16,16,0,0,0-16-16H104A16,16,0,0,0,88,40V56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M215.99609,48H176V40a24.02718,24.02718,0,0,0-24-24H104A24.02718,24.02718,0,0,0,80,40v8H39.99609a8,8,0,0,0,0,16h8V208a16.01833,16.01833,0,0,0,16,16h128a16.01833,16.01833,0,0,0,16-16V64h8a8,8,0,0,0,0-16ZM112,168a8,8,0,0,1-16,0V104a8,8,0,0,1,16,0Zm48,0a8,8,0,0,1-16,0V104a8,8,0,0,1,16,0Zm0-120H96V40a8.00917,8.00917,0,0,1,8-8h48a8.00917,8.00917,0,0,1,8,8Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "215.99609",
        y1: "56",
        x2: "39.99609",
        y2: "56.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "104",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "152",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M199.99609,56.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M168,56V40a16,16,0,0,0-16-16H104A16,16,0,0,0,88,40V56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "215.99609",
        y1: "56",
        x2: "39.99609",
        y2: "56.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "104",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "152",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M199.99609,56.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M168,56V40a16,16,0,0,0-16-16H104A16,16,0,0,0,88,40V56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "215.99609",
        y1: "56",
        x2: "39.99609",
        y2: "56.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "104",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "152",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M199.99609,56.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M168,56V40a16,16,0,0,0-16-16H104A16,16,0,0,0,88,40V56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Trash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$9$(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Trash.displayName = "Trash";

var renderPathFor$a0 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "215.99609",
        y1: "60",
        x2: "39.99609",
        y2: "60.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "104",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "152",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "20",
        x2: "168",
        y2: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M199.99609,60.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-148",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M199.99609,56.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-152Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "215.99609",
        y1: "56",
        x2: "39.99609",
        y2: "56.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "104",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "152",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "24",
        x2: "168",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M199.99609,56.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M88,32h80a8,8,0,0,0,0-16H88a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M216,48H40a8,8,0,0,0,0,16h8V208a16.01582,16.01582,0,0,0,16,16H192a16.01582,16.01582,0,0,0,16-16V64h8a8,8,0,0,0,0-16ZM112,168a8,8,0,0,1-16,0V104a8,8,0,0,1,16,0Zm48,0a8,8,0,0,1-16,0V104a8,8,0,0,1,16,0Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "215.99609",
        y1: "56",
        x2: "39.99609",
        y2: "56.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "104",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "152",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "24",
        x2: "168",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M199.99609,56.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "215.99609",
        y1: "56",
        x2: "39.99609",
        y2: "56.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "104",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "152",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "24",
        x2: "168",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M199.99609,56.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "215.99609",
        y1: "56",
        x2: "39.99609",
        y2: "56.00005",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "104",
        y1: "104",
        x2: "104",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "152",
        y1: "104",
        x2: "152",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "88",
        y1: "24",
        x2: "168",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M199.99609,56.00005V208a8,8,0,0,1-8,8h-128a8,8,0,0,1-8-8v-152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TrashSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$a0(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TrashSimple.displayName = "TrashSimple";

var renderPathFor$a1 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M39.99414,156H76.68043a8,8,0,0,1,5.65686,2.34315l19.3137,19.3137A8,8,0,0,0,107.30785,180h41.37258a8,8,0,0,0,5.65686-2.34315l19.3137-19.3137A8,8,0,0,1,179.30785,156h36.68629",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M76.68066,160a7.9996,7.9996,0,0,1,5.65674,2.34326l19.31348,19.31348A7.99962,7.99962,0,0,0,107.30762,184h41.373a7.9996,7.9996,0,0,0,5.65674-2.34326l19.31348-19.31348A7.99962,7.99962,0,0,1,179.30762,160h36.68652l.00586.00439V48a7.99977,7.99977,0,0,0-8-8H48a7.99977,7.99977,0,0,0-8,8V160Z",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M39.99414,160H76.68043a8,8,0,0,1,5.65686,2.34315l19.3137,19.3137A8,8,0,0,0,107.30785,184h41.37258a8,8,0,0,0,5.65686-2.34315l19.3137-19.3137A8,8,0,0,1,179.30785,160h36.68629",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.00293,32h-160a16.01833,16.01833,0,0,0-16,16V159.88379c-.00049.03906-.00586.07715-.00586.11621s.00537.07715.00586.11621V208a16.01833,16.01833,0,0,0,16,16h160a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,208.00293,32Zm0,176h-160V168l28.68066-.001,19.31446,19.31641A15.89834,15.89834,0,0,0,107.31055,192h41.373a15.89606,15.89606,0,0,0,11.31348-4.68652L179.31055,168h28.6997l.00245,40Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M39.99414,160H76.68043a8,8,0,0,1,5.65686,2.34315l19.3137,19.3137A8,8,0,0,0,107.30785,184h41.37258a8,8,0,0,0,5.65686-2.34315l19.3137-19.3137A8,8,0,0,1,179.30785,160h36.68629",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M39.99414,160H76.68043a8,8,0,0,1,5.65686,2.34315l19.3137,19.3137A8,8,0,0,0,107.30785,184h41.37258a8,8,0,0,0,5.65686-2.34315l19.3137-19.3137A8,8,0,0,1,179.30785,160h36.68629",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M39.99414,160H76.68043a8,8,0,0,1,5.65686,2.34315l19.3137,19.3137A8,8,0,0,0,107.30785,184h41.37258a8,8,0,0,0,5.65686-2.34315l19.3137-19.3137A8,8,0,0,1,179.30785,160h36.68629",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Tray = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$a1(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Tray.displayName = "Tray";

var renderPathFor$a2 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232.002 200 136.002 104 96.002 144 24.002 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "232.002 136 232.002 200 168.002 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232.002 200 136.002 104 96.002 144 24.002 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "232.002 136 232.002 200 168.002 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M238.41943,204.76245c.07862-.10571.16065-.20862.23438-.31836.08057-.1206.15088-.24585.22461-.36987.05957-.1001.12207-.19751.17724-.30029.06788-.126.125-.25538.18506-.384.05078-.1084.10547-.2146.15137-.32568.05127-.12463.09326-.25195.13867-.37842.04248-.11987.08887-.238.126-.36059.03857-.12769.06738-.25757.09912-.38672.03125-.124.06592-.24622.09131-.37244.02978-.15088.04785-.30334.06933-.45544.01465-.10645.03516-.21094.0459-.31861q.03955-.39769.04-.79712V136a8,8,0,0,0-16,0v44.686L141.65967,98.34326a8.00122,8.00122,0,0,0-11.31446,0L96.00244,132.686,29.65967,66.34326A8.00018,8.00018,0,1,0,18.34521,77.65674l72,72a8.00122,8.00122,0,0,0,11.31446,0L136.00244,115.314,212.68848,192h-44.686a8,8,0,1,0,0,16h64c.26367,0,.52735-.014.78955-.03992.11817-.01159.23242-.03369.34912-.05041.1416-.02027.28418-.03687.42481-.0647.13428-.02661.26465-.0636.39648-.09692.12061-.0304.24219-.05689.36231-.093.1289-.03931.2539-.08765.38037-.13318.12012-.043.24072-.0824.35888-.13147.11719-.04858.2295-.10547.34375-.15942.12256-.05762.2461-.11206.36622-.17627.10888-.0586.21289-.12525.31933-.18872.11768-.07032.23682-.13684.35156-.21363.11622-.078.22608-.16479.33789-.24853.09717-.07263.19678-.14014.291-.21765.18652-.153.36426-.31531.53565-.48413.01611-.016.03417-.02918.05029-.04529.02051-.02051.0376-.04321.05762-.064.16357-.167.32177-.33935.47021-.52026C238.27051,204.97192,238.34277,204.866,238.41943,204.76245Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232.002 200 136.002 104 96.002 144 24.002 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "232.002 136 232.002 200 168.002 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232.002 200 136.002 104 96.002 144 24.002 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "232.002 136 232.002 200 168.002 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232.002 200 136.002 104 96.002 144 24.002 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "232.002 136 232.002 200 168.002 200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TrendDown = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$a2(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TrendDown.displayName = "TrendDown";

var renderPathFor$a3 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232.002 56 136.002 152 96.002 112 24.002 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "232.002 120 232.002 56 168.002 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232.002 56 136.002 152 96.002 112 24.002 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "232.002 120 232.002 56 168.002 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M24.00244,192a7.97619,7.97619,0,0,0,5.65723-2.34326L96.00244,123.314l34.34277,34.34278a8.00122,8.00122,0,0,0,11.31446,0L224.00244,75.314V120a8,8,0,0,0,16,0V56.00513q0-.39918-.04-.79712c-.01074-.10767-.03125-.21216-.0459-.31861-.02148-.1521-.03955-.30444-.06933-.45532-.02539-.12646-.06006-.24853-.09131-.37256-.03174-.12915-.06055-.259-.09912-.38672-.03711-.12255-.0835-.24072-.126-.36059-.04541-.12647-.0874-.25366-.13867-.37842-.0459-.11108-.10059-.21728-.15137-.32568-.06006-.12866-.11718-.25806-.18506-.384-.05517-.10278-.11767-.20019-.17724-.30029-.07373-.124-.144-.24927-.22461-.36987-.07373-.10962-.15576-.21265-.23438-.31836-.07666-.10352-.14892-.20947-.23193-.31006-.14844-.18091-.30664-.35327-.47021-.52026-.02-.02076-.03711-.04346-.05762-.064-.01612-.01611-.03418-.0293-.05029-.04541-.17139-.1687-.34913-.331-.53565-.48389-.09375-.07714-.19287-.14453-.28955-.21679-.11279-.084-.22266-.17139-.33984-.24951-.1128-.07569-.23047-.14136-.34668-.2107-.10791-.06469-.21387-.13257-.3252-.19214-.1167-.0625-.23682-.11523-.356-.17138-.11767-.05591-.23339-.1145-.35449-.16455-.11377-.04712-.22949-.085-.34472-.12647-.13135-.04736-.26075-.09741-.395-.13794-.11377-.03442-.2295-.05932-.34424-.08862-.1377-.03516-.27442-.07324-.41455-.10107-.13037-.02588-.26221-.04078-.39356-.06006-.12695-.01856-.25195-.04248-.38086-.05494-.23193-.02294-.46484-.03271-.69824-.0354C232.061,48.00415,232.03223,48,232.00244,48h-64a8,8,0,0,0,0,16h44.686l-76.686,76.686-34.34277-34.34278a8.00122,8.00122,0,0,0-11.31446,0l-72,72A8,8,0,0,0,24.00244,192Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232.002 56 136.002 152 96.002 112 24.002 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "232.002 120 232.002 56 168.002 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232.002 56 136.002 152 96.002 112 24.002 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "232.002 120 232.002 56 168.002 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "232.002 56 136.002 152 96.002 112 24.002 184",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "232.002 120 232.002 56 168.002 56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TrendUp = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$a3(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TrendUp.displayName = "TrendUp";

var renderPathFor$a4 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M236.74219,187.96875,148.77344,35.97656a24.00413,24.00413,0,0,0-41.54688,0h.00781L19.25781,187.96875a23.9925,23.9925,0,0,0,20.76563,36.02344H215.97656a23.9925,23.9925,0,0,0,20.76563-36.02344Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Triangle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$a4(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Triangle.displayName = "Triangle";

var renderPathFor$a5 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,120H176V80h42.58374a8,8,0,0,1,7.42781,5.02887Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "144",
        x2: "176",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "180",
        cy: "192",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "76",
        cy: "192",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "156",
        y1: "192",
        x2: "100",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M52,192H24a8,8,0,0,1-8-8V72a8,8,0,0,1,8-8H176V168.33192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M176,168.33192V120h64v64a8,8,0,0,1-8,8H204",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,144H16v40a8,8,0,0,0,8,8H44a24,24,0,0,1,48,0h72a23.99048,23.99048,0,0,1,11.99813-20.78815Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M212,192a24.00631,24.00631,0,0,0-36.00187-20.78815L176,120h64v64a8,8,0,0,1-8,8H212",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M240,120H176V80h42.58374a8,8,0,0,1,7.42781,5.02887Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "144",
        x2: "176",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "192",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "192",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "164",
        y1: "192",
        x2: "92",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M44,192H24a8,8,0,0,1-8-8V72a8,8,0,0,1,8-8H176V171.21508",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,171.21508V120h64v64a8,8,0,0,1-8,8H212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M247.99682,119.94092c-.00073-.084-.00952-.168-.01269-.252-.00855-.22216-.02271-.44287-.04907-.66015-.01148-.09424-.02808-.188-.04322-.28223-.03393-.21631-.07568-.4292-.12695-.63965-.02051-.08447-.0415-.16845-.06494-.25293q-.10035-.36108-.23364-.708c-.0149-.03858-.02344-.07862-.03882-.11719l-.04956-.12354-.01075-.02734-13.928-34.82031A15.92368,15.92368,0,0,0,218.58374,72h-34.584V64a8.00039,8.00039,0,0,0-8-8h-152a16.01833,16.01833,0,0,0-16,16V184a16.01833,16.01833,0,0,0,16,16h13.0127a32.00444,32.00444,0,0,0,61.97461,0h58.02539a32.00444,32.00444,0,0,0,61.97461,0h13.01269a16.01833,16.01833,0,0,0,16-16V120C247.99975,119.98,247.99682,119.96094,247.99682,119.94092ZM183.99975,88h34.584l9.59961,24h-44.1836Zm-160-16h144v64h-144Zm44,136a16,16,0,1,1,16-16A16.01833,16.01833,0,0,1,67.99975,208Zm120,0a16,16,0,1,1,16-16A16.01833,16.01833,0,0,1,187.99975,208Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,120H176V80h42.58374a8,8,0,0,1,7.42781,5.02887Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "144",
        x2: "176",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "192",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "192",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "164",
        y1: "192",
        x2: "92",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M44,192H24a8,8,0,0,1-8-8V72a8,8,0,0,1,8-8H176V171.21508",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M176,171.21508V120h64v64a8,8,0,0,1-8,8H212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,120H176V80h42.58374a8,8,0,0,1,7.42781,5.02887Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "144",
        x2: "176",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "192",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "192",
        r: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "164",
        y1: "192",
        x2: "92",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M44,192H24a8,8,0,0,1-8-8V72a8,8,0,0,1,8-8H176V171.21508",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M176,171.21508V120h64v64a8,8,0,0,1-8,8H212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240,120H176V80h42.58374a8,8,0,0,1,7.42781,5.02887Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "144",
        x2: "176",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "192",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "68",
        cy: "192",
        r: "24",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "164",
        y1: "192",
        x2: "92",
        y2: "192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M44,192H24a8,8,0,0,1-8-8V72a8,8,0,0,1,8-8H176V171.21508",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M176,171.21508V120h64v64a8,8,0,0,1-8,8H212",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Truck = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$a5(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Truck.displayName = "Truck";

var renderPathFor$a6 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M165.1036,200H122.8964a8,8,0,0,0-5.12148,1.85423L72,240V200H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.253a8,8,0,0,1-2.87852,6.14577l-42.89641,35.747A8,8,0,0,1,165.1036,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "88.00002",
        x2: "168",
        y2: "136.00002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "88.00002",
        x2: "120",
        y2: "136.00002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M165.1036,200H122.8964a8,8,0,0,0-5.12148,1.85423L72,240V200H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.253a8,8,0,0,1-2.87852,6.14577l-42.89641,35.747A8,8,0,0,1,165.1036,200Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M165.1036,200H122.8964a8,8,0,0,0-5.12148,1.85423L72,240V200H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.253a8,8,0,0,1-2.87852,6.14577l-42.89641,35.747A8,8,0,0,1,165.1036,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "88.00002",
        x2: "168",
        y2: "136.00002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "88.00002",
        x2: "120",
        y2: "136.00002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V192a16.01833,16.01833,0,0,0,16,16H64v32a7.99949,7.99949,0,0,0,13.12109,6.14551L122.89648,208h42.207a16.03033,16.03033,0,0,0,10.24316-3.709l42.896-35.7461A15.958,15.958,0,0,0,224,156.253V48A16.01833,16.01833,0,0,0,208,32ZM128,136a8,8,0,0,1-16,0V88a8,8,0,0,1,16,0Zm48,0a8,8,0,0,1-16,0V88a8,8,0,0,1,16,0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M165.1036,200H122.8964a8,8,0,0,0-5.12148,1.85423L72,240V200H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.253a8,8,0,0,1-2.87852,6.14577l-42.89641,35.747A8,8,0,0,1,165.1036,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "88.00002",
        x2: "168",
        y2: "136.00002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "88.00002",
        x2: "120",
        y2: "136.00002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M165.1036,200H122.8964a8,8,0,0,0-5.12148,1.85423L72,240V200H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.253a8,8,0,0,1-2.87852,6.14577l-42.89641,35.747A8,8,0,0,1,165.1036,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "88.00002",
        x2: "168",
        y2: "136.00002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "88.00002",
        x2: "120",
        y2: "136.00002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M165.1036,200H122.8964a8,8,0,0,0-5.12148,1.85423L72,240V200H48a8,8,0,0,1-8-8V48a8,8,0,0,1,8-8H208a8,8,0,0,1,8,8V156.253a8,8,0,0,1-2.87852,6.14577l-42.89641,35.747A8,8,0,0,1,165.1036,200Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "168",
        y1: "88.00002",
        x2: "168",
        y2: "136.00002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "120",
        y1: "88.00002",
        x2: "120",
        y2: "136.00002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TwitchLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$a6(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TwitchLogo.displayName = "TwitchLogo";

var renderPathFor$a7 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240.00526,60.66136A127.734,127.734,0,0,1,207.91934,92.591l-.0001-.00015A128.04082,128.04082,0,0,1,17.97784,199.99759l.0065-.01172a127.3714,127.3714,0,0,0,70.01685-22.14062l-.00076.00111A128.2051,128.2051,0,0,1,36.64049,37.72648l-.00039.00025A127.98517,127.98517,0,0,0,128.82832,95.1112l-.0028.00058a40.009,40.009,0,0,1,74.03809-27.81035l.00013.00442a128.63506,128.63506,0,0,0,37.14152-6.64449",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240.00526,60.66136A127.734,127.734,0,0,1,207.91934,92.591l-.0001-.00015A128.04082,128.04082,0,0,1,17.97784,199.99759l.0065-.01172a127.3714,127.3714,0,0,0,70.01685-22.14062l-.00076.00111A128.2051,128.2051,0,0,1,36.64049,37.72648l-.00039.00025A127.98517,127.98517,0,0,0,128.82832,95.1112l-.0028.00058a40.009,40.009,0,0,1,74.03809-27.81035l.00013.00442a128.63506,128.63506,0,0,0,37.14152-6.64449",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M240.00526,60.66136A127.734,127.734,0,0,1,207.91934,92.591l-.0001-.00015A128.04082,128.04082,0,0,1,17.97784,199.99759l.0065-.01172a127.3714,127.3714,0,0,0,70.01685-22.14062l-.00076.00111A128.2051,128.2051,0,0,1,36.64049,37.72648l-.00039.00025A127.98517,127.98517,0,0,0,128.82832,95.1112l-.0028.00058a40.009,40.009,0,0,1,74.03809-27.81035l.00013.00442a128.63506,128.63506,0,0,0,37.14152-6.64449",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M246.41211,55.87061a7.99856,7.99856,0,0,0-8.95459-2.793,120.50746,120.50746,0,0,1-30.34131,6.01465,48.00284,48.00284,0,0,0-87.11963,26.51123A119.68665,119.68665,0,0,1,43.3457,33.36279a8.00016,8.00016,0,0,0-14.41455,2.22657A136.21055,136.21055,0,0,0,73.793,177.19482a119.46448,119.46448,0,0,1-55.93018,14.792,8.00707,8.00707,0,0,0-3.76709,15.00586A136.02811,136.02811,0,0,0,215.71631,96.85742a135.60493,135.60493,0,0,0,30.84228-31.60791A7.99891,7.99891,0,0,0,246.41211,55.87061Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240.00526,60.66136A127.734,127.734,0,0,1,207.91934,92.591l-.0001-.00015A128.04082,128.04082,0,0,1,17.97784,199.99759l.0065-.01172a127.3714,127.3714,0,0,0,70.01685-22.14062l-.00076.00111A128.2051,128.2051,0,0,1,36.64049,37.72648l-.00039.00025A127.98517,127.98517,0,0,0,128.82832,95.1112l-.0028.00058a40.009,40.009,0,0,1,74.03809-27.81035l.00013.00442a128.63506,128.63506,0,0,0,37.14152-6.64449",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240.00526,60.66136A127.734,127.734,0,0,1,207.91934,92.591l-.0001-.00015A128.04082,128.04082,0,0,1,17.97784,199.99759l.0065-.01172a127.3714,127.3714,0,0,0,70.01685-22.14062l-.00076.00111A128.2051,128.2051,0,0,1,36.64049,37.72648l-.00039.00025A127.98517,127.98517,0,0,0,128.82832,95.1112l-.0028.00058a40.009,40.009,0,0,1,74.03809-27.81035l.00013.00442a128.63506,128.63506,0,0,0,37.14152-6.64449",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240.00526,60.66136A127.734,127.734,0,0,1,207.91934,92.591l-.0001-.00015A128.04082,128.04082,0,0,1,17.97784,199.99759l.0065-.01172a127.3714,127.3714,0,0,0,70.01685-22.14062l-.00076.00111A128.2051,128.2051,0,0,1,36.64049,37.72648l-.00039.00025A127.98517,127.98517,0,0,0,128.82832,95.1112l-.0028.00058a40.009,40.009,0,0,1,74.03809-27.81035l.00013.00442a128.63506,128.63506,0,0,0,37.14152-6.64449",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var TwitterLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$a7(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
TwitterLogo.displayName = "TwitterLogo";

var renderPathFor$a8 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M172,128h52a8,8,0,0,1,8,8v64a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8V136a8,8,0,0,1,8-8H84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "80 72 128 24 176 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "24",
        y: "128",
        width: "208",
        height: "80",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M176,128h48a8,8,0,0,1,8,8v64a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8V136a8,8,0,0,1,8-8H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "80 72 128 24 176 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M85.65674,77.65723,120,43.31348V128a8,8,0,0,0,16,0V43.31348l34.34326,34.34375a8.00018,8.00018,0,0,0,11.31348-11.31446l-48-48c-.023-.02246-.04785-.0415-.0708-.064-.165-.16113-.33545-.31787-.51416-.46485-.09619-.07861-.19776-.14746-.29639-.22119-.11035-.08252-.21826-.168-.333-.24511-.11377-.07618-.23242-.14209-.34912-.21192-.10742-.06445-.2124-.13183-.32324-.19092-.11572-.062-.23535-.11425-.35352-.17041-.11865-.05615-.23584-.11523-.35742-.166-.11181-.0459-.22558-.083-.33887-.12354-.1333-.04834-.26513-.09961-.40185-.14062-.10889-.0332-.21973-.05664-.33008-.085-.14258-.03662-.28369-.07617-.42969-.105-.12109-.02393-.24365-.0376-.36523-.05567-.13623-.0205-.271-.04541-.40918-.05908-.20215-.01953-.40479-.02637-.60742-.03076C128.11768,16.00781,128.05957,16,128,16s-.11768.00781-.17676.00879c-.20263.00439-.40527.01123-.60742.03076-.13818.01367-.27295.03858-.40918.05908-.12158.01807-.24414.03174-.36523.05567-.146.02881-.28711.06836-.42969.105-.11035.02832-.22119.05176-.33008.085-.13672.041-.26855.09228-.40185.14062-.11329.04053-.22706.07764-.33887.12354-.12158.05078-.23877.10986-.35742.166-.11817.05616-.2378.1084-.35352.17041-.11084.05909-.21582.12647-.32324.19092-.1167.06983-.23535.13574-.34912.21192-.11475.07714-.22266.16259-.333.24511-.09863.07373-.2002.14258-.29639.22119-.17578.14454-.34277.29834-.50537.457-.02588.0249-.0542.04638-.07959.07177l-48,48A8.00018,8.00018,0,0,0,85.65674,77.65723Z"
      }), React__default.createElement("path", {
        d: "M224,120H152v8a24,24,0,0,1-48,0v-8H32a16.01833,16.01833,0,0,0-16,16v64a16.01833,16.01833,0,0,0,16,16H224a16.01833,16.01833,0,0,0,16-16V136A16.01833,16.01833,0,0,0,224,120Zm-35.99951,60a12,12,0,1,1,12-12A12,12,0,0,1,188.00049,180Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,128h48a8,8,0,0,1,8,8v64a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8V136a8,8,0,0,1,8-8H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "80 72 128 24 176 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,128h48a8,8,0,0,1,8,8v64a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8V136a8,8,0,0,1,8-8H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "80 72 128 24 176 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M176,128h48a8,8,0,0,1,8,8v64a8,8,0,0,1-8,8H32a8,8,0,0,1-8-8V136a8,8,0,0,1,8-8H80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "128",
        x2: "128",
        y2: "24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "80 72 128 24 176 72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "188",
        cy: "168",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Upload = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$a8(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Upload.displayName = "Upload";

var renderPathFor$a9 = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "86 81.971 128 39.971 170 81.971",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "152",
        x2: "128",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M224,136v72a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "86 81.971 128 39.971 170 81.971",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "152",
        x2: "128",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,136v72a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M91.65674,87.62793,120,59.2843V152a8,8,0,0,0,16,0V59.2843l28.34326,28.34363a8.00018,8.00018,0,1,0,11.31348-11.31445l-42-42a8.0018,8.0018,0,0,0-11.31348,0l-42,42A8.00018,8.00018,0,1,0,91.65674,87.62793Z"
      }), React__default.createElement("path", {
        d: "M224,128a8.00039,8.00039,0,0,0-8,8v72H40V136a8,8,0,0,0-16,0v72a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V136A8.00039,8.00039,0,0,0,224,128Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "86 81.971 128 39.971 170 81.971",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "152",
        x2: "128",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M224,136v72a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "86 81.971 128 39.971 170 81.971",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "152",
        x2: "128",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M224,136v72a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polyline", {
        points: "86 81.971 128 39.971 170 81.971",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "152",
        x2: "128",
        y2: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M224,136v72a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var UploadSimple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$a9(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
UploadSimple.displayName = "UploadSimple";

var renderPathFor$aa = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "64",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "64",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M231.93652,211.98633a120.48718,120.48718,0,0,0-67.12-54.14258,72.00007,72.00007,0,1,0-73.63294,0,120.48813,120.48813,0,0,0-67.11865,54.14062,7.99981,7.99981,0,0,0,6.92432,12.00635l194.023.002a7.99957,7.99957,0,0,0,6.92431-12.00635Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "64",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "64",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var User = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$aa(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
User.displayName = "User";

var renderPathFor$ab = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32A96.00088,96.00088,0,0,0,63.79883,199.375v-.001A71.99731,71.99731,0,0,1,128,160a40,40,0,1,1,40-40,40.0001,40.0001,0,0,1-40,40,71.99731,71.99731,0,0,1,64.20117,39.374A96.0002,96.0002,0,0,0,128,32Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "44"
      }), React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.11791,104.11791,0,0,0,128,24Zm65.75806,162.41016a79.70266,79.70266,0,0,0-24.43091-22.97461,59.83641,59.83641,0,0,1-82.6543,0A79.7048,79.7048,0,0,0,62.2417,186.41016a88.00015,88.00015,0,1,1,131.51636,0Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var UserCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ab(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
UserCircle.displayName = "UserCircle";

var renderPathFor$ac = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "200",
        y2: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "180.97887",
        y2: "49.81966",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "188.24429",
        y2: "72.18034",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "211.75571",
        y2: "72.18034",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "219.02113",
        y2: "49.81966",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M223.31831,116.5001A96.987,96.987,0,0,1,224,128a96,96,0,1,1-96-96q4.50554,0,8.90843.40785",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M205.30634,71.08008A15.965,15.965,0,0,1,184.92,50.6936,96.001,96.001,0,0,0,63.79883,199.375v-.001A71.99731,71.99731,0,0,1,128,160a40,40,0,1,1,40-40,40.0001,40.0001,0,0,1-40,40,71.99731,71.99731,0,0,1,64.20117,39.374A96.002,96.002,0,0,0,205.30634,71.08008Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "56",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "48",
        x2: "175.75129",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "64",
        x2: "175.75129",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "72",
        x2: "200",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "64",
        x2: "224.24871",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "48",
        x2: "224.24871",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M223.31831,116.5001A96.987,96.987,0,0,1,224,128a96,96,0,1,1-96-96q4.50554,0,8.90843.40785",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,76a44,44,0,1,1-44,44A44,44,0,0,1,128,76Zm103.17676-2a7.99671,7.99671,0,0,1-10.92822,2.92822l-4.66822-2.69531A24.0036,24.0036,0,0,1,208,78.624V84a8,8,0,0,1-16,0V78.624a24.0036,24.0036,0,0,1-7.58032-4.39111l-4.66822,2.69531a8,8,0,0,1-8-13.85644l4.65687-2.68872a23.72829,23.72829,0,0,1,0-8.76612l-4.65687-2.68872a8,8,0,0,1,8-13.85644l4.66822,2.69531A24.0036,24.0036,0,0,1,192,33.376V28a8,8,0,0,1,16,0v5.376a24.0036,24.0036,0,0,1,7.58032,4.39111l4.66822-2.69531a8,8,0,1,1,8,13.85644l-4.65687,2.68872a23.72829,23.72829,0,0,1,0,8.76612l4.65687,2.68872A8.00037,8.00037,0,0,1,231.17676,74ZM200,64a8,8,0,1,0-8-8A8.00917,8.00917,0,0,0,200,64Zm22.37012,44.5564a7.99991,7.99991,0,0,0-6.99512,8.89209A89.40475,89.40475,0,0,1,216,128a87.63852,87.63852,0,0,1-22.24194,58.41064,79.70677,79.70677,0,0,0-24.431-22.97485,59.83657,59.83657,0,0,1-82.65418-.00024A79.7048,79.7048,0,0,0,62.2417,186.41016,87.9498,87.9498,0,0,1,128,40c2.72656,0,5.477.126,8.1748.37427a8.00012,8.00012,0,0,0,1.4668-15.93286C134.4585,24.14844,131.21436,24,128,24A103.95123,103.95123,0,0,0,57.81982,204.68091a7.93384,7.93384,0,0,0,1.32544,1.18921,103.78418,103.78418,0,0,0,137.71155-.002,7.935,7.935,0,0,0,1.31983-1.18383A103.74663,103.74663,0,0,0,232,128a105.40092,105.40092,0,0,0-.73828-12.44849A8,8,0,0,0,222.37012,108.5564Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "56",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "48",
        x2: "175.75129",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "64",
        x2: "175.75129",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "72",
        x2: "200",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "64",
        x2: "224.24871",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "48",
        x2: "224.24871",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M223.31831,116.5001A96.987,96.987,0,0,1,224,128a96,96,0,1,1-96-96q4.50554,0,8.90843.40785",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "56",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "48",
        x2: "175.75129",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "64",
        x2: "175.75129",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "72",
        x2: "200",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "64",
        x2: "224.24871",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "48",
        x2: "224.24871",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M223.31831,116.5001A96.987,96.987,0,0,1,224,128a96,96,0,1,1-96-96q4.50554,0,8.90843.40785",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "56",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "48",
        x2: "175.75129",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "64",
        x2: "175.75129",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "72",
        x2: "200",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "64",
        x2: "224.24871",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "48",
        x2: "224.24871",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M223.31831,116.5001A96.987,96.987,0,0,1,224,128a96,96,0,1,1-96-96q4.50554,0,8.90843.40785",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var UserCircleGear = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ac(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
UserCircleGear.displayName = "UserCircleGear";

var renderPathFor$ad = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M218.5374,96A95.90174,95.90174,0,1,1,143.13974,33.187",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32A96.00088,96.00088,0,0,0,63.79883,199.375v-.001A71.99731,71.99731,0,0,1,128,160a40,40,0,1,1,40-40,40.0001,40.0001,0,0,1-40,40,71.99731,71.99731,0,0,1,64.20117,39.374A96.0002,96.0002,0,0,0,128,32Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M218.5374,96A95.90174,95.90174,0,1,1,143.13974,33.187",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,76a44,44,0,1,1-44,44A43.99983,43.99983,0,0,1,128,76Zm48-12h48a8,8,0,0,0,0-16H176a8,8,0,0,0,0,16Zm39.87158,24.457a8.00076,8.00076,0,0,0-4.87695,10.209,88.016,88.016,0,0,1-17.23645,87.74414,79.7044,79.7044,0,0,0-24.431-22.97461,59.83641,59.83641,0,0,1-82.6543,0A79.70345,79.70345,0,0,0,62.2417,186.41016,87.9498,87.9498,0,0,1,128,40a89.04252,89.04252,0,0,1,13.8877,1.08838,7.99994,7.99994,0,0,0,2.5039-15.80274A104.08275,104.08275,0,0,0,24,128a103.74716,103.74716,0,0,0,33.81934,76.68066,7.94507,7.94507,0,0,0,1.32629,1.18946,103.784,103.784,0,0,0,137.71252-.00293,7.94633,7.94633,0,0,0,1.31678-1.18115A104.0138,104.0138,0,0,0,226.08008,93.334,8.00062,8.00062,0,0,0,215.87158,88.457Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M218.5374,96A95.90174,95.90174,0,1,1,143.13974,33.187",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M218.5374,96A95.90174,95.90174,0,1,1,143.13974,33.187",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M218.5374,96A95.90174,95.90174,0,1,1,143.13974,33.187",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var UserCircleMinus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ad(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
UserCircleMinus.displayName = "UserCircleMinus";

var renderPathFor$ae = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "32",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M222.81257,112.85778a95.9029,95.9029,0,1,1-79.67019-79.67033",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,32A96.00088,96.00088,0,0,0,63.79883,199.375v-.001A71.99731,71.99731,0,0,1,128,160a40,40,0,1,1,40-40,40.0001,40.0001,0,0,1-40,40,71.99731,71.99731,0,0,1,64.20117,39.374A96.0002,96.0002,0,0,0,128,32Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "32",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M222.81257,112.85778a95.9029,95.9029,0,1,1-79.67019-79.67033",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,76a44,44,0,1,1-44,44A43.99983,43.99983,0,0,1,128,76Zm48-12h16V80a8,8,0,0,0,16,0V64h16a8,8,0,0,0,0-16H208V32a8,8,0,0,0-16,0V48H176a8,8,0,0,0,0,16Zm45.56006,40.95605a8.00039,8.00039,0,0,0-6.64893,9.15381A89.00044,89.00044,0,0,1,216,128a87.63672,87.63672,0,0,1-22.24182,58.41016,79.7044,79.7044,0,0,0-24.431-22.97461,59.83641,59.83641,0,0,1-82.6543,0A79.70345,79.70345,0,0,0,62.2417,186.41016,87.9498,87.9498,0,0,1,128,40a89.02966,89.02966,0,0,1,13.89062,1.08887,7.99994,7.99994,0,1,0,2.50391-15.80274A104.0826,104.0826,0,0,0,24,128a103.74716,103.74716,0,0,0,33.81934,76.68066,7.94507,7.94507,0,0,0,1.32629,1.18946,103.784,103.784,0,0,0,137.71252-.00293,7.94633,7.94633,0,0,0,1.31678-1.18115A103.74751,103.74751,0,0,0,232,128a105.04749,105.04749,0,0,0-1.28613-16.39453A7.99752,7.99752,0,0,0,221.56006,104.95605Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "32",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M222.81257,112.85778a95.9029,95.9029,0,1,1-79.67019-79.67033",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "32",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M222.81257,112.85778a95.9029,95.9029,0,1,1-79.67019-79.67033",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M63.79905,199.37405a72.02812,72.02812,0,0,1,128.40177-.00026",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "32",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M222.81257,112.85778a95.9029,95.9029,0,1,1-79.67019-79.67033",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var UserCirclePlus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ae(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
UserCirclePlus.displayName = "UserCirclePlus";

var renderPathFor$af = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "200",
        y2: "36",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "180.97887",
        y2: "49.81966",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "188.24429",
        y2: "72.18034",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "211.75571",
        y2: "72.18034",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "219.02113",
        y2: "49.81966",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M186.62671,121.70942a63.97327,63.97327,0,1,1-49.76733-89.10119",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "64",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "56",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "48",
        x2: "175.75129",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "64",
        x2: "175.75129",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "72",
        x2: "200",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "64",
        x2: "224.24871",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "48",
        x2: "224.24871",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M186.62671,121.70942a63.97327,63.97327,0,1,1-49.76733-89.10119",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M168.82324,74a7.99606,7.99606,0,0,0,10.92822,2.92822l4.66822-2.69519A23.999,23.999,0,0,0,192,78.6239V84a8,8,0,0,0,16,0V78.6239a23.999,23.999,0,0,0,7.58032-4.39087l4.66822,2.69519a8,8,0,0,0,8-13.85644l-4.65674-2.68866a23.73636,23.73636,0,0,0,0-8.76624l4.65674-2.68866a8,8,0,1,0-8-13.85644L215.58032,37.767A23.999,23.999,0,0,0,208,33.3761V28a8,8,0,0,0-16,0v5.3761a23.999,23.999,0,0,0-7.58032,4.39087l-4.66822-2.69519a8,8,0,0,0-8,13.85644l4.65674,2.68866a23.73636,23.73636,0,0,0,0,8.76624l-4.65674,2.68866A8.00032,8.00032,0,0,0,168.82324,74ZM200,48a8,8,0,1,1-8,8A8.00917,8.00917,0,0,1,200,48Z"
      }), React__default.createElement("path", {
        d: "M231.93652,211.98633a120.48718,120.48718,0,0,0-67.12-54.14258,72.17933,72.17933,0,0,0,34.18786-49.8808,24.03068,24.03068,0,0,1-20.874-14.07977q-1.18011.11783-2.37158.11828a24.02578,24.02578,0,0,1-19.51672-38.00152,24.06161,24.06161,0,0,1-1.27454-26.0011c.11694-.20264.24707-.3949.36963-.59326A71.9779,71.9779,0,0,0,91.18359,157.84375a120.48811,120.48811,0,0,0-67.11865,54.14063,7.99981,7.99981,0,0,0,6.92432,12.00634l194.023.002a7.99957,7.99957,0,0,0,6.92431-12.00635Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "200",
        cy: "56",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "48",
        x2: "175.75129",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "64",
        x2: "175.75129",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "72",
        x2: "200",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "64",
        x2: "224.24871",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "48",
        x2: "224.24871",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M186.62671,121.70942a63.97327,63.97327,0,1,1-49.76733-89.10119",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "200",
        cy: "56",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "48",
        x2: "175.75129",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "64",
        x2: "175.75129",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "72",
        x2: "200",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "64",
        x2: "224.24871",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "48",
        x2: "224.24871",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M186.62671,121.70942a63.97327,63.97327,0,1,1-49.76733-89.10119",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "200",
        cy: "56",
        r: "16",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "40",
        x2: "200",
        y2: "28",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "48",
        x2: "175.75129",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "186.14359",
        y1: "64",
        x2: "175.75129",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "72",
        x2: "200",
        y2: "84",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "64",
        x2: "224.24871",
        y2: "70",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "213.85641",
        y1: "48",
        x2: "224.24871",
        y2: "42",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M186.62671,121.70942a63.97327,63.97327,0,1,1-49.76733-89.10119",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var UserGear = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$af(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
UserGear.displayName = "UserGear";

var renderPathFor$ag = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M192,96a63.929,63.929,0,1,1-49.22128-62.2852",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "64",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M192,96a63.929,63.929,0,1,1-49.22128-62.2852",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M176,64h48a8,8,0,0,0,0-16H176a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M231.93652,211.98633a120.48718,120.48718,0,0,0-67.12-54.14258A71.86434,71.86434,0,0,0,198.18579,80H176a23.99523,23.99523,0,0,1-10.62024-45.51459A71.97718,71.97718,0,1,0,91.18359,157.84375a120.48811,120.48811,0,0,0-67.11865,54.14063,7.99981,7.99981,0,0,0,6.92432,12.00634l194.023.002a7.99957,7.99957,0,0,0,6.92431-12.00635Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M192,96a63.929,63.929,0,1,1-49.22128-62.2852",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M192,96a63.929,63.929,0,1,1-49.22128-62.2852",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M192,96a63.929,63.929,0,1,1-49.22128-62.2852",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var UserMinus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ag(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
UserMinus.displayName = "UserMinus";

var renderPathFor$ah = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "32",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M188.05124,118.18275a63.96647,63.96647,0,1,1-45.27249-84.46794",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "96",
        r: "64",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "32",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M188.05124,118.18275a63.96647,63.96647,0,1,1-45.27249-84.46794",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M176,64h16V80a8,8,0,0,0,16,0V64h16a8,8,0,0,0,0-16H208V32a8,8,0,0,0-16,0V48H176a8,8,0,0,0,0,16Z"
      }), React__default.createElement("path", {
        d: "M231.93652,211.98633a120.48718,120.48718,0,0,0-67.12-54.14258,72.111,72.111,0,0,0,34.73474-53.85516A24.02341,24.02341,0,0,1,176,80a23.99523,23.99523,0,0,1-10.62024-45.51459A71.97718,71.97718,0,1,0,91.18359,157.84375a120.48811,120.48811,0,0,0-67.11865,54.14063,7.99981,7.99981,0,0,0,6.92432,12.00634l194.023.002a7.99957,7.99957,0,0,0,6.92431-12.00635Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "32",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M188.05124,118.18275a63.96647,63.96647,0,1,1-45.27249-84.46794",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "32",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M188.05124,118.18275a63.96647,63.96647,0,1,1-45.27249-84.46794",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "176",
        y1: "56",
        x2: "224",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "32",
        x2: "200",
        y2: "80",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M30.989,215.99064a112.03731,112.03731,0,0,1,194.02311.002",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M188.05124,118.18275a63.96647,63.96647,0,1,1-45.27249-84.46794",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var UserPlus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ah(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
UserPlus.displayName = "UserPlus";

var renderPathFor$ai = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M63.48467,207.999a72.02867,72.02867,0,0,1,129.03066,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M216,48H40a8,8,0,0,0-8,8V200a8,8,0,0,0,8,8H60.09857v-.00439A72.02979,72.02979,0,0,1,128,160a40,40,0,1,1,40-40,40.00006,40.00006,0,0,1-40,40,72.02986,72.02986,0,0,1,67.90149,47.99561V208H216a8,8,0,0,0,8-8V56A8,8,0,0,0,216,48Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M60.09854,207.99545a72.02945,72.02945,0,0,1,135.80292,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "44"
      }), React__default.createElement("path", {
        d: "M216,40H40A16.01833,16.01833,0,0,0,24,56V200a16.01833,16.01833,0,0,0,16,16H216a16.01833,16.01833,0,0,0,16-16V56A16.01833,16.01833,0,0,0,216,40Zm0,160H201.32227a80.03059,80.03059,0,0,0-32.05469-36.50757,59.83658,59.83658,0,0,1-82.53516,0A80.03059,80.03059,0,0,0,54.67773,200H40V56H216l.01025,143.99951Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M60.09854,207.99545a72.02945,72.02945,0,0,1,135.80292,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M60.09854,207.99545a72.02945,72.02945,0,0,1,135.80292,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "32",
        y: "48",
        width: "192",
        height: "160",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M60.09854,207.99545a72.02945,72.02945,0,0,1,135.80292,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var UserRectangle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ai(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
UserRectangle.displayName = "UserRectangle";

var renderPathFor$aj = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M57.78418,215.99979a72.02025,72.02025,0,0,1,140.43164,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208,40H48a8,8,0,0,0-8,8V208a8,8,0,0,0,8,8H208a8,8,0,0,0,8-8V48A8,8,0,0,0,208,40ZM57.78418,215.99976A72.0276,72.0276,0,0,1,128,160a40,40,0,1,1,40-40,40.00006,40.00006,0,0,1-40,40,72.02755,72.02755,0,0,1,70.21582,55.99976Z",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M57.78418,215.99979a72.02025,72.02025,0,0,1,140.43164,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "44"
      }), React__default.createElement("path", {
        d: "M208,32H48A16.01833,16.01833,0,0,0,32,48V208a16.01833,16.01833,0,0,0,16,16H208a16.01833,16.01833,0,0,0,16-16V48A16.01833,16.01833,0,0,0,208,32Zm0,176h-3.67322a80.44452,80.44452,0,0,0-26.069-38.24561,79.23073,79.23073,0,0,0-8.98218-6.26953,59.83684,59.83684,0,0,1-82.55126,0,79.23073,79.23073,0,0,0-8.98218,6.26953A80.44452,80.44452,0,0,0,51.67322,208H48V48H208l.01025,159.99951Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M57.78418,215.99979a72.02025,72.02025,0,0,1,140.43164,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M57.78418,215.99979a72.02025,72.02025,0,0,1,140.43164,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "120",
        r: "40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("path", {
        d: "M57.78418,215.99979a72.02025,72.02025,0,0,1,140.43164,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var UserSquare = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$aj(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
UserSquare.displayName = "UserSquare";

var renderPathFor$ak = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88",
        cy: "108",
        r: "52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M155.41251,57.937A52.00595,52.00595,0,1,1,169.52209,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M16,197.39665a88.013,88.013,0,0,1,144-.0055",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M169.52209,160a87.89491,87.89491,0,0,1,72.00032,37.3912",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88.00033",
        cy: "108",
        r: "52",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "88.00033",
        cy: "108",
        r: "52",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M155.41251,57.937A52.00595,52.00595,0,1,1,169.52209,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M15.99613,197.39669a88.01736,88.01736,0,0,1,144.00452-.00549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M169.52209,160a87.89491,87.89491,0,0,1,72.00032,37.3912",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M121.19873,157.94751a59.99994,59.99994,0,1,0-66.39661,0A96.21448,96.21448,0,0,0,9.45459,192.791a8.0002,8.0002,0,0,0,6.542,12.60546l144.0044-.00537a7.99991,7.99991,0,0,0,6.54052-12.606A96.21491,96.21491,0,0,0,121.19873,157.94751Z"
      }), React__default.createElement("path", {
        d: "M248.06348,192.78516a96.214,96.214,0,0,0-45.34327-34.83765A60.00088,60.00088,0,0,0,153.24707,50.23535a8,8,0,0,0-4.251,12.47852,75.83151,75.83151,0,0,1,3.84082,84.88623,8,8,0,0,0,2.04493,10.60107,113.20643,113.20643,0,0,1,8.74365,7.2146c.14429.15674.28979.31275.44873.46021a112.03418,112.03418,0,0,1,25.479,34.90527,7.99971,7.99971,0,0,0,7.24951,4.61523l44.72071-.00537a8.0001,8.0001,0,0,0,6.54-12.606Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88.00033",
        cy: "108",
        r: "52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M155.41251,57.937A52.00595,52.00595,0,1,1,169.52209,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M15.99613,197.39669a88.01736,88.01736,0,0,1,144.00452-.00549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M169.52209,160a87.89491,87.89491,0,0,1,72.00032,37.3912",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88.00033",
        cy: "108",
        r: "52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M155.41251,57.937A52.00595,52.00595,0,1,1,169.52209,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M15.99613,197.39669a88.01736,88.01736,0,0,1,144.00452-.00549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M169.52209,160a87.89491,87.89491,0,0,1,72.00032,37.3912",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "88.00033",
        cy: "108",
        r: "52",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M155.41251,57.937A52.00595,52.00595,0,1,1,169.52209,160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M15.99613,197.39669a88.01736,88.01736,0,0,1,144.00452-.00549",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M169.52209,160a87.89491,87.89491,0,0,1,72.00032,37.3912",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Users = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ak(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Users.displayName = "Users";

var renderPathFor$al = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "76",
        width: "176",
        height: "104",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "220.00244",
        y1: "100",
        x2: "220.00244",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "36",
        y1: "100",
        x2: "36",
        y2: "156",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "80",
        width: "176",
        height: "96",
        rx: "16",
        transform: "translate(256) rotate(90)",
        opacity: "0.2"
      }), React__default.createElement("rect", {
        x: "40",
        y: "80",
        width: "176",
        height: "96",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "208.00244",
        y1: "88",
        x2: "208.00244",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "240.00244",
        y1: "104",
        x2: "240.00244",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "88",
        x2: "48",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "104",
        x2: "16",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("rect", {
        x: "71.99951",
        y: "32",
        width: "112",
        height: "192",
        rx: "24"
      }), React__default.createElement("path", {
        d: "M208.00244,80a8.00039,8.00039,0,0,0-8,8v80a8,8,0,0,0,16,0V88A8.00039,8.00039,0,0,0,208.00244,80Z"
      }), React__default.createElement("path", {
        d: "M240.00244,96a8.00039,8.00039,0,0,0-8,8v48a8,8,0,0,0,16,0V104A8.00039,8.00039,0,0,0,240.00244,96Z"
      }), React__default.createElement("path", {
        d: "M47.99951,80a8.00039,8.00039,0,0,0-8,8v80a8,8,0,0,0,16,0V88A8.00039,8.00039,0,0,0,47.99951,80Z"
      }), React__default.createElement("path", {
        d: "M15.99951,96a8.00039,8.00039,0,0,0-8,8v48a8,8,0,0,0,16,0V104A8.00039,8.00039,0,0,0,15.99951,96Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "80",
        width: "176",
        height: "96",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "208.00244",
        y1: "88",
        x2: "208.00244",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "240.00244",
        y1: "104",
        x2: "240.00244",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "88",
        x2: "48",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "104",
        x2: "16",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "80",
        width: "176",
        height: "96",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "208.00244",
        y1: "88",
        x2: "208.00244",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "240.00244",
        y1: "104",
        x2: "240.00244",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "88",
        x2: "48",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "104",
        x2: "16",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "80",
        width: "176",
        height: "96",
        rx: "16",
        transform: "translate(256) rotate(90)",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React__default.createElement("line", {
        x1: "208.00244",
        y1: "88",
        x2: "208.00244",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "240.00244",
        y1: "104",
        x2: "240.00244",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "88",
        x2: "48",
        y2: "168",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "16",
        y1: "104",
        x2: "16",
        y2: "152",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Vibrate = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$al(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Vibrate.displayName = "Vibrate";

var renderPathFor$am = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M24,60H152a32,32,0,0,1,32,32v96a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68A8,8,0,0,1,24,60Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "184 112 240 80 240 176 184 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M24,60H152a32,32,0,0,1,32,32v96a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68A8,8,0,0,1,24,60Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M24,60H152a32,32,0,0,1,32,32v96a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68A8,8,0,0,1,24,60Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "184 112 240 80 240 176 184 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M244.01562,73.08105a8.001,8.001,0,0,0-7.98437-.02734L192,98.21436V92a40.04584,40.04584,0,0,0-40-40H24A16.01833,16.01833,0,0,0,8,68v96a40.04584,40.04584,0,0,0,40,40H176a16.01833,16.01833,0,0,0,16-16V157.78564l44.03125,25.16065A8.0003,8.0003,0,0,0,248,176V80A7.99807,7.99807,0,0,0,244.01562,73.08105ZM232,162.21484,192,139.3573V116.6427l40-22.85754Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M24,60H152a32,32,0,0,1,32,32v96a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68A8,8,0,0,1,24,60Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "184 112 240 80 240 176 184 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M24,60H152a32,32,0,0,1,32,32v96a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68A8,8,0,0,1,24,60Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "184 112 240 80 240 176 184 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M24,60H152a32,32,0,0,1,32,32v96a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68A8,8,0,0,1,24,60Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "184 112 240 80 240 176 184 144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var VideoCamera = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$am(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
VideoCamera.displayName = "VideoCamera";

var renderPathFor$an = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "240 176 184 144 184 112 240 80 240 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "34.9091",
        y1: "24",
        x2: "224",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M121.69523,60H152a32,32,0,0,1,32,32v96a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68a8,8,0,0,1,8-8H67.63637",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M24,60H152a32,32,0,0,1,32,32v96a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68A8,8,0,0,1,24,60Z",
        opacity: "0.2"
      }), React__default.createElement("polygon", {
        points: "240 176 184 144 184 112 240 80 240 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "34.9091",
        y1: "24",
        x2: "224",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M110.8827,60H152a32,32,0,0,1,32,32v52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M184,188a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68a8,8,0,0,1,8-8H67.63637",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M244.01562,73.08105a8.001,8.001,0,0,0-7.98437-.02734L192,98.21436V92a40.04584,40.04584,0,0,0-40-40H110.88281a7.99931,7.99931,0,0,0-6.03418,13.25195l73.11719,84c.07324.084.155.15772.2312.23828.085.08985.1687.17969.25781.26563.16919.16309.34644.31445.52735.46094.06958.05615.13452.11621.20581.16992a7.96909,7.96909,0,0,0,.814.54c.01026.00586.019.01367.0293.01953l56,32A8.0003,8.0003,0,0,0,248,176V80A7.99807,7.99807,0,0,0,244.01562,73.08105Z"
      }), React__default.createElement("path", {
        d: "M40.8291,18.61816A8.0006,8.0006,0,0,0,28.98926,29.38184L49.55127,52H24A16.01833,16.01833,0,0,0,8,68v96a40.04584,40.04584,0,0,0,40,40H176a15.89763,15.89763,0,0,0,9.12158-2.87256l32.9585,36.2544a8.0006,8.0006,0,1,0,11.83984-10.76368Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "240 176 184 144 184 112 240 80 240 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "34.9091",
        y1: "24",
        x2: "224",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M110.8827,60H152a32,32,0,0,1,32,32v52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M184,188a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68a8,8,0,0,1,8-8H67.63637",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "240 176 184 144 184 112 240 80 240 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "34.9091",
        y1: "24",
        x2: "224",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M110.8827,60H152a32,32,0,0,1,32,32v52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M184,188a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68a8,8,0,0,1,8-8H67.63637",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("polygon", {
        points: "240 176 184 144 184 112 240 80 240 176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "34.9091",
        y1: "24",
        x2: "224",
        y2: "232",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M110.8827,60H152a32,32,0,0,1,32,32v52",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M184,188a8,8,0,0,1-8,8H48a32,32,0,0,1-32-32V68a8,8,0,0,1,8-8H67.63637",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var VideoCameraSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$an(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
VideoCameraSlash.displayName = "VideoCameraSlash";

var renderPathFor$ao = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "60",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "196",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "60",
        y1: "176",
        x2: "196",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "56",
        cy: "128",
        r: "48",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "128",
        r: "48",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "56",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "200",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M200,72a55.96339,55.96339,0,0,0-39.13867,96H95.13867A55.96225,55.96225,0,1,0,56,184H200a56,56,0,0,0,0-112ZM16,128a40,40,0,1,1,40,40A40.04584,40.04584,0,0,1,16,128Zm184,40a40,40,0,1,1,40-40A40.04584,40.04584,0,0,1,200,168Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "56",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "200",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "56",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "200",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "56",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "200",
        cy: "128",
        r: "48",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "56",
        y1: "176",
        x2: "200",
        y2: "176",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Voicemail = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ao(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Voicemail.displayName = "Voicemail";

var renderPathFor$ap = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "176",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "12"
      }), React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M236.74414,187.96585l-87.96875-152a24.012,24.012,0,0,0-41.54687,0v.00782L19.25977,187.96585a23.9982,23.9982,0,0,0,20.76562,36.02344H215.97852a23.9982,23.9982,0,0,0,20.76562-36.02344Zm-116.75-91.96875a8,8,0,1,1,16,0v48a8,8,0,1,1-16,0ZM128,192a12,12,0,1,1,12-12A12.00059,12.00059,0,0,1,128,192Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "96",
        x2: "128",
        y2: "144",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M114.15243,39.98472,26.17616,191.977a16.00005,16.00005,0,0,0,13.84762,24.01535H215.97625A16,16,0,0,0,229.82386,191.977L141.84757,39.98472A16,16,0,0,0,114.15243,39.98472Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "180",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Warning = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ap(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Warning.displayName = "Warning";

var renderPathFor$aq = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "172",
        r: "12"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24.00012a104,104,0,1,0,104,104A104.11759,104.11759,0,0,0,128,24.00012Zm-8,56a8,8,0,1,1,16,0v56a8,8,0,1,1-16,0Zm8,104a12,12,0,1,1,12-12A12,12,0,0,1,128,184.00012Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var WarningCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$aq(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
WarningCircle.displayName = "WarningCircle";

var renderPathFor$ar = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "132",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "172",
        r: "12"
      }), React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M227.3125,80.23438,175.76562,28.6875A16.11511,16.11511,0,0,0,164.45312,24H91.54687a16.11515,16.11515,0,0,0-11.3125,4.6875L28.6875,80.23438A16.11511,16.11511,0,0,0,24,91.54688v72.90625a16.11515,16.11515,0,0,0,4.6875,11.3125L80.23437,227.3125A16.11515,16.11515,0,0,0,91.54687,232h72.90625a16.11511,16.11511,0,0,0,11.3125-4.6875l51.54688-51.54687A16.11515,16.11515,0,0,0,232,164.45313V91.54688A16.11511,16.11511,0,0,0,227.3125,80.23438ZM120,80a8,8,0,0,1,16,0v56a8,8,0,0,1-16,0Zm8,104a12,12,0,1,1,12-12A12.0006,12.0006,0,0,1,128,184Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "128",
        y1: "80",
        x2: "128",
        y2: "136",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M164.45079,32H91.54921a8,8,0,0,0-5.65686,2.34315l-51.5492,51.5492A8,8,0,0,0,32,91.54921v72.90158a8,8,0,0,0,2.34315,5.65686l51.5492,51.5492A8,8,0,0,0,91.54921,224h72.90158a8,8,0,0,0,5.65686-2.34315l51.5492-51.5492A8,8,0,0,0,224,164.45079V91.54921a8,8,0,0,0-2.34315-5.65686l-51.5492-51.5492A8,8,0,0,0,164.45079,32Z",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "172",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var WarningOctagon = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ar(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
WarningOctagon.displayName = "WarningOctagon";

var renderPathFor$as = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "128 96 128 128 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,68.12774l6.95849-45.34129A8,8,0,0,1,102.86591,16h50.26817a8,8,0,0,1,7.90743,6.78646L168,68.128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M88,187.87226l6.95849,45.34129A8,8,0,0,0,102.86591,240h50.26817a8,8,0,0,0,7.90743-6.78646L168,187.872",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "72",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "72",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 88 128 128 168 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,68.12774l6.80838-37.55481A8,8,0,0,1,102.68007,24h50.63985a8,8,0,0,1,7.87169,6.57294L168,68.128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,187.87226l6.80838,37.55481A8,8,0,0,0,102.68007,232h50.63985a8,8,0,0,0,7.87169-6.57294L168,187.872",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M175.29687,63.53107l-6.23339-34.38556A15.99062,15.99062,0,0,0,153.31982,16H102.68018A15.99062,15.99062,0,0,0,86.93652,29.14551l-6.2334,34.38556a79.89661,79.89661,0,0,0,0,128.93786l6.2334,34.38556A15.99062,15.99062,0,0,0,102.68018,240h50.63964a15.99062,15.99062,0,0,0,15.74366-13.14551l6.23339-34.38556a79.8966,79.8966,0,0,0,0-128.93786ZM102.68018,32h50.64013l3.90723,21.55316a79.69216,79.69216,0,0,0-58.45508,0Zm50.63964,192H102.67969l-3.90723-21.55316a79.69216,79.69216,0,0,0,58.45508,0ZM168,136H128a8.00008,8.00008,0,0,1-8-8V88a8,8,0,0,1,16,0v32h32a8,8,0,0,1,0,16Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "128 88 128 128 168 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,68.12774l6.80838-37.55481A8,8,0,0,1,102.68007,24h50.63985a8,8,0,0,1,7.87169,6.57294L168,68.128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M88,187.87226l6.80838,37.55481A8,8,0,0,0,102.68007,232h50.63985a8,8,0,0,0,7.87169-6.57294L168,187.872",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "72",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "128 88 128 128 168 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,68.12774l6.80838-37.55481A8,8,0,0,1,102.68007,24h50.63985a8,8,0,0,1,7.87169,6.57294L168,68.128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M88,187.87226l6.80838,37.55481A8,8,0,0,0,102.68007,232h50.63985a8,8,0,0,0,7.87169-6.57294L168,187.872",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "72",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "128 88 128 128 168 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,68.12774l6.80838-37.55481A8,8,0,0,1,102.68007,24h50.63985a8,8,0,0,1,7.87169,6.57294L168,68.128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M88,187.87226l6.80838,37.55481A8,8,0,0,0,102.68007,232h50.63985a8,8,0,0,0,7.87169-6.57294L168,187.872",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Watch = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$as(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Watch.displayName = "Watch";

var renderPathFor$at = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.429,176.99811A95.95978,95.95978,0,1,1,79.00277,210.5717l.00023-.001L45.84643,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M80.00147,103.535A23.89033,23.89033,0,0,1,104,80h3.47048a8,8,0,0,1,6.85994,3.884l7.41013,12.35021a8,8,0,0,1,.29548,7.69368l-4.7745,9.549-.00127-.00063a36.06864,36.06864,0,0,0,25.26306,25.26334l-.00052-.001,9.54928-4.77464a8,8,0,0,1,7.69368.29548l12.35021,7.41013A8,8,0,0,1,176,148.52952V152a23.89033,23.89033,0,0,1-23.535,23.99853A72.00011,72.00011,0,0,1,80.00147,103.535Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128.00049,32A96.02264,96.02264,0,0,0,45.4292,176.99807l.00049-.00061-9.47315,33.15661a8,8,0,0,0,9.89014,9.8899l33.15625-9.47327v.001A96.00624,96.00624,0,1,0,128.00049,32ZM152.11377,183.9999A80.0001,80.0001,0,0,1,72,103.88625,27.97634,27.97634,0,0,1,100,76h0a6.89208,6.89208,0,0,1,5.98438,3.4729l11.6914,20.45923a8.00129,8.00129,0,0,1-.08594,8.08521l-9.38916,15.64843h0a48.18271,48.18271,0,0,0,24.1333,24.13379l.00049-.00012,15.64795-9.389a8.00033,8.00033,0,0,1,8.08545-.08594l20.459,11.69092A6.89223,6.89223,0,0,1,180,156,28.081,28.081,0,0,1,152.11377,183.9999Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M45.429,176.99811A95.95978,95.95978,0,1,1,79.00277,210.5717l.00023-.001L45.84643,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152.11369,183.99992a80,80,0,0,1-80.11361-80.11361A27.97622,27.97622,0,0,1,100,76h0a6.89265,6.89265,0,0,1,5.98451,3.47295l11.69105,20.45931a8,8,0,0,1-.086,8.08508l-9.38907,15.64844h0a48.18239,48.18239,0,0,0,24.13373,24.13373l0,0,15.64841-9.389a8,8,0,0,1,8.08508-.086l20.45931,11.691A6.89265,6.89265,0,0,1,180,156v0A28.081,28.081,0,0,1,152.11369,183.99992Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M128.00049,24a104.0281,104.0281,0,0,0-91.189,154.041l-8.54687,29.915A15.99944,15.99944,0,0,0,48.044,227.73635l29.916-8.54688A104.00728,104.00728,0,1,0,128.00049,24ZM152.125,192c-.0293.02344-.084,0-.126,0A87.99949,87.99949,0,0,1,64,103.876,36.01385,36.01385,0,0,1,100,68,14.92643,14.92643,0,0,1,112.93066,75.503l11.69092,20.46094a16.01674,16.01674,0,0,1-.17187,16.16992l-7.11084,11.85156a40.03607,40.03607,0,0,0,14.67627,14.67676l11.85107-7.11133a16.01883,16.01883,0,0,1,16.17041-.17285l20.45947,11.69141A14.9238,14.9238,0,0,1,188,156,36.01427,36.01427,0,0,1,152.125,192Z"
      }), React__default.createElement("path", {
        d: "M136.4502,154.6592a7.99584,7.99584,0,0,1-7.397.43652,56.03179,56.03179,0,0,1-28.14892-28.14843,7.99972,7.99972,0,0,1,.43652-7.39746l9.38867-15.64844L99.36328,84.00979A19.99027,19.99027,0,0,0,80,103.89748,72.00036,72.00036,0,0,0,152,176h.10254a19.99027,19.99027,0,0,0,19.88769-19.36328l-19.8916-11.36621Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.429,176.99811A95.95978,95.95978,0,1,1,79.00277,210.5717l.00023-.001L45.84643,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M152.11369,183.99992a80,80,0,0,1-80.11361-80.11361A27.97622,27.97622,0,0,1,100,76h0a6.89265,6.89265,0,0,1,5.98451,3.47295l11.69105,20.45931a8,8,0,0,1-.086,8.08508l-9.38907,15.64844h0a48.18239,48.18239,0,0,0,24.13373,24.13373l0,0,15.64841-9.389a8,8,0,0,1,8.08508-.086l20.45931,11.691A6.89265,6.89265,0,0,1,180,156v0A28.081,28.081,0,0,1,152.11369,183.99992Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.429,176.99811A95.95978,95.95978,0,1,1,79.00277,210.5717l.00023-.001L45.84643,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M152.11369,183.99992a80,80,0,0,1-80.11361-80.11361A27.97622,27.97622,0,0,1,100,76h0a6.89265,6.89265,0,0,1,5.98451,3.47295l11.69105,20.45931a8,8,0,0,1-.086,8.08508l-9.38907,15.64844h0a48.18239,48.18239,0,0,0,24.13373,24.13373l0,0,15.64841-9.389a8,8,0,0,1,8.08508-.086l20.45931,11.691A6.89265,6.89265,0,0,1,180,156v0A28.081,28.081,0,0,1,152.11369,183.99992Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M45.429,176.99811A95.95978,95.95978,0,1,1,79.00277,210.5717l.00023-.001L45.84643,220.044a8,8,0,0,1-9.89-9.89l9.47331-33.15657Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152.11369,183.99992a80,80,0,0,1-80.11361-80.11361A27.97622,27.97622,0,0,1,100,76h0a6.89265,6.89265,0,0,1,5.98451,3.47295l11.69105,20.45931a8,8,0,0,1-.086,8.08508l-9.38907,15.64844h0a48.18239,48.18239,0,0,0,24.13373,24.13373l0,0,15.64841-9.389a8,8,0,0,1,8.08508-.086l20.45931,11.691A6.89265,6.89265,0,0,1,180,156v0A28.081,28.081,0,0,1,152.11369,183.99992Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var WhatsappLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$at(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
WhatsappLogo.displayName = "WhatsappLogo";

var renderPathFor$au = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "95.88745",
        cy: "40",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polyline", {
        points: "95.887 60 95.887 136 183.887 136 215.887 200 239.887 192",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M163.20563,184.07319A64.00734,64.00734,0,1,1,103.88745,96h56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "95.88745",
        cy: "40",
        r: "20",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "95.88745",
        cy: "40",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "95.887 60 95.887 132 183.887 132 215.887 196 239.887 188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M167.76447,164.00014A64.001,64.001,0,1,1,103.88745,96h56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M247.47729,185.47021a7.99737,7.99737,0,0,0-10.12012-5.05957l-17.417,5.80567-28.89746-57.79395A7.99979,7.99979,0,0,0,183.88745,124h-80V104h56a8,8,0,0,0,0-16h-56V62.629a24,24,0,1,0-16,0V89.81421a71.99395,71.99395,0,1,0,87.86133,74.678,7.99953,7.99953,0,1,0-15.96875-.98438,56.001,56.001,0,1,1-71.89258-57.16644V132a8.00008,8.00008,0,0,0,8,8h83.05566l29.78906,59.57764a7.9934,7.9934,0,0,0,9.68555,4.01172l24-8A8.00045,8.00045,0,0,0,247.47729,185.47021Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "95.88745",
        cy: "40",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polyline", {
        points: "95.887 60 95.887 132 183.887 132 215.887 196 239.887 188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M167.76447,164.00014A64.001,64.001,0,1,1,103.88745,96h56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "95.88745",
        cy: "40",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polyline", {
        points: "95.887 60 95.887 132 183.887 132 215.887 196 239.887 188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M167.76447,164.00014A64.001,64.001,0,1,1,103.88745,96h56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "95.88745",
        cy: "40",
        r: "20",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polyline", {
        points: "95.887 60 95.887 132 183.887 132 215.887 196 239.887 188",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M167.76447,164.00014A64.001,64.001,0,1,1,103.88745,96h56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Wheelchair = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$au(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Wheelchair.displayName = "Wheelchair";

var renderPathFor$av = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.75415,98.75415,0,0,1,138.02724,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M25.06379,98.17952a146.68225,146.68225,0,0,1,205.8568,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M20.20855,75.93124c63.48474-47.90809,152.098-47.90812,215.58263.00015a8.015,8.015,0,0,1,1.201,11.61025c-19.04723,22.44929-82.94714,97.76169-102.95188,121.33925a7.93583,7.93583,0,0,1-12.14044-.0705L19.03968,87.57941A8.055,8.055,0,0,1,20.20855,75.93124Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M20.20855,75.93124c63.48474-47.90809,152.098-47.90812,215.58263.00015a8.015,8.015,0,0,1,1.201,11.61025c-19.04723,22.44929-82.94714,97.76169-102.95188,121.33925a7.93583,7.93583,0,0,1-12.14044-.0705L19.03968,87.57941A8.055,8.055,0,0,1,20.20855,75.93124Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M246.86034,80.49665a15.72068,15.72068,0,0,0-6.209-10.91944C174.34325,19.50788,81.71141,19.49665,15.39061,69.54548a15.73529,15.73529,0,0,0-6.21142,10.936,16.27674,16.27674,0,0,0,3.76074,12.27393L115.85985,214.05768a15.95117,15.95117,0,0,0,12.17383,5.65528A15.77638,15.77638,0,0,0,140.081,214.127L243.12206,92.6822A16.16767,16.16767,0,0,0,246.86034,80.49665Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.75415,98.75415,0,0,1,138.02724,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M25.06379,98.17952a146.68225,146.68225,0,0,1,205.8568,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.75415,98.75415,0,0,1,138.02724,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M25.06379,98.17952a146.68225,146.68225,0,0,1,205.8568,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.75415,98.75415,0,0,1,138.02724,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M25.06379,98.17952a146.68225,146.68225,0,0,1,205.8568,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var WifiHigh = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$av(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
WifiHigh.displayName = "WifiHigh";

var renderPathFor$aw = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M71.06558,148.89719a88.00756,88.00756,0,0,1,113.86856-.00025l-50.89382,59.98395a7.93583,7.93583,0,0,1-12.14044-.0705Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M20.20855,75.93124c63.48474-47.90809,152.098-47.90812,215.58263.00015a8.015,8.015,0,0,1,1.201,11.61025c-19.04723,22.44929-82.94714,97.76169-102.95188,121.33925a7.93583,7.93583,0,0,1-12.14044-.0705L19.03968,87.57941A8.055,8.055,0,0,1,20.20855,75.93124Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M71.06558,148.89719a88.00756,88.00756,0,0,1,113.86856-.00025",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M246.84081,80.49756a15.76545,15.76545,0,0,0-6.231-10.95215c-66.30273-50.03516-158.9165-50.03516-225.22021,0l-.00049.00049a15.73787,15.73787,0,0,0-6.21045,10.936,16.28081,16.28081,0,0,0,3.76074,12.27344l102.86035,121.231a16.15644,16.15644,0,0,0,3.97534,3.38556,15.97543,15.97543,0,0,0,8.25709,2.29852h.00048a15.84564,15.84564,0,0,0,10.90992-4.34833,16.03046,16.03046,0,0,0,1.198-1.26544L243.09227,92.71729A16.20974,16.20974,0,0,0,246.84081,80.49756Zm-15.94873,1.86816-47.10327,55.516a95.96888,95.96888,0,0,0-111.57813-.00012L25.14013,82.4043a.23245.23245,0,0,1-.05958-.12744c60.625-45.71192,145.28174-45.69922,205.85694-.01954A.138.138,0,0,1,230.89208,82.36572Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var WifiLow = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$aw(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
WifiLow.displayName = "WifiLow";

var renderPathFor$ax = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.75415,98.75415,0,0,1,138.02724,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M134.04032,208.88089a7.93583,7.93583,0,0,1-12.14044-.0705L50.36222,124.49611a120.01033,120.01033,0,0,1,155.27524-.00029Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M20.20855,75.93124c63.48474-47.90809,152.098-47.90812,215.58263.00015a8.015,8.015,0,0,1,1.201,11.61025c-19.04723,22.44929-82.94714,97.76169-102.95188,121.33925a7.93583,7.93583,0,0,1-12.14044-.0705L19.03968,87.57941A8.055,8.055,0,0,1,20.20855,75.93124Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M50.36222,124.49611a120.01033,120.01033,0,0,1,155.27524-.00029",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M240.60352,69.55179C174.33789,19.52054,81.71289,19.50492,15.416,69.53617a15.67919,15.67919,0,0,0-6.23438,10.9375,16.20384,16.20384,0,0,0,3.76563,12.28125L115.791,213.98148a16.04165,16.04165,0,0,0,12.21875,5.6875h.01562a15.846,15.846,0,0,0,12.10938-5.60938v-.00781L243.10352,92.708a16.264,16.264,0,0,0,3.73437-12.22656A15.76645,15.76645,0,0,0,240.60352,69.55179ZM25.00977,82.333h0l.01562-.01562C25.02539,82.32523,25.02539,82.32523,25.00977,82.333ZM204.48242,113.4971A127.38716,127.38716,0,0,0,187.502,102.81156c-.2539-.13575-.50781-.26953-.76562-.40235a127.88589,127.88589,0,0,0-17.78711-7.57129c-.50195-.17089-1.00781-.3164-1.51367-.48144a127.931,127.931,0,0,0-18.42188-4.5625c-.53125-.08985-1.0664-.13086-1.60156-.21387a119.8284,119.8284,0,0,0-38.80859-.00293c-.53711.083-1.07813.126-1.61524.21582a127.94763,127.94763,0,0,0-18.40039,4.55567c-.50781.165-1.01562.3125-1.51953.48437a128.124,128.124,0,0,0-17.76563,7.55762c-.26367.13672-.52343.27441-.78515.41308a127.2435,127.2435,0,0,0-16.96094,10.666l-.002.001L25.10352,82.27054c60.625-45.71875,145.26562-45.6875,205.79687.09375Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.75415,98.75415,0,0,1,138.02724,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.75415,98.75415,0,0,1,138.02724,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.75415,98.75415,0,0,1,138.02724,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var WifiMedium = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ax(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
WifiMedium.displayName = "WifiMedium";

var renderPathFor$ay = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M20.20827,75.93119c63.485-47.90816,152.09866-47.90813,215.58361.00009a8.06594,8.06594,0,0,1,1.208,11.6015c-19.03707,22.43714-82.95213,97.76737-102.95962,121.34817a7.87135,7.87135,0,0,1-12.08054,0C101.9523,185.30027,38.03757,109.97061,19.00019,87.53317A8.06626,8.06626,0,0,1,20.20827,75.93119Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,219.70508a15.90814,15.90814,0,0,1-12.14014-5.64844L12.8999,92.709a16.182,16.182,0,0,1-3.71826-12.206,15.97026,15.97026,0,0,1,6.208-10.95752c66.30371-50.03418,158.91748-50.03516,225.22119,0a15.97226,15.97226,0,0,1,6.20752,10.957A16.18377,16.18377,0,0,1,243.10059,92.708L140.14014,214.05664A15.90814,15.90814,0,0,1,128,219.70508ZM25.084,82.27441a.12788.12788,0,0,0,.01612.083l102.89844,121.2749L230.8999,82.35693a.16373.16373,0,0,0,.01074-.11767C170.36279,36.57764,85.709,36.563,25.084,82.27441Zm-.05664.04248ZM20.2085,75.93115h0Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var WifiNone = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$ay(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
WifiNone.displayName = "WifiNone";

var renderPathFor$az = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "47.98242",
        y1: "40",
        x2: "207.98242",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M25.04621,98.17952A145.88673,145.88673,0,0,1,72.40779,66.8671",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M58.961,132.12064a97.89874,97.89874,0,0,1,49.03639-26.105",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M92.90211,166.06177a50.81565,50.81565,0,0,1,67.576-2.317",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "127.97656",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M116.96071,56.40892q5.45356-.4036,11.0139-.406A145.90176,145.90176,0,0,1,230.903,98.17952",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M167.79881,112.332a97.8573,97.8573,0,0,1,29.18942,19.78862",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M20.20855,75.93124c63.48474-47.90809,152.098-47.90812,215.58263.00015a8.015,8.015,0,0,1,1.201,11.61025c-19.04723,22.44929-82.94714,97.76169-102.95188,121.33925a7.93583,7.93583,0,0,1-12.14044-.0705L19.03968,87.57941A8.055,8.055,0,0,1,20.20855,75.93124Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M166.62276,170.47925l-32.58244,38.40164a7.93583,7.93583,0,0,1-12.14044-.0705L19.03968,87.57941a8.055,8.055,0,0,1,1.16887-11.64817A177.24421,177.24421,0,0,1,60.07361,53.27507",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M94.16029,43.19328A179.46662,179.46662,0,0,1,235.79118,75.93139a8.015,8.015,0,0,1,1.201,11.61025c-9.27624,10.93309-29.19069,34.40431-49.49207,58.33153",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M53.86491,34.61787A8.0029,8.0029,0,0,0,42.01886,45.38155l4.63294,5.093A185.51021,185.51021,0,0,0,15.31272,69.55151,15.73558,15.73558,0,0,0,9.097,80.48806a16.27045,16.27045,0,0,0,3.76351,12.27248L115.78283,213.99217a16.0416,16.0416,0,0,0,12.24131,5.6836,15.86724,15.86724,0,0,0,12.11428-5.61329l26.70577-31.4561,35.27175,38.77545a8.0029,8.0029,0,0,0,11.846-10.76369Z"
      }), React__default.createElement("path", {
        d: "M246.90336,80.50173a15.766,15.766,0,0,0-6.23425-10.95022,187.8405,187.8405,0,0,0-148.037-34.211A7.99849,7.99849,0,0,0,88.207,48.5798L181.6035,151.25965a8.00587,8.00587,0,0,0,5.923,2.61915c.04593,0,.09136,0,.13729-.001a8.007,8.007,0,0,0,5.967-2.82325l49.5227-58.33212A16.20333,16.20333,0,0,0,246.90336,80.50173Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "47.98828",
        y1: "40",
        x2: "207.98828",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M107.11812,57.47077a148.358,148.358,0,0,1,20.86235-1.46787,145.90176,145.90176,0,0,1,102.9284,42.17662",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M25.05207,98.17952A145.88673,145.88673,0,0,1,72.41365,66.8671",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M152.10795,106.95874a97.88563,97.88563,0,0,1,44.88614,25.1619",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M58.96685,132.12064a97.89874,97.89874,0,0,1,49.03639-26.105",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M92.908,166.06177a50.81565,50.81565,0,0,1,67.576-2.317",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "127.98242",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "47.99414",
        y1: "40",
        x2: "207.99414",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M107.124,57.47077a148.358,148.358,0,0,1,20.86235-1.46787,145.90176,145.90176,0,0,1,102.9284,42.17662",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M25.05793,98.17952A145.88673,145.88673,0,0,1,72.41951,66.8671",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M152.11381,106.95874A97.88563,97.88563,0,0,1,197,132.12064",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M58.97271,132.12064a97.89874,97.89874,0,0,1,49.03639-26.105",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M92.91383,166.06177a50.81565,50.81565,0,0,1,67.576-2.317",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "127.98828",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "48",
        y1: "40",
        x2: "208",
        y2: "216",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M107.12984,57.47077a148.358,148.358,0,0,1,20.86235-1.46787,145.90176,145.90176,0,0,1,102.9284,42.17662",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M25.06379,98.17952A145.88673,145.88673,0,0,1,72.42537,66.8671",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M152.11967,106.95874a97.88568,97.88568,0,0,1,44.88614,25.1619",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a97.89874,97.89874,0,0,1,49.03639-26.105",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M92.91969,166.06177a50.81565,50.81565,0,0,1,67.576-2.317",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "127.99414",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var WifiSlash = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$az(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
WifiSlash.displayName = "WifiSlash";

var renderPathFor$aA = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "56",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "104",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M25.06379,98.17952A145.90174,145.90174,0,0,1,127.99219,56.0029q4.03231,0,8.0117.21441",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.11506,98.11506,0,0,1,69.01362-28.11774q4.04751,0,8.0141.319",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M20.20855,75.93124c63.48474-47.90809,152.098-47.90812,215.58263.00015a8.015,8.015,0,0,1,1.201,11.61025c-19.04723,22.44929-82.94714,97.76169-102.95188,121.33925a7.93583,7.93583,0,0,1-12.14044-.0705L19.03968,87.57941A8.055,8.055,0,0,1,20.20855,75.93124Z",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "56",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "104",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M202.73959,127.91193c-25.42164,29.962-55.96036,65.9549-68.69927,80.969a7.93583,7.93583,0,0,1-12.14044-.0705L19.03968,87.57941a8.055,8.055,0,0,1,1.16887-11.64817A179.20728,179.20728,0,0,1,147.6789,41.073",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("g", null, React__default.createElement("path", {
        d: "M211.30223,79.99421,229.645,61.65143A8.00018,8.00018,0,1,0,218.33153,50.337L199.98827,68.68024,181.645,50.337a8.00018,8.00018,0,1,0-11.31348,11.31445L188.6743,79.99421,170.33153,98.337A8.00018,8.00018,0,0,0,181.645,109.65143l18.34326-18.34326,18.34326,18.34326A8.00018,8.00018,0,0,0,229.645,98.337Z"
      }), React__default.createElement("path", {
        d: "M199.98827,113.93561l-7.03113,7.03125a24.00024,24.00024,0,0,1-33.93933-33.9436l7.02905-7.029-7.0299-7.03a24.03027,24.03027,0,0,1,4.60974-37.55127A187.51454,187.51454,0,0,0,15.39061,69.54548a15.73529,15.73529,0,0,0-6.21142,10.936,16.27674,16.27674,0,0,0,3.76074,12.27393L115.85985,214.05768a15.95117,15.95117,0,0,0,12.17383,5.65528A15.77638,15.77638,0,0,0,140.081,214.127l74.647-87.97925a23.97614,23.97614,0,0,1-7.71021-5.18262Z"
      })));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "56",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "104",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M25.06379,98.17952A145.90174,145.90174,0,0,1,127.99219,56.0029a148.757,148.757,0,0,1,16.01524.86162",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.11506,98.11506,0,0,1,69.01362-28.11774,99.87589,99.87589,0,0,1,16.02985,1.28855",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "56",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "104",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M25.06379,98.17952A145.90174,145.90174,0,0,1,127.99219,56.0029a148.757,148.757,0,0,1,16.01524.86162",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.11506,98.11506,0,0,1,69.01362-28.11774,99.87589,99.87589,0,0,1,16.02985,1.28855",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M92.91969,166.06177a50.7769,50.7769,0,0,1,70.145,0",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "56",
        x2: "176",
        y2: "104",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "224",
        y1: "104",
        x2: "176",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M25.06379,98.17952A145.90174,145.90174,0,0,1,127.99219,56.0029a148.757,148.757,0,0,1,16.01524.86162",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M58.97857,132.12064a98.11506,98.11506,0,0,1,69.01362-28.11774,99.87589,99.87589,0,0,1,16.02985,1.28855",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "200",
        r: "4",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var WifiX = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$aA(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
WifiX.displayName = "WifiX";

var renderPathFor$aB = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M102.11138,51.99974A24.0001,24.0001,0,1,1,120,92H24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M190.11128,91.99985A24.0001,24.0001,0,1,1,208,132H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("path", {
        d: "M134.11121,212.00007A24.0001,24.0001,0,1,0,152,172H40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M129.48449,192.32854A24.00285,24.00285,0,1,0,152,160H40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M97.48449,63.67146A24.00285,24.00285,0,1,1,120,96H24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M185.48449,95.67146A24.00285,24.00285,0,1,1,208,128H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M184,184a32.00415,32.00415,0,0,1-62.01855,11.10449,8.00013,8.00013,0,1,1,15.00585-5.55273A16.00278,16.00278,0,1,0,152,168H40a8,8,0,0,1,0-16H152A32.03635,32.03635,0,0,1,184,184Zm-64-80A32,32,0,1,0,89.98145,60.89551a8.00013,8.00013,0,1,0,15.00585,5.55273A16.00278,16.00278,0,1,1,120,88H24a8,8,0,0,0,0,16Zm88-32a32.13165,32.13165,0,0,0-30.01855,20.89551,8.00013,8.00013,0,1,0,15.00585,5.55273A16.00278,16.00278,0,1,1,208,120H32a8,8,0,0,0,0,16H208a32,32,0,0,0,0-64Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M129.48449,192.32854A24.00285,24.00285,0,1,0,152,160H40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M97.48449,63.67146A24.00285,24.00285,0,1,1,120,96H24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("path", {
        d: "M185.48449,95.67146A24.00285,24.00285,0,1,1,208,128H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M129.48449,192.32854A24.00285,24.00285,0,1,0,152,160H40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M97.48449,63.67146A24.00285,24.00285,0,1,1,120,96H24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("path", {
        d: "M185.48449,95.67146A24.00285,24.00285,0,1,1,208,128H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M129.48449,192.32854A24.00285,24.00285,0,1,0,152,160H40",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M97.48449,63.67146A24.00285,24.00285,0,1,1,120,96H24",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("path", {
        d: "M185.48449,95.67146A24.00285,24.00285,0,1,1,208,128H32",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Wind = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$aB(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Wind.displayName = "Wind";

var renderPathFor$aC = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M184.99131,37.06756,143.02944,79.02944l5.65685,28.28427,28.28427,5.65685,41.96188-41.96187.0041-.00174a64.02489,64.02489,0,0,1-89.88113,81.03367l.00123-.00214L72.97056,216.97056a24,24,0,0,1-33.94112-33.94112L103.9608,126.944l-.00137.0007a64.02489,64.02489,0,0,1,81.03363-89.88122Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M184.99131,37.06756,143.02944,79.02944l5.65685,28.28427,28.28427,5.65685,41.96188-41.96187.0041-.00174a64.02489,64.02489,0,0,1-89.88113,81.03367l.00123-.00214L72.97056,216.97056a24,24,0,0,1-33.94112-33.94112L103.9608,126.944l-.00137.0007a64.02489,64.02489,0,0,1,81.03363-89.88122Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M184.99131,37.06756,143.02944,79.02944l5.65685,28.28427,28.28427,5.65685,41.96188-41.96187.0041-.00174a64.02489,64.02489,0,0,1-89.88113,81.03367l.00123-.00214L72.97056,216.97056a24,24,0,0,1-33.94112-33.94112L103.9608,126.944l-.00137.0007a64.02489,64.02489,0,0,1,81.03363-89.88122Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M210.91162,146.91211a72.37653,72.37653,0,0,1-79.84424,15.03613L79.0249,222.2002q-.19116.22119-.39746.42773a32.00021,32.00021,0,0,1-45.25537-45.25488c.1377-.1377.28076-.27051.42773-.39844l60.25293-52.043a72.02489,72.02489,0,0,1,94.06153-95.23437A8.004,8.004,0,0,1,190.648,42.72461L151.71387,81.6582l3.77148,18.85645,18.856,3.77148,38.93457-38.93457a8.00429,8.00429,0,0,1,13.02685,2.53418A71.72729,71.72729,0,0,1,210.91162,146.91211Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M184.99131,37.06756,143.02944,79.02944l5.65685,28.28427,28.28427,5.65685,41.96188-41.96187.0041-.00174a64.02489,64.02489,0,0,1-89.88113,81.03367l.00123-.00214L72.97056,216.97056a24,24,0,0,1-33.94112-33.94112L103.9608,126.944l-.00137.0007a64.02489,64.02489,0,0,1,81.03363-89.88122Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M184.99131,37.06756,143.02944,79.02944l5.65685,28.28427,28.28427,5.65685,41.96188-41.96187.0041-.00174a64.02489,64.02489,0,0,1-89.88113,81.03367l.00123-.00214L72.97056,216.97056a24,24,0,0,1-33.94112-33.94112L103.9608,126.944l-.00137.0007a64.02489,64.02489,0,0,1,81.03363-89.88122Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M184.99131,37.06756,143.02944,79.02944l5.65685,28.28427,28.28427,5.65685,41.96188-41.96187.0041-.00174a64.02489,64.02489,0,0,1-89.88113,81.03367l.00123-.00214L72.97056,216.97056a24,24,0,0,1-33.94112-33.94112L103.9608,126.944l-.00137.0007a64.02489,64.02489,0,0,1,81.03363-89.88122Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var Wrench = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$aC(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
Wrench.displayName = "Wrench";

var renderPathFor$aD = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "200",
        x2: "56",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "200",
        x2: "56",
        y2: "56",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M139.31348,128l66.34326-66.34326a7.99984,7.99984,0,0,0-11.31348-11.31348L128,116.68652,61.65674,50.34326A7.99984,7.99984,0,0,0,50.34326,61.65674L116.68652,128,50.34326,194.34326a7.99984,7.99984,0,1,0,11.31348,11.31348L128,139.31348l66.34326,66.34326a7.99984,7.99984,0,0,0,11.31348-11.31348Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "200",
        x2: "56",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "200",
        x2: "56",
        y2: "56",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "200",
        y1: "56",
        x2: "56",
        y2: "200",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "200",
        y1: "200",
        x2: "56",
        y2: "56",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var X = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$aD(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
X.displayName = "X";

var renderPathFor$aE = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "96",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "160",
        x2: "96",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        opacity: "0.2"
      }), React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "96",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "160",
        x2: "96",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M128,24A104,104,0,1,0,232,128,104.12041,104.12041,0,0,0,128,24Zm37.65625,130.34375a7.99915,7.99915,0,1,1-11.3125,11.3125L128,139.3125l-26.34375,26.34375a7.99915,7.99915,0,0,1-11.3125-11.3125L116.6875,128,90.34375,101.65625a7.99915,7.99915,0,0,1,11.3125-11.3125L128,116.6875l26.34375-26.34375a7.99915,7.99915,0,0,1,11.3125,11.3125L139.3125,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "96",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "160",
        x2: "96",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "96",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "160",
        x2: "96",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("circle", {
        cx: "128",
        cy: "128",
        r: "96",
        fill: "none",
        stroke: color,
        strokeMiterlimit: "10",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "96",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "160",
        x2: "96",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var XCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$aE(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
XCircle.displayName = "XCircle";

var renderPathFor$aF = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "96",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "160",
        x2: "96",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        opacity: "0.2"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "96",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "160",
        x2: "96",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M208.00146,32h-160a16.01582,16.01582,0,0,0-16,16V208a16.01583,16.01583,0,0,0,16,16h160a16.01582,16.01582,0,0,0,16-16V48A16.01581,16.01581,0,0,0,208.00146,32ZM165.65771,154.34375a7.99915,7.99915,0,1,1-11.3125,11.3125L128.00146,139.3125l-26.34375,26.34375a7.99915,7.99915,0,0,1-11.3125-11.3125L116.689,128,90.34521,101.65625a7.99915,7.99915,0,0,1,11.3125-11.3125l26.34375,26.34375,26.34375-26.34375a7.99915,7.99915,0,0,1,11.3125,11.3125L139.314,128Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "96",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "160",
        x2: "96",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "96",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "160",
        x2: "96",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("line", {
        x1: "160",
        y1: "96",
        x2: "96",
        y2: "160",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("line", {
        x1: "160",
        y1: "160",
        x2: "96",
        y2: "96",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "8",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var XSquare = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$aF(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
XSquare.displayName = "XSquare";

var renderPathFor$aG = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M204,205.93091a698.14835,698.14835,0,0,1-152,0C43.228,204.92627,34.62451,196.7876,33.22754,188a394.631,394.631,0,0,1,0-120C34.625,59.2124,43.22754,51.07422,52,50.06909a698.14835,698.14835,0,0,1,152,0C212.76953,51.07446,221.377,59.21167,222.77246,68a394.631,394.631,0,0,1,0,120C221.37646,196.78735,212.77393,204.927,204,205.93091Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }), React__default.createElement("polygon", {
        points: "164 128 108 92 108 164 164 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "24"
      }));

    case "duotone":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M222.77246,68C221.377,59.21167,212.76953,51.07446,204,50.06909a698.14835,698.14835,0,0,0-152,0C43.22754,51.07422,34.625,59.2124,33.22754,68a394.631,394.631,0,0,0,0,120C34.62451,196.7876,43.228,204.92627,52,205.93091a698.14835,698.14835,0,0,0,152,0c8.77393-1.00391,17.37646-9.14356,18.77246-17.93091A394.631,394.631,0,0,0,222.77246,68ZM112,160V96l48,32Z",
        opacity: "0.2"
      }), React__default.createElement("path", {
        d: "M204,205.93091a698.14835,698.14835,0,0,1-152,0C43.228,204.92627,34.62451,196.7876,33.22754,188a394.631,394.631,0,0,1,0-120C34.625,59.2124,43.22754,51.07422,52,50.06909a698.14835,698.14835,0,0,1,152,0C212.76953,51.07446,221.377,59.21167,222.77246,68a394.631,394.631,0,0,1,0,120C221.37646,196.78735,212.77393,204.927,204,205.93091Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "160 128 112 96 112 160 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    case "fill":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M230.67334,66.74561C228.708,54.36768,217.3916,43.55127,204.86816,42.1167a709.54987,709.54987,0,0,0-153.77832.00439c-12.47851,1.42969-23.79492,12.24512-25.7705,24.66944a404.54889,404.54889,0,0,0,.00732,122.46533c1.96777,12.37842,13.28467,23.19385,25.80518,24.62744A708.4668,708.4668,0,0,0,128,218.06055a708.4668,708.4668,0,0,0,76.86816-4.17725l.041-.00439c12.48047-1.42823,23.79736-12.24414,25.77148-24.66944A404.53923,404.53923,0,0,0,230.67334,66.74561ZM164.4375,134.65625l-48,32A8,8,0,0,1,104,160V96a8,8,0,0,1,12.4375-6.65625l48,32a7.99959,7.99959,0,0,1,0,13.3125Z"
      }));

    case "light":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M204,205.93091a698.14835,698.14835,0,0,1-152,0C43.228,204.92627,34.62451,196.7876,33.22754,188a394.631,394.631,0,0,1,0-120C34.625,59.2124,43.22754,51.07422,52,50.06909a698.14835,698.14835,0,0,1,152,0C212.76953,51.07446,221.377,59.21167,222.77246,68a394.631,394.631,0,0,1,0,120C221.37646,196.78735,212.77393,204.927,204,205.93091Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }), React__default.createElement("polygon", {
        points: "160 128 112 96 112 160 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "12"
      }));

    case "thin":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M204,205.93091a698.14835,698.14835,0,0,1-152,0C43.228,204.92627,34.62451,196.7876,33.22754,188a394.631,394.631,0,0,1,0-120C34.625,59.2124,43.22754,51.07422,52,50.06909a698.14835,698.14835,0,0,1,152,0C212.76953,51.07446,221.377,59.21167,222.77246,68a394.631,394.631,0,0,1,0,120C221.37646,196.78735,212.77393,204.927,204,205.93091Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }), React__default.createElement("polygon", {
        points: "160 128 112 96 112 160 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "8"
      }));

    case "regular":
      return React__default.createElement(React__default.Fragment, null, React__default.createElement("path", {
        d: "M204,205.93091a698.14835,698.14835,0,0,1-152,0C43.228,204.92627,34.62451,196.7876,33.22754,188a394.631,394.631,0,0,1,0-120C34.625,59.2124,43.22754,51.07422,52,50.06909a698.14835,698.14835,0,0,1,152,0C212.76953,51.07446,221.377,59.21167,222.77246,68a394.631,394.631,0,0,1,0,120C221.37646,196.78735,212.77393,204.927,204,205.93091Z",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }), React__default.createElement("polygon", {
        points: "160 128 112 96 112 160 160 128",
        fill: "none",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: "16"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var YoutubeLogo = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = React.useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React__default.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React__default.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor$aG(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
YoutubeLogo.displayName = "YoutubeLogo";

exports.Activity = Activity;
exports.Airplane = Airplane;
exports.AirplaneInFlight = AirplaneInFlight;
exports.AirplaneLanding = AirplaneLanding;
exports.AirplaneTakeoff = AirplaneTakeoff;
exports.Airplay = Airplay;
exports.Alarm = Alarm;
exports.AlignBottom = AlignBottom;
exports.AlignCenterHorizontal = AlignCenterHorizontal;
exports.AlignCenterVertical = AlignCenterVertical;
exports.AlignLeft = AlignLeft;
exports.AlignRight = AlignRight;
exports.AlignTop = AlignTop;
exports.Anchor = Anchor;
exports.AndroidLogo = AndroidLogo;
exports.Aperture = Aperture;
exports.AppleLogo = AppleLogo;
exports.Archive = Archive;
exports.ArchiveBox = ArchiveBox;
exports.ArchiveTray = ArchiveTray;
exports.ArrowArcLeft = ArrowArcLeft;
exports.ArrowArcRight = ArrowArcRight;
exports.ArrowBendDoubleUpLeft = ArrowBendDoubleUpLeft;
exports.ArrowBendDoubleUpRight = ArrowBendDoubleUpRight;
exports.ArrowBendDownLeft = ArrowBendDownLeft;
exports.ArrowBendDownRight = ArrowBendDownRight;
exports.ArrowBendLeftDown = ArrowBendLeftDown;
exports.ArrowBendLeftUp = ArrowBendLeftUp;
exports.ArrowBendRightDown = ArrowBendRightDown;
exports.ArrowBendRightUp = ArrowBendRightUp;
exports.ArrowBendUpLeft = ArrowBendUpLeft;
exports.ArrowBendUpRight = ArrowBendUpRight;
exports.ArrowCircleDown = ArrowCircleDown;
exports.ArrowCircleDownLeft = ArrowCircleDownLeft;
exports.ArrowCircleDownRight = ArrowCircleDownRight;
exports.ArrowCircleLeft = ArrowCircleLeft;
exports.ArrowCircleRight = ArrowCircleRight;
exports.ArrowCircleUp = ArrowCircleUp;
exports.ArrowCircleUpLeft = ArrowCircleUpLeft;
exports.ArrowCircleUpRight = ArrowCircleUpRight;
exports.ArrowClockwise = ArrowClockwise;
exports.ArrowCounterClockwise = ArrowCounterClockwise;
exports.ArrowDown = ArrowDown;
exports.ArrowDownLeft = ArrowDownLeft;
exports.ArrowDownRight = ArrowDownRight;
exports.ArrowElbowDownLeft = ArrowElbowDownLeft;
exports.ArrowElbowDownRight = ArrowElbowDownRight;
exports.ArrowElbowLeft = ArrowElbowLeft;
exports.ArrowElbowLeftDown = ArrowElbowLeftDown;
exports.ArrowElbowLeftUp = ArrowElbowLeftUp;
exports.ArrowElbowRight = ArrowElbowRight;
exports.ArrowElbowRightDown = ArrowElbowRightDown;
exports.ArrowElbowRightUp = ArrowElbowRightUp;
exports.ArrowElbowUpLeft = ArrowElbowUpLeft;
exports.ArrowElbowUpRight = ArrowElbowUpRight;
exports.ArrowFatDown = ArrowFatDown;
exports.ArrowFatLeft = ArrowFatLeft;
exports.ArrowFatLineDown = ArrowFatLineDown;
exports.ArrowFatLineLeft = ArrowFatLineLeft;
exports.ArrowFatLineRight = ArrowFatLineRight;
exports.ArrowFatLineUp = ArrowFatLineUp;
exports.ArrowFatLinesDown = ArrowFatLinesDown;
exports.ArrowFatLinesLeft = ArrowFatLinesLeft;
exports.ArrowFatLinesRight = ArrowFatLinesRight;
exports.ArrowFatLinesUp = ArrowFatLinesUp;
exports.ArrowFatRight = ArrowFatRight;
exports.ArrowFatUp = ArrowFatUp;
exports.ArrowLeft = ArrowLeft;
exports.ArrowLineDown = ArrowLineDown;
exports.ArrowLineDownLeft = ArrowLineDownLeft;
exports.ArrowLineDownRight = ArrowLineDownRight;
exports.ArrowLineLeft = ArrowLineLeft;
exports.ArrowLineRight = ArrowLineRight;
exports.ArrowLineUp = ArrowLineUp;
exports.ArrowLineUpLeft = ArrowLineUpLeft;
exports.ArrowLineUpRight = ArrowLineUpRight;
exports.ArrowRight = ArrowRight;
exports.ArrowSquareDown = ArrowSquareDown;
exports.ArrowSquareDownLeft = ArrowSquareDownLeft;
exports.ArrowSquareDownRight = ArrowSquareDownRight;
exports.ArrowSquareLeft = ArrowSquareLeft;
exports.ArrowSquareRight = ArrowSquareRight;
exports.ArrowSquareUp = ArrowSquareUp;
exports.ArrowSquareUpLeft = ArrowSquareUpLeft;
exports.ArrowSquareUpRight = ArrowSquareUpRight;
exports.ArrowUDownLeft = ArrowUDownLeft;
exports.ArrowUDownRight = ArrowUDownRight;
exports.ArrowULeftDown = ArrowULeftDown;
exports.ArrowULeftUp = ArrowULeftUp;
exports.ArrowURightDown = ArrowURightDown;
exports.ArrowURightUp = ArrowURightUp;
exports.ArrowUUpLeft = ArrowUUpLeft;
exports.ArrowUUpRight = ArrowUUpRight;
exports.ArrowUp = ArrowUp;
exports.ArrowUpLeft = ArrowUpLeft;
exports.ArrowUpRight = ArrowUpRight;
exports.ArrowsClockwise = ArrowsClockwise;
exports.ArrowsCounterClockwise = ArrowsCounterClockwise;
exports.ArrowsDownUp = ArrowsDownUp;
exports.ArrowsIn = ArrowsIn;
exports.ArrowsInCardinal = ArrowsInCardinal;
exports.ArrowsInLineHorizontal = ArrowsInLineHorizontal;
exports.ArrowsInLineVertical = ArrowsInLineVertical;
exports.ArrowsInSimple = ArrowsInSimple;
exports.ArrowsLeftRight = ArrowsLeftRight;
exports.ArrowsOut = ArrowsOut;
exports.ArrowsOutCardinal = ArrowsOutCardinal;
exports.ArrowsOutLineHorizontal = ArrowsOutLineHorizontal;
exports.ArrowsOutLineVertical = ArrowsOutLineVertical;
exports.ArrowsOutSimple = ArrowsOutSimple;
exports.Article = Article;
exports.Asterisk = Asterisk;
exports.At = At;
exports.Backspace = Backspace;
exports.Bag = Bag;
exports.Bandaids = Bandaids;
exports.Bank = Bank;
exports.Barbell = Barbell;
exports.Barcode = Barcode;
exports.BatteryCharging = BatteryCharging;
exports.BatteryChargingVertical = BatteryChargingVertical;
exports.BatteryEmpty = BatteryEmpty;
exports.BatteryFull = BatteryFull;
exports.BatteryHigh = BatteryHigh;
exports.BatteryLow = BatteryLow;
exports.BatteryMedium = BatteryMedium;
exports.BatteryWarning = BatteryWarning;
exports.BatteryWarningVertical = BatteryWarningVertical;
exports.Bed = Bed;
exports.Bell = Bell;
exports.BellSimple = BellSimple;
exports.BellSimpleSlash = BellSimpleSlash;
exports.BellSlash = BellSlash;
exports.Bicycle = Bicycle;
exports.Bluetooth = Bluetooth;
exports.BluetoothConnected = BluetoothConnected;
exports.BluetoothSlash = BluetoothSlash;
exports.BluetoothX = BluetoothX;
exports.Book = Book;
exports.BookBookmark = BookBookmark;
exports.BookOpen = BookOpen;
exports.Bookmark = Bookmark;
exports.BookmarkSimple = BookmarkSimple;
exports.Bookmarks = Bookmarks;
exports.Briefcase = Briefcase;
exports.BriefcaseSimple = BriefcaseSimple;
exports.Broadcast = Broadcast;
exports.Browser = Browser;
exports.Browsers = Browsers;
exports.BrowsersSimple = BrowsersSimple;
exports.Buildings = Buildings;
exports.Bus = Bus;
exports.Calculator = Calculator;
exports.Calendar = Calendar;
exports.CalendarBlank = CalendarBlank;
exports.CalendarX = CalendarX;
exports.Camera = Camera;
exports.CameraSlash = CameraSlash;
exports.Car = Car;
exports.CarSimple = CarSimple;
exports.CaretCircleDoubleDown = CaretCircleDoubleDown;
exports.CaretCircleDoubleLeft = CaretCircleDoubleLeft;
exports.CaretCircleDoubleRight = CaretCircleDoubleRight;
exports.CaretCircleDoubleUp = CaretCircleDoubleUp;
exports.CaretCircleDown = CaretCircleDown;
exports.CaretCircleLeft = CaretCircleLeft;
exports.CaretCircleRight = CaretCircleRight;
exports.CaretCircleUp = CaretCircleUp;
exports.CaretDoubleDown = CaretDoubleDown;
exports.CaretDoubleLeft = CaretDoubleLeft;
exports.CaretDoubleRight = CaretDoubleRight;
exports.CaretDoubleUp = CaretDoubleUp;
exports.CaretDown = CaretDown;
exports.CaretLeft = CaretLeft;
exports.CaretRight = CaretRight;
exports.CaretUp = CaretUp;
exports.CellSignalFull = CellSignalFull;
exports.CellSignalHigh = CellSignalHigh;
exports.CellSignalLow = CellSignalLow;
exports.CellSignalMedium = CellSignalMedium;
exports.CellSignalNone = CellSignalNone;
exports.CellSignalSlash = CellSignalSlash;
exports.CellSignalX = CellSignalX;
exports.ChartBar = ChartBar;
exports.ChartBarHorizontal = ChartBarHorizontal;
exports.ChartLine = ChartLine;
exports.ChartLineUp = ChartLineUp;
exports.ChartPie = ChartPie;
exports.ChartPieSlice = ChartPieSlice;
exports.Chat = Chat;
exports.ChatCentered = ChatCentered;
exports.ChatCenteredDots = ChatCenteredDots;
exports.ChatCenteredText = ChatCenteredText;
exports.ChatCircle = ChatCircle;
exports.ChatCircleDots = ChatCircleDots;
exports.ChatCircleText = ChatCircleText;
exports.ChatDots = ChatDots;
exports.ChatTeardrop = ChatTeardrop;
exports.ChatTeardropDots = ChatTeardropDots;
exports.ChatTeardropText = ChatTeardropText;
exports.ChatText = ChatText;
exports.Chats = Chats;
exports.ChatsCircle = ChatsCircle;
exports.ChatsTeardrop = ChatsTeardrop;
exports.Check = Check;
exports.CheckCircle = CheckCircle;
exports.CheckSquare = CheckSquare;
exports.CheckSquareOffset = CheckSquareOffset;
exports.Checks = Checks;
exports.Circle = Circle;
exports.CircleHalf = CircleHalf;
exports.CircleHalfTilt = CircleHalfTilt;
exports.CirclesFour = CirclesFour;
exports.CirclesThree = CirclesThree;
exports.CirclesThreePlus = CirclesThreePlus;
exports.Clipboard = Clipboard;
exports.ClipboardText = ClipboardText;
exports.Clock = Clock;
exports.ClockAfternoon = ClockAfternoon;
exports.ClockClockwise = ClockClockwise;
exports.ClockCounterClockwise = ClockCounterClockwise;
exports.ClosedCaptioning = ClosedCaptioning;
exports.Cloud = Cloud;
exports.CloudArrowDown = CloudArrowDown;
exports.CloudArrowUp = CloudArrowUp;
exports.CloudCheck = CloudCheck;
exports.CloudFog = CloudFog;
exports.CloudLightning = CloudLightning;
exports.CloudMoon = CloudMoon;
exports.CloudRain = CloudRain;
exports.CloudSlash = CloudSlash;
exports.CloudSnow = CloudSnow;
exports.CloudSun = CloudSun;
exports.Club = Club;
exports.Code = Code;
exports.CodeSimple = CodeSimple;
exports.Coffee = Coffee;
exports.Columns = Columns;
exports.Command = Command;
exports.Compass = Compass;
exports.ComputerTower = ComputerTower;
exports.Copy = Copy;
exports.CopySimple = CopySimple;
exports.Copyright = Copyright;
exports.CornersIn = CornersIn;
exports.CornersOut = CornersOut;
exports.CreditCard = CreditCard;
exports.Crop = Crop;
exports.Crosshair = Crosshair;
exports.CrosshairSimple = CrosshairSimple;
exports.Cube = Cube;
exports.CurrencyCircleDollar = CurrencyCircleDollar;
exports.CurrencyCny = CurrencyCny;
exports.CurrencyDollar = CurrencyDollar;
exports.CurrencyDollarSimple = CurrencyDollarSimple;
exports.CurrencyEur = CurrencyEur;
exports.CurrencyGbp = CurrencyGbp;
exports.CurrencyInr = CurrencyInr;
exports.CurrencyJpy = CurrencyJpy;
exports.CurrencyKrw = CurrencyKrw;
exports.CurrencyRub = CurrencyRub;
exports.Cursor = Cursor;
exports.Database = Database;
exports.Desktop = Desktop;
exports.DesktopTower = DesktopTower;
exports.DeviceMobile = DeviceMobile;
exports.DeviceMobileCamera = DeviceMobileCamera;
exports.DeviceMobileSpeaker = DeviceMobileSpeaker;
exports.DeviceTablet = DeviceTablet;
exports.DeviceTabletCamera = DeviceTabletCamera;
exports.DeviceTabletSpeaker = DeviceTabletSpeaker;
exports.Diamond = Diamond;
exports.DiceFive = DiceFive;
exports.DiceFour = DiceFour;
exports.DiceOne = DiceOne;
exports.DiceSix = DiceSix;
exports.DiceThree = DiceThree;
exports.DiceTwo = DiceTwo;
exports.Disc = Disc;
exports.Divide = Divide;
exports.DotsNine = DotsNine;
exports.DotsThree = DotsThree;
exports.DotsThreeCircle = DotsThreeCircle;
exports.DotsThreeCircleVertical = DotsThreeCircleVertical;
exports.DotsThreeOutline = DotsThreeOutline;
exports.DotsThreeOutlineVertical = DotsThreeOutlineVertical;
exports.DotsThreeVertical = DotsThreeVertical;
exports.Download = Download;
exports.DownloadSimple = DownloadSimple;
exports.DribbbleLogo = DribbbleLogo;
exports.Drop = Drop;
exports.DropHalf = DropHalf;
exports.Eject = Eject;
exports.Envelope = Envelope;
exports.EnvelopeOpen = EnvelopeOpen;
exports.EnvelopeSimple = EnvelopeSimple;
exports.EnvelopeSimpleOpen = EnvelopeSimpleOpen;
exports.Equals = Equals;
exports.Eraser = Eraser;
exports.Eye = Eye;
exports.EyeClosed = EyeClosed;
exports.EyeSlash = EyeSlash;
exports.Eyedropper = Eyedropper;
exports.FaceMask = FaceMask;
exports.FacebookLogo = FacebookLogo;
exports.Faders = Faders;
exports.FadersHorizontal = FadersHorizontal;
exports.FastForwardCircle = FastForwardCircle;
exports.FigmaLogo = FigmaLogo;
exports.File = File;
exports.FileArrowDown = FileArrowDown;
exports.FileMinus = FileMinus;
exports.FilePlus = FilePlus;
exports.FileSearch = FileSearch;
exports.FileText = FileText;
exports.FileX = FileX;
exports.Fingerprint = Fingerprint;
exports.FingerprintSimple = FingerprintSimple;
exports.FinnTheHuman = FinnTheHuman;
exports.Fire = Fire;
exports.FirstAid = FirstAid;
exports.FirstAidKit = FirstAidKit;
exports.Flag = Flag;
exports.Flashlight = Flashlight;
exports.FloppyDisk = FloppyDisk;
exports.Folder = Folder;
exports.FolderMinus = FolderMinus;
exports.FolderNotch = FolderNotch;
exports.FolderNotchMinus = FolderNotchMinus;
exports.FolderNotchOpen = FolderNotchOpen;
exports.FolderNotchPlus = FolderNotchPlus;
exports.FolderOpen = FolderOpen;
exports.FolderPlus = FolderPlus;
exports.FolderSimple = FolderSimple;
exports.FolderSimpleMinus = FolderSimpleMinus;
exports.FolderSimplePlus = FolderSimplePlus;
exports.Folders = Folders;
exports.ForkKnife = ForkKnife;
exports.FramerLogo = FramerLogo;
exports.Funnel = Funnel;
exports.FunnelSimple = FunnelSimple;
exports.GameController = GameController;
exports.Gear = Gear;
exports.GearSix = GearSix;
exports.Gif = Gif;
exports.Gift = Gift;
exports.GitBranch = GitBranch;
exports.GitCommit = GitCommit;
exports.GitDiff = GitDiff;
exports.GitFork = GitFork;
exports.GitMerge = GitMerge;
exports.GitPullRequest = GitPullRequest;
exports.GithubLogo = GithubLogo;
exports.Globe = Globe;
exports.GlobeHemisphereEast = GlobeHemisphereEast;
exports.GlobeHemisphereWest = GlobeHemisphereWest;
exports.GlobeSimple = GlobeSimple;
exports.GlobeStand = GlobeStand;
exports.GoogleLogo = GoogleLogo;
exports.GooglePlayLogo = GooglePlayLogo;
exports.GridFour = GridFour;
exports.Hand = Hand;
exports.HandFist = HandFist;
exports.HandGrabbing = HandGrabbing;
exports.HandPalm = HandPalm;
exports.HandPointing = HandPointing;
exports.HandWaving = HandWaving;
exports.Handbag = Handbag;
exports.Handshake = Handshake;
exports.HardDrive = HardDrive;
exports.HardDrives = HardDrives;
exports.Hash = Hash;
exports.HashStraight = HashStraight;
exports.Headphones = Headphones;
exports.Headset = Headset;
exports.Heart = Heart;
exports.HeartStraight = HeartStraight;
exports.Heartbeat = Heartbeat;
exports.Hexagon = Hexagon;
exports.Horse = Horse;
exports.Hourglass = Hourglass;
exports.HourglassHigh = HourglassHigh;
exports.HourglassLow = HourglassLow;
exports.HourglassMedium = HourglassMedium;
exports.HourglassSimple = HourglassSimple;
exports.HourglassSimpleHigh = HourglassSimpleHigh;
exports.HourglassSimpleLow = HourglassSimpleLow;
exports.HourglassSimpleMedium = HourglassSimpleMedium;
exports.House = House;
exports.HouseLine = HouseLine;
exports.HouseSimple = HouseSimple;
exports.IconContext = IconContext;
exports.IdentificationCard = IdentificationCard;
exports.Image = Image;
exports.ImageSquare = ImageSquare;
exports.Info = Info;
exports.InstagramLogo = InstagramLogo;
exports.Intersect = Intersect;
exports.Jeep = Jeep;
exports.Key = Key;
exports.Keyboard = Keyboard;
exports.Laptop = Laptop;
exports.Leaf = Leaf;
exports.Lightbulb = Lightbulb;
exports.Lightning = Lightning;
exports.LightningSlash = LightningSlash;
exports.Link = Link;
exports.LinkBreak = LinkBreak;
exports.LinkSimple = LinkSimple;
exports.LinkSimpleBreak = LinkSimpleBreak;
exports.LinkSimpleHorizontal = LinkSimpleHorizontal;
exports.LinkSimpleHorizontalBreak = LinkSimpleHorizontalBreak;
exports.LinkedinLogo = LinkedinLogo;
exports.List = List;
exports.ListBullets = ListBullets;
exports.ListDashes = ListDashes;
exports.ListNumbers = ListNumbers;
exports.ListPlus = ListPlus;
exports.Lock = Lock;
exports.LockKey = LockKey;
exports.LockKeyOpen = LockKeyOpen;
exports.LockLaminated = LockLaminated;
exports.LockLaminatedOpen = LockLaminatedOpen;
exports.LockOpen = LockOpen;
exports.LockSimple = LockSimple;
exports.LockSimpleOpen = LockSimpleOpen;
exports.MagnifyingGlass = MagnifyingGlass;
exports.MagnifyingGlassMinus = MagnifyingGlassMinus;
exports.MagnifyingGlassPlus = MagnifyingGlassPlus;
exports.MapPin = MapPin;
exports.MapPinLine = MapPinLine;
exports.MapTrifold = MapTrifold;
exports.Martini = Martini;
exports.MathOperations = MathOperations;
exports.Medal = Medal;
exports.MediumLogo = MediumLogo;
exports.Megaphone = Megaphone;
exports.Microphone = Microphone;
exports.MicrophoneSlash = MicrophoneSlash;
exports.Minus = Minus;
exports.MinusCircle = MinusCircle;
exports.Money = Money;
exports.Monitor = Monitor;
exports.MonitorPlay = MonitorPlay;
exports.Moon = Moon;
exports.MoonStars = MoonStars;
exports.Mouse = Mouse;
exports.MusicNote = MusicNote;
exports.MusicNoteSimple = MusicNoteSimple;
exports.MusicNotes = MusicNotes;
exports.MusicNotesSimple = MusicNotesSimple;
exports.NavigationArrow = NavigationArrow;
exports.Newspaper = Newspaper;
exports.NewspaperClipping = NewspaperClipping;
exports.Note = Note;
exports.NoteBlank = NoteBlank;
exports.NotePencil = NotePencil;
exports.Notebook = Notebook;
exports.NumberCircleEight = NumberCircleEight;
exports.NumberCircleFive = NumberCircleFive;
exports.NumberCircleFour = NumberCircleFour;
exports.NumberCircleNine = NumberCircleNine;
exports.NumberCircleOne = NumberCircleOne;
exports.NumberCircleSeven = NumberCircleSeven;
exports.NumberCircleSix = NumberCircleSix;
exports.NumberCircleThree = NumberCircleThree;
exports.NumberCircleTwo = NumberCircleTwo;
exports.NumberCircleZero = NumberCircleZero;
exports.NumberEight = NumberEight;
exports.NumberFive = NumberFive;
exports.NumberFour = NumberFour;
exports.NumberNine = NumberNine;
exports.NumberOne = NumberOne;
exports.NumberSeven = NumberSeven;
exports.NumberSix = NumberSix;
exports.NumberSquareEight = NumberSquareEight;
exports.NumberSquareFive = NumberSquareFive;
exports.NumberSquareFour = NumberSquareFour;
exports.NumberSquareNine = NumberSquareNine;
exports.NumberSquareOne = NumberSquareOne;
exports.NumberSquareSeven = NumberSquareSeven;
exports.NumberSquareSix = NumberSquareSix;
exports.NumberSquareThree = NumberSquareThree;
exports.NumberSquareTwo = NumberSquareTwo;
exports.NumberSquareZero = NumberSquareZero;
exports.NumberThree = NumberThree;
exports.NumberTwo = NumberTwo;
exports.NumberZero = NumberZero;
exports.Nut = Nut;
exports.Octagon = Octagon;
exports.Package = Package;
exports.PaintBrushBroad = PaintBrushBroad;
exports.PaintBucket = PaintBucket;
exports.PaperPlane = PaperPlane;
exports.PaperPlaneRight = PaperPlaneRight;
exports.PaperPlaneTilt = PaperPlaneTilt;
exports.Paperclip = Paperclip;
exports.PaperclipHorizontal = PaperclipHorizontal;
exports.Path = Path;
exports.Pause = Pause;
exports.PauseCircle = PauseCircle;
exports.Peace = Peace;
exports.Pedestrian = Pedestrian;
exports.Pen = Pen;
exports.PenNib = PenNib;
exports.Pencil = Pencil;
exports.PencilCircle = PencilCircle;
exports.PencilLine = PencilLine;
exports.PencilSimple = PencilSimple;
exports.Percent = Percent;
exports.Phone = Phone;
exports.PhoneCall = PhoneCall;
exports.PhoneDisconnect = PhoneDisconnect;
exports.PhoneIncoming = PhoneIncoming;
exports.PhoneOutgoing = PhoneOutgoing;
exports.PhoneSlash = PhoneSlash;
exports.PhoneX = PhoneX;
exports.PhosphorLogo = PhosphorLogo;
exports.Play = Play;
exports.PlayCircle = PlayCircle;
exports.Plus = Plus;
exports.PlusCircle = PlusCircle;
exports.PlusMinus = PlusMinus;
exports.PokerChip = PokerChip;
exports.Power = Power;
exports.Printer = Printer;
exports.Prohibit = Prohibit;
exports.ProhibitInset = ProhibitInset;
exports.PushPin = PushPin;
exports.PushPinSlash = PushPinSlash;
exports.PuzzlePiece = PuzzlePiece;
exports.QrCode = QrCode;
exports.Question = Question;
exports.Radical = Radical;
exports.Rainbow = Rainbow;
exports.RainbowCloud = RainbowCloud;
exports.Receipt = Receipt;
exports.Record = Record;
exports.Rectangle = Rectangle;
exports.RedditLogo = RedditLogo;
exports.Repeat = Repeat;
exports.RepeatOnce = RepeatOnce;
exports.RewindCircle = RewindCircle;
exports.Rocket = Rocket;
exports.RocketLaunch = RocketLaunch;
exports.Rows = Rows;
exports.Rss = Rss;
exports.RssSimple = RssSimple;
exports.Scissors = Scissors;
exports.Screencast = Screencast;
exports.Share = Share;
exports.ShareNetwork = ShareNetwork;
exports.Shield = Shield;
exports.ShieldCheck = ShieldCheck;
exports.ShieldChevron = ShieldChevron;
exports.ShieldSlash = ShieldSlash;
exports.ShieldWarning = ShieldWarning;
exports.ShoppingBag = ShoppingBag;
exports.ShoppingBagOpen = ShoppingBagOpen;
exports.ShoppingCart = ShoppingCart;
exports.ShoppingCartSimple = ShoppingCartSimple;
exports.Shuffle = Shuffle;
exports.ShuffleAngular = ShuffleAngular;
exports.ShuffleSimple = ShuffleSimple;
exports.SignIn = SignIn;
exports.SignOut = SignOut;
exports.SketchLogo = SketchLogo;
exports.SkipBack = SkipBack;
exports.SkipBackCircle = SkipBackCircle;
exports.SkipForward = SkipForward;
exports.SkipForwardCircle = SkipForwardCircle;
exports.SlackLogo = SlackLogo;
exports.Sliders = Sliders;
exports.SlidersHorizontal = SlidersHorizontal;
exports.Smiley = Smiley;
exports.SmileyBlank = SmileyBlank;
exports.SmileyMeh = SmileyMeh;
exports.SmileyNervous = SmileyNervous;
exports.SmileySad = SmileySad;
exports.SmileySticker = SmileySticker;
exports.SmileyXEyes = SmileyXEyes;
exports.Snowflake = Snowflake;
exports.SortAscending = SortAscending;
exports.SortDescending = SortDescending;
exports.Spade = Spade;
exports.SpeakerHigh = SpeakerHigh;
exports.SpeakerLow = SpeakerLow;
exports.SpeakerNone = SpeakerNone;
exports.SpeakerSimpleHigh = SpeakerSimpleHigh;
exports.SpeakerSimpleLow = SpeakerSimpleLow;
exports.SpeakerSimpleNone = SpeakerSimpleNone;
exports.SpeakerSimpleSlash = SpeakerSimpleSlash;
exports.SpeakerSimpleX = SpeakerSimpleX;
exports.SpeakerSlash = SpeakerSlash;
exports.SpeakerX = SpeakerX;
exports.Square = Square;
exports.SquareHalf = SquareHalf;
exports.SquaresFour = SquaresFour;
exports.Stack = Stack;
exports.StackSimple = StackSimple;
exports.Star = Star;
exports.Sticker = Sticker;
exports.Stop = Stop;
exports.StopCircle = StopCircle;
exports.Storefront = Storefront;
exports.Suitcase = Suitcase;
exports.SuitcaseSimple = SuitcaseSimple;
exports.Sun = Sun;
exports.SunDim = SunDim;
exports.SunHorizon = SunHorizon;
exports.Swatches = Swatches;
exports.Sword = Sword;
exports.Table = Table;
exports.Tag = Tag;
exports.TagSimple = TagSimple;
exports.Target = Target;
exports.TelegramLogo = TelegramLogo;
exports.Terminal = Terminal;
exports.TextAlignCenter = TextAlignCenter;
exports.TextAlignJustify = TextAlignJustify;
exports.TextAlignLeft = TextAlignLeft;
exports.TextAlignRight = TextAlignRight;
exports.TextBolder = TextBolder;
exports.TextItalic = TextItalic;
exports.TextStrikethrough = TextStrikethrough;
exports.TextT = TextT;
exports.TextUnderline = TextUnderline;
exports.Thermometer = Thermometer;
exports.ThermometerCold = ThermometerCold;
exports.ThermometerHot = ThermometerHot;
exports.ThermometerSimple = ThermometerSimple;
exports.ThumbsDown = ThumbsDown;
exports.ThumbsUp = ThumbsUp;
exports.Ticket = Ticket;
exports.Timer = Timer;
exports.Tote = Tote;
exports.Train = Train;
exports.TrainRegional = TrainRegional;
exports.TrainSimple = TrainSimple;
exports.Translate = Translate;
exports.Trash = Trash;
exports.TrashSimple = TrashSimple;
exports.Tray = Tray;
exports.TrendDown = TrendDown;
exports.TrendUp = TrendUp;
exports.Triangle = Triangle;
exports.Truck = Truck;
exports.TwitchLogo = TwitchLogo;
exports.TwitterLogo = TwitterLogo;
exports.Upload = Upload;
exports.UploadSimple = UploadSimple;
exports.User = User;
exports.UserCircle = UserCircle;
exports.UserCircleGear = UserCircleGear;
exports.UserCircleMinus = UserCircleMinus;
exports.UserCirclePlus = UserCirclePlus;
exports.UserGear = UserGear;
exports.UserMinus = UserMinus;
exports.UserPlus = UserPlus;
exports.UserRectangle = UserRectangle;
exports.UserSquare = UserSquare;
exports.Users = Users;
exports.Vibrate = Vibrate;
exports.VideoCamera = VideoCamera;
exports.VideoCameraSlash = VideoCameraSlash;
exports.Voicemail = Voicemail;
exports.Warning = Warning;
exports.WarningCircle = WarningCircle;
exports.WarningOctagon = WarningOctagon;
exports.Watch = Watch;
exports.WhatsappLogo = WhatsappLogo;
exports.Wheelchair = Wheelchair;
exports.WifiHigh = WifiHigh;
exports.WifiLow = WifiLow;
exports.WifiMedium = WifiMedium;
exports.WifiNone = WifiNone;
exports.WifiSlash = WifiSlash;
exports.WifiX = WifiX;
exports.Wind = Wind;
exports.Wrench = Wrench;
exports.X = X;
exports.XCircle = XCircle;
exports.XSquare = XSquare;
exports.YoutubeLogo = YoutubeLogo;
//# sourceMappingURL=phosphor-react.cjs.development.js.map
